@@ -17,8 +17,8 @@
 
     You should have received a copy of the GNU Lesser General Public
     License along with Csound; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-    02111-1307 USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+    02110-1301 USA
 */
 
 #include <stdio.h>
@@ -49,15 +49,15 @@ static INSTR_SEMANTICS *instr_semantics_alloc(CSOUND *csound, char *name)
     INSTR_SEMANTICS *instr =
       csound->Malloc(csound, sizeof(INSTR_SEMANTICS));
     memset(instr, 0, sizeof(INSTR_SEMANTICS));
-    strncpy(instr->hdr, INSTR_SEMANTICS_HDR, HDR_LEN);
+    memcpy(instr->hdr, INSTR_SEMANTICS_HDR, HDR_LEN);
     instr->name = name;
     instr->insno = -1;
     /* always check for greater than 0 in optimisation
        so this is a good default
      */
-    csp_set_alloc_string(csound, &(instr->read_write));
-    csp_set_alloc_string(csound, &(instr->write));
-    csp_set_alloc_string(csound, &(instr->read));
+    instr->read_write = csp_set_alloc_string(csound);
+    instr->write = csp_set_alloc_string(csound);
+    instr->read = csp_set_alloc_string(csound);
 
     return instr;
 }
@@ -175,14 +175,13 @@ void csp_orc_sa_global_read_write_add_list1(CSOUND *csound,
                       "write lists\n"));
     }
     else {
-      struct set_t *new = NULL;
-      csp_set_union(csound, write, read, &new);
+      struct set_t *new = csp_set_union(csound, write, read);
       //printf("Line: %d of cs_par_orc_semantics(%p)\n", __LINE__, *new);
       if (write->count == 1 && read->count == 1 && new->count == 1) {
         /* this is a read_write list thing */
-        struct set_t *new_read_write = NULL;
-        csp_set_union(csound, csound->instCurr->read_write,
-                      new, &new_read_write);
+        struct set_t *new_read_write = csp_set_union(csound,
+                                                     csound->instCurr->read_write,
+                                                     new);
         //printf("Line: %d of cs_par_orc_semantics(%p)\n",
         //       __LINE__, *new_read_write);
         csp_set_dealloc(csound, &csound->instCurr->read_write);
@@ -208,8 +207,7 @@ void csp_orc_sa_global_write_add_list(CSOUND *csound, struct set_t *set)
                       "global write_list\n"));
     }
     else {
-      struct set_t *new = NULL;
-      csp_set_union(csound, csound->instCurr->write, set, &new);
+      struct set_t *new = csp_set_union(csound, csound->instCurr->write, set);
 
       csp_set_dealloc(csound, &csound->instCurr->write);
       csp_set_dealloc(csound, &set);
@@ -231,8 +229,7 @@ void csp_orc_sa_global_read_add_list(CSOUND *csound, struct set_t *set)
                       "global read_list\n"));
     }
     else {
-      struct set_t *new = NULL;
-      csp_set_union(csound, csound->instCurr->read, set, &new);
+      struct set_t *new = csp_set_union(csound, csound->instCurr->read, set);
 
       csp_set_dealloc(csound, &csound->instCurr->read);
       csp_set_dealloc(csound, &set);
@@ -247,8 +244,8 @@ void csp_orc_sa_interlocksf(CSOUND *csound, int code)
       /* zak etc */
       struct set_t *rr = NULL;
       struct set_t *ww = NULL;
-      csp_set_alloc_string(csound, &ww);
-      csp_set_alloc_string(csound, &rr);
+      ww = csp_set_alloc_string(csound);
+      rr = csp_set_alloc_string(csound);
       if (code&ZR) csp_set_add(csound, rr, "##zak");
       if (code&ZW) csp_set_add(csound, ww, "##zak");
       if (code&TR) csp_set_add(csound, rr, "##tab");
@@ -326,14 +323,12 @@ struct set_t *csp_orc_sa_globals_find(CSOUND *csound, TREE *node)
     struct set_t *current_set = NULL;
 
     if (node == NULL) {
-      struct set_t *set = NULL;
-      csp_set_alloc_string(csound, &set);
-      return set;
+      return csp_set_alloc_string(csound);
     }
 
     left  = csp_orc_sa_globals_find(csound, node->left);
     right = csp_orc_sa_globals_find(csound, node->right);
-    csp_set_union(csound, left, right, &current_set);
+    current_set = csp_set_union(csound, left, right);
     //printf("Line: %d of cs_par_orc_semantics(%p)\n", __LINE__, current_set);
     csp_set_dealloc(csound, &left);
     csp_set_dealloc(csound, &right);
@@ -346,7 +341,7 @@ struct set_t *csp_orc_sa_globals_find(CSOUND *csound, TREE *node)
     if (node->next != NULL) {
       struct set_t *prev_set = current_set;
       struct set_t *next = csp_orc_sa_globals_find(csound, node->next);
-      csp_set_union(csound, prev_set, next, &current_set);
+      current_set = csp_set_union(csound, prev_set, next);
       //printf("Line: %d of cs_par_orc_semantics(%p)\n", __LINE__, current_set);
       csp_set_dealloc(csound, &prev_set);
       csp_set_dealloc(csound, &next);
