@@ -17,8 +17,8 @@
 
     You should have received a copy of the GNU Lesser General Public
     License along with Csound; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-    02111-1307 USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+    02110-1301 USA
 */
 
 #include "csoundCore.h"         /*                      DISPREP.C       */
@@ -31,14 +31,14 @@
 # define hypot _hypot
 #endif
 
-int printv(CSOUND *csound, PRINTV *p)
+int32_t printv(CSOUND *csound, PRINTV *p)
 {
-    int    nargs = p->INOCOUNT;
+    int32_t    nargs = p->INOCOUNT;
     char   **txtp = p->h.optext->t.inlist->arg;
     MYFLT  **valp = p->iargs;
 
     csound->MessageS(csound, CSOUNDMSG_ORCH,
-                     "instr %d:", (int) p->h.insdshead->p1.value);
+                     "instr %d:", (int32_t) p->h.insdshead->p1.value);
     while (nargs--) {
       csound->MessageS(csound, CSOUNDMSG_ORCH,
                        "  %s = %5.3f", *txtp++, **valp++);
@@ -47,30 +47,30 @@ int printv(CSOUND *csound, PRINTV *p)
     return OK;
 }
 
-int fdspset(CSOUND *csound, FSIGDISP *p){
+int32_t fdspset(CSOUND *csound, FSIGDISP *p){
     char strmsg[256];
     p->size = p->fin->N/2 + 1;
-    if ((*p->points != (MYFLT) 0) && (p->size > (int) *p->points)) {
+    if ((*p->points != (MYFLT) 0) && (p->size > (int32_t) *p->points)) {
       p->size = *p->points;
     }
     if ((p->fdata.auxp == NULL) ||
-        (p->fdata.size < (unsigned int) (p->size*sizeof(MYFLT)))) {
+        (p->fdata.size < (uint32_t) (p->size*sizeof(MYFLT)))) {
       csound->AuxAlloc(csound, p->size*sizeof(MYFLT), &p->fdata);
     }
     snprintf(strmsg, 256, Str("instr %d, pvs-signal %s:"),
-            (int) p->h.insdshead->p1.value, p->h.optext->t.inlist->arg[0]);
+            (int32_t) p->h.insdshead->p1.value, p->h.optext->t.inlist->arg[0]);
     dispset(csound, &p->dwindow, (MYFLT*) p->fdata.auxp, p->size, strmsg,
-                    (int) *p->flag, Str("display"));
+                    (int32_t) *p->flag, Str("display"));
     p->lastframe = 0;
     return OK;
 
 }
 
-int fdsplay(CSOUND *csound, FSIGDISP *p)
+int32_t fdsplay(CSOUND *csound, FSIGDISP *p)
 {
     float *fin   = p->fin->frame.auxp;
     MYFLT *pdata = p->fdata.auxp;
-    int i,k, end = p->size;
+    int32_t i,k, end = p->size;
 
     if (p->lastframe < p->fin->framecount) {
       for (i=0, k=0; k < end; i+=2,k++) pdata[k] = fin[i];
@@ -80,20 +80,20 @@ int fdsplay(CSOUND *csound, FSIGDISP *p)
     return OK;
  }
 
-int dspset(CSOUND *csound, DSPLAY *p)
+int32_t dspset(CSOUND *csound, DSPLAY *p)
 {
-    int32  npts, nprds, bufpts, totpts;
+    int32_t  npts, nprds, bufpts, totpts;
     char   *auxp;
     char   strmsg[256];
 
     if (p->h.optext->t.intype == 'k')
-      npts = (int32)(*p->iprd * CS_EKR);
-    else npts = (int32)(*p->iprd * csound->esr);
+      npts = (int32_t)(*p->iprd * CS_EKR);
+    else npts = (int32_t)(*p->iprd * csound->esr);
     if (UNLIKELY(npts <= 0)) {
       return csound->InitError(csound, Str("illegal iprd in display"));
 
     }
-    if ((nprds = (int32)*p->inprds) <= 1) {
+    if ((nprds = (int32_t)*p->inprds) <= 1) {
       nprds  = 0;
       bufpts = npts;
       totpts = npts;
@@ -115,13 +115,13 @@ int dspset(CSOUND *csound, DSPLAY *p)
     p->nxtp = (MYFLT *) auxp;
     p->pntcnt = npts;
     snprintf(strmsg, 256, Str("instr %d, signal %s:"),
-             (int) p->h.insdshead->p1.value, p->h.optext->t.inlist->arg[0]);
+             (int32_t) p->h.insdshead->p1.value, p->h.optext->t.inlist->arg[0]);
     dispset(csound, &p->dwindow, (MYFLT*) auxp, bufpts, strmsg,
-            (int) *p->iwtflg, Str("display"));
+            (int32_t) *p->iwtflg, Str("display"));
     return OK;
 }
 
-int kdsplay(CSOUND *csound, DSPLAY *p)
+int32_t kdsplay(CSOUND *csound, DSPLAY *p)
 {
     MYFLT  *fp = p->nxtp;
 
@@ -154,7 +154,7 @@ int kdsplay(CSOUND *csound, DSPLAY *p)
                              Str("display: not initialised"));
 }
 
-int dsplay(CSOUND *csound, DSPLAY *p)
+int32_t dsplay(CSOUND *csound, DSPLAY *p)
 {
     MYFLT  *fp = p->nxtp, *sp = p->signal, *endp = p->endp;
     uint32_t offset = p->h.insdshead->ksmps_offset;
@@ -192,11 +192,11 @@ int dsplay(CSOUND *csound, DSPLAY *p)
 }
 
 /* Write window coefs into buffer, don't malloc */
-static void FillHalfWin(MYFLT *wBuf, int32 size, MYFLT max, int hannq)
+static void FillHalfWin(MYFLT *wBuf, int32_t size, MYFLT max, int32_t hannq)
     /* 1 => hanning window else hamming */
 {
     MYFLT       a,b;
-    int32        i;
+    int32_t        i;
 
     if (hannq) {
       a = FL(0.50);
@@ -217,10 +217,10 @@ static void FillHalfWin(MYFLT *wBuf, int32 size, MYFLT max, int hannq)
     return;
 }
 
-static void ApplyHalfWin(MYFLT *buf, MYFLT *win, int32 len)
+static void ApplyHalfWin(MYFLT *buf, MYFLT *win, int32_t len)
 {   /* Window only store 1st half, is symmetric */
-    int32    j;
-    int32    lenOn2 = (len/2);
+    int32_t    j;
+    int32_t    lenOn2 = (len/2);
 
     for (j=lenOn2+1; j--; )
       *buf++ *= *win++;
@@ -228,23 +228,23 @@ static void ApplyHalfWin(MYFLT *buf, MYFLT *win, int32 len)
       *buf++ *= *--win;
 }
 
-int fftset(CSOUND *csound, DSPFFT *p) /* fftset, dspfft -- calc Fast Fourier */
+int32_t fftset(CSOUND *csound, DSPFFT *p) /* fftset, dspfft -- calc Fast Fourier */
                                       /* Transform of collected samples and  */
                                       /* displays coefficients (mag or db)   */
 {
-    int32 window_size, step_size;
-    int   hanning;
+    int32_t window_size, step_size;
+    int32_t   hanning;
     char  strmsg[256];
-    int32  minbin, maxbin;
+    int32_t  minbin, maxbin;
     minbin = *p->imin;
     maxbin = *p->imax;
 
-    if(p->smpbuf.auxp == NULL)
+    if (p->smpbuf.auxp == NULL)
       csound->AuxAlloc(csound, sizeof(MYFLT)*WINDMAX, &(p->smpbuf));
 
     p->sampbuf = (MYFLT *) p->smpbuf.auxp;
 
-    window_size = (int32)*p->inpts;
+    window_size = (int32_t)*p->inpts;
     if (UNLIKELY(window_size > WINDMAX)) {
       return csound->InitError(csound, Str("too many points requested"));
     }
@@ -255,13 +255,13 @@ int fftset(CSOUND *csound, DSPFFT *p) /* fftset, dspfft -- calc Fast Fourier */
       return csound->InitError(csound, Str("window size must be power of two"));
     }
     if (p->h.optext->t.intype == 'k')
-      step_size = (int32)(*p->iprd * CS_EKR);
-    else step_size = (int32)(*p->iprd * csound->esr);
+      step_size = (int32_t)(*p->iprd * CS_EKR);
+    else step_size = (int32_t)(*p->iprd * csound->esr);
     if (UNLIKELY(step_size <= 0)) {
       return csound->InitError(csound, Str("illegal iprd in ffy display"));
     }
-    hanning = (int)*p->ihann;
-    p->dbout   = (int)*p->idbout;
+    hanning = (int32_t)*p->ihann;
+    p->dbout   = (int32_t)*p->idbout;
     p->overlap = window_size - step_size;
 
 
@@ -270,7 +270,7 @@ int fftset(CSOUND *csound, DSPFFT *p) /* fftset, dspfft -- calc Fast Fourier */
          minbin != p->start         ||
          window_size != p->windsize ||
          hanning != p->hanning) {             /* if windowing has changed:  */
-      int32 auxsiz;
+      int32_t auxsiz;
       MYFLT *hWin;
       p->windsize = window_size;                /* set new parameter values */
       p->hanning = hanning;
@@ -279,7 +279,7 @@ int fftset(CSOUND *csound, DSPFFT *p) /* fftset, dspfft -- calc Fast Fourier */
       p->overN   = FL(1.0)/(*p->inpts);
       p->ncoefs  = window_size >>1;
       auxsiz = (window_size/2 + 1) * sizeof(MYFLT);  /* size for half window */
-      csound->AuxAlloc(csound, (int32)auxsiz, &p->auxch); /* alloc or realloc */
+      csound->AuxAlloc(csound, (int32_t)auxsiz, &p->auxch); /* alloc or realloc */
       hWin = (MYFLT *) p->auxch.auxp;
       FillHalfWin(hWin, window_size,
                   FL(1.0), hanning);            /* fill with proper values */
@@ -289,22 +289,22 @@ int fftset(CSOUND *csound, DSPFFT *p) /* fftset, dspfft -- calc Fast Fourier */
                                                             * sizeof(MYFLT));
       }
       snprintf(strmsg, 256, Str("instr %d, signal %s, fft (%s):"),
-                      (int) p->h.insdshead->p1.value, p->h.optext->t.inlist->arg[0],
-                      p->dbout ? Str("db") : Str("mag"));
-      if(maxbin == 0) maxbin = p->ncoefs;
-      if(minbin > maxbin) minbin = 0;
+               (int32_t) p->h.insdshead->p1.value, p->h.optext->t.inlist->arg[0],
+               p->dbout ? Str("db") : Str("mag"));
+      if (maxbin == 0) maxbin = p->ncoefs;
+      if (minbin > maxbin) minbin = 0;
       p->npts = maxbin - minbin;
       p->start = minbin;
       dispset(csound, &p->dwindow,
               csound->disprep_fftcoefs+p->start, p->npts, strmsg,
-              (int) *p->iwtflg, Str("fft"));
+              (int32_t) *p->iwtflg, Str("fft"));
        }
 
     return OK;
 }
 
 /* pack re,im,re,im into re,re */
-static void PackReals(MYFLT *buffer, int32 size)
+static void PackReals(MYFLT *buffer, int32_t size)
 {
     MYFLT   *b2 = buffer;
 
@@ -316,9 +316,9 @@ static void PackReals(MYFLT *buffer, int32 size)
 }
 
 /* Convert Real & Imaginary spectra into Amplitude & Phase */
-static void Rect2Polar(MYFLT *buffer, int32 size, MYFLT scal)
+static void Rect2Polar(MYFLT *buffer, int32_t size, MYFLT scal)
 {
-    int32   i;
+    int32_t   i;
     MYFLT   *real,*imag;
     MYFLT   re,im;
     MYFLT   mag;
@@ -337,10 +337,10 @@ static void Rect2Polar(MYFLT *buffer, int32 size, MYFLT scal)
 }
 
 /* packed buffer ie. reals, not complex */
-static void Lin2DB(MYFLT *buffer, int32 size)
+static void Lin2DB(MYFLT *buffer, int32_t size)
 {
     while (size--) {
-      if(*buffer > 0.0)
+      if (*buffer > 0.0)
       *buffer = /* FL(20.0)*log10 */ FL(8.68589)*LOG(*buffer);
       buffer++;
     }
@@ -350,13 +350,13 @@ static void d_fft(      /* perform an FFT as reqd below */
   CSOUND *csound,
   MYFLT  *sce,   /* input array - pure packed real */
   MYFLT  *dst,   /* output array - packed magnitude, only half-length */
-  int32  size,   /* number of points in input */
+  int32_t  size,   /* number of points in input */
   MYFLT  *hWin,  /* hanning window lookup table */
-  int    dbq, MYFLT scal)    /* flag: 1-> convert output into db */
+  int32_t    dbq, MYFLT scal)    /* flag: 1-> convert output into db */
 {
     memcpy(dst, sce, sizeof(MYFLT) * size);     /* copy into scratch buffer */
     ApplyHalfWin(dst, hWin, size);
-    csound->RealFFT(csound, dst, (int) size);   /* perform the FFT */
+    csound->RealFFT(csound, dst, (int32_t) size);   /* perform the FFT */
     dst[size] = dst[1];
     dst[1] = dst[size + 1L] = FL(0.0);
     Rect2Polar(dst, (size >> 1) + 1, scal);
@@ -365,11 +365,11 @@ static void d_fft(      /* perform an FFT as reqd below */
       Lin2DB(dst, (size >> 1) + 1);
 }
 
-int kdspfft(CSOUND *csound, DSPFFT *p)
+int32_t kdspfft(CSOUND *csound, DSPFFT *p)
 {
     MYFLT *bufp = p->bufp, *endp = p->endp;
 
-    if(p->dbout) p->dwindow.polarity = NEGPOL;
+    if (p->dbout) p->dwindow.polarity = NEGPOL;
           else p->dwindow.polarity = POSPOL;
 
     if (UNLIKELY(p->auxch.auxp==NULL)) goto err1; /* RWD fix */
@@ -406,18 +406,18 @@ int kdspfft(CSOUND *csound, DSPFFT *p)
                              Str("dispfft: not initialised"));
 }
 
-int dspfft(CSOUND *csound, DSPFFT *p)
+int32_t dspfft(CSOUND *csound, DSPFFT *p)
 {
     MYFLT *sigp = p->signal, *bufp = p->bufp, *endp = p->endp;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
 
-    if(p->dbout){
+    if (p->dbout) {
        p->dwindow.polarity = NEGPOL;
        p->dwindow.absflag = 1;
     }
-          else p->dwindow.polarity = POSPOL;
+    else p->dwindow.polarity = POSPOL;
 
     if (UNLIKELY(p->auxch.auxp==NULL)) goto err1;
     nsmps -= early;
@@ -445,7 +445,7 @@ int dspfft(CSOUND *csound, DSPFFT *p)
             tp   = endp - p->overlap;
             do {
               *bufp++ = *tp++;
-            } while(tp < endp);
+            } while (tp < endp);
           }
           else bufp = p->sampbuf + p->overlap;
         }
@@ -461,24 +461,24 @@ int dspfft(CSOUND *csound, DSPFFT *p)
 #define NTERMS  4
 #define NCROSS  (NTERMS * (NTERMS-1))
 
-int tempeset(CSOUND *csound, TEMPEST *p)
+int32_t tempeset(CSOUND *csound, TEMPEST *p)
 {
-    int   npts = 0, nptsm1, minlam = 0, maxlam, lamspan, auxsiz;
+    int32_t   npts = 0, nptsm1, minlam = 0, maxlam, lamspan, auxsiz;
     MYFLT *fltp;
     FUNC  *ftp;
     MYFLT b, iperiod = *p->iprd;
     char  strmsg[256];
 
-    if (UNLIKELY((p->timcount = (int)(CS_EKR * iperiod)) <= 0))
+    if (UNLIKELY((p->timcount = (int32_t)(CS_EKR * iperiod)) <= 0))
       return csound->InitError(csound, Str("illegal iperiod"));
-    if (UNLIKELY((p->dtimcnt = (int)(CS_EKR * *p->idisprd)) < 0))
+    if (UNLIKELY((p->dtimcnt = (int32_t)(CS_EKR * *p->idisprd)) < 0))
       return csound->InitError(csound, Str("illegal idisprd"));
     if (UNLIKELY((p->tweek = *p->itweek) <= 0))
       return csound->InitError(csound, Str("illegal itweek"));
     if (iperiod != FL(0.0)) {
-      if (UNLIKELY((minlam = (int)(*p->imindur/iperiod)) <= 0))
+      if (UNLIKELY((minlam = (int32_t)(*p->imindur/iperiod)) <= 0))
         return csound->InitError(csound, Str("illegal imindur"));
-      if (UNLIKELY((npts = (int)(*p->imemdur / iperiod)) <= 0))
+      if (UNLIKELY((npts = (int32_t)(*p->imemdur / iperiod)) <= 0))
         return csound->InitError(csound, Str("illegal imemdur"));
     }
     if (UNLIKELY(*p->ihtim <= FL(0.0)))
@@ -499,7 +499,7 @@ int tempeset(CSOUND *csound, TEMPEST *p)
       p->maxlam = maxlam = nptsm1/(NTERMS-1);
       lamspan = maxlam - minlam + 1;          /* alloc 8 bufs: 2 circ, 6 lin */
       auxsiz = (npts * 5 + lamspan * 3) * sizeof(MYFLT);
-      csound->AuxAlloc(csound, (int32)auxsiz, &p->auxch);
+      csound->AuxAlloc(csound, (int32_t)auxsiz, &p->auxch);
       fltp = (MYFLT *) p->auxch.auxp;
       p->hbeg   = fltp;   fltp += npts;
       p->hend   = fltp;
@@ -514,16 +514,16 @@ int tempeset(CSOUND *csound, TEMPEST *p)
       p->stmemnow = p->stmemp + nptsm1;
     }
     if (p->dtimcnt && !(p->dwindow.windid)) {  /* init to display stmem & exp */
-      snprintf(strmsg, 256, "instr %d tempest:", (int) p->h.insdshead->p1.value);
-      dispset(csound, &p->dwindow, p->stmemp, (int32)npts * 2, strmsg, 0,
+      snprintf(strmsg, 256, "instr %d tempest:", (int32_t) p->h.insdshead->p1.value);
+      dispset(csound, &p->dwindow, p->stmemp, (int32_t)npts * 2, strmsg, 0,
                       Str("tempest"));
       p->dwindow.danflag = 1;                    /* for mid-scale axis */
     }
     {
       MYFLT *funp = ftp->ftable;
-      int32 phs = 0;
-      int32 inc = (int32)PHMASK / npts;
-      int32 nn, lobits = ftp->lobits;
+      int32_t phs = 0;
+      int32_t inc = (int32_t)PHMASK / npts;
+      int32_t nn, lobits = ftp->lobits;
       for (fltp=p->hbeg, nn=npts*4; nn--; )   /* clr 2 circ & 1st 2 lin bufs */
         *fltp++ = FL(0.0);
       for (fltp=p->ftable+npts, nn=npts; nn--; ) {  /* now sample the ftable  */
@@ -533,8 +533,8 @@ int tempeset(CSOUND *csound, TEMPEST *p)
     }
     {
       MYFLT *tblp, sumraw, sumsqr;      /* calc the CROSS prod scalers */
-      int32 terms;
-      int32 lambda, maxlam;
+      int32_t terms;
+      int32_t lambda, maxlam;
       MYFLT crossprods, RMS, *endtable = p->ftable + nptsm1;
    /* MYFLT coef, log001 = -6.9078; */
       MYFLT *xscale = p->xscale;
@@ -592,7 +592,7 @@ static const MYFLT lenfracs[NMULTS*2] = {
     FL(1.88), FL(2.12),     FL(2.85), FL(3.15)
 };
 
-int tempest(CSOUND *csound, TEMPEST *p)
+int32_t tempest(CSOUND *csound, TEMPEST *p)
 {
     p->yt1 = p->coef0 * *p->kin + p->coef1 * p->yt1; /* get lo-pass of kinput */
 
@@ -617,7 +617,7 @@ int tempest(CSOUND *csound, TEMPEST *p)
         MYFLT *hcur = p->hcur;
         MYFLT *hend = p->hend;
         MYFLT *tblp = p->ftable;
-        int32  wrap;
+        int32_t  wrap;
         *hcur++ = kin + expect * p->xfdbak;   /* join insample & expect val */
         if (hcur < hend)  p->hcur = hcur;     /* stor pntr for next insamp  */
         else p->hcur = p->hbeg;
@@ -631,8 +631,8 @@ int tempest(CSOUND *csound, TEMPEST *p)
       if (p->yt1 > p->thresh        /* if lo-pass of kinput now significant */
           && kin > p->fwdmask) {    /*    & kin > masking due to prev kin */
         MYFLT sumraw, sumsqr;
-        int32 lambda, minlam, maxlam;
-        int  terms, nn, npts = p->npts;
+        int32_t lambda, minlam, maxlam;
+        int32_t  terms, nn, npts = p->npts;
         MYFLT mult, crossprods, RMScross, RMStot, unilam, rd;
         MYFLT *xend = p->xend;
    /*   MYFLT *xscale = p->xscale;   */
@@ -725,7 +725,7 @@ int tempest(CSOUND *csound, TEMPEST *p)
       MYFLT *linp = p->linexp;
       MYFLT *xcur = p->xcur;
       MYFLT *xend = p->xend;
-      int32 wrap = xcur - p->xbeg;
+      int32_t wrap = xcur - p->xbeg;
       while (xcur < xend)                   /* lineariz the circ xbuf */
         *linp++ = *xcur++;                  /*  into linexp buf       */
       for (xcur=p->xbeg; wrap--; )
