@@ -17,8 +17,8 @@
 
     You should have received a copy of the GNU Lesser General Public
     License along with Csound; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-    02111-1307 USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+    02110-1301 USA
 */
 
 /****************************************/
@@ -38,16 +38,16 @@
 
 extern void openMIDIout(CSOUND *);
 /* static MYFLT   invkr; */
-void note_on(CSOUND *, int chan, int num, int vel);
-void note_off(CSOUND *, int chan, int num, int vel);
-void control_change(CSOUND *, int chan, int num, int value);
-void after_touch(CSOUND *, int chan, int value);
-void program_change(CSOUND *, int chan, int num);
-void pitch_bend(CSOUND *, int chan, int lsb, int msb);
-void poly_after_touch(CSOUND *, int chan, int note_num, int value);
-void send_midi_message(CSOUND *, int status, int data1, int data2);
+void note_on(CSOUND *, int32_t chan, int32_t num, int32_t vel);
+void note_off(CSOUND *, int32_t chan, int32_t num, int32_t vel);
+void control_change(CSOUND *, int32_t chan, int32_t num, int32_t value);
+void after_touch(CSOUND *, int32_t chan, int32_t value);
+void program_change(CSOUND *, int32_t chan, int32_t num);
+void pitch_bend(CSOUND *, int32_t chan, int32_t lsb, int32_t msb);
+void poly_after_touch(CSOUND *, int32_t chan, int32_t note_num, int32_t value);
+void send_midi_message(CSOUND *, int32_t status, int32_t data1, int32_t data2);
 
-int release_set(CSOUND *csound, REL *p)
+int32_t release_set(CSOUND *csound, REL *p)
 {
     IGN(csound);
     if (p->h.insdshead->xtratim < EXTRA_TIME)
@@ -56,7 +56,7 @@ int release_set(CSOUND *csound, REL *p)
     return OK;
 }
 
-int release(CSOUND *csound, REL *p)
+int32_t release(CSOUND *csound, REL *p)
 {
     IGN(csound);
     if (p->h.insdshead->relesing)
@@ -66,17 +66,17 @@ int release(CSOUND *csound, REL *p)
     return OK;
 }
 
-int xtratim(CSOUND *csound, XTRADUR *p)
+int32_t xtratim(CSOUND *csound, XTRADUR *p)
 {
     IGN(csound);
-    int *xtra = &(p->h.insdshead->xtratim);
-    int tim = (int)(*p->extradur * p->h.insdshead->ekr);
+    int32_t *xtra = &(p->h.insdshead->xtratim);
+    int32_t tim = (int32_t)(*p->extradur * p->h.insdshead->ekr);
     if (*xtra < tim)  /* gab-a5 revised */
       *xtra = tim;
     return OK;
 }
 
-int mclock_set(CSOUND *csound, MCLOCK *p)
+int32_t mclock_set(CSOUND *csound, MCLOCK *p)
 {
     IGN(csound);
     p->period= CS_EKR / *p->freq;
@@ -85,7 +85,7 @@ int mclock_set(CSOUND *csound, MCLOCK *p)
     return OK;
 }
 
-int mclock(CSOUND *csound, MCLOCK *p)
+int32_t mclock(CSOUND *csound, MCLOCK *p)
 {
     if (UNLIKELY(p->beginning_flag)) {    /* first time */
       send_midi_message(csound, 0xF8, 0, 0);    /* clock message */
@@ -99,9 +99,9 @@ int mclock(CSOUND *csound, MCLOCK *p)
     return OK;
 }
 
-int mrtmsg(CSOUND *csound, MRT *p)
+int32_t mrtmsg(CSOUND *csound, MRT *p)
 {
-    switch ((int)*p->message) {
+    switch ((int32_t)*p->message) {
     case 0:
       send_midi_message(csound, 0xFC, 0, 0); /* stop */
       break;
@@ -123,28 +123,28 @@ int mrtmsg(CSOUND *csound, MRT *p)
     return OK;
 }
 
-int iout_on(CSOUND *csound, OUT_ON *p)
+int32_t iout_on(CSOUND *csound, OUT_ON *p)
 {
-    note_on(csound, (int)*p->ichn-1,(int)*p->inum,(int)*p->ivel);
+    note_on(csound, (int32_t)*p->ichn-1,(int32_t)*p->inum,(int32_t)*p->ivel);
     return OK;
 }
 
-int iout_off(CSOUND *csound, OUT_ON *p)
+int32_t iout_off(CSOUND *csound, OUT_ON *p)
 {
-    note_off(csound, (int)*p->ichn-1,(int)*p->inum,(int)*p->ivel);
+    note_off(csound, (int32_t)*p->ichn-1,(int32_t)*p->inum,(int32_t)*p->ivel);
     return OK;
 }
 
-int iout_on_dur_set(CSOUND *csound, OUT_ON_DUR *p)
+int32_t iout_on_dur_set(CSOUND *csound, OUT_ON_DUR *p)
 {
-    int temp;
+    int32_t temp;
     if (p->h.insdshead->xtratim < EXTRA_TIME)
       /* if not initialised by another opcode */
       p->h.insdshead->xtratim = EXTRA_TIME;
 
-    p->chn = (temp = abs((int)*p->ichn-1)) < NUMCHN ? temp : NUMCHN-1;
-    p->num = (temp = abs((int)*p->inum)) < 128 ? temp : 127;
-    p->vel = (temp = abs((int)*p->ivel)) < 128 ? temp : 127;
+    p->chn = (temp = abs((int32_t)*p->ichn-1)) < NUMCHN ? temp : NUMCHN-1;
+    p->num = (temp = abs((int32_t)*p->inum)) < 128 ? temp : 127;
+    p->vel = (temp = abs((int32_t)*p->ivel)) < 128 ? temp : 127;
 
     note_on(csound, p->chn,p->num, p->vel);
     p->istart_time = (MYFLT)CS_KCNT * CS_ONEDKR;
@@ -153,7 +153,7 @@ int iout_on_dur_set(CSOUND *csound, OUT_ON_DUR *p)
     return OK;
 }
 
-int iout_on_dur(CSOUND *csound, OUT_ON_DUR *p)
+int32_t iout_on_dur(CSOUND *csound, OUT_ON_DUR *p)
 {
     if (!(p->fl_expired)) {
       MYFLT actual_dur = (MYFLT) CS_KCNT * CS_ONEDKR
@@ -171,7 +171,7 @@ int iout_on_dur(CSOUND *csound, OUT_ON_DUR *p)
     return OK;
 }
 
-int iout_on_dur2(CSOUND *csound, OUT_ON_DUR *p)
+int32_t iout_on_dur2(CSOUND *csound, OUT_ON_DUR *p)
 {
     if (!(p->fl_expired)) {
       MYFLT actual_dur = (MYFLT)CS_KCNT * CS_ONEDKR
@@ -197,7 +197,7 @@ int iout_on_dur2(CSOUND *csound, OUT_ON_DUR *p)
     return OK;
 }
 
-int moscil_set(CSOUND *csound, MOSCIL *p)
+int32_t moscil_set(CSOUND *csound, MOSCIL *p)
 {
     IGN(csound);
     if (p->h.insdshead->xtratim < EXTRA_TIME)
@@ -210,7 +210,7 @@ int moscil_set(CSOUND *csound, MOSCIL *p)
     return OK;
 }
 
-int moscil(CSOUND *csound, MOSCIL *p)
+int32_t moscil(CSOUND *csound, MOSCIL *p)
 {
     if (p->fl_first_note) {
       p->fl_first_note = FALSE;
@@ -240,11 +240,11 @@ int moscil(CSOUND *csound, MOSCIL *p)
         p->last_pause = (ftemp = *p->kpause) > 0 ? ftemp : CS_ONEDKR;
  first_note:
         {
-          int temp;
-          p->last_chn = (temp = abs((int)*p->kchn-1)) < NUMCHN ? temp :
+          int32_t temp;
+          p->last_chn = (temp = abs((int32_t)*p->kchn-1)) < NUMCHN ? temp :
                                                                   NUMCHN-1;
-          p->last_num = (temp = abs((int)*p->knum)) < 128    ? temp : 127;
-          p->last_vel = (temp = abs((int)*p->kvel)) < 128    ? temp : 127;
+          p->last_num = (temp = abs((int32_t)*p->knum)) < 128    ? temp : 127;
+          p->last_vel = (temp = abs((int32_t)*p->kvel)) < 128    ? temp : 127;
         }
         p->fl_note_expired = FALSE;
         note_on(csound, p->last_chn, p->last_num, p->last_vel);
@@ -253,7 +253,7 @@ int moscil(CSOUND *csound, MOSCIL *p)
     return OK;
 }
 
-int kvar_out_on_set(CSOUND *csound, KOUT_ON *p)
+int32_t kvar_out_on_set(CSOUND *csound, KOUT_ON *p)
 {
     IGN(csound);
     if (p->h.insdshead->xtratim < EXTRA_TIME)
@@ -263,14 +263,14 @@ int kvar_out_on_set(CSOUND *csound, KOUT_ON *p)
     return OK;
 }
 
-int kvar_out_on(CSOUND *csound, KOUT_ON *p)
+int32_t kvar_out_on(CSOUND *csound, KOUT_ON *p)
 {
     if (p->fl_first_note) {
-      int temp;
+      int32_t temp;
 
-      p->last_chn = (temp = abs((int)*p->kchn-1)) < NUMCHN  ? temp : NUMCHN-1;
-      p->last_num = (temp = abs((int)*p->knum)) < 128     ? temp : 127;
-      p->last_vel = (temp = abs((int)*p->kvel)) < 128     ? temp : 127;
+      p->last_chn = (temp = abs((int32_t)*p->kchn-1)) < NUMCHN  ? temp : NUMCHN-1;
+      p->last_num = (temp = abs((int32_t)*p->knum)) < 128     ? temp : 127;
+      p->last_vel = (temp = abs((int32_t)*p->kvel)) < 128     ? temp : 127;
       p->fl_first_note   = FALSE;
       p->fl_note_expired = FALSE;
 
@@ -283,10 +283,10 @@ int kvar_out_on(CSOUND *csound, KOUT_ON *p)
         p->fl_note_expired = TRUE;
       }
       else {
-        int temp;
-        int curr_chn = (temp = abs((int)*p->kchn-1)) < NUMCHN ? temp : NUMCHN-1;
-        int curr_num = (temp = abs((int)*p->knum)) < 128    ? temp : 127;
-        int curr_vel = (temp = abs((int)*p->kvel)) < 128    ? temp : 127;
+        int32_t tt;
+        int32_t curr_chn = (tt = abs((int32_t)*p->kchn-1)) < NUMCHN ? tt : NUMCHN-1;
+        int32_t curr_num = (tt = abs((int32_t)*p->knum)) < 128    ? tt : 127;
+        int32_t curr_vel = (tt = abs((int32_t)*p->kvel)) < 128    ? tt : 127;
 
         if (  p->last_chn != curr_chn
                || p->last_num != curr_num
@@ -305,20 +305,20 @@ int kvar_out_on(CSOUND *csound, KOUT_ON *p)
     return OK;
 }
 
-int out_controller (CSOUND *csound, OUT_CONTR *p)
+int32_t out_controller (CSOUND *csound, OUT_CONTR *p)
 {
     if (!(p->h.insdshead->prvinstance)) {
       /* if prev instance already allocated in the same MIDI chan */
-      int value;
+      int32_t value;
       MYFLT min = *p->min;
-      value =  (int)((*p->value - min) * FL(127.0) / (*p->max - min));
+      value =  (int32_t)((*p->value - min) * FL(127.0) / (*p->max - min));
       value = (value < 128) ?  value : 127;
       value = (value > -1) ?  value : 0;
       if (value != p->last_value ||
           *p->chn != p->lastchn ||
           *p->num != p->lastctrl) {
         /* csound->Message(csound, "out contr value: %d\n", value); */
-        control_change(csound, (int)*p->chn-1,(int)*p->num ,value);
+        control_change(csound, (int32_t)*p->chn-1,(int32_t)*p->num ,value);
         p->last_value = value;
         p->lastchn = *p->chn;
         p->lastctrl = *p->num;
@@ -327,17 +327,17 @@ int out_controller (CSOUND *csound, OUT_CONTR *p)
     return OK;
 }
 
-int out_aftertouch (CSOUND *csound, OUT_ATOUCH *p)
+int32_t out_aftertouch (CSOUND *csound, OUT_ATOUCH *p)
 {
     if (!(p->h.insdshead->prvinstance)) {
       /* if prev instance already allocated in the same MIDI chan */
-      int value;
+      int32_t value;
       MYFLT min = *p->min;
-      value =  (int)((*p->value - min) * FL(127.0) / (*p->max - min));
+      value =  (int32_t)((*p->value - min) * FL(127.0) / (*p->max - min));
       value = value < 128 ?  value : 127;
       value = value > -1  ?  value : 0;
       if (value != p->last_value || *p->chn != p->lastchn) {
-        after_touch(csound, (int)*p->chn-1, value);
+        after_touch(csound, (int32_t)*p->chn-1, value);
         p->last_value = value;
         p->lastchn = *p->chn;
        }
@@ -345,17 +345,17 @@ int out_aftertouch (CSOUND *csound, OUT_ATOUCH *p)
     return OK;
 }
 
-int out_poly_aftertouch (CSOUND *csound, OUT_POLYATOUCH *p)
+int32_t out_poly_aftertouch (CSOUND *csound, OUT_POLYATOUCH *p)
 {
-    int value;
+    int32_t value;
     MYFLT min = *p->min;
-    value =  (int)((*p->value - min) * FL(127.0) / (*p->max - min));
+    value =  (int32_t)((*p->value - min) * FL(127.0) / (*p->max - min));
     value = value < 128 ?  value : 127;
     value = value > -1  ?  value : 0;
     if (value != p->last_value ||
         *p->chn != p->lastchn  ||
         *p->num != p->lastctrl) {
-      poly_after_touch(csound, (int)*p->chn-1, (int)*p->num, value);
+      poly_after_touch(csound, (int32_t)*p->chn-1, (int32_t)*p->num, value);
       p->last_value = value;
       p->lastchn = *p->chn;
       p->lastctrl = *p->num;
@@ -364,17 +364,17 @@ int out_poly_aftertouch (CSOUND *csound, OUT_POLYATOUCH *p)
     return OK;
 }
 
-int out_progchange (CSOUND *csound, OUT_PCHG *p)
+int32_t out_progchange (CSOUND *csound, OUT_PCHG *p)
 {
     if (!(p->h.insdshead->prvinstance)) {
       /* if prev instance already allocated in the same MIDI chan */
-      int prog_num;
+      int32_t prog_num;
       MYFLT min = *p->min;
-      prog_num =  (int)((*p->prog_num - min) * FL(127.0) / (*p->max - min));
+      prog_num =  (int32_t)((*p->prog_num - min) * FL(127.0) / (*p->max - min));
       prog_num = prog_num < 128 ?  prog_num : 127;
       prog_num = prog_num > -1  ?  prog_num : 0;
       if (prog_num != p->last_prog_num || *p->chn != p->lastchn) {
-        program_change(csound, (int)*p->chn-1, prog_num);
+        program_change(csound, (int32_t)*p->chn-1, prog_num);
         p->last_prog_num = prog_num;
         p->lastchn = *p->chn;
         }
@@ -382,25 +382,25 @@ int out_progchange (CSOUND *csound, OUT_PCHG *p)
     return OK;
 }
 
-int out_controller14 (CSOUND *csound, OUT_CONTR14 *p)
+int32_t out_controller14 (CSOUND *csound, OUT_CONTR14 *p)
 {
     if (!(p->h.insdshead->prvinstance)) {
       /* if prev instance already allocated in the same MIDI chan */
-      int value;
+      int32_t value;
       MYFLT min = *p->min;
 
-      value =  (int)((*p->value - min) * FL(16383.0) / (*p->max - min));
+      value =  (int32_t)((*p->value - min) * FL(16383.0) / (*p->max - min));
       value = (value < 16384) ?  value : 16383;
       value = (value > -1) ?  value : 0;
 
       if (value != p->last_value  ||
           *p->chn != p->lastchn   ||
           *p->msb_num != p->lastctrl) {
-        unsigned int msb = value >> 7;
-        unsigned int lsb = value & 0x7F;
+        uint32_t msb = value >> 7;
+        uint32_t lsb = value & 0x7F;
         csound->Warning(csound, Str("out contr14 msb:%x lsb:%x\n"), msb, lsb);
-        control_change(csound, (int)*p->chn-1, (int)*p->msb_num, msb);
-        control_change(csound, (int)*p->chn-1, (int)*p->lsb_num, lsb);
+        control_change(csound, (int32_t)*p->chn-1, (int32_t)*p->msb_num, msb);
+        control_change(csound, (int32_t)*p->chn-1, (int32_t)*p->lsb_num, lsb);
         p->last_value = value;
         p->lastchn = *p->chn;
         p->lastctrl = *p->msb_num;
@@ -409,23 +409,23 @@ int out_controller14 (CSOUND *csound, OUT_CONTR14 *p)
     return OK;
 }
 
-int out_pitch_bend(CSOUND *csound, OUT_PB *p)
+int32_t out_pitch_bend(CSOUND *csound, OUT_PB *p)
 {
     if (p->h.insdshead->prvinstance) {
       /* if prev instance already allocated in the same MIDI chan */
       return OK;
     }
     else {
-      int   value;
+      int32_t   value;
       MYFLT min = *p->min;
 
-      value = (int)((*p->value - min) * FL(16383.0) / (*p->max - min));
+      value = (int32_t)((*p->value - min) * FL(16383.0) / (*p->max - min));
       value = (value < 16384  ?  value : 16383);
       value = (value > -1     ?  value : 0);
       if (value != p->last_value || *p->chn != p->lastchn )  {
-        unsigned int msb = value >> 7;
-        unsigned int lsb = value & 0x7F;
-        pitch_bend(csound, (int)*p->chn - 1, lsb, msb);
+        uint32_t msb = value >> 7;
+        uint32_t lsb = value & 0x7F;
+        pitch_bend(csound, (int32_t)*p->chn - 1, lsb, msb);
         p->last_value = value;
         p->lastchn = *p->chn;
         }
@@ -433,7 +433,7 @@ int out_pitch_bend(CSOUND *csound, OUT_PB *p)
     return OK;
 }
 
-int kon2_set(CSOUND *csound, KON2 *p)
+int32_t kon2_set(CSOUND *csound, KON2 *p)
 {
    IGN(csound);
     /* if not initialised by another opcode */
@@ -445,15 +445,15 @@ int kon2_set(CSOUND *csound, KON2 *p)
     return OK;
 }
 
-int kon2(CSOUND *csound, KON2 *p)
+int32_t kon2(CSOUND *csound, KON2 *p)
 {
     /*
         if (p->fl_first_note) {
-          register int temp;
+          register int32_t tt;
 
-          p->last_chn = (temp = abs((int)*p->kchn)) < NUMCHN  ? temp : NUMCHN-1;
-          p->last_num = (temp = abs((int)*p->knum)) < 128     ? temp : 127;
-          p->last_vel = (temp = abs((int)*p->kvel)) < 128     ? temp : 127;
+          p->last_chn = (tt = abs((int32_t)*p->kchn)) < NUMCHN  ? tt : NUMCHN-1;
+          p->last_num = (tt = abs((int32_t)*p->knum)) < 128     ? tt : 127;
+          p->last_vel = (tt = abs((int32_t)*p->kvel)) < 128     ? tt : 127;
           p->fl_first_note   = FALSE;
           p->fl_note_expired = FALSE;
 
@@ -469,13 +469,13 @@ int kon2(CSOUND *csound, KON2 *p)
         p->fl_note_expired = TRUE;
       }
       else {
-        int temp;
+        int32_t tt;
 
-        int curr_chn = (temp = abs((int)*p->kchn-1)) <= NUMCHN ? temp : NUMCHN;
-        int curr_num = (temp = abs((int)*p->knum)) < 128    ? temp : 127;
-        int curr_vel = (temp = abs((int)*p->kvel)) < 128    ? temp : 127;
+        int32_t curr_chn = (tt = abs((int32_t)*p->kchn-1)) <= NUMCHN ? tt : NUMCHN;
+        int32_t curr_num = (tt = abs((int32_t)*p->knum)) < 128    ? tt : 127;
+        int32_t curr_vel = (tt = abs((int32_t)*p->kvel)) < 128    ? tt : 127;
 
-        if ((int)(*p->ktrig +FL(0.5)) != 0  )/* i.e. equal to 1  */
+        if ((int32_t)(*p->ktrig +FL(0.5)) != 0  )/* i.e. equal to 1  */
                                 /*   p->last_chn != curr_chn
                                 || p->last_num != curr_num
                                 || p->last_vel != curr_vel
@@ -492,32 +492,32 @@ int kon2(CSOUND *csound, KON2 *p)
     return OK;
 }
 
-int midiout(CSOUND *csound, MIDIOUT *p)         /*gab-A6 fixed*/
+int32_t midiout(CSOUND *csound, MIDIOUT *p)         /*gab-A6 fixed*/
 {
-    int st, ch, d1, d2;
+    int32_t st, ch, d1, d2;
 
-    st = (int)(*p->in_type + FL(0.5));
+    st = (int32_t)(*p->in_type + FL(0.5));
     if (!st)
       return OK;
     st = (st & 0x70) | 0x80;
-    ch = (int)(*p->in_chan - FL(0.5)) & 0x0F;
-    d1 = (int)(*p->in_dat1 + FL(0.5)) & 0x7F;
-    d2 = (int)(*p->in_dat2 + FL(0.5)) & 0x7F;
+    ch = (int32_t)(*p->in_chan - FL(0.5)) & 0x0F;
+    d1 = (int32_t)(*p->in_dat1 + FL(0.5)) & 0x7F;
+    d2 = (int32_t)(*p->in_dat2 + FL(0.5)) & 0x7F;
     send_midi_message(csound, st | ch, d1, d2);
     return OK;
 }
 
-int nrpn(CSOUND *csound, NRPN *p)
+int32_t nrpn(CSOUND *csound, NRPN *p)
 {
-    int chan = (int)*p->chan-1, parm = (int)*p->parm_num;
-    int value = (int)*p->parm_value;
+    int32_t chan = (int32_t)*p->chan-1, parm = (int32_t)*p->parm_num;
+    int32_t value = (int32_t)*p->parm_value;
     if (chan != p->old_chan || parm != p->old_parm || value != p->old_value) {
-      int status = 176 | chan;
-      int parm_msb =  parm >> 7;
-      int parm_lsb =  parm  & 0x7f;
+      int32_t status = 176 | chan;
+      int32_t parm_msb =  parm >> 7;
+      int32_t parm_lsb =  parm  & 0x7f;
 
-      int value_msb = (value + 8192) >> 7;
-      int value_lsb = (value + 8192) % 128;
+      int32_t value_msb = (value + 8192) >> 7;
+      int32_t value_lsb = (value + 8192) % 128;
 
       send_midi_message(csound, status, 99, parm_msb);
       send_midi_message(csound, status, 98, parm_lsb);
@@ -530,7 +530,7 @@ int nrpn(CSOUND *csound, NRPN *p)
     return OK;
 }
 
-int mdelay_set(CSOUND *csound, MDELAY *p)
+int32_t mdelay_set(CSOUND *csound, MDELAY *p)
 {
    IGN(csound);
     p->read_index = 0;
@@ -539,24 +539,24 @@ int mdelay_set(CSOUND *csound, MDELAY *p)
     return OK;
 }
 
-int mdelay(CSOUND *csound, MDELAY *p)                   /*gab-A6 fixed*/
+int32_t mdelay(CSOUND *csound, MDELAY *p)                   /*gab-A6 fixed*/
 {
-    int read_index = p->read_index % DELTAB_LENGTH;
-    int write_index = p->write_index % DELTAB_LENGTH;
+    int32_t read_index = p->read_index % DELTAB_LENGTH;
+    int32_t write_index = p->write_index % DELTAB_LENGTH;
     MYFLT present_time =  CS_KCNT * CS_ONEDKR;
 
-    if (((int)*p->in_status == 0x90 || (int)*p->in_status == 0x80)) {
-      p->status[write_index] = (int)*p->in_status;
-      p->chan[write_index] = (int)*p->in_chan-1;
-      p->dat1[write_index] = (int)*p->in_dat1;
-      p->dat2[write_index] = (int)*p->in_dat2;
+    if (((int32_t)*p->in_status == 0x90 || (int32_t)*p->in_status == 0x80)) {
+      p->status[write_index] = (int32_t)*p->in_status;
+      p->chan[write_index] = (int32_t)*p->in_chan-1;
+      p->dat1[write_index] = (int32_t)*p->in_dat1;
+      p->dat2[write_index] = (int32_t)*p->in_dat2;
       p->time[write_index] = present_time;
       (p->write_index)++;
     }
     if (p->status[read_index] &&
         p->time[read_index] + *p->kdelay <= present_time) {
-      int number = p->dat1[read_index];
-      int velocity = p->dat2[read_index];
+      int32_t number = p->dat1[read_index];
+      int32_t velocity = p->dat2[read_index];
       send_midi_message(csound,  p->status[read_index] | p->chan[read_index],
                                  ((number   > 127) ? 127 : number),
                                  ((velocity > 127) ? 127 : velocity));
