@@ -17,8 +17,8 @@
 
     You should have received a copy of the GNU Lesser General Public
     License along with Csound; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-    02111-1307 USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+    02110-1301 USA
 */
 
 /* TODO:
@@ -34,7 +34,7 @@
 #include <assert.h>
 #endif
 
-int fsigs_equal(const PVSDAT *f1, const PVSDAT *f2)
+int32_t fsigs_equal(const PVSDAT *f1, const PVSDAT *f2)
 {
     if ((f1->overlap    == f2->overlap)
         && (f1->winsize == f2->winsize)
@@ -51,9 +51,9 @@ int fsigs_equal(const PVSDAT *f1, const PVSDAT *f2)
 /* Pandora's box opcode, but we can make it at least plausible,
    by forbidding copy to different format. */
 
-int fassign_set(CSOUND *csound, FASSIGN *p)
+int32_t fassign_set(CSOUND *csound, FASSIGN *p)
 {
-     int32 N = p->fsrc->N;
+    int32_t N = p->fsrc->N;
 
     p->fout->N =  N;
     p->fout->overlap = p->fsrc->overlap;
@@ -81,9 +81,9 @@ int fassign_set(CSOUND *csound, FASSIGN *p)
 }
 
 
-int fassign(CSOUND *csound, FASSIGN *p)
+int32_t fassign(CSOUND *csound, FASSIGN *p)
 {
-    int32 framesize;
+    int32_t framesize;
     float *fout,*fsrc;
     fout = (float *) p->fout->frame.auxp;
     fsrc = (float *) p->fsrc->frame.auxp;
@@ -112,15 +112,15 @@ int fassign(CSOUND *csound, FASSIGN *p)
 
 /************* OSCBANK SYNTH ***********/
 
-int pvadsynset(CSOUND *csound, PVADS *p)
+int32_t pvadsynset(CSOUND *csound, PVADS *p)
 {
     /* get params from input fsig */
     /* we trust they are legit! */
-    int i;
+    int32_t i;
     PVSDAT  *fs = p->fsig;
-    int32 N = fs->N;
-    int32 noscs,n_oscs;
-    int32 startbin,binoffset;
+    int32_t N = fs->N;
+    int32_t noscs,n_oscs;
+    int32_t startbin,binoffset;
     MYFLT *p_x;
 
     if (UNLIKELY(fs->sliding))
@@ -132,7 +132,7 @@ int pvadsynset(CSOUND *csound, PVADS *p)
     p->wintype = fs->wintype;
     p->fftsize = N;
     noscs   = N/2 + 1;                     /* max possible */
-    n_oscs = (int32) *p->n_oscs;    /* user param*/
+    n_oscs = (int32_t) *p->n_oscs;    /* user param*/
     if (UNLIKELY(n_oscs <=0))
       csound->InitError(csound, Str("pvadsyn: bad value for inoscs\n"));
     /* remove this when I know how to do it... */
@@ -145,8 +145,8 @@ int pvadsynset(CSOUND *csound, PVADS *p)
                as have to set/reset each osc when started and stopped */
 
     /* check bin params */
-    startbin = (int32) *p->ibin;            /* default 0 */
-    binoffset = (int32) *p->ibinoffset; /* default 1 */
+    startbin = (int32_t) *p->ibin;            /* default 0 */
+    binoffset = (int32_t) *p->ibinoffset; /* default 1 */
     if (UNLIKELY(startbin < 0 || startbin > noscs))
       return csound->InitError(csound,
                                Str("pvsadsyn: ibin parameter out of range.\n"));
@@ -193,8 +193,8 @@ static inline MYFLT fastoscil(MYFLT *a, MYFLT *x, MYFLT *y)
 
 static void adsyn_frame(CSOUND *csound, PVADS *p)
 {
-    int i,j;
-    int32 startbin,lastbin,binoffset;
+    int32_t i,j;
+    int32_t startbin,lastbin,binoffset;
     MYFLT *outbuf = (MYFLT *) (p->outbuf.auxp);
 
     float *frame;        /* RWD MUST be 32bit */
@@ -212,8 +212,8 @@ static void adsyn_frame(CSOUND *csound, PVADS *p)
     amps      = (MYFLT *) p->amps.auxp;
     freqs     = (MYFLT *) p->freqs.auxp;
     lastamps  = (MYFLT *) p->lastamps.auxp;
-    startbin  = (int32)  *p->ibin;
-    binoffset = (int32)  *p->ibinoffset;
+    startbin  = (int32_t)  *p->ibin;
+    binoffset = (int32_t)  *p->ibinoffset;
     lastbin   = p->maxosc;
 
     /*update amps, freqs*/
@@ -257,7 +257,7 @@ static MYFLT adsyn_tick(CSOUND *csound, PVADS *p)
     return  outbuf[p->outptr++];
 }
 
-int pvadsyn(CSOUND *csound, PVADS *p)
+int32_t pvadsyn(CSOUND *csound, PVADS *p)
 {
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
@@ -281,11 +281,11 @@ int pvadsyn(CSOUND *csound, PVADS *p)
 
 /******* PVSCROSS ***********/
 
-int pvscrosset(CSOUND *csound, PVSCROSS *p)
+int32_t pvscrosset(CSOUND *csound, PVSCROSS *p)
 {
     PVSDAT  *fsrc = p->fsrc;
     PVSDAT  *fout = p->fout;
-    int32 N = fsrc->N;
+    int32_t N = fsrc->N;
     /* source fsig */
     p->overlap = fsrc->overlap;
     p->winsize = fsrc->winsize;
@@ -317,9 +317,9 @@ int pvscrosset(CSOUND *csound, PVSCROSS *p)
     return OK;
 }
 
-int pvscross(CSOUND *csound, PVSCROSS *p)
+int32_t pvscross(CSOUND *csound, PVSCROSS *p)
 {
-    int32 i,N = p->fftsize;
+    int32_t i,N = p->fftsize;
     MYFLT amp1 = FABS(*p->kamp1);
     MYFLT amp2 = FABS(*p->kamp2);
     float *fsrc = (float *) p->fsrc->frame.auxp;    /* RWD all must be 32bit */
@@ -342,7 +342,7 @@ int pvscross(CSOUND *csound, PVSCROSS *p)
       uint32_t offset = p->h.insdshead->ksmps_offset;
       uint32_t early  = p->h.insdshead->ksmps_no_end;
       uint32_t n, nsmps = CS_KSMPS;
-      int NB = p->fsrc->NB;
+      int32_t NB = p->fsrc->NB;
       nsmps -= early;
       for (n=offset; n<nsmps; n++) {
         fsrc = (CMPLX *) p->fsrc->frame.auxp +n*NB;    /* RWD all must be 32bit */
@@ -373,15 +373,15 @@ int pvscross(CSOUND *csound, PVSCROSS *p)
 
 /******** PVSFREAD ************/
 
-static int pvsfreadset_(CSOUND *csound, PVSFREAD *p, int stringname)
+static int32_t pvsfreadset_(CSOUND *csound, PVSFREAD *p, int32_t stringname)
 {
     PVOCEX_MEMFILE  pp;
     uint32   N;
     char            pvfilnam[MAXNAME];
 
-    if (stringname) strncpy(pvfilnam, ((STRINGDAT*)p->ifilno)->data, MAXNAME-1);
+    if (stringname) strNcpy(pvfilnam, ((STRINGDAT*)p->ifilno)->data, MAXNAME-1);
     else if (csound->ISSTRCOD(*p->ifilno))
-      strncpy(pvfilnam, get_arg_string(csound, *p->ifilno), MAXNAME-1);
+      strNcpy(pvfilnam, get_arg_string(csound, *p->ifilno), MAXNAME-1);
     else csound->strarg2name(csound, pvfilnam, p->ifilno, "pvoc.", 0);
 
     if (UNLIKELY(PVOCEX_LoadFile(csound, pvfilnam, &pp) != 0)) {
@@ -398,7 +398,7 @@ static int pvsfreadset_(CSOUND *csound, PVSFREAD *p, int stringname)
     p->arate   = csound->esr / (MYFLT) pp.overlap;
     p->membase = (float*) pp.data;
 
-    if (UNLIKELY(p->overlap < (int)CS_KSMPS || p->overlap < 10))
+    if (UNLIKELY(p->overlap < (int32_t)CS_KSMPS || p->overlap < 10))
       return csound->InitError(csound, Str("Sliding version not yet available"));
     if (UNLIKELY(p->nframes <= 0))
       return csound->InitError(csound, Str("pvsfread: file is empty!\n"));
@@ -406,14 +406,14 @@ static int pvsfreadset_(CSOUND *csound, PVSFREAD *p, int stringname)
     if (UNLIKELY(p->nframes == 1))
       return csound->InitError(csound, Str("pvsfread: file has only one frame "
                               "(= impulse response).\n"));
-    if (UNLIKELY(p->overlap < (int)CS_KSMPS))
+    if (UNLIKELY(p->overlap < (int32_t)CS_KSMPS))
       return csound->InitError(csound, Str("pvsfread: analysis frame overlap "
                               "must be >= ksmps\n"));
     p->blockalign = (p->fftsize+2) * p->chans;
     if (UNLIKELY((*p->ichan) >= p->chans))
       return csound->InitError(csound, Str("pvsfread: ichan value exceeds "
                               "file channel count.\n"));
-    if (UNLIKELY((int32) (*p->ichan) < 0))
+    if (UNLIKELY((int32_t) (*p->ichan) < 0))
       return csound->InitError(csound,
                                Str("pvsfread: ichan cannot be negative.\n"));
 
@@ -422,10 +422,10 @@ static int pvsfreadset_(CSOUND *csound, PVSFREAD *p, int stringname)
     csound->AuxAlloc(csound, (N + 2) * sizeof(float), &p->fout->frame);
     /* init sig with first frame from file,
        regardless (always zero amps, but with bin freqs) */
-    p->chanoffset = (int32) MYFLT2LRND(*p->ichan) * (N + 2);
+    p->chanoffset = (int32_t) MYFLT2LRND(*p->ichan) * (N + 2);
     memcpy((float *) p->fout->frame.auxp,               /* RWD MUST be 32bit */
-           (float *) pp.data + (int32) p->chanoffset,    /* RWD MUST be 32bit */
-           (size_t) ((int) (N + 2) * (int) sizeof(float)));
+           (float *) pp.data + (int32_t) p->chanoffset,    /* RWD MUST be 32bit */
+           (size_t) ((int32_t) (N + 2) * (int32_t) sizeof(float)));
     p->membase += p->blockalign;  /* move to 2nd frame in file, as startpoint */
     p->nframes--;
     p->fout->N           =  N;
@@ -439,21 +439,21 @@ static int pvsfreadset_(CSOUND *csound, PVSFREAD *p, int stringname)
 }
 
 
-int pvsfreadset(CSOUND *csound, PVSFREAD *p){
+int32_t pvsfreadset(CSOUND *csound, PVSFREAD *p){
   return pvsfreadset_(csound,p, 0);
   }
 
-int pvsfreadset_S(CSOUND *csound, PVSFREAD *p){
+int32_t pvsfreadset_S(CSOUND *csound, PVSFREAD *p){
   return pvsfreadset_(csound,p, 1);
   }
 
 
-int pvsfread(CSOUND *csound, PVSFREAD *p)
+int32_t pvsfread(CSOUND *csound, PVSFREAD *p)
 {
-    int i,j;
+    int32_t i,j;
     MYFLT pos = *p->kpos;
     MYFLT framepos,frac;
-    int32 frame1pos,/*frame2pos,*/framesize,n_mcframes;
+    int32_t frame1pos,/*frame2pos,*/framesize,n_mcframes;
 
     float *pmem,*pframe1,*pframe2;               /* RWD all MUST be 32bit */
     float *fout = (float *) p->fout->frame.auxp;
@@ -470,7 +470,7 @@ int pvsfread(CSOUND *csound, PVSFREAD *p)
       if (UNLIKELY(pos < FL(0.0)))
         pos = FL(0.0);     /* or report as error... */
       framepos = pos * p->arate;
-      frame1pos = (int32) framepos;
+      frame1pos = (int32_t) framepos;
 
       if (frame1pos>= n_mcframes -1) {
         /* just return final frame */
@@ -506,9 +506,9 @@ int pvsfread(CSOUND *csound, PVSFREAD *p)
 }
 
 /************* PVSMASKA ****************/
-int pvsmaskaset(CSOUND *csound, PVSMASKA *p)
+int32_t pvsmaskaset(CSOUND *csound, PVSMASKA *p)
 {
-    unsigned int i;
+    uint32_t i;
     MYFLT *ftable;
     uint32_t N = p->fsrc->N;
     uint32_t nbins = N/2 + 1;
@@ -557,10 +557,10 @@ int pvsmaskaset(CSOUND *csound, PVSMASKA *p)
     return OK;
 }
 
-int pvsmaska(CSOUND *csound, PVSMASKA *p)
+int32_t pvsmaska(CSOUND *csound, PVSMASKA *p)
 {
-    int i;
-    int32 /*flen, */nbins;
+    int32_t i;
+    int32_t /*flen, */nbins;
     MYFLT *ftable;
     float *fout,*fsrc;                      /* RWD MUST be 32bit */
     float margin, depth = (float)*p->kdepth;
@@ -599,7 +599,7 @@ int pvsmaska(CSOUND *csound, PVSMASKA *p)
 
     margin = 1.0f - depth;
     if (p->fsrc->sliding) {
-      int NB = p->fsrc->NB;
+      int32_t NB = p->fsrc->NB;
       CMPLX *fout, *fsrc;
       uint32_t offset = p->h.insdshead->ksmps_offset;
       uint32_t early  = p->h.insdshead->ksmps_no_end;
@@ -621,7 +621,7 @@ int pvsmaska(CSOUND *csound, PVSMASKA *p)
     /* only process when a new frame is ready */
     if (p->lastframe < p->fsrc->framecount) {
       MYFLT amp = FL(1.0);
-      int aindex, findex;
+      int32_t aindex, findex;
       for (i=0;i < nbins;i++) {
         amp = depth + margin * ftable[i];
         aindex = i*2;
@@ -638,12 +638,12 @@ int pvsmaska(CSOUND *csound, PVSMASKA *p)
 
 /**************PVSFTW ******************/
 
-int pvsftwset(CSOUND *csound, PVSFTW *p)
+int32_t pvsftwset(CSOUND *csound, PVSFTW *p)
 {
-    int i;
+    int32_t i;
     MYFLT *ftablea,*ftablef;
     float *fsrc;                                        /* RWD MUST be 32bit */
-    int32 flena,flenf,nbins, N = p->fsrc->N;
+    int32_t flena,flenf,nbins, N = p->fsrc->N;
     /* source fsig */
     p->overlap = p->fsrc->overlap;
     p->winsize = p->fsrc->winsize;
@@ -679,7 +679,7 @@ int pvsftwset(CSOUND *csound, PVSFTW *p)
       ftablea[i] = fsrc[i*2];
 
     /* freq table? */
-    if ((int32) *p->ifnf >= 1) {
+    if ((int32_t) *p->ifnf >= 1) {
       p->outfnf = csound->FTnp2Find(csound, p->ifnf);
       if (UNLIKELY(p->outfnf==NULL))
         return NOTOK;
@@ -697,10 +697,10 @@ int pvsftwset(CSOUND *csound, PVSFTW *p)
     return OK;
 }
 
-int pvsftw(CSOUND *csound, PVSFTW *p)
+int32_t pvsftw(CSOUND *csound, PVSFTW *p)
 {
-    int i;
-    int32 nbins;
+    int32_t i;
+    int32_t nbins;
     MYFLT *ftablea, *ftablef = NULL;
     float *fsrc;                /* RWD MUST be 32bit */
 
@@ -742,11 +742,11 @@ int pvsftw(CSOUND *csound, PVSFTW *p)
 
 /************ PVSFTR ****************/
 
-int pvsftrset(CSOUND *csound, PVSFTR *p)
+int32_t pvsftrset(CSOUND *csound, PVSFTR *p)
 {
-    int i;
+    int32_t i;
     float *fdest;                         /* RWD MUST be 32bit */
-    int32 flena,flenf,nbins, N = p->fdest->N;
+    int32_t flena,flenf,nbins, N = p->fdest->N;
     /* source fsig */
     p->overlap   = p->fdest->overlap;
     p->winsize   = p->fdest->winsize;
@@ -770,7 +770,7 @@ int pvsftrset(CSOUND *csound, PVSFTR *p)
     /* if ifna=0; no amps to read; one assumes the user ias changing freqs only,
        otherwise, there is no change!
     */
-    if ((int32) *p->ifna != 0) {
+    if ((int32_t) *p->ifna != 0) {
       p->infna = csound->FTnp2Find(csound, p->ifna);
       if (UNLIKELY(p->infna==NULL))
         return NOTOK;
@@ -779,7 +779,7 @@ int pvsftrset(CSOUND *csound, PVSFTR *p)
       if (UNLIKELY(flena < nbins))
         return csound->InitError(csound, Str("pvsftr: amps ftable too small.\n"));
     }
-    if (UNLIKELY(p->overlap < (int)CS_KSMPS || p->overlap < 10))
+    if (UNLIKELY(p->overlap < (int32_t)CS_KSMPS || p->overlap < 10))
       return csound->InitError(csound, Str("Sliding version not yet available"));
     fdest = (float *) p->fdest->frame.auxp;             /* RWD MUST be 32bit */
 
@@ -789,7 +789,7 @@ int pvsftrset(CSOUND *csound, PVSFTR *p)
         fdest[i*2] = (float) p->ftablea[i];
 
     /* freq table? */
-    if ((int32) *p->ifnf >= 1) {
+    if ((int32_t) *p->ifnf >= 1) {
       p->infnf = csound->FTnp2Find(csound, p->ifnf);
       if (UNLIKELY(p->infnf==NULL))
         return NOTOK;
@@ -805,10 +805,10 @@ int pvsftrset(CSOUND *csound, PVSFTR *p)
     return OK;
 }
 
-int pvsftr(CSOUND *csound, PVSFTR *p)
+int32_t pvsftr(CSOUND *csound, PVSFTR *p)
 {
-    int   i;
-    int32 nbins;
+    int32_t   i;
+    int32_t nbins;
     float *fdest;                       /*RWD MUST be 32bit */
 
     fdest = (float *) p->fdest->frame.auxp;
@@ -834,7 +834,7 @@ int pvsftr(CSOUND *csound, PVSFTR *p)
 
 /************** PVSINFO ***********/
 
-int pvsinfo(CSOUND *csound, PVSINFO *p)
+int32_t pvsinfo(CSOUND *csound, PVSINFO *p)
 {
    IGN(csound);
 #ifdef _DEBUG
