@@ -17,13 +17,14 @@
 
     You should have received a copy of the GNU Lesser General Public
     License along with Csound; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-    02111-1307 USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+    02110-1301 USA
 */
 
 #include "csoundCore.h"         /*                      UGENS5.C        */
 #include "ugens5.h"
 #include <math.h>
+#include <inttypes.h>
 
 /*
  * LPC storage slots
@@ -32,8 +33,9 @@
 #define MAX_LPC_SLOT 20
 
 
-int porset(CSOUND *csound, PORT *p)
+int32_t porset(CSOUND *csound, PORT *p)
 {
+   IGN(csound);
     p->c2 = pow(0.5, (double)CS_ONEDKR / *p->ihtim);
     p->c1 = 1.0 - p->c2;
     if (LIKELY(*p->isig >= FL(0.0)))
@@ -41,17 +43,19 @@ int porset(CSOUND *csound, PORT *p)
     p->ihtim_old = *p->ihtim;
     return OK;
 }
-int kporset(CSOUND *csound, PORT *p) { return porset(csound, p); }
+int32_t kporset(CSOUND *csound, PORT *p) { return porset(csound, p); }
 
-int port(CSOUND *csound, PORT *p)
+int32_t port(CSOUND *csound, PORT *p)
 {
+    IGN(csound);
     p->yt1 = p->c1 * (double)*p->ksig + p->c2 * p->yt1;
     *p->kr = (MYFLT)p->yt1;
     return OK;
 }
 
-int kport(CSOUND *csound, KPORT *p)
+int32_t kport(CSOUND *csound, KPORT *p)
 {
+    IGN(csound);
     if (p->ihtim_old != *p->ihtim) {
       p->c2 = pow(0.5, (double)CS_ONEDKR / *p->ihtim);
       p->c1 = 1.0 - p->c2;
@@ -62,7 +66,7 @@ int kport(CSOUND *csound, KPORT *p)
     return OK;
 }
 
-int tonset(CSOUND *csound, TONE *p)
+int32_t tonset(CSOUND *csound, TONE *p)
 {
     double b;
     p->prvhp = (double)*p->khp;
@@ -75,7 +79,8 @@ int tonset(CSOUND *csound, TONE *p)
     return OK;
 }
 
-int ktonset(CSOUND *csound, TONE *p) {
+int32_t ktonset(CSOUND *csound, TONE *p) {
+    IGN(csound);
     double b;
     p->prvhp = (double)*p->khp;
     b = 2.0 - cos((double)(p->prvhp * CS_ONEDKR *TWOPI));
@@ -87,8 +92,9 @@ int ktonset(CSOUND *csound, TONE *p) {
     return OK;
  }
 
-int ktone(CSOUND *csound, TONE *p)
+int32_t ktone(CSOUND *csound, TONE *p)
 {
+    IGN(csound);
     double      c1 = p->c1, c2 = p->c2;
     double      yt1 = p->yt1;
 
@@ -105,8 +111,9 @@ int ktone(CSOUND *csound, TONE *p)
     return OK;
 }
 
-int tone(CSOUND *csound, TONE *p)
+int32_t tone(CSOUND *csound, TONE *p)
 {
+    IGN(csound);
     MYFLT       *ar, *asig;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
@@ -136,7 +143,7 @@ int tone(CSOUND *csound, TONE *p)
     return OK;
 }
 
-int tonsetx(CSOUND *csound, TONEX *p)
+int32_t tonsetx(CSOUND *csound, TONEX *p)
 {                   /* From Gabriel Maldonado, modified for arbitrary order */
     {
       double b;
@@ -145,10 +152,10 @@ int tonsetx(CSOUND *csound, TONEX *p)
       p->c2 = b - sqrt(b * b - 1.0);
       p->c1 = 1.0 - p->c2;
     }
-    if (UNLIKELY((p->loop = (int) (*p->ord + FL(0.5))) < 1)) p->loop = 4;
+    if (UNLIKELY((p->loop = (int32_t) (*p->ord + FL(0.5))) < 1)) p->loop = 4;
     if (!*p->istor && (p->aux.auxp == NULL ||
-                    (unsigned int)(p->loop*sizeof(double)) > p->aux.size))
-        csound->AuxAlloc(csound, (int32)(p->loop*sizeof(double)), &p->aux);
+                    (uint32_t)(p->loop*sizeof(double)) > p->aux.size))
+        csound->AuxAlloc(csound, (int32_t)(p->loop*sizeof(double)), &p->aux);
     p->yt1 = (double*)p->aux.auxp;
     if (LIKELY(!(*p->istor))) {
     memset(p->yt1, 0, p->loop*sizeof(double)); /* Punning zero and 0.0 */
@@ -156,14 +163,14 @@ int tonsetx(CSOUND *csound, TONEX *p)
     return OK;
 }
 
-int tonex(CSOUND *csound, TONEX *p)      /* From Gabriel Maldonado, modified */
+int32_t tonex(CSOUND *csound, TONEX *p)      /* From Gabriel Maldonado, modified */
 {
     MYFLT       *ar = p->ar;
     double      c2 = p->c2, *yt1 = p->yt1,c1 = p->c1;
-    uint32_t offset = p->h.insdshead->ksmps_offset;
-    uint32_t early  = p->h.insdshead->ksmps_no_end;
-    uint32_t n, nsmps = CS_KSMPS;
-    int      j, lp = p->loop;
+    uint32_t    offset = p->h.insdshead->ksmps_offset;
+    uint32_t    early  = p->h.insdshead->ksmps_no_end;
+    uint32_t    n, nsmps = CS_KSMPS;
+    int32_t     j, lp = p->loop;
 
     if (*p->khp != p->prvhp) {
       double b;
@@ -190,8 +197,9 @@ int tonex(CSOUND *csound, TONEX *p)      /* From Gabriel Maldonado, modified */
     return OK;
 }
 
-int katone(CSOUND *csound, TONE *p)
+int32_t katone(CSOUND *csound, TONE *p)
 {
+    IGN(csound);
     double     sig, x;
     double      c2 = p->c2, yt1 = p->yt1;
 
@@ -212,12 +220,12 @@ int katone(CSOUND *csound, TONE *p)
 }
 
 
-int atone(CSOUND *csound, TONE *p)
+int32_t atone(CSOUND *csound, TONE *p)
 {
     MYFLT       *ar, *asig;
-    uint32_t offset = p->h.insdshead->ksmps_offset;
-    uint32_t early  = p->h.insdshead->ksmps_no_end;
-    uint32_t n, nsmps = CS_KSMPS;
+    uint32_t    offset = p->h.insdshead->ksmps_offset;
+    uint32_t    early  = p->h.insdshead->ksmps_no_end;
+    uint32_t    n, nsmps = CS_KSMPS;
     double      c2 = p->c2, yt1 = p->yt1;
 
     if (*p->khp != p->prvhp) {
@@ -244,14 +252,14 @@ int atone(CSOUND *csound, TONE *p)
     return OK;
 }
 
-int atonex(CSOUND *csound, TONEX *p)      /* Gabriel Maldonado, modified */
+int32_t atonex(CSOUND *csound, TONEX *p)      /* Gabriel Maldonado, modified */
 {
     MYFLT       *ar = p->ar;
     double      c2 = p->c2, *yt1 = p->yt1;
-    uint32_t offset = p->h.insdshead->ksmps_offset;
-    uint32_t early  = p->h.insdshead->ksmps_no_end;
-    uint32_t n, nsmps = CS_KSMPS;
-    int      j, lp = p->loop;
+    uint32_t    offset = p->h.insdshead->ksmps_offset;
+    uint32_t    early  = p->h.insdshead->ksmps_no_end;
+    uint32_t    n, nsmps = CS_KSMPS;
+    int32_t     j, lp = p->loop;
 
     if (*p->khp != p->prvhp) {
       double b;
@@ -278,10 +286,10 @@ int atonex(CSOUND *csound, TONEX *p)      /* Gabriel Maldonado, modified */
     return OK;
 }
 
-int rsnset(CSOUND *csound, RESON *p)
+int32_t rsnset(CSOUND *csound, RESON *p)
 {
-    int scale;
-    p->scale = scale = (int)*p->iscl;
+    int32_t scale;
+    p->scale = scale = (int32_t)*p->iscl;
     if (UNLIKELY(scale && scale != 1 && scale != 2)) {
       return csound->InitError(csound, Str("illegal reson iscl value, %f"),
                                        *p->iscl);
@@ -295,9 +303,9 @@ int rsnset(CSOUND *csound, RESON *p)
     return OK;
 }
 
-int krsnset(CSOUND *csound, RESON *p){ return rsnset(csound,p); }
+int32_t krsnset(CSOUND *csound, RESON *p){ return rsnset(csound,p); }
 
-int kreson(CSOUND *csound, RESON *p)
+int32_t kreson(CSOUND *csound, RESON *p)
 {
     uint32_t flag = 0;
     double      c3p1, c3t4, omc3, c2sqr;
@@ -335,16 +343,16 @@ int kreson(CSOUND *csound, RESON *p)
 }
 
 
-int reson(CSOUND *csound, RESON *p)
+int32_t reson(CSOUND *csound, RESON *p)
 {
-    uint32_t offset = p->h.insdshead->ksmps_offset;
-    uint32_t early  = p->h.insdshead->ksmps_no_end;
-    uint32_t flag = 0, n, nsmps = CS_KSMPS;
+    uint32_t    offset = p->h.insdshead->ksmps_offset;
+    uint32_t    early  = p->h.insdshead->ksmps_no_end;
+    uint32_t    flag = 0, n, nsmps = CS_KSMPS;
     MYFLT       *ar, *asig;
     double      c3p1, c3t4, omc3, c2sqr;
     double      yt1, yt2, c1 = p->c1, c2 = p->c2, c3 = p->c3;
-    int         asigf = p->asigf;
-    int         asigw = p->asigw;
+    int32_t     asigf = p->asigf;
+    int32_t     asigw = p->asigw;
 
     asig = p->asig;
     ar = p->ar;
@@ -390,15 +398,15 @@ int reson(CSOUND *csound, RESON *p)
     return OK;
 }
 
-int rsnsetx(CSOUND *csound, RESONX *p)
+int32_t rsnsetx(CSOUND *csound, RESONX *p)
 {                               /* Gabriel Maldonado, modifies for arb order */
-    int scale;
-    p->scale = scale = (int) *p->iscl;
-    if ((p->loop = (int) (*p->ord + FL(0.5))) < 1)
+    int32_t scale;
+    p->scale = scale = (int32_t) *p->iscl;
+    if ((p->loop = (int32_t) (*p->ord + FL(0.5))) < 1)
       p->loop = 4; /* default value */
     if (!*p->istor && (p->aux.auxp == NULL ||
-                       (unsigned int)(p->loop*2*sizeof(double)) > p->aux.size))
-      csound->AuxAlloc(csound, (int32)(p->loop*2*sizeof(double)), &p->aux);
+                       (uint32_t)(p->loop*2*sizeof(double)) > p->aux.size))
+      csound->AuxAlloc(csound, (int32_t)(p->loop*2*sizeof(double)), &p->aux);
     p->yt1 = (double*)p->aux.auxp; p->yt2 = (double*)p->aux.auxp + p->loop;
     if (UNLIKELY(scale && scale != 1 && scale != 2)) {
       return csound->InitError(csound, Str("illegal reson iscl value, %f"),
@@ -413,17 +421,17 @@ int rsnsetx(CSOUND *csound, RESONX *p)
     return OK;
 }
 
-int resonx(CSOUND *csound, RESONX *p)   /* Gabriel Maldonado, modified  */
+int32_t resonx(CSOUND *csound, RESONX *p)   /* Gabriel Maldonado, modified  */
 {
     uint32_t    offset = p->h.insdshead->ksmps_offset;
-    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t    early  = p->h.insdshead->ksmps_no_end;
     uint32_t    flag = 0, n, nsmps = CS_KSMPS;
-    int         j;
+    int32_t     j;
     MYFLT       *ar;
     double      c3p1, c3t4, omc3, c2sqr;
     double      *yt1, *yt2, c1,c2,c3;
-    int asgf = IS_ASIG_ARG(p->kcf);
-    int asgw = IS_ASIG_ARG(p->kbw);
+    int32_t     asgf = IS_ASIG_ARG(p->kcf);
+    int32_t     asgw = IS_ASIG_ARG(p->kbw);
 
     ar   = p->ar;
     c1   = p->c1;
@@ -476,9 +484,9 @@ int resonx(CSOUND *csound, RESONX *p)   /* Gabriel Maldonado, modified  */
     return OK;
 }
 
-int kareson(CSOUND *csound, RESON *p)
+int32_t kareson(CSOUND *csound, RESON *p)
 {
-    uint32_t flag = 0;
+    uint32_t    flag = 0;
     double      c3p1, c3t4, omc3, c2sqr; //, D = 2.0; /* 1/RMS = root2 (rand) */
                                                    /*      or 1/.5  (sine) */
     double      yt1, yt2, c1, c2, c3;
@@ -526,11 +534,11 @@ int kareson(CSOUND *csound, RESON *p)
     return OK;
 }
 
-int areson(CSOUND *csound, RESON *p)
+int32_t areson(CSOUND *csound, RESON *p)
 {
-    uint32_t offset = p->h.insdshead->ksmps_offset;
-    uint32_t early  = p->h.insdshead->ksmps_no_end;
-    uint32_t flag = 0, n, nsmps = CS_KSMPS;
+    uint32_t    offset = p->h.insdshead->ksmps_offset;
+    uint32_t    early  = p->h.insdshead->ksmps_no_end;
+    uint32_t    flag = 0, n, nsmps = CS_KSMPS;
     MYFLT       *ar, *asig;
     double      c3p1, c3t4, omc3, c2sqr;//, D = 2.0; /* 1/RMS = root2 (rand) */
                                                    /*      or 1/.5  (sine) */
@@ -595,13 +603,13 @@ int areson(CSOUND *csound, RESON *p)
  *
  */
 
-int lprdset_(CSOUND *csound, LPREAD *p, int stringname)
+int32_t lprdset_(CSOUND *csound, LPREAD *p, int32_t stringname)
 {
     LPHEADER *lph;
     MEMFIL   *mfp;
-    int32     magic;
-    int32     totvals;
-    char      lpfilname[MAXNAME];
+    int32_t  magic;
+    int32_t  totvals;
+    char     lpfilname[MAXNAME];
 
     /* Store adress of opcode for other lpXXXX init to point to */
     if (csound->lprdaddr == NULL ||
@@ -614,9 +622,9 @@ int lprdset_(CSOUND *csound, LPREAD *p, int stringname)
     ((LPREAD**) csound->lprdaddr)[csound->currentLPCSlot] = p;
 
     /* Build file name */
-    if (stringname) strncpy(lpfilname, ((STRINGDAT*)p->ifilcod)->data, MAXNAME-1);
+    if (stringname) strNcpy(lpfilname, ((STRINGDAT*)p->ifilcod)->data, MAXNAME-1);
     else if (csound->ISSTRCOD(*p->ifilcod))
-      strncpy(lpfilname, get_arg_string(csound, *p->ifilcod), MAXNAME-1);
+      strNcpy(lpfilname, get_arg_string(csound, *p->ifilcod), MAXNAME-1);
     else csound->strarg2name(csound, lpfilname, p->ifilcod, "lp.", 0);
 
     /* Do not reload existing file ? */
@@ -660,7 +668,7 @@ int lprdset_(CSOUND *csound, LPREAD *p, int stringname)
     }
     else {                                    /* No Header on file:*/
       p->headlen = 0;
-      p->npoles = (int32)*p->inpoles;          /*  data from inargs */
+      p->npoles = (int32_t)*p->inpoles;          /*  data from inargs */
       p->nvals = p->npoles + 4;
       p->framrat16 = *p->ifrmrate * FL(65536.0);
       if (UNLIKELY(!p->npoles || !p->framrat16)) {
@@ -669,7 +677,7 @@ int lprdset_(CSOUND *csound, LPREAD *p, int stringname)
       }
     }
     /* Check pole number */
-    csound->AuxAlloc(csound, (int32)(p->npoles*8*sizeof(MYFLT)), &p->aux);
+    csound->AuxAlloc(csound, (int32_t)(p->npoles*8*sizeof(MYFLT)), &p->aux);
     p->kcoefs = (MYFLT*)p->aux.auxp;
     /* if (UNLIKELY(p->npoles > MAXPOLES)) { */
     /*   return csound->InitError(csound, Str("npoles > MAXPOLES")); */
@@ -680,27 +688,29 @@ int lprdset_(CSOUND *csound, LPREAD *p, int stringname)
     p->lastfram16 = (((totvals - p->nvals) / p->nvals) << 16) - 1;
     if (UNLIKELY(csound->oparms->odebug))
       csound->Message(csound, Str(
-                 "npoles %d, nvals %d, totvals %d, lastfram16 = %x\n"),
+                 "npoles %"PRIi32", nvals %"PRIi32", totvals %"PRIi32
+                 ", lastfram16 = %"PRIi32"x\n"),
              p->npoles, p->nvals, totvals, p->lastfram16);
  lpend:
     p->lastmsg = 0;
     return OK;
 }
 
-int lprdset(CSOUND *csound, LPREAD *p){
-  return lprdset_(csound, p, 0);
+int32_t lprdset(CSOUND *csound, LPREAD *p){
+    return lprdset_(csound, p, 0);
 }
 
-int lprdset_S(CSOUND *csound, LPREAD *p){
-  return lprdset_(csound, p, 1);
+int32_t lprdset_S(CSOUND *csound, LPREAD *p){
+    return lprdset_(csound, p, 1);
 }
 
 
 #ifdef TRACE_POLES
 static void
-  DumpPolesF(int poleCount, MYFLT *part1, MYFLT *part2, int isMagn, char *where)
+  DumpPolesF(int32_t poleCount, MYFLT *part1, MYFLT *part2,
+             int32_t isMagn, char *where)
 {
-    int i;
+    int32_t i;
 
     csound->Message(csound, "%s\n", where);
     for (i=0; i<poleCount; i++) {
@@ -714,11 +724,11 @@ static void
 }
 #endif
 
-static void SortPoles(int poleCount, MYFLT *poleMagn, MYFLT *polePhas)
+static void SortPoles(int32_t poleCount, MYFLT *poleMagn, MYFLT *polePhas)
 {
-    int i, j;
-    MYFLT diff, fTemp;
-    int shouldSwap;
+    int32_t i, j;
+    MYFLT   diff, fTemp;
+    int32_t shouldSwap;
 
     /*  DumpPolesF(poleCount, poleMagn, polePhas, 1, "Before sort"); */
 
@@ -755,25 +765,25 @@ static void SortPoles(int poleCount, MYFLT *poleMagn, MYFLT *polePhas)
 /*  DumpPolesF(poleCount, poleMagn, polePhas, 1, "After sort"); */
 }
 
-static int DoPoleInterpolation(int poleCount,
+static int32_t DoPoleInterpolation(int poleCount,
                                MYFLT *pm1, MYFLT *pp1,
                                MYFLT *pm2, MYFLT *pp2,
                                MYFLT factor, MYFLT *outMagn, MYFLT *outPhas)
 {
-    int i;
+    int32_t i;
 
     if (UNLIKELY(poleCount%2!=0)) {
-      printf (Str("Cannot handle uneven pole count yet \n"));
+      printf (Str("Cannot handle uneven pole count yet\n"));
       return (0);
     }
 
     for (i=0; i<poleCount; i++) {
-      if (FABS(FABS(pp1[i])-PI)<FL(1.0e-5)) {
+      if (FABS(FL(FABS(pp1[i])-PI))<FL(1.0e-5)) {
         pm1[i] = -pm1[i];
         pp1[i] = FL(0.0);
       }
 
-      if (FABS(FABS(pp2[i])-PI)<FL(1.0e-5)) {
+      if (FABS(FL(FABS(pp2[i])-PI))<FL(1.0e-5)) {
         pm2[i] = -pm2[i];
         pp2[i] = FL(0.0);
       }
@@ -799,10 +809,10 @@ static int DoPoleInterpolation(int poleCount,
     return(1);
 }
 
-static inline void InvertPoles(int count, double *real, double *imag)
+static inline void InvertPoles(int32_t count, double *real, double *imag)
 {
-    int    i;
-    double pr,pi,mag;
+    int32_t    i;
+    double     pr,pi,mag;
 
     for (i=0; i<count; i++) {
       pr = real[i];
@@ -820,12 +830,12 @@ static inline void InvertPoles(int count, double *real, double *imag)
  */
 
 static inline void
-    synthetize(int    poleCount,
+    synthetize(int32_t    poleCount,
                double *poleReal, double *poleImag,
                double *polyReal, double *polyImag)
 {
-    int    j, k;
-    double pr, pi, cr, ci;
+    int32_t    j, k;
+    double     pr, pi, cr, ci;
 
     polyReal[0] = 1;
     polyImag[0] = 0;
@@ -864,12 +874,12 @@ static inline void
  *
  */
 
-int lpread(CSOUND *csound, LPREAD *p)
+int32_t lpread(CSOUND *csound, LPREAD *p)
 {
     MYFLT   *bp, *np, *cp;
-    int32    nn, framphase;
+    int32_t  nn, framphase;
     MYFLT   fract;
-    int     i, status;
+    int32_t i, status;
     MYFLT   *poleMagn1 = p->kcoefs + 2*p->npoles;
     MYFLT   *polePhas1 = poleMagn1 + p->npoles;
     MYFLT   *poleMagn2 = polePhas1 + p->npoles;
@@ -950,7 +960,7 @@ int lpread(CSOUND *csound, LPREAD *p)
 }
 
 
-int lpformantset(CSOUND *csound, LPFORM *p)
+int32_t lpformantset(CSOUND *csound, LPFORM *p)
 {
     LPREAD *q;
 
@@ -961,13 +971,13 @@ int lpformantset(CSOUND *csound, LPFORM *p)
     return OK;
 }
 
-int lpformant(CSOUND *csound, LPFORM *p)
+int32_t lpformant(CSOUND *csound, LPFORM *p)
 {
-    LPREAD *q = p->lpread;
+    LPREAD  *q = p->lpread;
     MYFLT   *coefp, sr = csound->esr;
     MYFLT   *cfs = (MYFLT*)p->aux.auxp;
     MYFLT   *bws = cfs+p->lpread->npoles/2;
-    int     i, j, ndx = *p->kfor;
+    int32_t i, j, ndx = *p->kfor;
     double  pm,pp;
 
     if (q->storePoles) {
@@ -1007,7 +1017,7 @@ int lpformant(CSOUND *csound, LPFORM *p)
  *
  *
  */
-int lprsnset(CSOUND *csound, LPRESON *p)
+int32_t lprsnset(CSOUND *csound, LPRESON *p)
 {
     LPREAD *q;
 
@@ -1028,18 +1038,19 @@ int lprsnset(CSOUND *csound, LPRESON *p)
  *                  Uses a circular buffer to store previous signal values.
  */
 
-int lpreson(CSOUND *csound, LPRESON *p)
+int32_t lpreson(CSOUND *csound, LPRESON *p)
 {
-    LPREAD *q = p->lpread;
+    IGN(csound);
+    LPREAD   *q = p->lpread;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
-    MYFLT   *coefp, *pastp, *jp, *jp2, *rslt = p->ar, *asig = p->asig;
-    MYFLT   x;
-    double  poleReal[MAXPOLES], poleImag[MAXPOLES];
-    double  polyReal[MAXPOLES+1], polyImag[MAXPOLES+1];
-    int     i, nn;
-    double  pm,pp;
+    MYFLT    *coefp, *pastp, *jp, *jp2, *rslt = p->ar, *asig = p->asig;
+    MYFLT    x;
+    double   poleReal[MAXPOLES], poleImag[MAXPOLES];
+    double   polyReal[MAXPOLES+1], polyImag[MAXPOLES+1];
+    int32_t  i, nn;
+    double   pm,pp;
 
     jp = p->circjp;
     jp2 = jp + q->npoles;
@@ -1113,7 +1124,7 @@ int lpreson(CSOUND *csound, LPRESON *p)
  * LPFRESON : Initialisation time
  *
  */
-int lpfrsnset(CSOUND *csound, LPFRESON *p)
+int32_t lpfrsnset(CSOUND *csound, LPFRESON *p)
 {
 
    /* Connect to previously loaded analysis file */
@@ -1137,14 +1148,14 @@ int lpfrsnset(CSOUND *csound, LPFRESON *p)
  * LPFRESON : k & a time : actually filters the data
  *
  */
-int lpfreson(CSOUND *csound, LPFRESON *p)
+int32_t lpfreson(CSOUND *csound, LPFRESON *p)
 {
-    LPREAD  *q = p->lpread;
+    LPREAD   *q = p->lpread;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t nn, n, nsmps = CS_KSMPS;
-    MYFLT   *coefp, *pastp, *pastp1, *rslt = p->ar, *asig = p->asig;
-    MYFLT   x, temp1, temp2, ampscale, cq;
+    MYFLT    *coefp, *pastp, *pastp1, *rslt = p->ar, *asig = p->asig;
+    MYFLT    x, temp1, temp2, ampscale, cq;
 
     if (*p->kfrqratio != p->prvratio) {             /* for new freqratio */
       if (*p->kfrqratio <= FL(0.0)) {
@@ -1201,7 +1212,7 @@ int lpfreson(CSOUND *csound, LPFRESON *p)
     return OK;
 }
 
-int rmsset(CSOUND *csound, RMS *p)
+int32_t rmsset(CSOUND *csound, RMS *p)
 {
     double   b;
 
@@ -1213,7 +1224,7 @@ int rmsset(CSOUND *csound, RMS *p)
     return OK;
 }
 
-int gainset(CSOUND *csound, GAIN *p)
+int32_t gainset(CSOUND *csound, GAIN *p)
 {
     double   b;
 
@@ -1225,7 +1236,7 @@ int gainset(CSOUND *csound, GAIN *p)
     return OK;
 }
 
-int balnset(CSOUND *csound, BALANCE *p)
+int32_t balnset(CSOUND *csound, BALANCE *p)
 {
     double   b;
 
@@ -1237,14 +1248,15 @@ int balnset(CSOUND *csound, BALANCE *p)
     return OK;
 }
 
-int rms(CSOUND *csound, RMS *p)
+int32_t rms(CSOUND *csound, RMS *p)
 {
+    IGN(csound);
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
-    MYFLT   *asig;
-    double  q;
-    double  c1 = p->c1, c2 = p->c2;
+    MYFLT    *asig;
+    double   q;
+    double   c1 = p->c1, c2 = p->c2;
 
     q = p->prvq;
     asig = p->asig;
@@ -1258,14 +1270,15 @@ int rms(CSOUND *csound, RMS *p)
     return OK;
 }
 
-int gain(CSOUND *csound, GAIN *p)
+int32_t gain(CSOUND *csound, GAIN *p)
 {
+    IGN(csound);
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
-    MYFLT   *ar, *asig;
-    double  q, a, m, diff, inc;
-    double  c1 = p->c1, c2 = p->c2;
+    MYFLT    *ar, *asig;
+    double   q, a, m, diff, inc;
+    double   c1 = p->c1, c2 = p->c2;
 
     q = p->prvq;
     asig = p->asig;
@@ -1302,14 +1315,15 @@ int gain(CSOUND *csound, GAIN *p)
     return OK;
 }
 
-int balance(CSOUND *csound, BALANCE *p)
+int32_t balance(CSOUND *csound, BALANCE *p)
 {
+    IGN(csound);
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
-    MYFLT   *ar, *asig, *csig;
-    double  q, r, a, m, diff, inc;
-    double  c1 = p->c1, c2 = p->c2;
+    MYFLT    *ar, *asig, *csig;
+    double   q, r, a, m, diff, inc;
+    double   c1 = p->c1, c2 = p->c2;
 
     q = p->prvq;
     r = p->prvr;
@@ -1350,14 +1364,51 @@ int balance(CSOUND *csound, BALANCE *p)
     return OK;
 }
 
+
+int32_t balance2(CSOUND *csound, BALANCE *p)
+{
+    IGN(csound);
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t n, nsmps = CS_KSMPS;
+    MYFLT    *ar, *asig, *csig;
+    double   q, r, a;
+    double   c1 = p->c1, c2 = p->c2;
+
+    q = p->prvq;
+    r = p->prvr;
+    asig = p->asig;
+    csig = p->csig;
+    ar = p->ar;
+    if (UNLIKELY(offset)) memset(ar, '\0', offset*sizeof(MYFLT));
+    if (UNLIKELY(early)) {
+      nsmps -= early;
+      memset(&ar[nsmps], '\0', early*sizeof(MYFLT));
+    }
+    for (n = offset; n < nsmps; n++) {
+      double as = (double)asig[n];
+      double cs = (double)csig[n];
+      q = c1 * as * as + c2 * q;
+      r = c1 * cs * cs + c2 * r;
+      if (LIKELY(q != 0.0))
+        a = sqrt(r/q);
+      else
+        a = sqrt(r);
+      ar[n] = asig[n] * a;
+    }
+    p->prvq = q;
+    p->prvr = r;
+    return OK;
+}
+
 /*
  *   Set current lpc slot
  */
-int lpslotset(CSOUND *csound, LPSLOT *p)
+int32_t lpslotset(CSOUND *csound, LPSLOT *p)
 {
-    int n;
+    int32_t n;
 
-    n = (int) *(p->islotnum);
+    n = (int32_t) *(p->islotnum);
     if (UNLIKELY(n < 0))
       return csound->InitError(csound, Str("lpslot number should be positive"));
     else {
@@ -1372,17 +1423,17 @@ int lpslotset(CSOUND *csound, LPSLOT *p)
     return OK;
 }
 
-int lpitpset(CSOUND *csound, LPINTERPOL *p)
+int32_t lpitpset(CSOUND *csound, LPINTERPOL *p)
 {
 
-    if (UNLIKELY((unsigned int) ((int) *(p->islot1))
-                 >= (unsigned int) csound->max_lpc_slot ||
-                 (unsigned int) ((int) *(p->islot2))
-                 >= (unsigned int) csound->max_lpc_slot))
+    if (UNLIKELY((uint32_t) ((int32_t) *(p->islot1))
+                 >= (uint32_t) csound->max_lpc_slot ||
+                 (uint32_t) ((int32_t) *(p->islot2))
+                 >= (uint32_t) csound->max_lpc_slot))
       return csound->InitError(csound, Str("LPC slot is not allocated"));
   /* Get lpread pointers */
-    p->lp1 = ((LPREAD**) csound->lprdaddr)[(int) *(p->islot1)];
-    p->lp2 = ((LPREAD**) csound->lprdaddr)[(int) *(p->islot2)];
+    p->lp1 = ((LPREAD**) csound->lprdaddr)[(int32_t) *(p->islot1)];
+    p->lp2 = ((LPREAD**) csound->lprdaddr)[(int32_t) *(p->islot2)];
 
   /* Check if workable */
 
@@ -1408,9 +1459,9 @@ int lpitpset(CSOUND *csound, LPINTERPOL *p)
     return OK;
 }
 
-int lpinterpol(CSOUND *csound, LPINTERPOL *p)
+int32_t lpinterpol(CSOUND *csound, LPINTERPOL *p)
 {
-    int     i,status;
+    int32_t i,status;
     MYFLT   *cp,*cp1,*cp2;
     MYFLT   *poleMagn1 = p->kcoefs + 2*p->npoles;
     MYFLT   *polePhas1 = poleMagn1 + p->npoles;
@@ -1450,8 +1501,9 @@ int lpinterpol(CSOUND *csound, LPINTERPOL *p)
 }
 
 
-int klimit(CSOUND *csound, LIMIT *p)
+int32_t klimit(CSOUND *csound, LIMIT *p)
 {
+    IGN(csound);
     MYFLT       sig=*p->sig, min=*p->min, max=*p->max;
     if (LIKELY((sig <= max) && (sig >= min))) {
       *p->ans = sig;
@@ -1470,13 +1522,14 @@ int klimit(CSOUND *csound, LIMIT *p)
     return OK;
 }
 
-int limit(CSOUND *csound, LIMIT *p)
+int32_t limit(CSOUND *csound, LIMIT *p)
 {
+    IGN(csound);
     MYFLT       *ans, *asig;
     MYFLT       min=*p->min, max=*p->max, aver;
-    uint32_t offset = p->h.insdshead->ksmps_offset;
-    uint32_t early  = p->h.insdshead->ksmps_no_end;
-    uint32_t n, nsmps = CS_KSMPS;
+    uint32_t    offset = p->h.insdshead->ksmps_offset;
+    uint32_t    early  = p->h.insdshead->ksmps_no_end;
+    uint32_t    n, nsmps = CS_KSMPS;
     ans = p->ans;
     asig  = p->sig;
 
