@@ -18,8 +18,8 @@
 
     You should have received a copy of the GNU Lesser General Public
     License along with Csound; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-    02111-1307 USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+    02110-1301 USA
 */
 
 #include "csoundCore.h" /*                              UGENS6.C        */
@@ -28,19 +28,20 @@
 
 #define log001 (-FL(6.9078))    /* log(.001) */
 
-int downset(CSOUND *csound, DOWNSAMP *p)
+int32_t downset(CSOUND *csound, DOWNSAMP *p)
 {
-    if (UNLIKELY((p->len = (unsigned int)*p->ilen) > CS_KSMPS))
+    if (UNLIKELY((p->len = (uint32_t)*p->ilen) > CS_KSMPS))
       return csound->InitError(csound, "ilen > ksmps");
     return OK;
 }
 
-int downsamp(CSOUND *csound, DOWNSAMP *p)
+int32_t downsamp(CSOUND *csound, DOWNSAMP *p)
 {
+    IGN(csound);
     MYFLT       *asig, sum;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
-    int len, n;
+    int32_t len, n;
 
     if (p->len <= 1)
       *p->kr = p->asig[offset];
@@ -48,7 +49,7 @@ int downsamp(CSOUND *csound, DOWNSAMP *p)
       asig = p->asig;
       sum = FL(0.0);
       len = p->len;
-      if (len>(int)(CS_KSMPS-early)) len = early;
+      if (len>(int32_t)(CS_KSMPS-early)) len = early;
       for (n=offset; n<len; n++) {
         sum += asig[n];
       }
@@ -57,8 +58,9 @@ int downsamp(CSOUND *csound, DOWNSAMP *p)
     return OK;
 }
 
-int upsamp(CSOUND *csound, UPSAMP *p)
+int32_t upsamp(CSOUND *csound, UPSAMP *p)
 {
+    IGN(csound);
     MYFLT kval = *p->ksig;
     MYFLT *ar = p->ar;
     uint32_t offset = p->h.insdshead->ksmps_offset;
@@ -75,15 +77,17 @@ int upsamp(CSOUND *csound, UPSAMP *p)
     return OK;
 }
 
-int a_k_set(CSOUND *csound, INTERP *p)
+int32_t a_k_set(CSOUND *csound, INTERP *p)
 {
+    IGN(csound);
     p->prev = FL(0.0);
     p->init_k = 0;              /* IV - Sep 5 2002 */
     return OK;
 }
 
-int interpset(CSOUND *csound, INTERP *p)
+int32_t interpset(CSOUND *csound, INTERP *p)
 {
+    IGN(csound);
     if (*p->istor == FL(0.0)) {
       p->prev = (*p->imode == FL(0.0) ? *p->istart : FL(0.0));
       p->init_k = (*p->imode == FL(0.0) ? 0 : 1);       /* IV - Sep 5 2002 */
@@ -92,8 +96,9 @@ int interpset(CSOUND *csound, INTERP *p)
     return OK;
 }
 
-int interp(CSOUND *csound, INTERP *p)
+int32_t interp(CSOUND *csound, INTERP *p)
 {
+    IGN(csound);
     MYFLT *ar, val, incr;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
@@ -118,21 +123,24 @@ int interp(CSOUND *csound, INTERP *p)
     return OK;
 }
 
-int indfset(CSOUND *csound, INDIFF *p)
+int32_t indfset(CSOUND *csound, INDIFF *p)
 {
+    IGN(csound);
     if (*p->istor == FL(0.0))   /* IV - Sep 5 2002 */
       p->prev = FL(0.0);
     return OK;
 }
 
-int kntegrate(CSOUND *csound, INDIFF *p)
+int32_t kntegrate(CSOUND *csound, INDIFF *p)
 {
+    IGN(csound);
     *p->rslt = p->prev += *p->xsig;
     return OK;
 }
 
-int integrate(CSOUND *csound, INDIFF *p)
+int32_t integrate(CSOUND *csound, INDIFF *p)
 {
+    IGN(csound);
     MYFLT       *rslt, *asig, sum;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
@@ -153,8 +161,9 @@ int integrate(CSOUND *csound, INDIFF *p)
     return OK;
 }
 
-int kdiff(CSOUND *csound, INDIFF *p)
+int32_t kdiff(CSOUND *csound, INDIFF *p)
 {
+    IGN(csound);
     MYFLT       tmp;
     tmp = *p->xsig;             /* IV - Sep 5 2002: fix to make */
     *p->rslt = tmp - p->prev;   /* diff work when the input and */
@@ -162,8 +171,9 @@ int kdiff(CSOUND *csound, INDIFF *p)
     return OK;
 }
 
-int diff(CSOUND *csound, INDIFF *p)
+int32_t diff(CSOUND *csound, INDIFF *p)
 {
+    IGN(csound);
     MYFLT       *ar, *asig, prev, tmp;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
@@ -186,24 +196,27 @@ int diff(CSOUND *csound, INDIFF *p)
     return OK;
 }
 
-int samphset(CSOUND *csound, SAMPHOLD *p)
+int32_t samphset(CSOUND *csound, SAMPHOLD *p)
 {
+    IGN(csound);
     if (!(*p->istor))
       p->state = *p->ival;
     p->audiogate = IS_ASIG_ARG(p->xgate) ? 1 : 0;
     return OK;
 }
 
-int ksmphold(CSOUND *csound, SAMPHOLD *p)
+int32_t ksmphold(CSOUND *csound, SAMPHOLD *p)
 {
+    IGN(csound);
     if (*p->xgate > FL(0.0))
       p->state = *p->xsig;
     *p->xr = p->state;
     return OK;
 }
 
-int samphold(CSOUND *csound, SAMPHOLD *p)
+int32_t samphold(CSOUND *csound, SAMPHOLD *p)
 {
+    IGN(csound);
     MYFLT       *ar, *asig, *agate, state;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
@@ -241,9 +254,9 @@ int samphold(CSOUND *csound, SAMPHOLD *p)
     return OK;
 }
 
-int delset(CSOUND *csound, DELAY *p)
+int32_t delset(CSOUND *csound, DELAY *p)
 {
-    int32      npts;
+    int32_t      npts;
     char        *auxp;
 
     if (UNLIKELY(*p->istor && p->auxch.auxp != NULL))
@@ -255,7 +268,7 @@ int delset(CSOUND *csound, DELAY *p)
 
     if ((auxp = p->auxch.auxp) == NULL ||
         npts != p->npts) { /* new space if reqd */
-      csound->AuxAlloc(csound, (int32)npts*sizeof(MYFLT), &p->auxch);
+      csound->AuxAlloc(csound, (int32_t)npts*sizeof(MYFLT), &p->auxch);
       auxp = p->auxch.auxp;
       p->npts = npts;
     }
@@ -267,7 +280,7 @@ int delset(CSOUND *csound, DELAY *p)
     return OK;
 }
 
-int delrset(CSOUND *csound, DELAYR *p)
+int32_t delrset(CSOUND *csound, DELAYR *p)
 {
     uint32_t    npts;
     MYFLT       *auxp;
@@ -296,7 +309,7 @@ int delrset(CSOUND *csound, DELAYR *p)
     }
     if ((auxp = (MYFLT*)p->auxch.auxp) == NULL ||       /* new space if reqd */
         npts != p->npts) {
-      csound->AuxAlloc(csound, (int32)npts*sizeof(MYFLT), &p->auxch);
+      csound->AuxAlloc(csound, (int32_t)npts*sizeof(MYFLT), &p->auxch);
       auxp = (MYFLT*)p->auxch.auxp;
       p->npts = npts;
     }
@@ -307,7 +320,7 @@ int delrset(CSOUND *csound, DELAYR *p)
     return OK;
 }
 
-int delwset(CSOUND *csound, DELAYW *p)
+int32_t delwset(CSOUND *csound, DELAYW *p)
 {
    /* fifo for delayr pointers by Jens Groh: */
     if (UNLIKELY(csound->first_delayr == NULL)) {
@@ -328,7 +341,7 @@ int delwset(CSOUND *csound, DELAYW *p)
 static DELAYR *delayr_find(CSOUND *csound, MYFLT *ndx)
 {
     DELAYR  *d = (DELAYR*) csound->first_delayr;
-    int     n = (int)MYFLT2LRND(*ndx);
+    int32_t     n = (int32_t)MYFLT2LRND(*ndx);
 
     if (UNLIKELY(d == NULL)) {
       csound->InitError(csound, Str("deltap: associated delayr not found"));
@@ -352,13 +365,13 @@ static DELAYR *delayr_find(CSOUND *csound, MYFLT *ndx)
     return d;
 }
 
-int tapset(CSOUND *csound, DELTAP *p)
+int32_t tapset(CSOUND *csound, DELTAP *p)
 {
     p->delayr = delayr_find(csound, p->indx);
     return (p->delayr != NULL ? OK : NOTOK);
 }
 
-int delay(CSOUND *csound, DELAY *p)
+int32_t delay(CSOUND *csound, DELAY *p)
 {
     MYFLT       *ar, *asig, *curp, *endp;
     uint32_t offset = 0;
@@ -394,7 +407,7 @@ int delay(CSOUND *csound, DELAY *p)
                              Str("delay: not initialised"));
 }
 
-int delayr(CSOUND *csound, DELAYR *p)
+int32_t delayr(CSOUND *csound, DELAYR *p)
 {
     MYFLT       *ar, *curp, *endp;
     uint32_t offset = p->h.insdshead->ksmps_offset;
@@ -421,7 +434,7 @@ int delayr(CSOUND *csound, DELAYR *p)
                              Str("delayr: not initialised"));
 }
 
-int delayw(CSOUND *csound, DELAYW *p)
+int32_t delayw(CSOUND *csound, DELAYW *p)
 {
     DELAYR      *q = p->delayr;
     MYFLT       *asig, *curp, *endp;
@@ -446,7 +459,7 @@ int delayw(CSOUND *csound, DELAYW *p)
                              Str("delayw: not initialised"));
 }
 
-int deltap(CSOUND *csound, DELTAP *p)
+int32_t deltap(CSOUND *csound, DELTAP *p)
 {
     DELAYR      *q = p->delayr;
     MYFLT       *ar, *tap, *endp;
@@ -476,14 +489,14 @@ int deltap(CSOUND *csound, DELTAP *p)
                              Str("deltap: not initialised"));
 }
 
-int deltapi(CSOUND *csound, DELTAP *p)
+int32_t deltapi(CSOUND *csound, DELTAP *p)
 {
     DELAYR      *q = p->delayr;
     MYFLT       *ar, *tap, *prv, *begp, *endp;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
-    int32       idelsmps;
+    int32_t       idelsmps;
     MYFLT       delsmps, delfrac;
 
     if (UNLIKELY(q->auxch.auxp==NULL)) goto err1;
@@ -496,9 +509,9 @@ int deltapi(CSOUND *csound, DELTAP *p)
     begp = (MYFLT *) q->auxch.auxp;
     endp = (MYFLT *) q->auxch.endp;
     if (!IS_ASIG_ARG(p->xdlt)) {
-      if(*p->xdlt == INFINITY) goto err2;
+      if (*p->xdlt == INFINITY) goto err2;
       delsmps = *p->xdlt * csound->esr;
-      idelsmps = (int32)delsmps;
+      idelsmps = (int32_t)delsmps;
       delfrac = delsmps - idelsmps;
       tap = q->curp - idelsmps;
       while (tap < begp) tap += q->npts;
@@ -514,9 +527,9 @@ int deltapi(CSOUND *csound, DELTAP *p)
     else {
       MYFLT *timp = p->xdlt, *curq = q->curp;
       for (n=offset; n<nsmps; n++) {
-        if(timp[n] == INFINITY) goto err2;
+        if (timp[n] == INFINITY) goto err2;
         delsmps = timp[n] * csound->esr;
-        idelsmps = (int32)delsmps;
+        idelsmps = (int32_t)delsmps;
         delfrac = delsmps - idelsmps;
         tap = curq++ - idelsmps;
         if (UNLIKELY(tap < begp)) tap += q->npts;
@@ -538,14 +551,14 @@ int deltapi(CSOUND *csound, DELTAP *p)
 
 /* ***** From Hans Mikelson ************* */
 /* Delay N samples */
-int deltapn(CSOUND *csound, DELTAP *p)
+int32_t deltapn(CSOUND *csound, DELTAP *p)
 {
     DELAYR *q = p->delayr;
     MYFLT  *ar, *tap, *begp, *endp;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
-    int32  idelsmps;
+    int32_t  idelsmps;
     MYFLT  delsmps;
 
     if (UNLIKELY(q->auxch.auxp==NULL)) goto err1;
@@ -559,7 +572,7 @@ int deltapn(CSOUND *csound, DELTAP *p)
     endp = (MYFLT *) q->auxch.endp;
     if (!IS_ASIG_ARG(p->xdlt)) {
       delsmps = *p->xdlt;
-      idelsmps = (int32)delsmps;
+      idelsmps = (int32_t)delsmps;
       tap = q->curp - idelsmps;
       while (tap < begp) tap += q->npts;
       for (n=offset; n<nsmps; n++) {
@@ -575,7 +588,7 @@ int deltapn(CSOUND *csound, DELTAP *p)
       MYFLT *timp = p->xdlt, *curq = q->curp;
       for (n=offset; n<nsmps; n++) {
         delsmps = timp[n];
-        idelsmps = (int32)delsmps;
+        idelsmps = (int32_t)delsmps;
         if (UNLIKELY((tap = curq++ - idelsmps) < begp))
           tap += q->npts;
         else if (UNLIKELY(tap >= endp))
@@ -590,14 +603,14 @@ int deltapn(CSOUND *csound, DELTAP *p)
 }
 
 /* **** JPff **** */
-int deltap3(CSOUND *csound, DELTAP *p)
+int32_t deltap3(CSOUND *csound, DELTAP *p)
 {
     DELAYR      *q = p->delayr;
     MYFLT       *ar, *tap, *prv, *begp, *endp;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
-    int32       idelsmps;
+    int32_t       idelsmps;
     MYFLT       delsmps, delfrac;
 
     if (UNLIKELY(q->auxch.auxp==NULL)) goto err1;
@@ -610,9 +623,9 @@ int deltap3(CSOUND *csound, DELTAP *p)
     begp = (MYFLT *) q->auxch.auxp;
     endp = (MYFLT *) q->auxch.endp;
     if (!IS_ASIG_ARG(p->xdlt)) {
-      if(*p->xdlt == INFINITY) goto err2;
+      if (*p->xdlt == INFINITY) goto err2;
       delsmps = *p->xdlt * csound->esr;
-      idelsmps = (int32)delsmps;
+      idelsmps = (int32_t)delsmps;
       delfrac = delsmps - idelsmps;
       tap = q->curp - idelsmps;
       while (tap < begp) tap += q->npts;
@@ -645,9 +658,9 @@ int deltap3(CSOUND *csound, DELTAP *p)
       MYFLT *timp = p->xdlt, *curq = q->curp;
       for (n=offset; n<nsmps; n++) {
         MYFLT ym1, y0, y1, y2;
-        if(timp[n] == INFINITY) goto err2;
+        if (timp[n] == INFINITY) goto err2;
         delsmps = *timp++ * csound->esr;
-        idelsmps = (int32)delsmps;
+        idelsmps = (int32_t)delsmps;
         delfrac = delsmps - idelsmps;
         if (UNLIKELY((tap = curq++ - idelsmps) < begp))
           tap += q->npts;
@@ -682,12 +695,12 @@ int deltap3(CSOUND *csound, DELTAP *p)
 
 /* deltapx and deltapxw opcodes by Istvan Varga */
 
-int tapxset(CSOUND *csound, DELTAPX *p)
+int32_t tapxset(CSOUND *csound, DELTAPX *p)
 {
     p->delayr = delayr_find(csound, p->indx);
     if (UNLIKELY(p->delayr == NULL))
       return NOTOK;
-    p->wsize = (int)(*(p->iwsize) + FL(0.5));          /* window size */
+    p->wsize = (int32_t)(*(p->iwsize) + FL(0.5));          /* window size */
     p->wsize = ((p->wsize + 2) >> 2) << 2;
     if (UNLIKELY(p->wsize < 4)) p->wsize = 4;
     if (UNLIKELY(p->wsize > 1024)) p->wsize = 1024;
@@ -697,14 +710,14 @@ int tapxset(CSOUND *csound, DELTAPX *p)
     return OK;
 }
 
-int deltapx(CSOUND *csound, DELTAPX *p)                 /* deltapx opcode */
+int32_t deltapx(CSOUND *csound, DELTAPX *p)                 /* deltapx opcode */
 {
     DELAYR  *q = p->delayr;
     MYFLT   *out1, *del, *buf1, *bufp, *bufend;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
-    int32   indx, maxd, xpos;
+    int32_t   indx, maxd, xpos;
 
     if (UNLIKELY(q->auxch.auxp == NULL)) goto err1; /* RWD fix */
     out1 = p->ar; del = p->adlt;
@@ -714,12 +727,12 @@ int deltapx(CSOUND *csound, DELTAPX *p)                 /* deltapx opcode */
       memset(&out1[nsmps], '\0', early*sizeof(MYFLT));
     }
     buf1 = (MYFLT *) q->auxch.auxp;
-    indx = (int32) (q->curp - buf1);
+    indx = (int32_t) (q->curp - buf1);
     maxd = q->npts; bufend = buf1 + maxd;
 
     if (p->wsize != 4) {                /* window size >= 8 */
       double  d, x1, n1, w, d2x;
-      int     i2, i;
+      int32_t     i2, i;
       i2 = (p->wsize >> 1);
       /* wsize = 4: d2x = 1 - 1/3, wsize = 64: d2x = 1 - 1/36 */
       d2x = p->d2x;
@@ -730,7 +743,7 @@ int deltapx(CSOUND *csound, DELTAPX *p)                 /* deltapx opcode */
 
         x1 = (double)indx - (double)*(del++) * (double)csound->esr;
         while (x1 < 0.0) x1 += (double)maxd;
-        xpos = (int32)x1; x1 -= (double)xpos;
+        xpos = (int32_t)x1; x1 -= (double)xpos;
         while (xpos >= maxd) xpos -= maxd;
 
         if (x1 > 0.00000001 && x1 < 0.99999999) {
@@ -763,7 +776,7 @@ int deltapx(CSOUND *csound, DELTAPX *p)                 /* deltapx opcode */
       for (n=offset; n<nsmps; n++) {
         am1 = (double)indx - (double)*(del++) * (double)csound->esr;
         while (am1 < 0.0) am1 += (double)maxd;
-        xpos = (int32) am1; am1 -= (double)xpos;
+        xpos = (int32_t) am1; am1 -= (double)xpos;
 
         a0  = am1 * am1; a2 = 0.16666667 * (am1 * a0 - am1);    /* sample +2 */
         a1  = 0.5 * (a0 + am1) - 3.0 * a2;                      /* sample +1 */
@@ -786,25 +799,25 @@ int deltapx(CSOUND *csound, DELTAPX *p)                 /* deltapx opcode */
                              Str("deltap: not initialised"));
 }
 
-int deltapxw(CSOUND *csound, DELTAPX *p)                /* deltapxw opcode */
+int32_t deltapxw(CSOUND *csound, DELTAPX *p)                /* deltapxw opcode */
 {
     DELAYR  *q = p->delayr;
     MYFLT   *in1, *del, *buf1, *bufp, *bufend;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
-    int32   indx, maxd, xpos;
+    int32_t   indx, maxd, xpos;
 
     if (UNLIKELY(q->auxch.auxp == NULL)) goto err1; /* RWD fix */
     in1 = p->ar; del = p->adlt;
     if (UNLIKELY(early)) nsmps -= early;
     buf1 = (MYFLT *) q->auxch.auxp;
-    indx = (int32) (q->curp - buf1);
+    indx = (int32_t) (q->curp - buf1);
     maxd = q->npts; bufend = buf1 + maxd;
 
     if (p->wsize != 4) {                /* window size >= 8 */
       double  d, x1, n1, w, d2x;
-      int     i2, i;
+      int32_t     i2, i;
       i2 = (p->wsize >> 1);
       /* wsize = 4: d2x = 1 - 1/3, wsize = 64: d2x = 1 - 1/36 */
       d2x = p->d2x;
@@ -815,7 +828,7 @@ int deltapxw(CSOUND *csound, DELTAPX *p)                /* deltapxw opcode */
 
         x1 = (double)indx - (double)*(del++) * (double)csound->esr;
         while (x1 < 0.0) x1 += (double)maxd;
-        xpos = (int32) x1; x1 -= (double)xpos;
+        xpos = (int32_t) x1; x1 -= (double)xpos;
         while (xpos >= maxd) xpos -= maxd;
 
         if (x1 > 0.00000001 && x1 < 0.99999999) {
@@ -847,7 +860,7 @@ int deltapxw(CSOUND *csound, DELTAPX *p)                /* deltapxw opcode */
       for (n=offset; n<nsmps; n++) {
         am1 = (double)indx - (double)*(del++) * (double)csound->esr;
         while (am1 < 0.0) am1 += (double)maxd;
-        xpos = (int32) am1; am1 -= (double)xpos;
+        xpos = (int32_t) am1; am1 -= (double)xpos;
 
         a0  = am1 * am1; a2 = 0.16666667 * (am1 * a0 - am1);    /* sample +2 */
         a1  = 0.5 * (a0 + am1) - 3.0 * a2;                      /* sample +1 */
@@ -871,15 +884,17 @@ int deltapxw(CSOUND *csound, DELTAPX *p)                /* deltapxw opcode */
                              Str("deltap: not initialised"));
 }
 
-int del1set(CSOUND *csound, DELAY1 *p)
+int32_t del1set(CSOUND *csound, DELAY1 *p)
 {
+    IGN(csound);
     if (!(*p->istor))
       p->sav1 = FL(0.0);
     return OK;
 }
 
-int delay1(CSOUND *csound, DELAY1 *p)
+int32_t delay1(CSOUND *csound, DELAY1 *p)
 {
+    IGN(csound);
     MYFLT       *ar, *asig;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
@@ -899,9 +914,9 @@ int delay1(CSOUND *csound, DELAY1 *p)
     return OK;
 }
 
-int cmbset(CSOUND *csound, COMB *p)
+int32_t cmbset(CSOUND *csound, COMB *p)
 {
-    int32       lpsiz, nbytes;
+    int32_t       lpsiz, nbytes;
 
     if (*p->insmps != 0) {
       if (UNLIKELY((lpsiz = MYFLT2LRND(*p->ilpt))) <= 0) {
@@ -913,13 +928,13 @@ int cmbset(CSOUND *csound, COMB *p)
     }
     nbytes = lpsiz * sizeof(MYFLT);
     if (p->auxch.auxp == NULL || (uint32_t)nbytes != p->auxch.size) {
-      csound->AuxAlloc(csound, (int32)nbytes, &p->auxch);
+      csound->AuxAlloc(csound, (int32_t)nbytes, &p->auxch);
       p->pntr = (MYFLT *) p->auxch.auxp;
       p->prvt = FL(0.0);
       p->coef = FL(0.0);
     }
     else if (!(*p->istor)) {
-      /* Does this assume sizeof(MYFLT)==sizeof(int32)?? */
+      /* Does this assume sizeof(MYFLT)==sizeof(int32_t)?? */
       p->pntr = (MYFLT *) p->auxch.auxp;
       memset(p->auxch.auxp, '\0', nbytes);
       p->prvt = FL(0.0);
@@ -928,7 +943,7 @@ int cmbset(CSOUND *csound, COMB *p)
     return OK;
 }
 
-int comb(CSOUND *csound, COMB *p)
+int32_t comb(CSOUND *csound, COMB *p)
 {
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
@@ -975,9 +990,9 @@ int comb(CSOUND *csound, COMB *p)
                              Str("comb: not initialised"));
 }
 
-int invcomb(CSOUND *csound, COMB *p)
+int32_t invcomb(CSOUND *csound, COMB *p)
 {
-    int n, nsmps = csound->ksmps;
+    int32_t n, nsmps = csound->ksmps;
     MYFLT       *ar, *asig, *xp, *endp;
     MYFLT       coef = p->coef;
 
@@ -1014,7 +1029,7 @@ int invcomb(CSOUND *csound, COMB *p)
                              Str("combinv: not initialised"));
 }
 
-int alpass(CSOUND *csound, COMB *p)
+int32_t alpass(CSOUND *csound, COMB *p)
 {
     uint32_t    offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
@@ -1057,8 +1072,8 @@ static const MYFLT revlptimes[6] = {FL(0.0297), FL(0.0371), FL(0.0411),
 void reverbinit(CSOUND *csound)         /* called once by oload */
 {                                       /*  to init reverb data */
     const MYFLT *lptimp = revlptimes;
-    int32       *lpsizp = csound->revlpsiz;
-    int n = 6;
+    int32_t     *lpsizp = csound->revlpsiz;
+    int32_t n = 6;
 
     if (csound->revlpsum==0) {
       csound->revlpsum = 0;
@@ -1069,7 +1084,7 @@ void reverbinit(CSOUND *csound)         /* called once by oload */
     }
 }
 
-int rvbset(CSOUND *csound, REVERB *p)
+int32_t rvbset(CSOUND *csound, REVERB *p)
 {
     if (p->auxch.auxp == NULL) {                        /* if no space yet, */
       int32      *sizp = csound->revlpsiz;               /*    allocate it   */
@@ -1098,7 +1113,7 @@ int rvbset(CSOUND *csound, REVERB *p)
     return OK;
 }
 
-int reverb(CSOUND *csound, REVERB *p)
+int32_t reverb(CSOUND *csound, REVERB *p)
 {
     MYFLT       *asig, *p1, *p2, *p3, *p4, *p5, *p6, *ar, *endp;
     MYFLT       c1,c2,c3,c4,c5,c6;
@@ -1176,7 +1191,7 @@ int reverb(CSOUND *csound, REVERB *p)
                              Str("reverb: not initialised"));
 }
 
-int panset(CSOUND *csound, PAN *p)
+int32_t panset(CSOUND *csound, PAN *p)
 {
     FUNC  *ftp;
 
@@ -1189,7 +1204,7 @@ int panset(CSOUND *csound, PAN *p)
     return OK;
 }
 
-int pan(CSOUND *csound, PAN *p)
+int32_t pan(CSOUND *csound, PAN *p)
 {
     MYFLT   flend2, xndx_f, yndx_f, xt, yt, ch1, ch2, ch3, ch4;
     int32   xndx, yndx, flen;
