@@ -17,8 +17,8 @@
 
     You should have received a copy of the GNU Lesser General Public
     License along with Csound; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-    02111-1307 USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+    02110-1301 USA
 */
 
 /* These files are based on Robin Whittle's
@@ -62,15 +62,15 @@
 /* Starting addresses of zk and za spaces */
 /* MYFLT   *zkstart = NULL, *zastart = NULL;  */
 /* Number of the last location in zk/za space */
-/* long    zklast = 0, zalast = 0; */
+/* int64_t    zklast = 0, zalast = 0; */
 /* There are currently no limits on the size of these spaces.  */
 
 /* zakinit is an opcode which must be called once to reserve the memory
  * for zk and za spaces.
  */
-int zakinit(CSOUND *csound, ZAKINIT *p)
+int32_t zakinit(CSOUND *csound, ZAKINIT *p)
 {
-    int32    length;
+    int32_t    length;
 
     /* Check to see this is the first time zakinit() has been called.
      * Global variables will be zero if it has not been called.     */
@@ -88,7 +88,7 @@ int zakinit(CSOUND *csound, ZAKINIT *p)
      * This is all set to 0 and there will be an error report if the
      * memory cannot be allocated. */
 
-    csound->zklast = (int32) *p->isizek;
+    csound->zklast = (int32_t) *p->isizek;
     length = (csound->zklast + 1L) * sizeof(MYFLT);
 
     csound->zkstart = (MYFLT*) csound->Calloc(csound, length);
@@ -97,7 +97,7 @@ int zakinit(CSOUND *csound, ZAKINIT *p)
      * length ksmps.
      * This is all set to 0 and there will be an error report if the
      * memory cannot be allocated.       */
-    csound->zalast = (int32) *p->isizea;
+    csound->zalast = (int32_t) *p->isizea;
 
     length = (csound->zalast + 1L) * sizeof(MYFLT) * CS_KSMPS;
     csound->zastart = (MYFLT*) csound->Calloc(csound, length);
@@ -111,7 +111,7 @@ int zakinit(CSOUND *csound, ZAKINIT *p)
 /* zkset() is called at the init time of the instance of the zir, zkr
  * zir and ziw ugens.  It complains if zk space has not been allocated yet.
  */
-int zkset(CSOUND *csound, ZKR *p)
+int32_t zkset(CSOUND *csound, ZKR *p)
 {
     (void) p;
     if (UNLIKELY(csound->zkstart == NULL)) {
@@ -126,12 +126,12 @@ int zkset(CSOUND *csound, ZKR *p)
 /* k rate READ code. */
 
 /* zkr reads from zk space at k rate. */
-int zkr(CSOUND *csound, ZKR *p)
+int32_t zkr(CSOUND *csound, ZKR *p)
 {
-    int32    indx;
+    int32_t    indx;
 
     /* Check to see this index is within the limits of zk space. */
-    indx = (int32) *p->ndx;
+    indx = (int32_t) *p->ndx;
     if (UNLIKELY(indx > csound->zklast)) {
       *p->rslt = FL(0.0);
       csound->Warning(csound, Str("zkr index > isizek. Returning 0."));
@@ -156,15 +156,15 @@ int zkr(CSOUND *csound, ZKR *p)
  * Call zkset() to check that zk space has been allocated, then do
  * similar code to zkr() above, except with csoundInitError() instead of
  * csoundPerfError(). */
-int zir(CSOUND *csound, ZKR *p)
+int32_t zir(CSOUND *csound, ZKR *p)
 {
     /* See zkr() for more comments.  */
-    int32    indx;
+    int32_t    indx;
 
     if (UNLIKELY(zkset(csound, p) != OK))
       return NOTOK;
     /* Check to see this index is within the limits of zk space. */
-    indx = (int32) *p->ndx;
+    indx = (int32_t) *p->ndx;
     if (UNLIKELY(indx > csound->zklast)) {
       csound->Warning(csound, Str("zir index > isizek. Returning 0."));
       *p->rslt = FL(0.0);
@@ -185,12 +185,12 @@ int zir(CSOUND *csound, ZKR *p)
 /*-----------------------------------*/
 
 /* Now the i and k rate WRITE code.  zkw writes to zk space at k rate. */
-int zkw(CSOUND *csound, ZKW *p)
+int32_t zkw(CSOUND *csound, ZKW *p)
 {
-    int32    indx;
+    int32_t    indx;
 
     /* Check to see this index is within the limits of zk space. */
-    indx = (int32) *p->ndx;
+    indx = (int32_t) *p->ndx;
     if (UNLIKELY(indx > csound->zklast)) {
       return csound->PerfError(csound, p->h.insdshead,
                                Str("zkw index > isizek. Not writing."));
@@ -214,13 +214,13 @@ int zkw(CSOUND *csound, ZKW *p)
  *
  * Call zkset() to check that zk space has been allocated, then use
  * same code as zkw() except that errors go to csoundInitError().  */
-int ziw(CSOUND *csound, ZKW *p)
+int32_t ziw(CSOUND *csound, ZKW *p)
 {
-    int32    indx;
+    int32_t    indx;
 
     if (UNLIKELY(zkset(csound, (ZKR*) p) != OK))
       return NOTOK;
-    indx = (int32) *p->ndx;
+    indx = (int32_t) *p->ndx;
     if (UNLIKELY(indx > csound->zklast)) {
       return csound->InitError(csound, Str("ziw index > isizek. Not writing."));
     }
@@ -241,12 +241,12 @@ int ziw(CSOUND *csound, ZKW *p)
 /* i and k rate zk WRITE code, with a mix option. */
 
 /* zkwm writes to zk space at k rate. */
-int zkwm(CSOUND *csound, ZKWM *p)
+int32_t zkwm(CSOUND *csound, ZKWM *p)
 {
-    int32    indx;
+    int32_t    indx;
 
     /* Check to see this index is within the limits of zk space.   */
-    indx = (int32) *p->ndx;
+    indx = (int32_t) *p->ndx;
     if (UNLIKELY(indx > csound->zklast)) {
       return csound->PerfError(csound, p->h.insdshead,
                                Str("zkwm index > isizek. Not writing."));
@@ -277,13 +277,13 @@ int zkwm(CSOUND *csound, ZKWM *p)
  * Call zkset() to check that zk space has been allocated, then run
  * similar code to zkwm() to do the work - but with errors to csoundInitError().
  */
-int ziwm(CSOUND *csound, ZKWM *p)
+int32_t ziwm(CSOUND *csound, ZKWM *p)
 {
-    int32    indx;
+    int32_t    indx;
 
     if (UNLIKELY(zkset(csound, (ZKR*) p) != OK))
       return NOTOK;
-    indx = (int32) *p->ndx;
+    indx = (int32_t) *p->ndx;
     if (UNLIKELY(indx > csound->zklast)) {
       return csound->InitError(csound,
                                Str("ziwm index > isizek. Not writing."));
@@ -305,11 +305,11 @@ int ziwm(CSOUND *csound, ZKWM *p)
 /*-----------------------------------*/
 
 /* k rate ZKMOD subroutine.      */
-int zkmod(CSOUND *csound, ZKMOD *p)
+int32_t zkmod(CSOUND *csound, ZKMOD *p)
 {
     MYFLT *readloc;
-    int32 indx;
-    int mflag = 0;    /* set to true if should do the modulation with
+    int32_t indx;
+    int32_t mflag = 0;    /* set to true if should do the modulation with
                          multiplication rather than addition.    */
 
     /* If zkmod = 0, then just copy input to output. We want to make
@@ -320,7 +320,7 @@ int zkmod(CSOUND *csound, ZKMOD *p)
      * the normal conversion rules to apply to negative numbers -
      * so -2.3 is converted to -2.                               */
 
-    if ((indx = (int32)*p->zkmod) == 0) {
+    if ((indx = (int32_t)*p->zkmod) == 0) {
       *p->rslt = *p->sig;
       return OK;
     }
@@ -350,10 +350,10 @@ int zkmod(CSOUND *csound, ZKMOD *p)
 /*-----------------------------------*/
 
 /* zkcl clears a range of variables in zk space at k rate.       */
-int zkcl(CSOUND *csound, ZKCL *p)
+int32_t zkcl(CSOUND *csound, ZKCL *p)
 {
     MYFLT       *writeloc;
-    int32 first = (int32) *p->first, last = (int32) *p->last, loopcount;
+    int32_t first = (int32_t) *p->first, last = (int32_t) *p->last, loopcount;
 
     /* Check to see both kfirst and klast are within the limits of zk space
      * and that last is >= first.                */
@@ -385,8 +385,9 @@ int zkcl(CSOUND *csound, ZKCL *p)
 /* zaset() is called at the init time of the instance of the zar or zaw ugens.
  * All it has to do is spit the dummy if za space has not been allocated yet.
  */
-int zaset(CSOUND *csound, ZAR *p)
+int32_t zaset(CSOUND *csound, ZAR *p)
 {
+    IGN(p);
     if  (csound->zastart == NULL) {
       return csound->InitError(csound, Str("No za space: "
                                            "zakinit has not been called yet."));
@@ -400,10 +401,10 @@ int zaset(CSOUND *csound, ZAR *p)
 /* a rate READ code. */
 
 /* zar reads from za space at a rate. */
-int zar(CSOUND *csound, ZAR *p)
+int32_t zar(CSOUND *csound, ZAR *p)
 {
     MYFLT       *readloc, *writeloc;
-    int32 indx;
+    int32_t indx;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t nsmps = CS_KSMPS;
@@ -413,7 +414,7 @@ int zar(CSOUND *csound, ZAR *p)
     writeloc = p->rslt;
 
     /* Check to see this index is within the limits of za space.    */
-    indx = (int32) *p->ndx;
+    indx = (int32_t) *p->ndx;
     if (UNLIKELY(indx > csound->zalast)) {
       memset(writeloc, 0, nsmps*sizeof(MYFLT));
       return csound->PerfError(csound, p->h.insdshead,
@@ -443,11 +444,11 @@ int zar(CSOUND *csound, ZAR *p)
 
 /* zarg() reads from za space at audio rate, with gain controlled by a
  * k rate variable. Code is almost identical to zar() above. */
-int zarg(CSOUND *csound, ZARG *p)
+int32_t zarg(CSOUND *csound, ZARG *p)
 {
     MYFLT       *readloc, *writeloc;
     MYFLT       kgain;          /* Gain control */
-    int32        indx;
+    int32_t        indx;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
@@ -458,7 +459,7 @@ int zarg(CSOUND *csound, ZARG *p)
     kgain = *p->kgain;
 
     /* Check to see this index is within the limits of za space.    */
-    indx = (int32) *p->ndx;
+    indx = (int32_t) *p->ndx;
     if (UNLIKELY(indx > csound->zalast)) {
       memset(writeloc, 0, nsmps*sizeof(MYFLT));
       return csound->PerfError(csound, p->h.insdshead,
@@ -492,10 +493,10 @@ int zarg(CSOUND *csound, ZARG *p)
 /* a rate WRITE code. */
 
 /* zaw writes to za space at a rate. */
-int zaw(CSOUND *csound, ZAW *p)
+int32_t zaw(CSOUND *csound, ZAW *p)
 {
     MYFLT       *readloc, *writeloc;
-    int32 indx;
+    int32_t indx;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t nsmps = CS_KSMPS;
@@ -503,7 +504,7 @@ int zaw(CSOUND *csound, ZAW *p)
     /* Set up the pointer for the source of data to write.    */
     readloc = p->sig;
     /* Check to see this index is within the limits of za space.     */
-    indx = (int32) *p->ndx;
+    indx = (int32_t) *p->ndx;
     if (UNLIKELY(indx > csound->zalast)) {
         return csound->PerfError(csound, p->h.insdshead,
                                  Str("zaw index > isizea. Not writing."));
@@ -530,10 +531,10 @@ int zaw(CSOUND *csound, ZAW *p)
 /* a rate WRITE code with mix facility. */
 
 /* zawm writes to za space at a rate. */
-int zawm(CSOUND *csound, ZAWM *p)
+int32_t zawm(CSOUND *csound, ZAWM *p)
 {
     MYFLT       *readloc, *writeloc;
-    int32 indx;
+    int32_t indx;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
@@ -543,7 +544,7 @@ int zawm(CSOUND *csound, ZAWM *p)
 
     readloc = p->sig;
     /* Check to see this index is within the limits of za space.    */
-    indx = (int32) *p->ndx;
+    indx = (int32_t) *p->ndx;
     if (UNLIKELY(indx > csound->zalast)) {
       return csound->PerfError(csound, p->h.insdshead,
                                Str("zaw index > isizea. Not writing."));
@@ -581,12 +582,12 @@ int zawm(CSOUND *csound, ZAWM *p)
  *
  * See zkmod() for fuller explanation of code.
  */
-int zamod(CSOUND *csound, ZAMOD *p)
+int32_t zamod(CSOUND *csound, ZAMOD *p)
 {
     MYFLT       *writeloc, *readloc;
     MYFLT       *readsig;       /* Array of input floats */
-    int32 indx;
-    int mflag = 0;             /* non zero if modulation with multiplication  */
+    int32_t indx;
+    int32_t mflag = 0;             /* non zero if modulation with multiplication  */
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
@@ -601,7 +602,7 @@ int zamod(CSOUND *csound, ZAMOD *p)
       memset(&writeloc[nsmps], '\0', early*sizeof(MYFLT));
     }
     /* If zkmod = 0, then just copy input to output.    */
-    if ((indx = (int32) *p->zamod) == 0) {
+    if ((indx = (int32_t) *p->zamod) == 0) {
       memcpy(&writeloc[offset], &readsig[offset], (nsmps-offset)*sizeof(MYFLT));
       return OK;
     }
@@ -635,13 +636,13 @@ int zamod(CSOUND *csound, ZAMOD *p)
 /*-----------------------------------*/
 
 /* zacl clears a range of variables in za space at k rate. */
-int zacl(CSOUND *csound, ZACL *p)
+int32_t zacl(CSOUND *csound, ZACL *p)
 {
     MYFLT       *writeloc;
-    int32 first, last, loopcount;
+    int32_t first, last, loopcount;
 
-    first = (int32) *p->first;
-    last  = (int32) *p->last;
+    first = (int32_t) *p->first;
+    last  = (int32_t) *p->last;
     /* Check to see both kfirst and klast are within the limits of za space
      * and that last is >= first.    */
     if (UNLIKELY((first > csound->zalast) || (last > csound->zalast)))
@@ -682,18 +683,19 @@ int zacl(CSOUND *csound, ZACL *p)
  * Actually moved to the glob structure -- JPff march 2002
  */
 
-int timek(CSOUND *csound, RDTIME *p)
+int32_t timek(CSOUND *csound, RDTIME *p)
 {
+    IGN(csound);
     /* Read the global variable kcounter and turn it into a float.   */
     *p->rslt = (MYFLT) CS_KCNT;
     return OK;
 }
 
 /* timesr() */
-int timesr(CSOUND *csound, RDTIME *p)
+int32_t timesr(CSOUND *csound, RDTIME *p)
 {
     /* Read the global variable kcounter divide it by the k rate.    */
-
+    IGN(csound);
     *p->rslt = (MYFLT) CS_KCNT * CS_ONEDKR;
     return OK;
 }
@@ -706,8 +708,9 @@ int timesr(CSOUND *csound, RDTIME *p)
  * in the RDTIME data structure.
  * Returns 0.
  */
-int instimset(CSOUND *csound, RDTIME *p)
+int32_t instimset(CSOUND *csound, RDTIME *p)
 {
+   IGN(csound);
     p->instartk = CS_KCNT;
     *p->rslt = FL(0.0);
     return OK;
@@ -718,8 +721,9 @@ int instimset(CSOUND *csound, RDTIME *p)
  * Read difference between the global variable kcounter and the starting
  * time of this instance. Return it as a float.
  */
-int instimek(CSOUND *csound, RDTIME *p)
+int32_t instimek(CSOUND *csound, RDTIME *p)
 {
+    IGN(csound);
     *p->rslt = (MYFLT) (CS_KCNT - p->instartk);
     return OK;
 }
@@ -729,8 +733,9 @@ int instimek(CSOUND *csound, RDTIME *p)
  * Read difference between the global variable kcounter and the starting
  * time of this instance.  Return it as a float in seconds.
  */
-int instimes(CSOUND *csound, RDTIME *p)
+int32_t instimes(CSOUND *csound, RDTIME *p)
 {
+    IGN(csound);
     *p->rslt = (MYFLT) (CS_KCNT - p->instartk) * CS_ONEDKR;
     return OK;
 }
@@ -742,33 +747,28 @@ int instimes(CSOUND *csound, RDTIME *p)
 
 /* printkset is called when the instance of the instrument is initialised. */
 
-int printkset(CSOUND *csound, PRINTK *p)
+int32_t printkset(CSOUND *csound, PRINTK *p)
 {
     /* Set up ctime so that if it was 0 or negative, it is set to a low value
      * to ensure that the print cycle happens every k cycle.  This low value is
      * 1 / ekr     */
+    /* Not sure this mattersin revised version.  Would just work! -- JPff */
     if (*p->ptime < CS_ONEDKR)
-      p->ctime = CS_ONEDKR;
+      p->ctime = FL(0.0);
     else
-      p->ctime = *p->ptime;
+      p->ctime = *p->ptime * csound->ekr;
 
     /* Set up the number of spaces.
        Limit to 120 for people with big screens or printers.
      */
-    p->pspace = (int32) *p->space;
+    p->pspace = (int32_t) *p->space;
     if (UNLIKELY(p->pspace < 0L))
       p->pspace = 0L;
     else if (UNLIKELY(p->pspace > 120L))
       p->pspace = 120L;
 
-    /* Set the initime variable - how many seconds in absolute time
-     * when this instance of the instrument was initialised.     */
-
-    p->initime = (MYFLT) CS_KCNT * CS_ONEDKR;
-
-    /* Set cysofar to - 1 so that on the first call to printk - when
-     * cycle = 0, then there will be a print cycle.     */
-    p->cysofar = -1;
+    //printf("printkset: ctime = %f\n", p->ctime);
+    p->printat = CS_KCNT;
     p->initialised = -1;
     return OK;
 }
@@ -778,35 +778,23 @@ int printkset(CSOUND *csound, PRINTK *p)
  *
  * Called on every k cycle. It must decide when to do a print operation.
  */
-int printk(CSOUND *csound, PRINTK *p)
+int32_t printk(CSOUND *csound, PRINTK *p)
 {
-    MYFLT       timel;          /* Time in seconds since initialised */
-    int32        cycles;         /* What print cycle */
-
-    /*-----------------------------------*/
-
-    /* Initialise variables.    */
     if (UNLIKELY(p->initialised != -1))
       csound->PerfError(csound, p->h.insdshead, Str("printk not initialised"));
-    timel =     ((MYFLT) CS_KCNT * CS_ONEDKR) - p->initime;
 
-    /* Divide the current elapsed time by the cycle time and round down to
-     * an integer.
-     */
-    cycles =    MYFLT2LRND(timel / p->ctime);
-
-    /* Now test if the cycle number we arein is higher than the one in which
-     * we last printed. If so, update cysofar and print.    */
-    if (p->cysofar < cycles) {
-      p->cysofar = cycles;
+    //printf("printk: KCNT = %lu\n", CS_KCNT);
+    //printf("printat = %lf\n", p->printat);
+    /* Now test if the cycle number has reached the next print time */
+    if (p->printat <= CS_KCNT-1) {
       /* Do the print cycle.
        * Print instrument number and time. Instrument number stuff from
        * printv() in disprep.c.
        */
       csound->MessageS(csound, CSOUNDMSG_ORCH, " i%4d ",
-                               (int)p->h.insdshead->p1.value);
+                               (int32_t)p->h.insdshead->p1.value);
       csound->MessageS(csound, CSOUNDMSG_ORCH, Str("time %11.5f: "),
-                               csound->icurTime/csound->esr);
+                               csound->icurTime/csound->esr-CS_ONEDKR);
       /* Print spaces and then the value we want to read.   */
       if (p->pspace > 0L) {
         char  s[128];   /* p->pspace is limited to 120 in printkset() above */
@@ -814,7 +802,12 @@ int printk(CSOUND *csound, PRINTK *p)
         s[p->pspace] = '\0';
         csound->MessageS(csound, CSOUNDMSG_ORCH, "%s", s);
       }
-      csound->MessageS(csound, CSOUNDMSG_ORCH, "%11.5f\n", *p->val);
+      if (*p->named)
+        csound->MessageS(csound, CSOUNDMSG_ORCH, "%s = %11.5f\n",
+                         p->h.optext->t.inlist->arg[1], *p->val);
+      else
+        csound->MessageS(csound, CSOUNDMSG_ORCH, "%11.5f\n", *p->val);
+      p->printat += p->ctime;
     }
     return OK;
 }
@@ -828,18 +821,16 @@ int printk(CSOUND *csound, PRINTK *p)
 #define ESC (0x1B)
 
 /* printksset is called when the instance of the instrument is initialised. */
-int printksset_(CSOUND *csound, PRINTKS *p, char *sarg)
+int32_t printksset_(CSOUND *csound, PRINTKS *p, char *sarg)
 {
     char        *sdest;
     char        temp, tempn;
 
-    p->initialised = -1;
     if (*p->ptime < CS_ONEDKR)
       p->ctime = CS_ONEDKR;
     else
-      p->ctime = *p->ptime;
-    p->initime = (MYFLT) CS_KCNT * CS_ONEDKR;
-    p->cysofar = -1;
+      p->ctime = *p->ptime * csound->ekr;
+    p->printat = CS_KCNT;
     memset(p->txtstring, 0, 8192);   /* This line from matt ingalls */
     sdest = p->txtstring;
     /* Copy the string to the storage place in PRINTKS.
@@ -946,11 +937,12 @@ int printksset_(CSOUND *csound, PRINTKS *p, char *sarg)
       /* Increment pointer and process next character until end of string.  */
       ++sarg;
     }
-
+    p->printat = CS_KCNT;
+    p->initialised = -1;
     return OK;
 }
 
-int printksset_S(CSOUND *csound, PRINTKS *p){
+int32_t printksset_S(CSOUND *csound, PRINTKS *p){
     char *sarg;
     sarg = ((STRINGDAT*)p->ifilcod)->data;
     if (sarg == NULL) return csoundInitError(csound, Str("null string\n"));
@@ -958,7 +950,7 @@ int printksset_S(CSOUND *csound, PRINTKS *p){
     return printksset_(csound, p, sarg);
 }
 
-int printksset(CSOUND *csound, PRINTKS *p){
+int32_t printksset(CSOUND *csound, PRINTKS *p){
     char* arg_string = get_arg_string(csound, *p->ifilcod);
 
     if (arg_string == NULL) {
@@ -969,10 +961,10 @@ int printksset(CSOUND *csound, PRINTKS *p){
 
 
 //perform a sprintf-style format  -- matt ingalls
-/* void sprints_local(char *outstring, char *fmt, MYFLT **kvals, int32 numVals) */
+/* void sprints_local(char *outstring, char *fmt, MYFLT **kvals, int32_t numVals) */
 /* { */
 /*     char strseg[8192]; */
-/*     int i = 0, j = 0; */
+/*     int32_t i = 0, j = 0; */
 /*     char *segwaiting = 0; */
 /*     puts(fmt); */
 /*     while (*fmt) { */
@@ -980,8 +972,8 @@ int printksset(CSOUND *csound, PRINTKS *p){
 /*         /\* if already a segment waiting, then lets print it *\/ */
 /*         if (segwaiting) { */
 /*           MYFLT xx = (j>=numVals? FL(0.0) : *kvals[j]); */
-/*           /\* printf("***xx = %f (int)(xx+.5)=%d round=%d mode=%d\n", *\/ */
-/*           /\*        xx, (int)(xx+.5), MYFLT2LRND(xx), fegetround()); *\/ */
+/*           /\* printf("***xx = %f (int32_t)(xx+.5)=%d round=%d mode=%d\n", *\/ */
+/*           /\*        xx, (int32_t)(xx+.5), MYFLT2LRND(xx), fegetround()); *\/ */
 /*           strseg[i] = '\0'; */
 
 /*           switch (*segwaiting) { */
@@ -992,13 +984,13 @@ int printksset(CSOUND *csound, PRINTKS *p){
 /*           case 'X': */
 /*           case 'u': */
 /*           case 'c': */
-/*             snprintf(outstring, 8196, strseg, (int)MYFLT2LRND(xx)); */
+/*             snprintf(outstring, 8196, strseg, (int32_t)MYFLT2LRND(xx)); */
 /*             break; */
 /*           case 'h': */
-/*             snprintf(outstring, 8196, strseg, (int16)MYFLT2LRND(xx)); */
+/*             snprintf(outstring, 8196, strseg, (int32_t16)MYFLT2LRND(xx)); */
 /*             break; */
 /*           case 'l': */
-/*             snprintf(outstring, 8196, strseg, (int32)MYFLT2LRND(xx)); */
+/*             snprintf(outstring, 8196, strseg, (int32_t32)MYFLT2LRND(xx)); */
 /*             break; */
 
 /*           default: */
@@ -1032,8 +1024,8 @@ int printksset(CSOUND *csound, PRINTKS *p){
 /*       strseg[i] = '\0'; */
 /*       if (segwaiting) { */
 /*         MYFLT xx = (j>=numVals? FL(0.0) : *kvals[j]); */
-/*            /\* printf("***xx = %f (int)(xx+.5)=%d round=%d mode=%d\n", *\/ */
-/*            /\*       xx, (int)(xx+.5), MYFLT2LRND(xx), fegetround()); *\/ */
+/*            /\* printf("***xx = %f (int32_t)(xx+.5)=%d round=%d mode=%d\n", *\/ */
+/*            /\*       xx, (int32_t)(xx+.5), MYFLT2LRND(xx), fegetround()); *\/ */
 /*        switch (*segwaiting) { */
 /*         case 'd': */
 /*         case 'i': */
@@ -1042,13 +1034,13 @@ int printksset(CSOUND *csound, PRINTKS *p){
 /*         case 'X': */
 /*         case 'u': */
 /*         case 'c': */
-/*           snprintf(outstring, 8196, strseg, (int)MYFLT2LRND(xx)); */
+/*           snprintf(outstring, 8196, strseg, (int32_t)MYFLT2LRND(xx)); */
 /*           break; */
 /*         case 'h': */
 /*           snprintf(outstring, 8196, strseg, (int16)MYFLT2LRND(xx)); */
 /*           break; */
 /*         case 'l': */
-/*           snprintf(outstring, 8196, strseg, (int32)MYFLT2LRND(xx)); */
+/*           snprintf(outstring, 8196, strseg, (int32_t)MYFLT2LRND(xx)); */
 /*           break; */
 
 /*         default: */
@@ -1063,11 +1055,11 @@ int printksset(CSOUND *csound, PRINTKS *p){
 /* VL - rewritten 1/16
    escaping %% correctly now.
  */
-static int sprints(char *outstring,  char *fmt, MYFLT **kvals, int32 numVals)
+static int32_t sprints(char *outstring,  char *fmt, MYFLT **kvals, int32_t numVals)
 {
     char tmp[8],cc;
-    int j = 0;
-    int len = 8192;
+    int32_t j = 0;
+    int32_t len = 8192;
     while (*fmt) {
       if (*fmt == '%') {
         if (*(fmt+1) == '%') {
@@ -1082,7 +1074,7 @@ static int sprints(char *outstring,  char *fmt, MYFLT **kvals, int32 numVals)
           len-=3;
         }
         else {
-          int n = 1;
+          int32_t n = 1;
           char check='%';
           tmp[0] = check;
           while (*(fmt+n) &&
@@ -1138,10 +1130,8 @@ static int sprints(char *outstring,  char *fmt, MYFLT **kvals, int32 numVals)
  * It must decide when to do a
  * print operation.
  */
-int printks(CSOUND *csound, PRINTKS *p)
+int32_t printks(CSOUND *csound, PRINTKS *p)
 {
-    MYFLT       timel;
-    int32        cycles;
     char        string[8192]; /* matt ingals replacement */
 
     if (csound->ISSTRCOD(*p->ifilcod) == 0) {
@@ -1149,7 +1139,7 @@ int printks(CSOUND *csound, PRINTKS *p)
       sarg = ((STRINGDAT*)p->ifilcod)->data;
       if (sarg == NULL)
         return csoundPerfError(csound, p->h.insdshead, Str("null string\n"));
-     if (strcmp(sarg, p->old) != 0) {
+      if (strcmp(sarg, p->old) != 0) {
         printksset_(csound, p, sarg);
         csound->Free(csound, p->old);
         p->old = cs_strdup(csound, sarg);
@@ -1159,18 +1149,7 @@ int printks(CSOUND *csound, PRINTKS *p)
     /*-----------------------------------*/
     if (UNLIKELY(p->initialised != -1))
       csound->PerfError(csound, p->h.insdshead, Str("printks not initialised"));
-    timel =     ((MYFLT) CS_KCNT * CS_ONEDKR) - p->initime;
-
-    /* Divide the current elapsed time by the cycle time and round down to
-     * an integer.     */
-    cycles = MYFLT2LRND(timel / p->ctime);
-    /* printf("cysofar = %d  cycles = %d (%f / %f)\n",
-       p->cysofar, cycles, timel, p->ctime); */
-    /* Now test if the cycle number we are in is higher than the one in which
-     * we last printed.  If so, update cysofar and print.     */
-    if (p->cysofar < cycles) {
-      p->cysofar = cycles;
-      /* Do the print cycle. */
+    if (p->printat <= CS_KCNT-1) {
       //string[0]='\0';           /* incase of empty string */
       memset(string,0,8192);
       if (sprints(string, p->txtstring, p->kvals, p->INOCOUNT-2)==NOTOK)
@@ -1178,12 +1157,13 @@ int printks(CSOUND *csound, PRINTKS *p)
           csound->PerfError(csound,  p->h.insdshead,
                             Str("Insufficient arguments in formatted printing"));
       csound->MessageS(csound, CSOUNDMSG_ORCH, "%s", string);
+      p->printat += p->ctime;
     }
     return OK;
 }
 
 /* matt ingalls --  i-rate prints */
-int printsset(CSOUND *csound, PRINTS *p)
+int32_t printsset(CSOUND *csound, PRINTS *p)
 {
     PRINTKS pk;
     char    string[8192];
@@ -1202,7 +1182,7 @@ int printsset(CSOUND *csound, PRINTS *p)
     return OK;
 }
 
-int printsset_S(CSOUND *csound, PRINTS *p)
+int32_t printsset_S(CSOUND *csound, PRINTS *p)
 {
     PRINTKS pk;
     char   string[8192];
@@ -1234,8 +1214,9 @@ int printsset_S(CSOUND *csound, PRINTS *p)
  *
  * Write the absolute value of the input argument to the output if the former
  * is higher. */
-int peakk(CSOUND *csound, PEAK *p)
+int32_t peakk(CSOUND *csound, PEAK *p)
 {
+   IGN(csound);
     if (*p->kpeakout < FABS(*p->xsigin)) {
       *p->kpeakout = FABS(*p->xsigin);
     }
@@ -1245,8 +1226,9 @@ int peakk(CSOUND *csound, PEAK *p)
 /* peaka()
  *
  * Similar to peakk, but looks at an a rate input variable. */
-int peaka(CSOUND *csound, PEAK *p)
+int32_t peaka(CSOUND *csound, PEAK *p)
 {
+    IGN(csound);
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
@@ -1270,9 +1252,10 @@ int peaka(CSOUND *csound, PEAK *p)
 /* Gab 21-8-97 */
 /* print a k variable each time it changes (useful for MIDI control sliders) */
 
-int printk2set(CSOUND *csound, PRINTK2 *p)
+int32_t printk2set(CSOUND *csound, PRINTK2 *p)
 {
-    p->pspace = (int)*p->space;
+    IGN(csound);
+    p->pspace = (int32_t)*p->space;
     if (UNLIKELY(p->pspace < 0))
       p->pspace = 0;
     else if (UNLIKELY(p->pspace > 120))
@@ -1284,33 +1267,38 @@ int printk2set(CSOUND *csound, PRINTK2 *p)
 /* Gab 21-8-97 */
 /* print a k variable each time it changes (useful for MIDI control sliders) */
 
-int printk2(CSOUND *csound, PRINTK2 *p)
+int32_t printk2(CSOUND *csound, PRINTK2 *p)
 {
     MYFLT   value = *p->val;
 
     if (p->oldvalue != value) {
       csound->MessageS(csound, CSOUNDMSG_ORCH, " i%d ",
-                                               (int)p->h.insdshead->p1.value);
+                                               (int32_t)p->h.insdshead->p1.value);
       if (p->pspace > 0) {
         char  s[128];   /* p->pspace is limited to 120 in printk2set() above */
         memset(s, ' ', (size_t) p->pspace);
         s[p->pspace] = '\0';
         csound->MessageS(csound, CSOUNDMSG_ORCH, "%s", s);
       }
-      csound->MessageS(csound, CSOUNDMSG_ORCH, "%11.5f\n", *p->val);
+      if (*p->named)
+        csound->MessageS(csound, CSOUNDMSG_ORCH, "%s = %11.5f\n",
+                         *p->h.optext->t.inlist->arg, *p->val);
+      else
+        csound->MessageS(csound, CSOUNDMSG_ORCH, "%11.5f\n", *p->val);
       p->oldvalue = value;
     }
     return OK;
 }
 
-int printk3set(CSOUND *csound, PRINTK3 *p)
+int32_t printk3set(CSOUND *csound, PRINTK3 *p)
 {
+    IGN(csound);
     p->oldvalue = FL(-1.12123e35);  /* hack to force printing first value */
     p->sarg = ((STRINGDAT*)p->iformat)->data;
     return OK;
 }
 
-int printk3(CSOUND *csound, PRINTK3 *p)
+int32_t printk3(CSOUND *csound, PRINTK3 *p)
 {
     MYFLT   value = *p->val;
 
@@ -1331,16 +1319,16 @@ int printk3(CSOUND *csound, PRINTK3 *p)
 }
 
 /* inz writes to za space at a rate as many channels as can. */
-int inz(CSOUND *csound, IOZ *p)
+int32_t inz(CSOUND *csound, IOZ *p)
 {
-    int32    indx, i;
-    int     nchns = csound->nchnls;
+    int32_t    indx, i;
+    int32_t     nchns = csound->nchnls;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
     /* Check to see this index is within the limits of za space.     */
-    indx = (int32) *p->ndx;
-    if (UNLIKELY((indx + csound->nchnls) >= csound->zalast)) goto err1;
+    indx = (int32_t) *p->ndx;
+    if (UNLIKELY(indx + csound->nchnls >= csound->zalast)) goto err1;
     else if (UNLIKELY(indx < 0)) goto err2;
     else {
       MYFLT *writeloc;
@@ -1362,14 +1350,14 @@ int inz(CSOUND *csound, IOZ *p)
 }
 
 /* outz reads from za space at a rate to output. */
-int outz(CSOUND *csound, IOZ *p)
+int32_t outz(CSOUND *csound, IOZ *p)
 {
-    int32    indx;
-    int     i;
+    int32_t    indx;
+    int32_t     i;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
-    int     nchns = csound->nchnls;
+    int32_t     nchns = csound->nchnls;
     MYFLT *spout = csound->spraw;
 
     /* Check to see this index is within the limits of za space.    */
