@@ -18,8 +18,8 @@
 
     You should have received a copy of the GNU Lesser General Public
     License along with Csound; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-    02111-1307 USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+    02110-1301 USA
 */
 
 /*      vdelay, multitap, reverb2 coded by Paris Smaragdis 1994 */
@@ -34,9 +34,9 @@
 //#define ESR     (csound->esr/FL(1000.0))
 #define ESR     (csound->esr*FL(0.001))
 
-int vdelset(CSOUND *csound, VDEL *p)            /*  vdelay set-up   */
+int32_t vdelset(CSOUND *csound, VDEL *p)            /*  vdelay set-up   */
 {
-    uint32 n = (int32)(*p->imaxd * ESR)+1;
+    uint32 n = (int32_t)(*p->imaxd * ESR)+1;
 
     if (!*p->istod) {
       if (p->aux.auxp == NULL || (uint32_t)(n * sizeof(MYFLT)) > p->aux.size)
@@ -51,12 +51,12 @@ int vdelset(CSOUND *csound, VDEL *p)            /*  vdelay set-up   */
     return OK;
 }
 
-int vdelay(CSOUND *csound, VDEL *p)               /*      vdelay  routine */
+int32_t vdelay(CSOUND *csound, VDEL *p)               /*      vdelay  routine */
 {
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t nn, nsmps = CS_KSMPS;
-    int32  maxd, indx;
+    int32_t  maxd, indx;
     MYFLT *out = p->sr;     /* assign object data to local variables   */
     MYFLT *in = p->ain;
     MYFLT *del = p->adel;
@@ -75,7 +75,7 @@ int vdelay(CSOUND *csound, VDEL *p)               /*      vdelay  routine */
     if (IS_ASIG_ARG(p->adel)) {          /*      if delay is a-rate      */
       for (nn=offset; nn<nsmps; nn++) {
         MYFLT  fv1, fv2;
-        int32   v1, v2;
+        int32_t   v1, v2;
 
         buf[indx] = in[nn];
         fv1 = indx - (del[nn]) * esr;
@@ -98,8 +98,8 @@ int vdelay(CSOUND *csound, VDEL *p)               /*      vdelay  routine */
         else
           fv2 = FL(0.0);
 
-        v1 = (int32)fv1;
-        v2 = (int32)fv2;
+        v1 = (int32_t)fv1;
+        v2 = (int32_t)fv2;
         out[nn] = buf[v1] + (fv1 - v1) * ( buf[v2] - buf[v1]);
 
         if (UNLIKELY(++indx == maxd))
@@ -111,7 +111,7 @@ int vdelay(CSOUND *csound, VDEL *p)               /*      vdelay  routine */
       MYFLT fdel=*del;
       for (nn=offset; nn<nsmps; nn++) {
         MYFLT  fv1, fv2;
-        int32   v1, v2;
+        int32_t   v1, v2;
 
         buf[indx] = in[nn];
         fv1 = indx - fdel * esr;
@@ -129,8 +129,8 @@ int vdelay(CSOUND *csound, VDEL *p)               /*      vdelay  routine */
         else
           fv2 = FL(0.0);
 
-        v1 = (int32)fv1;
-        v2 = (int32)fv2;
+        v1 = (int32_t)fv1;
+        v2 = (int32_t)fv2;
         out[nn] = buf[v1] + (fv1 - v1) * ( buf[v2] - buf[v1]);
 
         if (UNLIKELY(++indx == maxd)) indx = 0;   /*      Advance current pointer */
@@ -144,12 +144,12 @@ int vdelay(CSOUND *csound, VDEL *p)               /*      vdelay  routine */
                              Str("vdelay: not initialised"));
 }
 
-int vdelay3(CSOUND *csound, VDEL *p)    /*  vdelay routine with cubic interp */
+int32_t vdelay3(CSOUND *csound, VDEL *p)    /*  vdelay routine with cubic interp */
 {
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t nn, nsmps = CS_KSMPS;
-    int32  maxd, indx;
+    int32_t  maxd, indx;
     MYFLT *out = p->sr;  /* assign object data to local variables   */
     MYFLT *in = p->ain;
     MYFLT *del = p->adel;
@@ -169,29 +169,29 @@ int vdelay3(CSOUND *csound, VDEL *p)    /*  vdelay routine with cubic interp */
     if (IS_ASIG_ARG(p->adel)) {              /*      if delay is a-rate      */
       for (nn=offset; nn<nsmps; nn++) {
         MYFLT  fv1;
-        int32   v0, v1, v2, v3;
+        int32_t   v0, v1, v2, v3;
 
         buf[indx] = in[nn];      /* IV Oct 2001 */
         fv1 = del[nn] * (-esr);
-        v1 = (int32)fv1;
+        v1 = (int32_t)fv1;
         fv1 -= (MYFLT) v1;
-        v1 += (int32)indx;
+        v1 += (int32_t)indx;
         /* Make sure Inside the buffer      */
         if ((v1 < 0L) || (fv1 < FL(0.0))) {
-          fv1++; v1--; while (UNLIKELY(v1 < 0L)) v1 += (int32)maxd;
+          fv1++; v1--; while (UNLIKELY(v1 < 0L)) v1 += (int32_t)maxd;
         }
         else {
-          while (UNLIKELY(v1 >= (int32)maxd)) v1 -= (int32)maxd;
+          while (UNLIKELY(v1 >= (int32_t)maxd)) v1 -= (int32_t)maxd;
         }
         /* Find next sample for interpolation      */
-        v2 = (v1 == (int32)(maxd - 1UL) ? 0L : v1 + 1L);
+        v2 = (v1 == (int32_t)(maxd - 1UL) ? 0L : v1 + 1L);
 
         if (maxd<4) {
           out[nn] = buf[v1] + fv1 * (buf[v2] - buf[v1]);
         }
         else {
           v0 = (v1==0 ? maxd-1 : v1-1);
-          v3 = (v2==(int32)maxd-1 ? 0 : v2+1);
+          v3 = (v2==(int32_t)maxd-1 ? 0 : v2+1);
           {                     /* optimized by Istvan Varga (Oct 2001) */
             MYFLT w, x, y, z;
             z = fv1 * fv1; z--; z *= FL(0.1666666667);
@@ -208,24 +208,24 @@ int vdelay3(CSOUND *csound, VDEL *p)    /*  vdelay routine with cubic interp */
     }
     else {                      /* and, if delay is k-rate */
       MYFLT  fv1, w, x, y, z;
-      int32   v0, v1, v2, v3;
+      int32_t   v0, v1, v2, v3;
 
-      fv1 = *del * -esr; v1 = (int32)fv1; fv1 -= (MYFLT) v1;
-      v1 += (int32)indx;
+      fv1 = *del * -esr; v1 = (int32_t)fv1; fv1 -= (MYFLT) v1;
+      v1 += (int32_t)indx;
       /* Make sure Inside the buffer      */
       if ((v1 < 0L) || (fv1 < FL(0.0))) {
-        fv1++; v1--; while (UNLIKELY(v1 < 0L)) v1 += (int32)maxd;
+        fv1++; v1--; while (UNLIKELY(v1 < 0L)) v1 += (int32_t)maxd;
       }
       else {
-        while (UNLIKELY(v1 >= (int32)maxd)) v1 -= (int32)maxd;
+        while (UNLIKELY(v1 >= (int32_t)maxd)) v1 -= (int32_t)maxd;
       }
 
       if (maxd<4) {
         for (nn=offset; nn<nsmps; nn++) {
           /* Find next sample for interpolation      */
-          v2 = (v1 == (int32)(maxd - 1UL) ? 0L : v1 + 1L);
+          v2 = (v1 == (int32_t)(maxd - 1UL) ? 0L : v1 + 1L);
           out[nn] = buf[v1] + fv1 * (buf[v2] - buf[v1]);
-          if (UNLIKELY(++v1 >= (int32)maxd)) v1 -= (int32)maxd;
+          if (UNLIKELY(++v1 >= (int32_t)maxd)) v1 -= (int32_t)maxd;
               if (UNLIKELY(++indx >= maxd)) indx -= maxd;
         }
       }
@@ -237,12 +237,12 @@ int vdelay3(CSOUND *csound, VDEL *p)    /*  vdelay routine with cubic interp */
         for (nn=offset; nn<nsmps; nn++) {
           buf[indx] = in[nn];
           /* Find next sample for interpolation      */
-          v2 = (v1 == (int32)(maxd - 1UL) ? 0L : v1 + 1L);
-          v0 = (v1 == 0L ? (int32)(maxd - 1UL) : v1 - 1L);
-          v3 = (v2 == (int32)(maxd - 1UL) ? 0L : v2 + 1L);
+          v2 = (v1 == (int32_t)(maxd - 1UL) ? 0L : v1 + 1L);
+          v0 = (v1 == 0L ? (int32_t)(maxd - 1UL) : v1 - 1L);
+          v3 = (v2 == (int32_t)(maxd - 1UL) ? 0L : v2 + 1L);
           out[nn] = (w*buf[v0] + x*buf[v1] + y*buf[v2] + z*buf[v3])
                      * fv1 + buf[v1];
-          if (UNLIKELY(++v1 >= (int32)maxd)) v1 -= (int32)maxd;
+          if (UNLIKELY(++v1 >= (int32_t)maxd)) v1 -= (int32_t)maxd;
           if (UNLIKELY(++indx >= maxd))
             indx -= maxd;     /* Advance current pointer */
         }
@@ -258,9 +258,9 @@ int vdelay3(CSOUND *csound, VDEL *p)    /*  vdelay routine with cubic interp */
 /* vdelayx, vdelayxs, vdelayxq, vdelayxw, vdelayxws, vdelayxwq */
 /* coded by Istvan Varga, Mar 2001 */
 
-int vdelxset(CSOUND *csound, VDELX *p)      /*  vdelayx set-up (1 channel) */
+int32_t vdelxset(CSOUND *csound, VDELX *p)      /*  vdelayx set-up (1 channel) */
 {
-    unsigned int n = (int)(*p->imaxd * csound->esr);
+    uint32_t n = (int32_t)(*p->imaxd * csound->esr);
 
     if (UNLIKELY(n == 0)) n = 1;          /* fix due to Troxler */
 
@@ -271,7 +271,7 @@ int vdelxset(CSOUND *csound, VDELX *p)      /*  vdelayx set-up (1 channel) */
       else
         memset(p->aux1.auxp, 0, n*sizeof(MYFLT));
       p->left = 0;
-      p->interp_size = 4 * (int) (FL(0.5) + FL(0.25) * *(p->iquality));
+      p->interp_size = 4 * (int32_t) (FL(0.5) + FL(0.25) * *(p->iquality));
       p->interp_size = (p->interp_size < 4 ? 4 : p->interp_size);
       p->interp_size = (p->interp_size > 1024 ? 1024 : p->interp_size);
     }
@@ -279,9 +279,9 @@ int vdelxset(CSOUND *csound, VDELX *p)      /*  vdelayx set-up (1 channel) */
     return OK;
 }
 
-int vdelxsset(CSOUND *csound, VDELXS *p)    /*  vdelayxs set-up (stereo) */
+int32_t vdelxsset(CSOUND *csound, VDELXS *p)    /*  vdelayxs set-up (stereo) */
 {
-    unsigned int n = (int)(*p->imaxd * csound->esr);
+    uint32_t n = (int32_t)(*p->imaxd * csound->esr);
 
     if (UNLIKELY(n == 0)) n = 1;          /* fix due to Troxler */
 
@@ -297,7 +297,7 @@ int vdelxsset(CSOUND *csound, VDELXS *p)    /*  vdelayxs set-up (stereo) */
         memset(p->aux2.auxp, 0, n*sizeof(MYFLT));
 
       p->left = 0;
-      p->interp_size = 4 * (int) (FL(0.5) + FL(0.25) * *(p->iquality));
+      p->interp_size = 4 * (int32_t) (FL(0.5) + FL(0.25) * *(p->iquality));
       p->interp_size = (p->interp_size < 4 ? 4 : p->interp_size);
       p->interp_size = (p->interp_size > 1024 ? 1024 : p->interp_size);
     }
@@ -305,9 +305,9 @@ int vdelxsset(CSOUND *csound, VDELXS *p)    /*  vdelayxs set-up (stereo) */
     return OK;
 }
 
-int vdelxqset(CSOUND *csound, VDELXQ *p) /* vdelayxq set-up (quad channels) */
+int32_t vdelxqset(CSOUND *csound, VDELXQ *p) /* vdelayxq set-up (quad channels) */
 {
-    unsigned int n = (int)(*p->imaxd * csound->esr);
+    uint32_t n = (int32_t)(*p->imaxd * csound->esr);
 
     if (UNLIKELY(n == 0)) n = 1;          /* fix due to Troxler */
 
@@ -331,7 +331,7 @@ int vdelxqset(CSOUND *csound, VDELXQ *p) /* vdelayxq set-up (quad channels) */
         memset(p->aux4.auxp, 0, n*sizeof(MYFLT));
 
       p->left = 0;
-      p->interp_size = 4 * (int) (FL(0.5) + FL(0.25) * *(p->iquality));
+      p->interp_size = 4 * (int32_t) (FL(0.5) + FL(0.25) * *(p->iquality));
       p->interp_size = (p->interp_size < 4 ? 4 : p->interp_size);
       p->interp_size = (p->interp_size > 1024 ? 1024 : p->interp_size);
     }
@@ -339,19 +339,19 @@ int vdelxqset(CSOUND *csound, VDELXQ *p) /* vdelayxq set-up (quad channels) */
     return OK;
 }
 
-int vdelayx(CSOUND *csound, VDELX *p)               /*      vdelayx routine  */
+int32_t vdelayx(CSOUND *csound, VDELX *p)               /*      vdelayx routine  */
 {
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t nn, nsmps = CS_KSMPS;
-    int32 indx, maxd;
+    int32_t indx, maxd;
     MYFLT *out1 = p->sr1;  /* assign object data to local variables   */
     MYFLT *in1 = p->ain1;
     MYFLT *del = p->adel;
     MYFLT *buf1 = (MYFLT *)p->aux1.auxp;
-    int   wsize = p->interp_size;
+    int32_t   wsize = p->interp_size;
     double x1, x2, w, d, d2x, n1;
-    int32   i, i2, xpos;
+    int32_t   i, i2, xpos;
 
     if (UNLIKELY(buf1 == NULL)) goto err1;                          /* RWD fix */
     maxd = p->maxd;
@@ -375,7 +375,7 @@ int vdelayx(CSOUND *csound, VDELX *p)               /*      vdelayx routine  */
 
       x1 = (double)indx - ((double)del[nn] * (double)csound->esr);
       while (x1 < 0.0) x1 += (double)maxd;
-      xpos = (int32)x1;
+      xpos = (int32_t)x1;
       x1 -= (double)xpos;
       x2 = sin (PI * x1) / PI;
       while (xpos >= maxd) xpos -= maxd;
@@ -395,7 +395,7 @@ int vdelayx(CSOUND *csound, VDELX *p)               /*      vdelayx routine  */
         out1[nn] = (MYFLT) (n1 * x2);
       }
       else {                                            /* integer sample */
-        xpos = (int32)((double)xpos + x1 + 0.5);       /* position */
+        xpos = (int32_t)((double)xpos + x1 + 0.5);      /* position */
         if (UNLIKELY(xpos >= maxd)) xpos -= maxd;
         out1[nn] = buf1[xpos];
       }
@@ -410,19 +410,19 @@ int vdelayx(CSOUND *csound, VDELX *p)               /*      vdelayx routine  */
                              Str("vdelay: not initialised"));
 }
 
-int vdelayxw(CSOUND *csound, VDELX *p)      /*      vdelayxw routine  */
+int32_t vdelayxw(CSOUND *csound, VDELX *p)      /*      vdelayxw routine  */
 {
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t nn, nsmps = CS_KSMPS;
-    int32  maxd, indx;
+    int32_t  maxd, indx;
     MYFLT *out1 = p->sr1;  /* assign object data to local variables   */
     MYFLT *in1 = p->ain1;
     MYFLT *del = p->adel;
     MYFLT *buf1 = (MYFLT *)p->aux1.auxp;
-    int   wsize = p->interp_size;
+    int32_t   wsize = p->interp_size;
     double x1, x2, w, d, d2x, n1;
-    int32   i, i2, xpos;
+    int32_t   i, i2, xpos;
 
     if (UNLIKELY(buf1 == NULL)) goto err1;                          /* RWD fix */
     maxd =  p->maxd;
@@ -443,7 +443,7 @@ int vdelayxw(CSOUND *csound, VDELX *p)      /*      vdelayxw routine  */
 
       x1 = (double)indx + ((double)del[nn] * (double)csound->esr);
       while (x1 < 0.0) x1 += (double)maxd;
-      xpos = (int32)x1;
+      xpos = (int32_t)x1;
       x1 -= (double)xpos;
       x2 = sin (PI * x1) / PI;
       while (xpos >= maxd) xpos -= maxd;
@@ -463,7 +463,7 @@ int vdelayxw(CSOUND *csound, VDELX *p)      /*      vdelayxw routine  */
         }
       }
       else {                                            /* integer sample */
-        xpos = (int32)((double)xpos + x1 + 0.5);       /* position */
+        xpos = (int32_t)((double)xpos + x1 + 0.5);      /* position */
         if (UNLIKELY(xpos >= maxd)) xpos -= maxd;
         buf1[xpos] += in1[nn];
       }
@@ -479,9 +479,9 @@ int vdelayxw(CSOUND *csound, VDELX *p)      /*      vdelayxw routine  */
                              Str("vdelay: not initialised"));
 }
 
-int vdelayxs(CSOUND *csound, VDELXS *p)     /*      vdelayxs routine  */
+int32_t vdelayxs(CSOUND *csound, VDELXS *p)     /*      vdelayxs routine  */
 {
-    int32  maxd, indx;
+    int32_t  maxd, indx;
     MYFLT *out1 = p->sr1;  /* assign object data to local variables   */
     MYFLT *out2 = p->sr2;
     MYFLT *in1 = p->ain1;
@@ -489,9 +489,9 @@ int vdelayxs(CSOUND *csound, VDELXS *p)     /*      vdelayxs routine  */
     MYFLT *del = p->adel;
     MYFLT *buf1 = (MYFLT *)p->aux1.auxp;
     MYFLT *buf2 = (MYFLT *)p->aux2.auxp;
-    int   wsize = p->interp_size;
+    int32_t   wsize = p->interp_size;
     double x1, x2, w, d, d2x, n1, n2;
-    int32   i, i2, xpos;
+    int32_t   i, i2, xpos;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
@@ -522,7 +522,7 @@ int vdelayxs(CSOUND *csound, VDELXS *p)     /*      vdelayxs routine  */
 
       x1 = (double)indx - ((double)del[n] * (double)csound->esr);
       while (UNLIKELY(x1 < 0.0)) x1 += (double)maxd;
-      xpos = (int32)x1;
+      xpos = (int32_t)x1;
       x1 -= (double)xpos;
       x2 = sin (PI * x1) / PI;
       while (UNLIKELY(xpos >= maxd)) xpos -= maxd;
@@ -542,7 +542,7 @@ int vdelayxs(CSOUND *csound, VDELXS *p)     /*      vdelayxs routine  */
         out1[n] = (MYFLT) (n1 * x2); out2[n] = (MYFLT) (n2 * x2);
       }
       else {                                            /* integer sample */
-        xpos = (int32)((double)xpos + x1 + 0.5);       /* position */
+        xpos = (int32_t)((double)xpos + x1 + 0.5);      /* position */
         if (UNLIKELY(xpos >= maxd)) xpos -= maxd;
         out1[n] = buf1[xpos]; out2[n] = buf2[xpos];
       }
@@ -557,12 +557,12 @@ int vdelayxs(CSOUND *csound, VDELXS *p)     /*      vdelayxs routine  */
                              Str("vdelay: not initialised"));
 }
 
-int vdelayxws(CSOUND *csound, VDELXS *p)    /*      vdelayxws routine  */
+int32_t vdelayxws(CSOUND *csound, VDELXS *p)    /*      vdelayxws routine  */
 {
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
-    int32  maxd, indx;
+    int32_t  maxd, indx;
     MYFLT *out1 = p->sr1;  /* assign object data to local variables   */
     MYFLT *out2 = p->sr2;
     MYFLT *in1 = p->ain1;
@@ -570,9 +570,9 @@ int vdelayxws(CSOUND *csound, VDELXS *p)    /*      vdelayxws routine  */
     MYFLT *del = p->adel;
     MYFLT *buf1 = (MYFLT *)p->aux1.auxp;
     MYFLT *buf2 = (MYFLT *)p->aux2.auxp;
-    int   wsize = p->interp_size;
+    int32_t   wsize = p->interp_size;
     double x1, x2, w, d, d2x, n1, n2;
-    int32   i, i2, xpos;
+    int32_t   i, i2, xpos;
 
     if (UNLIKELY((buf1 == NULL) || (buf2 == NULL))) goto err1;     /* RWD fix */
     maxd =  p->maxd;
@@ -597,7 +597,7 @@ int vdelayxws(CSOUND *csound, VDELXS *p)    /*      vdelayxws routine  */
 
       x1 = (double)indx + ((double)del[n] * (double)csound->esr);
       while (UNLIKELY(x1 < 0.0)) x1 += (double)maxd;
-      xpos = (int32)x1;
+      xpos = (int32_t)x1;
       x1 -= (double)xpos;
       x2 = sin (PI * x1) / PI;
       while (UNLIKELY(xpos >= maxd)) xpos -= maxd;
@@ -617,7 +617,7 @@ int vdelayxws(CSOUND *csound, VDELXS *p)    /*      vdelayxws routine  */
         }
       }
       else {                                            /* integer sample */
-        xpos = (int32)((double)xpos + x1 + 0.5);       /* position */
+        xpos = (int32_t)((double)xpos + x1 + 0.5);       /* position */
         if (UNLIKELY(xpos >= maxd)) xpos -= maxd;
         buf1[xpos] += in1[n]; buf2[xpos] += in2[n];
       }
@@ -634,12 +634,12 @@ int vdelayxws(CSOUND *csound, VDELXS *p)    /*      vdelayxws routine  */
                              Str("vdelay: not initialised"));
 }
 
-int vdelayxq(CSOUND *csound, VDELXQ *p)     /*      vdelayxq routine  */
+int32_t vdelayxq(CSOUND *csound, VDELXQ *p)     /*      vdelayxq routine  */
 {
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
-    int32  maxd, indx;
+    int32_t  maxd, indx;
     MYFLT *out1 = p->sr1;  /* assign object data to local variables   */
     MYFLT *out2 = p->sr2;
     MYFLT *out3 = p->sr3;
@@ -653,9 +653,9 @@ int vdelayxq(CSOUND *csound, VDELXQ *p)     /*      vdelayxq routine  */
     MYFLT *buf2 = (MYFLT *)p->aux2.auxp;
     MYFLT *buf3 = (MYFLT *)p->aux3.auxp;
     MYFLT *buf4 = (MYFLT *)p->aux4.auxp;
-    int   wsize = p->interp_size;
+    int32_t   wsize = p->interp_size;
     double x1, x2, w, d, d2x, n1, n2, n3, n4;
-    int32   i, i2, xpos;
+    int32_t   i, i2, xpos;
     /* RWD fix */
     if (UNLIKELY((buf1 == NULL) || (buf2 == NULL) ||
                  (buf3 == NULL) || (buf4 == NULL))) goto err1;
@@ -690,7 +690,7 @@ int vdelayxq(CSOUND *csound, VDELXQ *p)     /*      vdelayxq routine  */
 
       x1 = (double)indx - ((double)*del++ * (double)csound->esr);
       while (UNLIKELY(x1 < 0.0)) x1 += (double)maxd;
-      xpos = (int32)x1;
+      xpos = (int32_t)x1;
       x1 -= (double)xpos;
       x2 = sin (PI * x1) / PI;
       while (UNLIKELY(xpos >= maxd)) xpos -= maxd;
@@ -713,7 +713,7 @@ int vdelayxq(CSOUND *csound, VDELXQ *p)     /*      vdelayxq routine  */
         out3[n] = (MYFLT) (n3 * x2); out4[n] = (MYFLT) (n4 * x2);
       }
       else {                                            /* integer sample */
-        xpos = (int32)((double)xpos + x1 + 0.5);       /* position */
+        xpos = (int32_t)((double)xpos + x1 + 0.5);       /* position */
         if (UNLIKELY(xpos >= maxd)) xpos -= maxd;
         out1[n] = buf1[xpos]; out2[n] = buf2[xpos];
         out3[n] = buf3[xpos]; out4[n] = buf4[xpos];
@@ -729,12 +729,12 @@ int vdelayxq(CSOUND *csound, VDELXQ *p)     /*      vdelayxq routine  */
                              Str("vdelay: not initialised"));
 }
 
-int vdelayxwq(CSOUND *csound, VDELXQ *p)    /*      vdelayxwq routine  */
+int32_t vdelayxwq(CSOUND *csound, VDELXQ *p)    /*      vdelayxwq routine  */
 {
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
-    int32  maxd, indx;
+    int32_t  maxd, indx;
     MYFLT *out1 = p->sr1;  /* assign object data to local variables   */
     MYFLT *out2 = p->sr2;
     MYFLT *out3 = p->sr3;
@@ -748,9 +748,9 @@ int vdelayxwq(CSOUND *csound, VDELXQ *p)    /*      vdelayxwq routine  */
     MYFLT *buf2 = (MYFLT *)p->aux2.auxp;
     MYFLT *buf3 = (MYFLT *)p->aux3.auxp;
     MYFLT *buf4 = (MYFLT *)p->aux4.auxp;
-    int   wsize = p->interp_size;
+    int32_t   wsize = p->interp_size;
     double x1, x2, w, d, d2x, n1, n2, n3, n4;
-    int32   i, i2, xpos;
+    int32_t   i, i2, xpos;
     /* RWD fix */
     if (UNLIKELY((buf1 == NULL) || (buf2 == NULL) ||
                  (buf3 == NULL) || (buf4 == NULL))) goto err1;
@@ -781,7 +781,7 @@ int vdelayxwq(CSOUND *csound, VDELXQ *p)    /*      vdelayxwq routine  */
 
       x1 = (double)indx + ((double)del[n] * (double)csound->esr);
       while (UNLIKELY(x1 < 0.0)) x1 += (double)maxd;
-      xpos = (int32)x1;
+      xpos = (int32_t)x1;
       x1 -= (double)xpos;
       x2 = sin (PI * x1) / PI;
       while (UNLIKELY(xpos >= maxd)) xpos -= maxd;
@@ -804,7 +804,7 @@ int vdelayxwq(CSOUND *csound, VDELXQ *p)    /*      vdelayxwq routine  */
         }
       }
       else {                                            /* integer sample */
-        xpos = (int32)((double)xpos + x1 + 0.5);       /* position */
+        xpos = (int32_t)((double)xpos + x1 + 0.5);       /* position */
         if (UNLIKELY(xpos >= maxd)) xpos -= maxd;
         buf1[xpos] += in1[n]; buf2[xpos] += in2[n];
         buf3[xpos] += in3[n]; buf4[xpos] += in4[n];
@@ -824,7 +824,7 @@ int vdelayxwq(CSOUND *csound, VDELXQ *p)    /*      vdelayxwq routine  */
                              Str("vdelay: not initialised"));
 }
 
-int multitap_set(CSOUND *csound, MDEL *p)
+int32_t multitap_set(CSOUND *csound, MDEL *p)
 {
     uint32_t n, i;
     MYFLT max = FL(0.0);
@@ -847,13 +847,13 @@ int multitap_set(CSOUND *csound, MDEL *p)
     }
 
     p->left = 0;
-    p->max = (int32)(csound->esr * max);
+    p->max = (int32_t)(csound->esr * max);
     return OK;
 }
 
-int multitap_play(CSOUND *csound, MDEL *p)
+int32_t multitap_play(CSOUND *csound, MDEL *p)
 {                               /* assign object data to local variables   */
-    int  indx = p->left, delay;
+    int32_t  indx = p->left, delay;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t i, n, nsmps = CS_KSMPS;
@@ -873,9 +873,9 @@ int multitap_play(CSOUND *csound, MDEL *p)
 
       if (UNLIKELY(++indx == max)) indx = 0;   /*      Advance input pointer   */
       for (i = 0; i < p->INOCOUNT - 1; i += 2) {
-        delay = indx - (int32)(csound->esr * *p->ndel[i]);
+        delay = indx - (int32_t)(csound->esr * *p->ndel[i]);
         if (UNLIKELY(delay < 0))
-          delay += (int32)max;
+          delay += (int32_t)max;
         v += buf[delay] * *p->ndel[i+1]; /*      Write output    */
       }
       out[n] = v;
@@ -891,7 +891,7 @@ int multitap_play(CSOUND *csound, MDEL *p)
 
 #define LOG001  (-6.9077552789821370521)       /* log(.001) */
 
-static const int smallprime[] = {
+static const int32_t smallprime[] = {
   2, 3, 5, 7, 11, 13, 17, 19, 23, 29, 31, 37, 41, 43, 47, 53, 59, 61,
   67, 71, 73, 79, 83, 89, 97, 101, 103, 107, 109, 113, 127, 131, 137,
   139, 149, 151, 157, 163, 167, 173, 179, 181, 191, 193, 197, 199, 211,
@@ -933,15 +933,15 @@ static const int smallprime[] = {
   3463, 3467, 3469, 3491, 3499, 3511, 3517, 3527, 3529, 3533, 3539, 3541,
   3547, 3557, 3559, 3571};
 
-static int prime(int val)
+static int32_t prime(int32_t val)
 {
-    int i, last;
+    int32_t i, last;
     if (val < 3572) {
       for (i = 0; smallprime[i] < val; i++)
         ;
       return (smallprime[i] == val ? 1 : 0);
     }
-    last = (int) sqrt((double)val);
+    last = (int32_t) sqrt((double)val);
     for (i = 0; smallprime[i] < (last < 3572 ? last : 3572); i++) {
       if (UNLIKELY((val % smallprime[i]) == 0))
         return 0;
@@ -995,13 +995,13 @@ static const MYFLT ca_gain[orgAlpas] = {
     FL(0.7), FL(0.7), FL(0.7), FL(0.7), FL(0.7)
 };
 
-int reverbx_set(CSOUND *csound, NREV2 *p)
+int32_t reverbx_set(CSOUND *csound, NREV2 *p)
 {
-    int32  i, n;
+    int32_t  i, n;
     /* Temp holder of old or user constants. */
     const MYFLT *c_orgtime, *a_orgtime;
-    int   c_time, a_time;
-    int   cmbAllocSize, alpAllocSize;
+    int32_t   c_time, a_time;
+    int32_t   cmbAllocSize, alpAllocSize;
 
     if (UNLIKELY(*p->hdif > FL(1.0) || *p->hdif < FL(0.0)))
       return
@@ -1016,7 +1016,7 @@ int reverbx_set(CSOUND *csound, NREV2 *p)
     }
     else {                          /* User provided constants */
       FUNC *ftCombs;
-      p->numCombs = (int) *p->inumCombs;
+      p->numCombs = (int32_t) *p->inumCombs;
       /* Get user-defined set of comb constants from table */
       if (UNLIKELY((ftCombs = csound->FTnp2Find(csound, p->ifnCombs)) == NULL))
         return NOTOK;
@@ -1049,10 +1049,10 @@ int reverbx_set(CSOUND *csound, NREV2 *p)
     }
     else {    /* Have user-defined set of alpas constants */
       FUNC *ftAlpas;
-      p->numAlpas = (int) *p->inumAlpas;
+      p->numAlpas = (int32_t) *p->inumAlpas;
       if (UNLIKELY((ftAlpas = csound->FTnp2Find(csound, p->ifnAlpas)) == NULL))
         return NOTOK;
-      if (UNLIKELY(ftAlpas->flen < (unsigned int)p->numAlpas * 2)) {
+      if (UNLIKELY(ftAlpas->flen < (uint32_t)p->numAlpas * 2)) {
         return csound->InitError(csound, Str("reverbx; Alpas ftable must have"
                                              " %d time and %d gain values"),
                                          p->numAlpas, p->numAlpas);
@@ -1081,10 +1081,10 @@ int reverbx_set(CSOUND *csound, NREV2 *p)
         MYFLT ftime = c_orgtime[i];
         /* Use directly as num samples if negative */
         if (ftime < FL(0.0))
-          c_time = (int) -ftime;
+          c_time = (int32_t) -ftime;
         else {
           /* convert from to seconds to samples, and make prime */
-          c_time = (int) (ftime * csound->esr);
+          c_time = (int32_t) (ftime * csound->esr);
           /* Mangle sample number to primes. */
           if (c_time % 2 == 0)
             c_time += 1;
@@ -1108,17 +1108,17 @@ int reverbx_set(CSOUND *csound, NREV2 *p)
       p->pcbuf_cur[0] = p->cbuf_cur[0] = (MYFLT*)p->caux.auxp;
       for (i = 0; i < p->numCombs; i++) {
         p->pcbuf_cur[i + 1] = p->cbuf_cur[i + 1] =
-          p->cbuf_cur[i] + (int) p->c_time[i];
+          p->cbuf_cur[i] + (int32_t) p->c_time[i];
         p->c_time[i] *= csound->onedsr; /* Scale to save division in reverbx */
       }
       n = 0;
       for (i = 0; i < p->numAlpas; i++) {
         MYFLT ftime = a_orgtime[i];
         if (ftime < FL(0.0))
-          a_time = (int) -ftime;
+          a_time = (int32_t) -ftime;
         else {
           /* convert seconds to samples and make prime */
-          a_time = (int) (ftime * csound->esr);
+          a_time = (int32_t) (ftime * csound->esr);
           if (a_time % 2 == 0)
             a_time += 1;
           while (!prime(a_time))
@@ -1138,7 +1138,7 @@ int reverbx_set(CSOUND *csound, NREV2 *p)
       p->pabuf_cur[0] = p->abuf_cur[0] = (MYFLT*) p->aaux.auxp;
       for (i = 0; i < p->numAlpas; i++) {
         p->pabuf_cur[i + 1] = p->abuf_cur[i + 1] =
-          p->abuf_cur[i] + (int) p->a_time[i];
+          p->abuf_cur[i] + (int32_t) p->a_time[i];
         p->a_time[i] *= csound->onedsr; /* Scale to save division in reverbx */
       }
     }
@@ -1149,9 +1149,9 @@ int reverbx_set(CSOUND *csound, NREV2 *p)
     return OK;
 }
 
-int reverbx(CSOUND *csound, NREV2 *p)
+int32_t reverbx(CSOUND *csound, NREV2 *p)
 {
-    int32   i;
+    int32_t i;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
@@ -1159,8 +1159,8 @@ int reverbx(CSOUND *csound, NREV2 *p)
     MYFLT   gain, z;
     MYFLT   hdif = *p->hdif;
     MYFLT   time = *p->time;
-    int     numCombs = p->numCombs;
-    int     numAlpas = p->numAlpas;
+    int32_t     numCombs = p->numCombs;
+    int32_t     numAlpas = p->numAlpas;
 
     if (UNLIKELY(p->temp.auxp == NULL)) goto err1;
     buf = (MYFLT*) p->temp.auxp;
