@@ -17,11 +17,12 @@
 
     You should have received a copy of the GNU Lesser General Public
     License along with Csound; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-    02111-1307 USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+    02110-1301 USA
 */
 
-#include "csdl.h"
+//#include "csdl.h"
+#include "csoundCore.h"
 #include <math.h>
 
 /* %% bar sound synthesis translated from Mathlab and much changed */
@@ -37,25 +38,25 @@ typedef struct {
     MYFLT   *ipos, *ivel, *iwid;
 
     double  *w, *w1, *w2;
-    int     step, first;
+    int32_t     step, first;
     double  s0, s1, s2, t0, t1;
-    int     bcL, bcR, N;
+    int32_t     bcL, bcR, N;
     AUXCH   w_aux;
 } BAR;
 
-static int bar_init(CSOUND *csound, BAR *p)
+static int32_t bar_init(CSOUND *csound, BAR *p)
 {
-    if (*p->iK >= FL(0.0)) {
-      double  K = *p->iK;       /* ~=3.0  stiffness parameter, dimensionless */
+    if (*p->iK >= FL(0.0) || p->w_aux.auxp == NULL) {
+      double  K = FABS(*p->iK); /* ~=3.0  stiffness parameter, dimensionless */
       double  T30 = *p->iT30;   /* ~=5.0; 30 db decay time (s) */
       double  b = *p->ib;       /* ~=0.001 high-frequency loss parameter
                                    (keep small) */
 
       /* %%%%%%%%%%%%%%%%%% derived parameters */
       double  dt = (double)csound->onedsr;
-      double  sig = (2.0*(double)csound->esr)*(pow(10.0,3.0*dt/T30)-1.0);
-      double  dxmin = sqrt(dt*(b+sqrt(b*b+4*K*K)));
-      int     N = (int) (1.0/dxmin);
+      double  sig = (2.0*(double)CS_ESR)*(pow(10.0,3.0*dt/T30)-1.0);
+      double  dxmin = sqrt(dt*(b+hypot(b, K+K)));
+      int32_t N = (int32_t) (1.0/dxmin);
       double  dx = 1.0/N;
 
       /* %%%%%%%%%%%%%%%%%%% scheme coefficients */
@@ -70,45 +71,56 @@ static int bar_init(CSOUND *csound, BAR *p)
 
       /* %%%%%%%%%%%%%%%%%%%%% create grid functions */
 
-      csound->AuxAlloc(csound, 3L*(long)((N+5)*sizeof(double)), &(p->w_aux));
+      csound->AuxAlloc(csound, (size_t)3*((N+5)*sizeof(double)), &(p->w_aux));
       p->w = (double *) p->w_aux.auxp;
       p->w1 = &(p->w[N + 5]);
       p->w2 = &(p->w1[N + 5]);
       p->step = p->first = 0;
       p->N = N;
     }
+    /*
     else {
-      if (p->w_aux.auxp == NULL)
+      if (UNLIKELY(p->w_aux.auxp == NULL))
         return csound->InitError(csound, Str("No data to continue"));
     }
+    */
     p->first = 0;
 
     return OK;
 }
 
-static int bar_run(CSOUND *csound, BAR *p)
+static int32_t bar_run(CSOUND *csound, BAR *p)
 {
-    double xofreq = TWOPI* (*p->kscan)/csound->esr; /* kspan ~=0.23; */
+    double xofreq = TWOPI* (*p->kscan)/CS_ESR; /* kspan ~=0.23; */
     double xo, xofrac;
-    int xoint;
-    int step = p->step;
-    int first = p->first;
-    int n, N = p->N, rr;
+    int32_t xoint;
+    int32_t step = p->step;
+    int32_t first = p->first;
+    int32_t N = p->N, rr;
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t n, nsmps = CS_KSMPS;
     double *w = p->w, *w1 = p->w1, *w2 = p->w2;
     double s0 = p->s0, s1 = p->s1, s2 = p->s2, t0 = p->t0, t1 = p->t1;
-    int bcL = (int)MYFLT2LONG(*p->kbcL);    /*  boundary condition pair */
-    int bcR = (int)MYFLT2LONG(*p->kbcR);    /*  1: clamped, 2: pivoting, 3: free */
+    /*  boundary condition pair  1: clamped, 2: pivoting, 3: free */
+    int32_t bcL = (int32_t)MYFLT2LONG(*p->kbcL);
+    int32_t bcR = (int32_t)MYFLT2LONG(*p->kbcR);
     double SINNW = sin(xofreq*step); /* these are to calculate sin/cos by */
     double COSNW = cos(xofreq*step); /* formula rather than many calls    */
     double SIN1W = sin(xofreq);      /* Wins in ksmps>4 */
     double COS1W = cos(xofreq);
+    MYFLT *ar = p->ar;
 
-    if ((bcL|bcR)&(~3) && (bcL|bcR)!=0)
-      return csound->PerfError(csound,
-                               Str("Ends but be clamped(1), "
+    if (UNLIKELY((bcL|bcR)&(~3) && (bcL|bcR)!=0))
+      return csound->PerfError(csound, p->h.insdshead,
+                               Str("Ends must be clamped(1), "
                                    "pivoting(2) or free(3)"));
-
-    for (n = 0; n < csound->ksmps; n++) {
+    if (UNLIKELY(offset)) memset(ar, '\0', offset*sizeof(MYFLT));
+    if (UNLIKELY(early)) {
+      nsmps -= early;
+      memset(&ar[nsmps], '\0', early*sizeof(MYFLT));
+    }
+    for (n = offset; n < nsmps; n++) {
       /* Fix ends */
       if (bcL == 3) {
         w1[1] = 2.0*w1[2]-w1[3];
@@ -126,10 +138,10 @@ static int bar_run(CSOUND *csound, BAR *p)
       if (bcR == 3) {
         w1[N+3] = 2.0*w1[N+2]-w1[N+1];
         w1[N+4] = 3.0*w1[N+3]-3.0*w1[N+2]+w1[N+1];
-   }
+      }
       else if (bcR == 1) {
         w1[N+1] = 0.0;
-        w1[N+1] = 0.0;
+        w1[N+2] = 0.0;
       }
       else if (bcR == 2) {
         w1[N+2] = 0.0;
@@ -137,7 +149,7 @@ static int bar_run(CSOUND *csound, BAR *p)
       }
 
       /* Iterate model */
-      for (rr = 0; rr < N; rr++) {
+      for (rr = 0; rr < N+1; rr++) { /* Is N+1 correct here?? */
         w[rr+2] = s0*w1[rr+2] + s1*(w1[rr+3]+w1[rr+1]) + s2*(w1[rr+4]+w1[rr]) +
                   t0*w2[rr+2] + t1*(w2[rr+3]+w2[rr+1]);
       }
@@ -147,7 +159,7 @@ static int bar_run(CSOUND *csound, BAR *p)
         p->first = first = 1;
         for (rr = 0; rr < N; rr++) {
           if (fabs(rr/(double)N - *p->ipos) <= *p->iwid) {
-            w[rr+2] += (1.0/csound->esr)*(*p->ivel)*0.5*
+            w[rr+2] += (1.0/CS_ESR)*(*p->ivel)*0.5*
                 (1.0+cos(PI*fabs(rr/(double)N-(*p->ipos))/(*p->iwid)));
           }
         }
@@ -155,12 +167,12 @@ static int bar_run(CSOUND *csound, BAR *p)
 
       /*  readouts */
 
-      /*       xo = (1.0/3.0) + 0.5*sin(TWOPI*xofreq*(step+1)/csound->esr); */
+      /*       xo = (1.0/3.0) + 0.5*sin(TWOPI*xofreq*(step+1)/CS_ESR); */
       /* sin((N+1)w) = sin(Nw)cos(w) + cos(Nw)sin(w) */
       /* cos((N+1)w) = cos(Nw)cos(w) - sin(Nw)sin(w) */
       /* so can calculate sin on next line by iteration at less cost */
       /* But is xofreq were to change could be difficult! */
-      /*      xo = 0.5 + 0.5*sin(TWOPI*xofreq*(step+1)/csound->esr); */
+      /*      xo = 0.5 + 0.5*sin(TWOPI*xofreq*(step+1)/CS_ESR); */
       {
         double  xx = SINNW*COS1W + COSNW*SIN1W;
         double  yy = COSNW*COS1W - SINNW*SIN1W;
@@ -169,12 +181,12 @@ static int bar_run(CSOUND *csound, BAR *p)
         COSNW = yy;
       }
       xo = 0.5 + 0.5*SINNW;
-      xoint = (int) (xo*N) + 2;
-      xofrac = xo*N - (int)(xo*N);
+      xoint = (int32_t) (xo*N) + 2;
+      xofrac = xo*N - (int32_t)(xo*N);
 
 /*       csound->Message(csound, "xo = %f (%d %f) w=(%f,%f) ",
                          xo, xoint, xofrac, w[xoint], w[xoint+1]); */
-      p->ar[n] = (csound->e0dbfs)*((1.0-xofrac)*w[xoint] + xofrac*w[xoint+1]);
+      ar[n] = (csound->e0dbfs)*((1.0-xofrac)*w[xoint] + xofrac*w[xoint+1]);
       step++;
       {
         double *ww = w2;
@@ -231,49 +243,50 @@ typedef struct {
     MYFLT *rub, *rub1, *rub2;
     MYFLT *s0, *s1, s2, t0, t1;
     MYFLT *hammer_force;
-    int    stereo;
-    int    NS, N, init, step;
-    int    rattle_num, rubber_num;
-    int    hammer_index, hammer_on, hammer_contact;
+    int32_t    stereo;
+    uint32_t    NS;
+    int32_t    N, init, step;
+    uint32_t    rattle_num, rubber_num;
+    int32_t    hammer_index, hammer_on, hammer_contact;
     MYFLT  ham, ham1, ham2;
     AUXCH  auxch;
     RATTLE *rattle;
     RUBBER *rubber;
 } CSPP;
 
-int init_pp(CSOUND *csound, CSPP *p)
+int32_t init_pp(CSOUND *csound, CSPP *p)
 {
     if (*p->K >= FL(0.0)) {
       double K = *p->K; /* stiffness parameter, dimensionless */
       double f0 = *p->ifreq;      /* fundamental freq. (Hz) */
       double T30 = *p->iT30;      /* 30 db decay time (s) */
       double b = *p->ib;          /* high-frequency loss parameter (keep small) */
-      int NS = p->NS = (int)*p->iNS;       /* number of strings */
+      uint32_t NS = p->NS = (int32_t)*p->iNS;       /* number of strings */
       double D = *p->iD;  /* detune parameter (multiple strings) in cents */
                           /* I.e., a total of D cents diff between highest */
                           /* and lowest string in set */
                           /* initialize prepared objects and hammer */
                           /* derived parameters */
       double dt = (double)csound->onedsr;
-      double sig = (2.0*(double)csound->esr)*(pow(10.0,3.0*dt/T30)-1.0);
+      double sig = (2.0*(double)CS_ESR)*(pow(10.0,3.0*dt/T30)-1.0);
 
-      int N, n;
-      double *c, dx, dxmin = 0.0; /* for stability */
+      uint32_t N, n;
+      double *c, /*dx,*/ dxmin = 0.0; /* for stability */
       FUNC  *ftp;
 
       csound->AuxAlloc(csound, NS*sizeof(double), &p->auxch);
       c = (double *)p->auxch.auxp;
 
       if (*p->rattle_tab==FL(0.0) ||
-          (ftp=csound->FTFind(csound, p->rattle_tab)) == NULL) p->rattle_num = 0;
+          (ftp=csound->FTnp2Find(csound, p->rattle_tab)) == NULL) p->rattle_num = 0;
       else {
-        p->rattle_num = (int)(*ftp->ftable);
+        p->rattle_num = (uint32_t)(*ftp->ftable);
         p->rattle = (RATTLE*)(&((MYFLT*)ftp->ftable)[1]);
       }
       if (*p->rubber_tab==FL(0.0) ||
-          (ftp=csound->FTFind(csound, p->rubber_tab)) == NULL) p->rubber_num = 0;
+          (ftp=csound->FTnp2Find(csound, p->rubber_tab)) == NULL) p->rubber_num = 0;
       else {
-        p->rubber_num = (int)(*ftp->ftable);
+        p->rubber_num = (uint32_t)(*ftp->ftable);
         p->rubber = (RUBBER*)(&((MYFLT*)ftp->ftable)[1]);
       }
 
@@ -284,11 +297,11 @@ int init_pp(CSOUND *csound, CSPP *p)
 
       for (n=0; n<NS; n++) {
         double y = c[n]*c[n]*dt*dt+2.0*b*dt;
-        double x = sqrt(y+sqrt(y*y+16.0*K*K*dt*dt))/sqrt(2);
+        double x = sqrt(y+hypot(y,4.0*K*dt))/sqrt(2);
         if (x>dxmin) dxmin = x;
       }
-      N = p->N = (int)(1.0/dxmin);
-      dx = 1.0/(double)N;
+      N = p->N = (uint32_t)(1.0/dxmin);
+      //dx = 1.0/(double)N;
 
       csound->AuxAlloc(csound,
                        3*((1+(N+5))*NS+p->rattle_num+p->rubber_num)*sizeof(MYFLT),
@@ -335,14 +348,16 @@ int init_pp(CSOUND *csound, CSPP *p)
     return OK;
 }
 
-int play_pp(CSOUND *csound, CSPP *p)
+int32_t play_pp(CSOUND *csound, CSPP *p)
 {
     MYFLT *ar = p->ar;
     MYFLT *ar1 = p->ar1;
-    int NS = p->NS;
-    int N = p->N;
-    int step = p->step;
-    int n, t, nsmps = csound->ksmps;
+    uint32_t NS = p->NS;
+    uint32_t N = p->N;
+    int32_t step = p->step;
+    uint32_t offset = p->h.insdshead->ksmps_offset;
+    uint32_t early  = p->h.insdshead->ksmps_no_end;
+    uint32_t t, n, nsmps = CS_KSMPS;
     double dt = csound->onedsr;
     MYFLT *w = p->w, *w1 = p->w1, *w2 = p->w2,
           *rub = p->rub, *rub1 = p->rub1, *rub2 = p->rub2,
@@ -358,8 +373,8 @@ int play_pp(CSOUND *csound, CSPP *p)
     double COS1W2 = 0;
 
     if (p->stereo) {
-      double f1 = (*p->scanfreq - FL(0.5)* *p->scanspread)/csound->esr;
-      double f2 = (*p->scanfreq + FL(0.5)* *p->scanspread)/csound->esr;
+      double f1 = (*p->scanfreq - FL(0.5)* *p->scanspread)/CS_ESR;
+      double f2 = (*p->scanfreq + FL(0.5)* *p->scanspread)/CS_ESR;
       SINNW = sin(f1*TWOPI*step); /* these are to calculate sin/cos by */
       COSNW = cos(f1*TWOPI*step); /* formula rather than many calls    */
       SIN1W = sin(f1*TWOPI);      /* Wins in ksmps>4 */
@@ -370,7 +385,7 @@ int play_pp(CSOUND *csound, CSPP *p)
       COS1W2 = cos(f2*TWOPI);
     }
     else {
-      double f1 = *p->scanfreq/csound->esr;
+      double f1 = *p->scanfreq/CS_ESR;
       SINNW = sin(f1*TWOPI*step); /* these are to calculate sin/cos by */
       COSNW = cos(f1*TWOPI*step); /* formula rather than many calls    */
       SIN1W = sin(f1*TWOPI);      /* Wins in ksmps>4 */
@@ -380,30 +395,39 @@ int play_pp(CSOUND *csound, CSPP *p)
     if (p->init) {
       p->hammer_on = 1;          /*  turns on hammer updating */
       p->hammer_contact = 0;     /* hammer not in contact with string yet */
-      p->hammer_index = 2+(int)(*p->ipos*N);   /* find location of hammer strike */
+      p->hammer_index = 2+(int32_t)(*p->ipos*N); /* find location of hammerstrike */
       p->ham2 = *p->ham_initial;
       p->ham1 = *p->ham_initial+dt*(*p->vel);    /* initialize hammer */
       p->init = 0;
     }
 
-    for (t=0; t<nsmps; t++) {
-      int qq;
+    if (UNLIKELY(offset)) {
+      memset(ar, '\0', offset*sizeof(MYFLT));
+      if (p->stereo) memset(ar1, '\0', offset*sizeof(MYFLT));
+    }
+    if (UNLIKELY(early)) {
+      nsmps -= early;
+      memset(&ar[nsmps], '\0', early*sizeof(MYFLT));
+      if (p->stereo) memset(&ar1[nsmps], '\0', early*sizeof(MYFLT));
+    }
+    for (t=offset; t<nsmps; t++) {
+      uint32_t qq;
       for (n=0; n<NS; n++) p->hammer_force[n] = 0.0;
       /* set boundary conditions on last state w1 */
-      if ((int)*p->kbcl==1) {
+      if ((int32_t)*p->kbcl==1) {
         for (n=0; n<NS; n++)
           w1[n+NS*2] = w1[n+NS*3] = 0.0;
       }
-      else if ((int)*p->kbcl==2) {
+      else if ((int32_t)*p->kbcl==2) {
         for (qq=0; qq<NS; qq++) {
           w1[qq+NS*2] = 0.0;  w1[qq+NS*1] = -w1[qq+NS*3];
         }
       }
-      if ((int)*p->kbcr==1) {
+      if ((int32_t)*p->kbcr==1) {
         for (n=0; n<NS; n++)
           w1[n+NS*(N+2)] = w1[n+NS*(N+1)] = 0.0;
       }
-      else if ((int)*p->kbcr==2) {
+      else if ((int32_t)*p->kbcr==2) {
         for (n=0; n<NS; n++) {
           w1[n+NS*(N+2)] = 0.0;  w1[n+NS*(N+3)] = -w1[n+NS*(N+1)];
         }
@@ -423,7 +447,7 @@ int play_pp(CSOUND *csound, CSPP *p)
       if (p->rattle_num)
         /* do this only if at least one rattle is specified */
         for (qq=0; qq<p->rattle_num; qq++) {
-          int rattle_index = (int)(2+p->rattle[qq].pos*N);
+          int32_t rattle_index = (int32_t)(2+p->rattle[qq].pos*N);
           for (n=0; n<NS; n++) {
             MYFLT pos, force, temp;
             /* calc. pos. diff between center of rattle and string */
@@ -444,7 +468,7 @@ int play_pp(CSOUND *csound, CSPP *p)
       if (p->rubber_num) {
         /* do this only if at least one rubber is specified */
         for (qq=0; qq<p->rubber_num; qq++) {
-          int rubber_index = (int)(2+p->rubber[0].pos*N);
+          int32_t rubber_index = (int32_t)(2+p->rubber[0].pos*N);
           MYFLT force = 0.0;
           for (n=0; n<NS; n++) {
             MYFLT pos;
@@ -495,7 +519,7 @@ int play_pp(CSOUND *csound, CSPP *p)
       {
 #define       xoamp  FL(0.3333)
 #define       xoctr  FL(0.3333)
-        int xoint;
+        int32_t xoint;
         MYFLT xofrac, xo;
         MYFLT out = 0.0;
         double  xx = SINNW*COS1W + COSNW*SIN1W;
@@ -505,7 +529,7 @@ int play_pp(CSOUND *csound, CSPP *p)
         COSNW = yy;
         xo = xoctr + xoamp*SINNW;
         /*        xo = xoctr+xoamp*(MYFLT)sin(TWOPI*(*p->scanfreq)*n*dt); */
-        xoint = (int)(xo*N)+2;
+        xoint = (int32_t)(xo*N)+2;
         xofrac = xo*N - xoint + FL(2.0);
         for (qq=0; qq<NS; qq++) {
           out += (1-xofrac)*w[xoint*NS+qq]+xofrac*w[(xoint+1)*NS+qq];
@@ -517,7 +541,7 @@ int play_pp(CSOUND *csound, CSPP *p)
           yy = COSNW2*COS1W2 - SINNW2*SIN1W2;
           xo = xoctr + xoamp*SINNW2;
           /*        xo = xoctr+xoamp*(MYFLT)sin(TWOPI*(*p->scanfreq)*n*dt); */
-          xoint = (int)(xo*N)+2;
+          xoint = (int32_t)(xo*N)+2;
           xofrac = xo*N - xoint + FL(2.0);
           for (qq=0; qq<NS; qq++) {
             out += (1-xofrac)*w[xoint*NS+qq]+xofrac*w[(xoint+1)*NS+qq];
@@ -529,7 +553,7 @@ int play_pp(CSOUND *csound, CSPP *p)
         step++;
       }
       {
-        int i;
+        uint32_t i;
         void *w3 = w2;
         w2 = w1;
         w1 = w;
@@ -547,12 +571,11 @@ int play_pp(CSOUND *csound, CSPP *p)
 
 #define S(x)    sizeof(x)
 
-static OENTRY localops[] = {
-    {"barmodel", S(BAR), 5, "a", "kkiikiiii", (SUBR) bar_init, NULL,
-     (SUBR) bar_run},
-    { "prepiano", S(CSPP), 5, "mm", "iiiiiikkiiiiiiioo",
-     (SUBR)init_pp, NULL, (SUBR)play_pp }
+static OENTRY bilbar_localops[] = {
+  {"barmodel", S(BAR), 0, 3, "a", "kkiikiiii", (SUBR) bar_init,
+                                               (SUBR) bar_run},
+  { "prepiano", S(CSPP), 0, 3, "mm", "iiiiiikkiiiiiiioo",
+                                (SUBR)init_pp, (SUBR)play_pp },
 };
 
-LINKAGE
-
+LINKAGE_BUILTIN(bilbar_localops)
