@@ -18,8 +18,8 @@
 
     You should have received a copy of the GNU Lesser General Public
     License along with Csound; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-    02111-1307 USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+    02110-1301 USA
 */
 
 /* Opcodes By Gabriel Maldonado, 1999 */
@@ -34,7 +34,7 @@
 
 /* remove a file reference, optionally closing the file */
 
-static CS_NOINLINE int fout_deinit_callback(CSOUND *csound, void *p_)
+static CS_NOINLINE int32_t fout_deinit_callback(CSOUND *csound, void *p_)
 {
     FOUT_FILE         *p = (FOUT_FILE*) p_;
     struct fileinTag  *pp;
@@ -69,13 +69,14 @@ static CS_NOINLINE int fout_deinit_callback(CSOUND *csound, void *p_)
     return OK;
 }
 
-static CS_NOINLINE int fout_open_file(CSOUND *csound, FOUT_FILE *p, void *fp,
-                                      int fileType, MYFLT *iFile, int isString,
-                                      void *fileParams, int forceSync)
+static CS_NOINLINE int32_t fout_open_file(CSOUND *csound, FOUT_FILE *p, void *fp,
+                                          int32_t fileType, MYFLT *iFile,
+                                          int32_t isString,
+                                          void *fileParams, int32_t forceSync)
 {
     STDOPCOD_GLOBALS  *pp = (STDOPCOD_GLOBALS*) csound->stdOp_Env;
     char              *name;
-    int               idx, csFileType, need_deinit = 0;
+    int32_t               idx, csFileType, need_deinit = 0;
 
     if (p != (FOUT_FILE*) NULL) p->async = 0;
     if (fp != NULL) {
@@ -98,7 +99,7 @@ static CS_NOINLINE int fout_open_file(CSOUND *csound, FOUT_FILE *p, void *fp,
     /* else csound->strarg2name(csound, NULL, iFile, "fout.", 0);*/
     else {
       /* or handle to previously opened file */
-      idx = (int) MYFLT2LRND(*iFile);
+      idx = (int32_t) MYFLT2LRND(*iFile);
       if (UNLIKELY(idx < 0 || idx > pp->file_num ||
                    (fileType == CSFILE_STD && pp->file_opened[idx].raw == NULL) ||
                    (fileType != CSFILE_STD && pp->file_opened[idx].file == NULL))) {
@@ -177,13 +178,13 @@ static CS_NOINLINE int fout_open_file(CSOUND *csound, FOUT_FILE *p, void *fp,
     else {
       SNDFILE *sf;
       void    *fd;
-      //int     buf_reqd;
-      int     do_scale = 0;
+      //int32_t     buf_reqd;
+      int32_t     do_scale = 0;
 
       if (fileType == CSFILE_SND_W) {
         do_scale = ((SF_INFO*) fileParams)->format;
         csFileType = csound->sftype2csfiletype(do_scale);
-        if (csound->realtime_audio_flag == 0 || forceSync == 1) {
+        if (csound->oparms->realtime == 0 || forceSync == 1) {
           fd = csound->FileOpen2(csound, &sf, fileType, name, fileParams,
                                 "SFDIR", csFileType, 0);
           p->async = 0;
@@ -198,7 +199,7 @@ static CS_NOINLINE int fout_open_file(CSOUND *csound, FOUT_FILE *p, void *fp,
         p->nchnls = ((SF_INFO*) fileParams)->channels;
       }
       else {
-        if (csound->realtime_audio_flag == 0 || forceSync == 1) {
+        if (csound->oparms->realtime == 0 || forceSync == 1) {
           fd = csound->FileOpen2(csound, &sf, fileType, name, fileParams,
                                  "SFDIR;SSDIR", CSFTYPE_UNKNOWN_AUDIO, 0);
           p->async = 0;
@@ -229,7 +230,7 @@ static CS_NOINLINE int fout_open_file(CSOUND *csound, FOUT_FILE *p, void *fp,
       /* if (CS_KSMPS >= 512)
         buf_reqd = CS_KSMPS * ((SF_INFO*) fileParams)->channels;
       else
-        buf_reqd = (1 + (int)(512 / CS_KSMPS)) * CS_KSMPS
+        buf_reqd = (1 + (int32_t)(512 / CS_KSMPS)) * CS_KSMPS
                    * ((SF_INFO*) fileParams)->channels;
       if (UNLIKELY(buf_reqd > pp->buf_size)) {
         pp->buf_size = buf_reqd;
@@ -272,7 +273,7 @@ static CS_NOINLINE int fout_open_file(CSOUND *csound, FOUT_FILE *p, void *fp,
     return idx;
 }
 
-static int outfile(CSOUND *csound, OUTFILE *p)
+static int32_t outfile(CSOUND *csound, OUTFILE *p)
 {
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
@@ -313,7 +314,7 @@ static int outfile(CSOUND *csound, OUTFILE *p)
     return OK;
 }
 
-static int outfile_array(CSOUND *csound, OUTFILEA *p)
+static int32_t outfile_array(CSOUND *csound, OUTFILEA *p)
 {
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
@@ -356,7 +357,7 @@ static int outfile_array(CSOUND *csound, OUTFILEA *p)
     return OK;
 }
 
-static const int fout_format_table[51] = {
+static const int32_t fout_format_table[51] = {
     /* 0 - 9 */
     (SF_FORMAT_FLOAT | SF_FORMAT_RAW), (SF_FORMAT_PCM_16 | SF_FORMAT_RAW),
     SF_FORMAT_PCM_16, SF_FORMAT_ULAW, SF_FORMAT_PCM_16, SF_FORMAT_PCM_32,
@@ -389,7 +390,7 @@ static const int fout_format_table[51] = {
     (SF_FORMAT_OGG | SF_FORMAT_VORBIS)
 };
 
-static int fout_flush_callback(CSOUND *csound, void *p_)
+static int32_t fout_flush_callback(CSOUND *csound, void *p_)
 {
     OUTFILE            *p = (OUTFILE*) p_;
 
@@ -407,7 +408,7 @@ static int fout_flush_callback(CSOUND *csound, void *p_)
     return OK;
 }
 
-static int fouta_flush_callback(CSOUND *csound, void *p_)
+static int32_t fouta_flush_callback(CSOUND *csound, void *p_)
 {
     OUTFILEA           *p = (OUTFILEA*) p_;
 
@@ -425,14 +426,14 @@ static int fouta_flush_callback(CSOUND *csound, void *p_)
     return OK;
 }
 
-static int outfile_set_S(CSOUND *csound, OUTFILE *p/*, int istring*/)
+static int32_t outfile_set_S(CSOUND *csound, OUTFILE *p/*, int32_t istring*/)
 {
     SF_INFO sfinfo;
-    int     format_, n, buf_reqd;
-    int istring = 1;
+    int32_t     format_, n, buf_reqd;
+    int32_t istring = 1;
 
     memset(&sfinfo, 0, sizeof(SF_INFO));
-    format_ = (int) MYFLT2LRND(*p->iflag);
+    format_ = (int32_t) MYFLT2LRND(*p->iflag);
     if (format_ >= 51)
       sfinfo.format = SF_FORMAT_PCM_16 | SF_FORMAT_RAW;
     else if (format_ < 0) {
@@ -444,7 +445,7 @@ static int outfile_set_S(CSOUND *csound, OUTFILE *p/*, int istring*/)
       sfinfo.format |= FORMAT2SF(csound->oparms->outformat);
     if (!SF2TYPE(sfinfo.format))
       sfinfo.format |= TYPE2SF(csound->oparms->filetyp);
-    sfinfo.samplerate = (int) MYFLT2LRND(CS_ESR);
+    sfinfo.samplerate = (int32_t) MYFLT2LRND(CS_ESR);
     p->nargs = p->INOCOUNT - 2;
     p->buf_pos = 0;
 
@@ -456,7 +457,7 @@ static int outfile_set_S(CSOUND *csound, OUTFILE *p/*, int istring*/)
     if (CS_KSMPS >= 512)
       buf_reqd = CS_KSMPS *  p->nargs;
     else
-      buf_reqd = (1 + (int)(512 / CS_KSMPS)) * CS_KSMPS *  p->nargs;
+      buf_reqd = (1 + (int32_t)(512 / CS_KSMPS)) * CS_KSMPS *  p->nargs;
     if (p->buf.auxp == NULL || p->buf.size < buf_reqd*sizeof(MYFLT)) {
       csound->AuxAlloc(csound, sizeof(MYFLT)*buf_reqd, &p->buf);
     }
@@ -476,22 +477,22 @@ static int outfile_set_S(CSOUND *csound, OUTFILE *p/*, int istring*/)
     return OK;
 }
 
-/* static int outfile_set(CSOUND *csound, OUTFILE *p){ */
+/* static int32_t outfile_set(CSOUND *csound, OUTFILE *p){ */
 /*   return outfile_set_(csound,p,0); */
 /* } */
 
-/* static int outfile_set_S(CSOUND *csound, OUTFILE *p){ */
+/* static int32_t outfile_set_S(CSOUND *csound, OUTFILE *p){ */
 /*   return outfile_set_(csound,p,1); */
 /* } */
 
-static int outfile_set_A(CSOUND *csound, OUTFILEA *p)
+static int32_t outfile_set_A(CSOUND *csound, OUTFILEA *p)
 {
     SF_INFO sfinfo;
-    int     format_, n, buf_reqd;
-    int len = p->tabin->sizes[0];
+    int32_t     format_, n, buf_reqd;
+    int32_t len = p->tabin->sizes[0];
 
     memset(&sfinfo, 0, sizeof(SF_INFO));
-    format_ = (int) MYFLT2LRND(*p->iflag);
+    format_ = (int32_t) MYFLT2LRND(*p->iflag);
      if (format_ >=  51)
       sfinfo.format = SF_FORMAT_PCM_16 | SF_FORMAT_RAW;
     else if (format_ < 0) {
@@ -504,16 +505,16 @@ static int outfile_set_A(CSOUND *csound, OUTFILEA *p)
       sfinfo.format |= FORMAT2SF(csound->oparms->outformat);
     if (!SF2TYPE(sfinfo.format))
       sfinfo.format |= TYPE2SF(csound->oparms->filetyp);
-    sfinfo.samplerate = (int) MYFLT2LRND(CS_ESR);
+    sfinfo.samplerate = (int32_t) MYFLT2LRND(CS_ESR);
     p->buf_pos = 0;
 
     if (CS_KSMPS >= 512)
       buf_reqd = p->guard_pos = CS_KSMPS * len;
     else {
       p->guard_pos = 512 * len;
-      buf_reqd = (1 + (int)(512 / CS_KSMPS)) * p->guard_pos;
+      buf_reqd = (1 + (int32_t)(512 / CS_KSMPS)) * p->guard_pos;
       // Or......
-      //buf_reqd = (1 + (int)(512 / CS_KSMPS)) * CS_KSMPS * len;
+      //buf_reqd = (1 + (int32_t)(512 / CS_KSMPS)) * CS_KSMPS * len;
     }
     if (p->buf.auxp == NULL || p->buf.size < buf_reqd*sizeof(MYFLT)) {
       csound->AuxAlloc(csound, sizeof(MYFLT)*buf_reqd, &p->buf);
@@ -535,10 +536,10 @@ static int outfile_set_A(CSOUND *csound, OUTFILEA *p)
 }
 
 
-static int koutfile(CSOUND *csound, KOUTFILE *p)
+static int32_t koutfile(CSOUND *csound, KOUTFILE *p)
 {
-    int   i, k;
-    int nargs = p->nargs;
+    int32_t   i, k;
+    int32_t nargs = p->nargs;
     MYFLT *buf = (MYFLT *) p->buf.auxp;
 
     for (i = 0, k = p->buf_pos; i < nargs; i++)
@@ -558,10 +559,10 @@ static int koutfile(CSOUND *csound, KOUTFILE *p)
     return OK;
 }
 
-static int koutfile_set_(CSOUND *csound, KOUTFILE *p, int istring)
+static int32_t koutfile_set_(CSOUND *csound, KOUTFILE *p, int32_t istring)
 {
     SF_INFO sfinfo;
-    int     format_, n, buf_reqd;
+    int32_t     format_, n, buf_reqd;
 
     memset(&sfinfo, 0, sizeof(SF_INFO));
     p->nargs = p->INOCOUNT - 2;
@@ -573,9 +574,9 @@ static int koutfile_set_(CSOUND *csound, KOUTFILE *p, int istring)
       p->guard_pos = 512 * p->nargs;
 
     sfinfo.channels = p->nargs;
-    sfinfo.samplerate = (int) MYFLT2LRND(CS_EKR);
-    format_ = (int) MYFLT2LRND(*p->iflag);
-    if ((unsigned int) format_ >= (unsigned int) 10)
+    sfinfo.samplerate = (int32_t) MYFLT2LRND(CS_EKR);
+    format_ = (int32_t) MYFLT2LRND(*p->iflag);
+    if ((uint32_t) format_ >= 10ul)
       sfinfo.format = SF_FORMAT_PCM_16 | SF_FORMAT_RAW;
     else
       sfinfo.format = fout_format_table[format_] | SF_FORMAT_RAW;
@@ -583,7 +584,7 @@ static int koutfile_set_(CSOUND *csound, KOUTFILE *p, int istring)
     if (CS_KSMPS >= 512)
       buf_reqd = CS_KSMPS *  p->nargs;
     else
-      buf_reqd = (1 + (int)(512 / CS_KSMPS)) * CS_KSMPS * p->nargs;
+      buf_reqd = (1 + (int32_t)(512 / CS_KSMPS)) * CS_KSMPS * p->nargs;
     if (p->buf.auxp == NULL || p->buf.size < buf_reqd*sizeof(MYFLT)) {
       csound->AuxAlloc(csound, sizeof(MYFLT)*buf_reqd, &p->buf);
     }
@@ -602,11 +603,11 @@ static int koutfile_set_(CSOUND *csound, KOUTFILE *p, int istring)
     return OK;
 }
 
-static int koutfile_set(CSOUND *csound, KOUTFILE *p){
+static int32_t koutfile_set(CSOUND *csound, KOUTFILE *p){
   return koutfile_set_(csound,p,0);
 }
 
-static int koutfile_set_S(CSOUND *csound, KOUTFILE *p){
+static int32_t koutfile_set_S(CSOUND *csound, KOUTFILE *p){
   return koutfile_set_(csound,p,1);
 }
 
@@ -620,11 +621,11 @@ static int koutfile_set_S(CSOUND *csound, KOUTFILE *p){
 /* open a file and return its handle  */
 /* the handle is simply a stack index */
 
-static int fiopen_(CSOUND *csound, FIOPEN *p, int istring)
+static int32_t fiopen_(CSOUND *csound, FIOPEN *p, int32_t istring)
 {
     char    *omodes[] = {"w", "r", "wb", "rb"};
     FILE    *rfp = (FILE*) NULL;
-    int     idx = (int) MYFLT2LRND(*p->iascii), n;
+    int32_t     idx = (int32_t) MYFLT2LRND(*p->iascii), n;
 
     if (idx < 0 || idx > 3)
       idx = 0;
@@ -639,18 +640,18 @@ static int fiopen_(CSOUND *csound, FIOPEN *p, int istring)
     return OK;
 }
 
-static int fiopen(CSOUND *csound, FIOPEN *p){
+static int32_t fiopen(CSOUND *csound, FIOPEN *p){
     return fiopen_(csound, p, 0);
 }
 
-static int fiopen_S(CSOUND *csound, FIOPEN *p){
+static int32_t fiopen_S(CSOUND *csound, FIOPEN *p){
     return fiopen_(csound, p, 1);
 }
 
-static int ficlose_opcode_(CSOUND *csound, FICLOSE *p, int istring)
+static int32_t ficlose_opcode_(CSOUND *csound, FICLOSE *p, int32_t istring)
 {
     STDOPCOD_GLOBALS  *pp = (STDOPCOD_GLOBALS*) csound->stdOp_Env;
-    int               idx = -1;
+    int32_t               idx = -1;
 
     if (istring || csound->ISSTRCOD(*(p->iFile))) {
       char    *fname = NULL;
@@ -676,7 +677,7 @@ static int ficlose_opcode_(CSOUND *csound, FICLOSE *p, int istring)
       csound->Free(csound, fname);
     }
     else {
-      idx = (int) MYFLT2LRND(*(p->iFile));
+      idx = (int32_t) MYFLT2LRND(*(p->iFile));
       if (UNLIKELY(idx < 0 || idx > pp->file_num ||
                    pp->file_opened[idx].fd == NULL)) {
         csound->Warning(csound,
@@ -705,11 +706,11 @@ static int ficlose_opcode_(CSOUND *csound, FICLOSE *p, int istring)
     return OK;
 }
 
-static int ficlose_opcode(CSOUND *csound, FICLOSE *p){
+static int32_t ficlose_opcode(CSOUND *csound, FICLOSE *p){
     return ficlose_opcode_(csound,p,0);
 }
 
-static int ficlose_opcode_S(CSOUND *csound, FICLOSE *p){
+static int32_t ficlose_opcode_S(CSOUND *csound, FICLOSE *p){
     return ficlose_opcode_(csound,p,1);
 }
 
@@ -717,13 +718,13 @@ static int ficlose_opcode_S(CSOUND *csound, FICLOSE *p){
    fouti  ihandle, iascii, iflag, iarg1 [, iarg2, ...., iargN]
 */
 
-static int ioutfile_set(CSOUND *csound, IOUTFILE *p)
+static int32_t ioutfile_set(CSOUND *csound, IOUTFILE *p)
 {
     STDOPCOD_GLOBALS  *pp = (STDOPCOD_GLOBALS*) csound->stdOp_Env;
     MYFLT   **args = p->argums;
     FILE    *rfil;
     uint32_t j;
-    int     n = (int) MYFLT2LRND(*p->ihandle);
+    int32_t     n = (int32_t) MYFLT2LRND(*p->ihandle);
 
     if (UNLIKELY(n < 0 || n > pp->file_num))
       return csound->InitError(csound, Str("fouti: invalid file handle"));
@@ -731,10 +732,10 @@ static int ioutfile_set(CSOUND *csound, IOUTFILE *p)
     if (UNLIKELY(rfil == NULL))
       return csound->InitError(csound, Str("fouti: invalid file handle"));
     if (*p->iascii == 0) { /* ascii format */
-      switch ((int) MYFLT2LRND(*p->iflag)) {
+      switch ((int32_t) MYFLT2LRND(*p->iflag)) {
       case 1:
         {     /* with prefix (i-statement, p1, p2 and p3) */
-          int     p1 = (int) p->h.insdshead->p1.value;
+          int32_t     p1 = (int32_t) p->h.insdshead->p1.value;
           double  p2 = (double) CS_KCNT * CS_ONEDKR;
           double  p3 = p->h.insdshead->p3.value;
           if (p3 > FL(0.0))
@@ -747,7 +748,7 @@ static int ioutfile_set(CSOUND *csound, IOUTFILE *p)
         if (pp->fout_kreset == 0)
           pp->fout_kreset = CS_KCNT;
         {
-          int p1 = (int) p->h.insdshead->p1.value;
+          int32_t p1 = (int32_t) p->h.insdshead->p1.value;
           double p2 = (double) (CS_KCNT - pp->fout_kreset)
                       * CS_ONEDKR;
           double p3 = p->h.insdshead->p3.value;
@@ -776,7 +777,7 @@ static int ioutfile_set(CSOUND *csound, IOUTFILE *p)
 
 
 
-static int ioutfile_set_r(CSOUND *csound, IOUTFILE_R *p)
+static int32_t ioutfile_set_r(CSOUND *csound, IOUTFILE_R *p)
 {
     STDOPCOD_GLOBALS  *pp = (STDOPCOD_GLOBALS*) csound->stdOp_Env;
     if (p->h.insdshead->xtratim < 1)
@@ -788,30 +789,30 @@ static int ioutfile_set_r(CSOUND *csound, IOUTFILE_R *p)
     return OK;
 }
 
-static int ioutfile_r(CSOUND *csound, IOUTFILE_R *p)
+static int32_t ioutfile_r(CSOUND *csound, IOUTFILE_R *p)
 {
     STDOPCOD_GLOBALS  *pp;
     MYFLT **args;
     FILE  *rfil;
     uint32_t   j;
-    int n;
+    int32_t n;
 
     if (!p->h.insdshead->relesing || !p->done)
       return OK;
 
     pp = (STDOPCOD_GLOBALS*) csound->stdOp_Env;
     args = p->argums;
-    n = (int) MYFLT2LRND(*p->ihandle);
+    n = (int32_t) MYFLT2LRND(*p->ihandle);
     if (UNLIKELY(n < 0 || n > pp->file_num))
       return csound->InitError(csound, Str("fouti: invalid file handle"));
     rfil = pp->file_opened[n].raw;
     if (UNLIKELY(rfil == NULL))
       return csound->InitError(csound, Str("fouti: invalid file handle"));
     if (*p->iascii == 0) { /* ascii format */
-      switch ((int) MYFLT2LRND(*p->iflag)) {
+      switch ((int32_t) MYFLT2LRND(*p->iflag)) {
       case 1:
         {     /* whith prefix (i-statement, p1, p2 and p3) */
-          int p1 = (int) p->h.insdshead->p1.value;
+          int32_t p1 = (int32_t) p->h.insdshead->p1.value;
           double p2 = p->counter * CS_ONEDKR;
           double p3 = (double) (CS_KCNT - p->counter)
                       * CS_ONEDKR;
@@ -820,7 +821,7 @@ static int ioutfile_r(CSOUND *csound, IOUTFILE_R *p)
         break;
       case 2: /* with prefix (start at 0 time) */
         {
-          int p1 = (int) p->h.insdshead->p1.value;
+          int32_t p1 = (int32_t) p->h.insdshead->p1.value;
           double p2 = (p->counter - pp->fout_kreset) * CS_ONEDKR;
           double p3 = (double) (CS_KCNT - p->counter)
                       * CS_ONEDKR;
@@ -848,16 +849,16 @@ static int ioutfile_r(CSOUND *csound, IOUTFILE_R *p)
 
 /*----------------------------------*/
 
-static int infile_set_(CSOUND *csound, INFILE *p, int istring)
+static int32_t infile_set_(CSOUND *csound, INFILE *p, int32_t istring)
 {
     SF_INFO sfinfo;
-    int     n, buf_reqd;
+    int32_t     n, buf_reqd;
     p->nargs = p->INOCOUNT - 3;
     p->currpos = MYFLT2LRND(*p->iskpfrms);
     p->flag = 1;
     memset(&sfinfo, 0, sizeof(SF_INFO));
-    sfinfo.samplerate = (int) MYFLT2LRND(CS_ESR);
-    if ((int) MYFLT2LRND(*p->iflag) == 0)
+    sfinfo.samplerate = (int32_t) MYFLT2LRND(CS_ESR);
+    if ((int32_t) MYFLT2LRND(*p->iflag) == 0)
       sfinfo.format = FORMAT2SF(AE_FLOAT) | TYPE2SF(TYP_RAW);
     else
       sfinfo.format = FORMAT2SF(AE_SHORT) | TYPE2SF(TYP_RAW);
@@ -865,12 +866,12 @@ static int infile_set_(CSOUND *csound, INFILE *p, int istring)
      if (CS_KSMPS >= 512)
       p->frames = CS_KSMPS;
     else
-      p->frames = (int)(512 / CS_KSMPS) * CS_KSMPS;
+      p->frames = (int32_t)(512 / CS_KSMPS) * CS_KSMPS;
 
     if (CS_KSMPS >= 512)
       buf_reqd = CS_KSMPS * sfinfo.channels;
     else
-      buf_reqd = (1 + (int)(512 / CS_KSMPS)) * CS_KSMPS * p->nargs;
+      buf_reqd = (1 + (int32_t)(512 / CS_KSMPS)) * CS_KSMPS * p->nargs;
     if (p->buf.auxp == NULL || p->buf.size < buf_reqd*sizeof(MYFLT)) {
       csound->AuxAlloc(csound, sizeof(MYFLT)*buf_reqd, &p->buf);
     }
@@ -896,15 +897,15 @@ static int infile_set_(CSOUND *csound, INFILE *p, int istring)
     return OK;
 }
 
-static int infile_set(CSOUND *csound, INFILE *p){
+static int32_t infile_set(CSOUND *csound, INFILE *p){
     return infile_set_(csound,p,0);
 }
 
-static int infile_set_S(CSOUND *csound, INFILE *p){
+static int32_t infile_set_S(CSOUND *csound, INFILE *p){
     return infile_set_(csound,p,1);
 }
 
-static inline void tabensure(CSOUND *csound, ARRAYDAT *p, int size)
+static inline void tabensure(CSOUND *csound, ARRAYDAT *p, int32_t size)
 {
     if (p->data==NULL || p->dimensions == 0 ||
         (p->dimensions==1 && p->sizes[0] < size)) {
@@ -913,20 +914,20 @@ static inline void tabensure(CSOUND *csound, ARRAYDAT *p, int size)
       else p->data = (MYFLT*) csound->ReAlloc(csound, p->data, ss);
       p->dimensions = 1;
       p->arrayMemberSize = sizeof(MYFLT);
-      p->sizes = (int*)csound->Malloc(csound, sizeof(int));
+      p->sizes = (int32_t*)csound->Malloc(csound, sizeof(int32_t));
       p->sizes[0] = size;
     }
 }
 
-static int infile_set_A(CSOUND *csound, INFILEA *p)
+static int32_t infile_set_A(CSOUND *csound, INFILEA *p)
 {
     SF_INFO sfinfo;
-    int     n, buf_reqd;
+    int32_t     n, buf_reqd;
     p->currpos = MYFLT2LRND(*p->iskpfrms);
     p->flag = 1;
     memset(&sfinfo, 0, sizeof(SF_INFO));
-    sfinfo.samplerate = (int) MYFLT2LRND(CS_ESR);
-    if ((int) MYFLT2LRND(*p->iflag) == 0)
+    sfinfo.samplerate = (int32_t) MYFLT2LRND(CS_ESR);
+    if ((int32_t) MYFLT2LRND(*p->iflag) == 0)
       sfinfo.format = FORMAT2SF(AE_FLOAT) | TYPE2SF(TYP_RAW);
     else
       sfinfo.format = FORMAT2SF(AE_SHORT) | TYPE2SF(TYP_RAW);
@@ -934,12 +935,12 @@ static int infile_set_A(CSOUND *csound, INFILEA *p)
     if (CS_KSMPS >= 512)
       p->frames = CS_KSMPS;
     else
-      p->frames = (int)(512 / CS_KSMPS) * CS_KSMPS;
+      p->frames = (int32_t)(512 / CS_KSMPS) * CS_KSMPS;
     p->chn = sfinfo.channels;
     if (CS_KSMPS >= 512)
       buf_reqd = CS_KSMPS * sfinfo.channels;
     else
-      buf_reqd = (1 + (int)(512 / CS_KSMPS)) * CS_KSMPS * sfinfo.channels;
+      buf_reqd = (1 + (int32_t)(512 / CS_KSMPS)) * CS_KSMPS * sfinfo.channels;
     if (p->buf.auxp == NULL || p->buf.size < buf_reqd*sizeof(MYFLT)) {
       csound->AuxAlloc(csound, sizeof(MYFLT)*buf_reqd, &p->buf);
     }
@@ -964,7 +965,7 @@ static int infile_set_A(CSOUND *csound, INFILEA *p)
     return OK;
 }
 
-static int infile_act(CSOUND *csound, INFILE *p)
+static int32_t infile_act(CSOUND *csound, INFILE *p)
 {
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
@@ -1018,7 +1019,7 @@ static int infile_act(CSOUND *csound, INFILE *p)
     return OK;
 }
 
-static int infile_arr(CSOUND *csound, INFILEA *p)
+static int32_t infile_arr(CSOUND *csound, INFILEA *p)
 {
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
@@ -1075,14 +1076,14 @@ static int infile_arr(CSOUND *csound, INFILEA *p)
 
 /* ---------------------------- */
 
-static int kinfile_set_(CSOUND *csound, KINFILE *p, int istring)
+static int32_t kinfile_set_(CSOUND *csound, KINFILE *p, int32_t istring)
 {
     SF_INFO sfinfo;
-    int     n, buf_reqd;
+    int32_t     n, buf_reqd;
 
     memset(&sfinfo, 0, sizeof(SF_INFO));
-    sfinfo.samplerate = (int) MYFLT2LRND(CS_EKR);
-    if ((int) MYFLT2LRND(*p->iflag) == 0)
+    sfinfo.samplerate = (int32_t) MYFLT2LRND(CS_EKR);
+    if ((int32_t) MYFLT2LRND(*p->iflag) == 0)
       sfinfo.format = FORMAT2SF(AE_FLOAT) | TYPE2SF(TYP_RAW);
     else
       sfinfo.format = FORMAT2SF(AE_SHORT) | TYPE2SF(TYP_RAW);
@@ -1095,12 +1096,12 @@ static int kinfile_set_(CSOUND *csound, KINFILE *p, int istring)
     if (CS_KSMPS >= 512)
       p->frames = CS_KSMPS;
     else
-      p->frames = (int)(512 / CS_KSMPS) * CS_KSMPS;
+      p->frames = (int32_t)(512 / CS_KSMPS) * CS_KSMPS;
 
     if (CS_KSMPS >= 512)
       buf_reqd = CS_KSMPS *   sfinfo.channels;
     else
-      buf_reqd = (1 + (int)(512 / CS_KSMPS)) * CS_KSMPS * p->nargs;
+      buf_reqd = (1 + (int32_t)(512 / CS_KSMPS)) * CS_KSMPS * p->nargs;
     if (p->buf.auxp == NULL || p->buf.size < buf_reqd*sizeof(MYFLT)) {
       csound->AuxAlloc(csound, sizeof(MYFLT)*buf_reqd, &p->buf);
     }
@@ -1124,19 +1125,19 @@ static int kinfile_set_(CSOUND *csound, KINFILE *p, int istring)
     return OK;
 }
 
-static int kinfile_set(CSOUND *csound, KINFILE *p){
+static int32_t kinfile_set(CSOUND *csound, KINFILE *p){
     return kinfile_set_(csound,p,0);
 }
 
-static int kinfile_set_S(CSOUND *csound, KINFILE *p){
+static int32_t kinfile_set_S(CSOUND *csound, KINFILE *p){
     return kinfile_set_(csound,p,1);
 }
 
 
-static int kinfile(CSOUND *csound, KINFILE *p)
+static int32_t kinfile(CSOUND *csound, KINFILE *p)
 {
-    int   i, k;
-    int nargs = p->nargs;
+    int32_t   i, k;
+    int32_t nargs = p->nargs;
     MYFLT *buf = (MYFLT *) p->buf.auxp;
 
     if (p->flag) {
@@ -1168,13 +1169,13 @@ static int kinfile(CSOUND *csound, KINFILE *p)
     return OK;
 }
 
-static int i_infile_(CSOUND *csound, I_INFILE *p, int istring)
+static int32_t i_infile_(CSOUND *csound, I_INFILE *p, int32_t istring)
 {
-    int     j, n, nargs;
+    int32_t     j, n, nargs;
     FILE    *fp = NULL;
     MYFLT   **args = p->argums;
     char    *omodes[] = {"r", "r", "rb"};
-    int     idx = (int) MYFLT2LRND(*p->iflag);
+    int32_t     idx = (int32_t) MYFLT2LRND(*p->iflag);
 
     if (UNLIKELY(idx < 0 || idx > 2))
       idx = 0;
@@ -1184,11 +1185,11 @@ static int i_infile_(CSOUND *csound, I_INFILE *p, int istring)
       return NOTOK;
 
     nargs = p->INOCOUNT - 3;
-    switch ((int) MYFLT2LRND(*p->iflag)) {
+    switch ((int32_t) MYFLT2LRND(*p->iflag)) {
     case 0: /* ascii file with loop */
       {
         char  cf[64], *cfp;
-        int   cc;
+        int32_t   cc;
       newcycle:
         for (j = 0; j < nargs; j++) {
           cfp = cf;
@@ -1212,7 +1213,7 @@ static int i_infile_(CSOUND *csound, I_INFILE *p, int istring)
     case 1: /* ascii file without loop */
       {
         char  cf[64], *cfp;
-        int   cc;
+        int32_t   cc;
         for (j = 0; j < nargs; j++) {
           cfp = cf;
           while ((*cfp = cc = getc(fp)) == 'i' || isspace(*cfp));
@@ -1247,19 +1248,20 @@ static int i_infile_(CSOUND *csound, I_INFILE *p, int istring)
     return OK;
 }
 
-static int i_infile(CSOUND *csound, I_INFILE *p){
+static int32_t i_infile(CSOUND *csound, I_INFILE *p){
     return i_infile_(csound,p,0);
 }
 
-static int i_infile_S(CSOUND *csound, I_INFILE *p){
+static int32_t i_infile_S(CSOUND *csound, I_INFILE *p){
     return i_infile_(csound,p,1);
 }
 
 
 /*---------------------------*/
 
-static int incr(CSOUND *csound, INCR *p)
+static int32_t incr(CSOUND *csound, INCR *p)
 {
+     IGN(csound);
     MYFLT *avar = p->avar, *aincr = p->aincr;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
@@ -1271,8 +1273,9 @@ static int incr(CSOUND *csound, INCR *p)
     return OK;
 }
 
-static int clear(CSOUND *csound, CLEARS *p)
+static int32_t clear(CSOUND *csound, CLEARS *p)
 {
+     IGN(csound);
     uint32_t   nsmps = CS_KSMPS, j;
 
     for (j = 0; j < p->INOCOUNT; j++) {
@@ -1284,9 +1287,9 @@ static int clear(CSOUND *csound, CLEARS *p)
 /*---------------------------------*/
 /* formatted output to a text file */
 
-static int fprintf_set_(CSOUND *csound, FPRINTF *p, int istring)
+static int32_t fprintf_set_(CSOUND *csound, FPRINTF *p, int32_t istring)
 {
-    int     n;
+    int32_t     n;
     char    *sarg = (char*) p->fmt->data;
     char    *sdest = p->txtstring;
 
@@ -1402,11 +1405,11 @@ static int fprintf_set_(CSOUND *csound, FPRINTF *p, int istring)
     return OK;
 }
 
-static int fprintf_set(CSOUND *csound, FPRINTF *p){
+static int32_t fprintf_set(CSOUND *csound, FPRINTF *p){
     return fprintf_set_(csound,p,0);
 }
 
-static int fprintf_set_S(CSOUND *csound, FPRINTF *p){
+static int32_t fprintf_set_S(CSOUND *csound, FPRINTF *p){
     return fprintf_set_(csound,p,1);
 }
 
@@ -1416,8 +1419,8 @@ static int fprintf_set_S(CSOUND *csound, FPRINTF *p){
 void sprints1(char *outstring,  char *fmt, MYFLT **kvals, int32 numVals)
 {
     char strseg[8192];
-    int len = 8192;
-    int i = 0, j = 0;
+    int32_t len = 8192;
+    int32_t i = 0, j = 0;
     char *segwaiting = 0;
     while (*fmt) {
       if (*fmt == '%') {
@@ -1426,7 +1429,7 @@ void sprints1(char *outstring,  char *fmt, MYFLT **kvals, int32 numVals)
           strseg[i] = '\0';
           switch (*segwaiting) {
           case '%':
-            strncpy(outstring, "%%", len);
+            strNcpy(outstring, "%%", len);
             j--;
             break;
           case 'd':
@@ -1436,7 +1439,7 @@ void sprints1(char *outstring,  char *fmt, MYFLT **kvals, int32 numVals)
           case 'X':
           case 'u':
           case 'c':
-            snprintf(outstring, len, strseg, (int) MYFLT2LRND(*kvals[j]));
+            snprintf(outstring, len, strseg, (int32_t) MYFLT2LRND(*kvals[j]));
             break;
           case 'h':
             snprintf(outstring, len, strseg, (int16) MYFLT2LRND(*kvals[j]));
@@ -1476,7 +1479,7 @@ void sprints1(char *outstring,  char *fmt, MYFLT **kvals, int32 numVals)
       if (segwaiting) {
         switch (*segwaiting) {
           case '%':
-            strncpy(outstring, "%%", len);
+            strNcpy(outstring, "%%", len);
             j--;
             break;
         case 'd':
@@ -1486,13 +1489,13 @@ void sprints1(char *outstring,  char *fmt, MYFLT **kvals, int32 numVals)
         case 'X':
         case 'u':
         case 'c':
-          snprintf(outstring, len, strseg, (int) MYFLT2LRND(*kvals[j]));
+          snprintf(outstring, len, strseg, (int32_t) MYFLT2LRND(*kvals[j]));
           break;
         case 'h':
           snprintf(outstring, len, strseg, (int16) MYFLT2LRND(*kvals[j]));
           break;
         case 'l':
-          snprintf(outstring, len, strseg, (long) MYFLT2LRND(*kvals[j]));
+          snprintf(outstring, len, strseg, (int64_t) MYFLT2LRND(*kvals[j]));
           break;
 
         default:
@@ -1506,7 +1509,7 @@ void sprints1(char *outstring,  char *fmt, MYFLT **kvals, int32 numVals)
 
 }
 
-static int fprintf_k(CSOUND *csound, FPRINTF *p)
+static int32_t fprintf_k(CSOUND *csound, FPRINTF *p)
 {
     char    string[8192];
 
@@ -1518,7 +1521,7 @@ static int fprintf_k(CSOUND *csound, FPRINTF *p)
 }
 
 /* i-rate fprints */
-static int fprintf_i(CSOUND *csound, FPRINTF *p)
+static int32_t fprintf_i(CSOUND *csound, FPRINTF *p)
 {
     char    string[8192];
 
@@ -1530,7 +1533,7 @@ static int fprintf_i(CSOUND *csound, FPRINTF *p)
     return OK;
 }
 
-static int fprintf_i_S(CSOUND *csound, FPRINTF *p)
+static int32_t fprintf_i_S(CSOUND *csound, FPRINTF *p)
 {
     char    string[8192];
 
@@ -1553,17 +1556,17 @@ static OENTRY localops[] = {
         (SUBR) fprintf_set_S,     (SUBR) fprintf_k,   (SUBR) NULL, NULL,},
     { "fprintks.i",   S(FPRINTF),    WR, 3,  "",     "iSM",
         (SUBR) fprintf_set,     (SUBR) fprintf_k,   (SUBR) NULL, NULL},
-     { "vincr",      S(INCR),        0, 4,  "",     "aa",
-        (SUBR) NULL,            (SUBR) NULL,        (SUBR) incr, NULL         },
-    { "clear",      S(CLEARS),      0, 4,  "",     "y",
+     { "vincr",      S(INCR),        0, 2,  "",     "aa",
+        (SUBR) NULL,            (SUBR) incr, NULL         },
+    { "clear",      S(CLEARS),      0, 2,  "",     "y",
 
-        (SUBR) NULL,            (SUBR) NULL,        (SUBR) clear, NULL},
-    { "fout",       S(OUTFILE),     0, 5,  "",     "Siy",
-        (SUBR) outfile_set_S,     (SUBR) NULL,        (SUBR) outfile, NULL},
-    { "fout.A",     S(OUTFILEA),    0, 5,  "",     "Sia[]",
-        (SUBR) outfile_set_A,     (SUBR) NULL,        (SUBR) outfile_array, NULL},
-    /* { "fout.i",       S(OUTFILE),     0, 5,  "",     "iiy", */
-    /*     (SUBR) outfile_set,     (SUBR) NULL,        (SUBR) outfile, NULL}, */
+        (SUBR) NULL,            (SUBR) clear, NULL},
+    { "fout",       S(OUTFILE),     0, 3,  "",     "Siy",
+        (SUBR) outfile_set_S,     (SUBR) outfile, NULL},
+    { "fout.A",     S(OUTFILEA),    0, 3,  "",     "Sia[]",
+        (SUBR) outfile_set_A,     (SUBR) outfile_array, NULL},
+    /* { "fout.i",       S(OUTFILE),     0, 3,  "",     "iiy", */
+    /*     (SUBR) outfile_set,     (SUBR) outfile, NULL}, */
     { "foutk",      S(KOUTFILE),    0, 3,  "",     "Siz",
         (SUBR) koutfile_set_S,    (SUBR) koutfile,    (SUBR) NULL, NULL },
         { "foutk.i",      S(KOUTFILE),    0, 3,  "",     "iiz",
@@ -1582,12 +1585,12 @@ static OENTRY localops[] = {
         (SUBR) ficlose_opcode_S,  (SUBR) NULL,        (SUBR) NULL, NULL},
     { "ficlose.S",  S(FICLOSE),     0, 1,  "",     "i",
         (SUBR) ficlose_opcode,  (SUBR) NULL,        (SUBR) NULL, NULL },
-    { "fin.a",      S(INFILE),      0, 5,  "",      "Siiy",
-        (SUBR) infile_set_S,    (SUBR) NULL,        (SUBR) infile_act, NULL},
-    { "fin.A",      S(INFILEA),      0, 5,  "",     "Siia[]",
-        (SUBR) infile_set_A,    (SUBR) NULL,        (SUBR) infile_arr, NULL},
-    { "fin.i",      S(INFILE),       0, 5,  "",     "iiiy",
-        (SUBR) infile_set,      (SUBR) NULL,        (SUBR) infile_act, NULL},
+    { "fin.a",      S(INFILE),      0, 3,  "",      "Siiy",
+        (SUBR) infile_set_S,    (SUBR) infile_act, NULL},
+    { "fin.A",      S(INFILEA),      0, 3,  "",     "Siia[]",
+        (SUBR) infile_set_A,    (SUBR) infile_arr, NULL},
+    { "fin.i",      S(INFILE),       0, 3,  "",     "iiiy",
+        (SUBR) infile_set,      (SUBR) infile_act, NULL},
     { "fink",       S(KINFILE),      0, 3,  "",     "Siiz",
         (SUBR) kinfile_set_S,     (SUBR) kinfile,     (SUBR) NULL, NULL},
     { "fink.i",       S(KINFILE),    0, 3,  "",     "iiiz",
@@ -1598,8 +1601,8 @@ static OENTRY localops[] = {
         (SUBR) i_infile,        (SUBR) NULL,        (SUBR) NULL, NULL}
 };
 
-int fout_init_(CSOUND *csound)
+int32_t fout_init_(CSOUND *csound)
 {
     return csound->AppendOpcodes(csound, &(localops[0]),
-                                 (int) (sizeof(localops) / sizeof(OENTRY)));
+                                 (int32_t) (sizeof(localops) / sizeof(OENTRY)));
 }
