@@ -17,8 +17,8 @@
 
     You should have received a copy of the GNU Lesser General Public
     License along with Csound; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-    02111-1307 USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+    02110-1301 USA
 */
 
 // #include "csdl.h"
@@ -35,12 +35,13 @@ typedef struct SNDLOAD_OPCODE_ {
     MYFLT   *iLoopMode1, *iLoopStart1, *iLoopEnd1;
 } SNDLOAD_OPCODE;
 
-static int sndload_opcode_init_(CSOUND *csound, SNDLOAD_OPCODE *p, int isstring)
+static int32_t sndload_opcode_init_(CSOUND *csound, SNDLOAD_OPCODE *p,
+                                    int32_t isstring)
 {
     char        *fname;
     SNDMEMFILE  *sf;
     SF_INFO     sfinfo;
-    int         sampleFormat, loopMode;
+    int32_t         sampleFormat, loopMode;
 
     if (isstring) fname = ((STRINGDAT *)p->Sfname)->data;
     else {
@@ -50,35 +51,35 @@ static int sndload_opcode_init_(CSOUND *csound, SNDLOAD_OPCODE *p, int isstring)
         fname = csound->strarg2name(csound, (char*) NULL, p->Sfname, "soundin.", 0);
     }
     memset(&sfinfo, 0, sizeof(SF_INFO));
-    sampleFormat = (int) MYFLT2LRND(*(p->iFormat));
-    sfinfo.format = (int) TYPE2SF(TYP_RAW);
+    sampleFormat = (int32_t) MYFLT2LRND(*(p->iFormat));
+    sfinfo.format = (int32_t) TYPE2SF(TYP_RAW);
     switch (sampleFormat) {
     case -1: sfinfo.format = 0; break;
-    case 0:  sfinfo.format |= (int) FORMAT2SF(csound->oparms->outformat); break;
-    case 1:  sfinfo.format |= (int) FORMAT2SF(AE_CHAR);   break;
-    case 2:  sfinfo.format |= (int) FORMAT2SF(AE_ALAW);   break;
-    case 3:  sfinfo.format |= (int) FORMAT2SF(AE_ULAW);   break;
-    case 4:  sfinfo.format |= (int) FORMAT2SF(AE_SHORT);  break;
-    case 5:  sfinfo.format |= (int) FORMAT2SF(AE_LONG);   break;
-    case 6:  sfinfo.format |= (int) FORMAT2SF(AE_FLOAT);  break;
-    case 7:  sfinfo.format |= (int) FORMAT2SF(AE_UNCH);   break;
-    case 8:  sfinfo.format |= (int) FORMAT2SF(AE_24INT);  break;
-    case 9:  sfinfo.format |= (int) FORMAT2SF(AE_DOUBLE); break;
+    case 0:  sfinfo.format |= (int32_t) FORMAT2SF(csound->oparms->outformat); break;
+    case 1:  sfinfo.format |= (int32_t) FORMAT2SF(AE_CHAR);   break;
+    case 2:  sfinfo.format |= (int32_t) FORMAT2SF(AE_ALAW);   break;
+    case 3:  sfinfo.format |= (int32_t) FORMAT2SF(AE_ULAW);   break;
+    case 4:  sfinfo.format |= (int32_t) FORMAT2SF(AE_SHORT);  break;
+    case 5:  sfinfo.format |= (int32_t) FORMAT2SF(AE_LONG);   break;
+    case 6:  sfinfo.format |= (int32_t) FORMAT2SF(AE_FLOAT);  break;
+    case 7:  sfinfo.format |= (int32_t) FORMAT2SF(AE_UNCH);   break;
+    case 8:  sfinfo.format |= (int32_t) FORMAT2SF(AE_24INT);  break;
+    case 9:  sfinfo.format |= (int32_t) FORMAT2SF(AE_DOUBLE); break;
     default:
       csound->Free(csound, fname);
       return csound->InitError(csound, Str("invalid sample format: %d"),
                                        sampleFormat);
     }
     if (sfinfo.format) {
-      int   tmp;
-      tmp = (int) MYFLT2LRND(*(p->iChannels));
+      int32_t   tmp;
+      tmp = (int32_t) MYFLT2LRND(*(p->iChannels));
       sfinfo.channels = (tmp > 0 ? tmp : 1);
-      tmp = (int) MYFLT2LRND(*(p->iSampleRate));
-      sfinfo.samplerate = (tmp > 0 ? tmp : (int) MYFLT2LRND(CS_ESR));
+      tmp = (int32_t) MYFLT2LRND(*(p->iSampleRate));
+      sfinfo.samplerate = (tmp > 0 ? tmp : (int32_t) MYFLT2LRND(CS_ESR));
     }
     sf = csound->LoadSoundFile(csound, fname,  &sfinfo);
     if (UNLIKELY(sf == NULL)) {
-      int xx = csound->InitError(csound, Str("could not load '%s'"), fname);
+      int32_t xx = csound->InitError(csound, Str("could not load '%s'"), fname);
       csound->Free(csound, fname);
       return xx;
     }
@@ -89,7 +90,7 @@ static int sndload_opcode_init_(CSOUND *csound, SNDLOAD_OPCODE *p, int isstring)
       sf->scaleFac = (double) *(p->iAmpScale);
     if (*(p->iStartOffset) >= FL(0.0))
       sf->startOffs = (double) *(p->iStartOffset);
-    loopMode = (int) MYFLT2LRND(*(p->iLoopMode1));
+    loopMode = (int32_t) MYFLT2LRND(*(p->iLoopMode1));
     if (loopMode >= 0) {
       if (UNLIKELY(loopMode > 3))
         return csound->InitError(csound, Str("invalid loop mode: %d"),
@@ -111,12 +112,12 @@ static int sndload_opcode_init_(CSOUND *csound, SNDLOAD_OPCODE *p, int isstring)
     return OK;
 }
 
-static int sndload_opcode_init(CSOUND *csound, SNDLOAD_OPCODE *p)
+static int32_t sndload_opcode_init(CSOUND *csound, SNDLOAD_OPCODE *p)
 {
     return sndload_opcode_init_(csound,p,0);
 }
 
-static int sndload_opcode_init_S(CSOUND *csound, SNDLOAD_OPCODE *p)
+static int32_t sndload_opcode_init_S(CSOUND *csound, SNDLOAD_OPCODE *p)
 {
     return sndload_opcode_init_(csound,p,1); /* JPff: surely wrong as 0 */
 }
@@ -136,17 +137,17 @@ typedef struct LOSCILX_OPCODE_ {
     MYFLT   *imod1, *ibeg1, *iend1;
     /* -------- */
     int_least64_t   curPos, curPosInc;
-    int             curLoopDir, curLoopMode;
+    int32_t             curLoopDir, curLoopMode;
     int_least64_t   curLoopStart, curLoopEnd;
     MYFLT   prvKcps, frqScale, ampScale, warpFact, winFact;
     void    *dataPtr;
     int32   nFrames;
-    int     nChannels;
-    int     winSize;
-    int     enableWarp;         /* non-zero when downsampling */
-    int     usingFtable;
-    int     arateXamp;
-    int     loopingWholeFile;
+    int32_t     nChannels;
+    int32_t     winSize;
+    int32_t     enableWarp;         /* non-zero when downsampling */
+    int32_t     usingFtable;
+    int32_t     arateXamp;
+    int32_t     loopingWholeFile;
 } LOSCILX_OPCODE;
 
 static inline int_least64_t loscilx_convert_phase(double phs)
@@ -161,25 +162,27 @@ static inline int_least64_t loscilx_convert_phase(double phs)
 
 static inline int32 loscilx_phase_int(int_least64_t phs)
 {
-    int32_t retval = (int32_t) ((uint32_t) ((uint_least64_t) phs >> 32));
+    int64_t retval = (int64_t) ((uint32_t) ((uint_least64_t) phs >> 32));
 #ifndef __i386__
+ #ifndef __arm__
     if ((int32_t) 0x80000000U >= (int32_t) 0)   /* for safety only */
-      retval += (-((int32_t) 0x40000000) << 2);
+      retval += (-((int64_t)((uint32_t) 0x40000000) << 2));
+   #endif
 #endif
-    return retval;
+    return (int32) retval;
 }
 
 static inline double loscilx_phase_frac(int_least64_t phs)
 {
-    return ((double) ((int) (((uint32_t) ((uint_least64_t) phs)
+    return ((double) ((int32_t) (((uint32_t) ((uint_least64_t) phs)
                              & (uint32_t) 0xFFFFFFFFU) >> 1))
             * (1.0 / 2147483648.0));
 }
 
-static int loscilx_opcode_init(CSOUND *csound, LOSCILX_OPCODE *p)
+static int32_t loscilx_opcode_init(CSOUND *csound, LOSCILX_OPCODE *p)
 {
     void    *dataPtr = NULL;
-    int     nChannels, loopMode;
+    int32_t     nChannels, loopMode;
     double  frqScale = 1.0;
 
     p->dataPtr = NULL;
@@ -236,13 +239,13 @@ static int loscilx_opcode_init(CSOUND *csound, LOSCILX_OPCODE *p)
       ftp = csound->FTnp2Find(csound, p->ifn);
       if (ftp == NULL)
         return NOTOK;
-      if (UNLIKELY((int) ftp->nchanls != nChannels))
+      if (UNLIKELY((int32_t) ftp->nchanls != nChannels))
         return csound->InitError(csound, Str("number of output arguments "
                                              "inconsistent with number of "
                                              "sound file channels"));
       dataPtr = (void*) &(ftp->ftable[0]);
       p->curPos = (int_least64_t) 0;
-      switch ((int) ftp->loopmode1) {
+      switch ((int32_t) ftp->loopmode1) {
       case 1:
         p->curLoopMode = 1;
         break;
@@ -273,7 +276,7 @@ static int loscilx_opcode_init(CSOUND *csound, LOSCILX_OPCODE *p)
       p->curPos = loscilx_convert_phase((double) *(p->istrt));
     p->curPosInc = (int_least64_t) 0;
     p->curLoopDir = 1;
-    loopMode = (int) MYFLT2LRND(*(p->imod1));
+    loopMode = (int32_t) MYFLT2LRND(*(p->imod1));
     if (loopMode >= 0) {
       if (UNLIKELY(loopMode > 3))
         return csound->InitError(csound, Str("invalid loop mode: %d"),
@@ -294,14 +297,14 @@ static int loscilx_opcode_init(CSOUND *csound, LOSCILX_OPCODE *p)
     p->prvKcps = FL(0.0);
     p->frqScale = (MYFLT) (frqScale * LOSCILX_PHASE_SCALE);
     p->warpFact = FL(1.0);
-    p->winSize = (int) MYFLT2LRND(*(p->iwsize));
+    p->winSize = (int32_t) MYFLT2LRND(*(p->iwsize));
     if (p->winSize < 1)
       p->winSize = 4;                   /* default to cubic interpolation */
     else if (p->winSize > 2) {
       if (p->winSize > LOSCILX_MAX_INTERP_SIZE)
         p->winSize = LOSCILX_MAX_INTERP_SIZE;
       else
-        p->winSize = (p->winSize + 2) & (~((int) 3));
+        p->winSize = (p->winSize + 2) & (~((int32_t) 3));
       if (p->winSize > 4) {
         /* constant for window calculation */
         p->winFact =
@@ -311,7 +314,7 @@ static int loscilx_opcode_init(CSOUND *csound, LOSCILX_OPCODE *p)
     }
     p->enableWarp = 0;
     if (IS_ASIG_ARG(p->xamp))
-      p->arateXamp = ~((int) 0);        /* used as a bit mask */
+      p->arateXamp = ~((int32_t) 0);        /* used as a bit mask */
     else
       p->arateXamp = 0;
     p->loopingWholeFile = 0;
@@ -361,16 +364,16 @@ static inline void init_sine_gen(double a, double f, double p, double c,
     *x = xx*a; *v = vv*a;
 }
 
-static int loscilx_opcode_perf(CSOUND *csound, LOSCILX_OPCODE *p)
+static int32_t loscilx_opcode_perf(CSOUND *csound, LOSCILX_OPCODE *p)
 {
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t i, nsmps = CS_KSMPS;
-    int     j;
+    int32_t     j;
     double  frac_d, pidwarp_d = 0.0, c = 0.0;
     MYFLT   frac, ampScale, winFact = p->winFact;
     int32   ndx;
-    int     winSmps;
+    int32_t     winSmps;
     float   winBuf[LOSCILX_MAX_INTERP_SIZE];
 
     if (UNLIKELY(p->dataPtr == NULL)) goto err1;
@@ -410,7 +413,7 @@ static int loscilx_opcode_perf(CSOUND *csound, LOSCILX_OPCODE *p)
       tmp1 *= tmp1;
       tmp1 = 1.0 / tmp1;
       tmp2 *= (double) p->warpFact;
-      tmp2 -= (double) ((int) tmp2) + 0.5;
+      tmp2 -= (double) ((int32_t) tmp2) + 0.5;
       tmp2 *= (4.0 * tmp2);
       winFact = (MYFLT) (((double) p->winFact - tmp1) * tmp2 + tmp1);
     }
@@ -457,7 +460,7 @@ static int loscilx_opcode_perf(CSOUND *csound, LOSCILX_OPCODE *p)
         {
           double  d, x, v;
           MYFLT   a0, a1;
-          int     wsized2 = winSmps >> 1;
+          int32_t     wsized2 = winSmps >> 1;
 
           ndx += (int32) (1 - wsized2);
           d = (double) (1 - wsized2) - frac_d;
@@ -597,7 +600,7 @@ static int loscilx_opcode_perf(CSOUND *csound, LOSCILX_OPCODE *p)
         p->ar[1][i] = ar2 * ampScale;
       }
       else {                                    /* generic multichannel code */
-        int     k = 0;
+        int32_t     k = 0;
         do {
           p->ar[k][i] = FL(0.0);
         } while (++k < p->nChannels);
@@ -700,8 +703,8 @@ static OENTRY loscilx_localops[] = {
     (SUBR) sndload_opcode_init, (SUBR) NULL, (SUBR) NULL                      },
  { "sndload.S",  sizeof(SNDLOAD_OPCODE), _QQ, 1,  "",                 "Sooooojjoo",
     (SUBR) sndload_opcode_init_S, (SUBR) NULL, (SUBR) NULL                      },
-  { "loscilx",  sizeof(LOSCILX_OPCODE), TR, 5,  "mmmmmmmmmmmmmmmm", "xkioojjoo",
-    (SUBR) loscilx_opcode_init, (SUBR) NULL, (SUBR) loscilx_opcode_perf       }
+  { "loscilx",  sizeof(LOSCILX_OPCODE), TR, 3,  "mmmmmmmmmmmmmmmm", "xkioojjoo",
+    (SUBR) loscilx_opcode_init, (SUBR) loscilx_opcode_perf       }
 };
 
 LINKAGE_BUILTIN(loscilx_localops)
