@@ -37,15 +37,15 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 /* macro used to wrap an index back to start position if it's out of bounds. */
 #define clip_index(index, from, to) \
-    if (index > (unsigned)(to) || index < (unsigned)(from)) \
-        index = (unsigned)(from);
+    if (index > (uint32_t)(to) || index < (uint32_t)(from)) \
+        index = (uint32_t)(from);
 
 /* here follows routines for maintaining a linked list of grains */
 
 /* initialises a linked list of NODEs */
-static void init_pool(GRAINPOOL *s, unsigned max_grains)
+static void init_pool(GRAINPOOL *s, uint32_t max_grains)
 {
-    unsigned i;
+    uint32_t i;
     NODE **p = &s->grainlist;
     NODE *grainpool = (NODE *)s->mempool;
 
@@ -91,14 +91,14 @@ static void kill_oldest_grain(GRAINPOOL *s, NODE *n)
     n->next = NULL;
 }
 
-static int setup_globals(CSOUND *csound, PARTIKKEL *p)
+static int32_t setup_globals(CSOUND *csound, PARTIKKEL *p)
 {
     PARTIKKEL_GLOBALS *pg;
     PARTIKKEL_GLOBALS_ENTRY **pe;
 
     pg = csound->QueryGlobalVariable(csound, "partikkel");
     if (pg == NULL) {
-      int i;
+      int32_t i;
 
       if (UNLIKELY(csound->CreateGlobalVariable(csound, "partikkel",
                                                 sizeof(PARTIKKEL_GLOBALS)) != 0))
@@ -135,7 +135,7 @@ static int setup_globals(CSOUND *csound, PARTIKKEL *p)
         pg->zzhhhhz_tab->ftable[i] = FL(0.5);
     }
     p->globals = pg;
-    if ((int)*p->opcodeid == 0) {
+    if ((int32_t)*p->opcodeid == 0) {
       /* opcodeid 0 means we do not bother with the sync opcode */
       p->globals_entry = NULL;
       return OK;
@@ -164,11 +164,11 @@ static int setup_globals(CSOUND *csound, PARTIKKEL *p)
  * zscale: 1/(1 << tab->lobits)
  * shift: length of phase register in bits minus length of table in bits
  */
-static inline MYFLT lrplookup(FUNC *tab, unsigned phase, MYFLT zscale,
-                              unsigned shift)
+static inline MYFLT lrplookup(FUNC *tab, uint32_t phase, MYFLT zscale,
+                              uint32_t shift)
 {
-    const unsigned index = phase >> shift;
-    const unsigned mask = (1 << shift) - 1;
+    const uint32_t index = phase >> shift;
+    const uint32_t mask = (1 << shift) - 1;
 
     MYFLT a = tab->ftable[index];
     MYFLT b = tab->ftable[index + 1];
@@ -177,7 +177,7 @@ static inline MYFLT lrplookup(FUNC *tab, unsigned phase, MYFLT zscale,
 }
 
 /* Why not use csound->intpow ? */
-static inline double intpow_(MYFLT x, unsigned n)
+static inline double intpow_(MYFLT x, uint32_t n)
 {
     double ans = 1.0;
 
@@ -192,14 +192,14 @@ static inline double intpow_(MYFLT x, unsigned n)
 
 /* dsf synthesis for trainlets */
 static inline MYFLT dsf(FUNC *tab, GRAIN *grain, double beta, MYFLT zscale,
-                        unsigned cosineshift)
+                        uint32_t cosineshift)
 {
     MYFLT numerator, denominator, cos_beta;
     MYFLT lastharmonic, result;
-    unsigned fbeta, N = grain->harmonics;
+    uint32_t fbeta, N = grain->harmonics;
     const MYFLT a = grain->falloff;
     const MYFLT a_pow_N = grain->falloff_pow_N;
-    fbeta = (unsigned)(beta*(double)UINT_MAX);
+    fbeta = (uint32_t)(beta*(double)UINT_MAX);
 
     cos_beta = lrplookup(tab, fbeta, zscale, cosineshift);
     denominator = FL(1.0) - FL(2.0)*a*cos_beta + a*a;
@@ -217,10 +217,10 @@ static inline MYFLT dsf(FUNC *tab, GRAIN *grain, double beta, MYFLT zscale,
     return result;
 }
 
-static int partikkel_init(CSOUND *csound, PARTIKKEL *p)
+static int32_t partikkel_init(CSOUND *csound, PARTIKKEL *p)
 {
     uint32_t size;
-    int ret;
+    int32_t ret;
 
     if ((ret = setup_globals(csound, p)) != OK)
         return ret;
@@ -290,10 +290,10 @@ static int partikkel_init(CSOUND *csound, PARTIKKEL *p)
     if (UNLIKELY(!p->wavgaintab))
         return INITERROR("unable to load wave gain table");
 
-    p->disttabshift = sizeof(unsigned)*CHAR_BIT -
-                      (unsigned)(log((double)p->disttab->flen)/log(2.0) + 0.5);
-    p->cosineshift = sizeof(unsigned)*CHAR_BIT -
-                     (unsigned)(log((double)p->costab->flen)/log(2.0) + 0.5);
+    p->disttabshift = sizeof(uint32_t)*CHAR_BIT -
+                      (uint32_t)(log((double)p->disttab->flen)/log(2.0) + 0.5);
+    p->cosineshift = sizeof(uint32_t)*CHAR_BIT -
+                     (uint32_t)(log((double)p->costab->flen)/log(2.0) + 0.5);
     p->zscale = FL(1.0)/FL(1 << p->cosineshift);
     p->wavfreqstartindex = p->wavfreqendindex = 0;
     p->gainmaskindex = p->channelmaskindex = 0;
@@ -314,11 +314,11 @@ static int partikkel_init(CSOUND *csound, PARTIKKEL *p)
     if (UNLIKELY(*p->max_grains < FL(1.0)))
         return INITERROR("maximum number of grains needs to be non-zero "
                          "and positive");
-    size = ((unsigned)*p->max_grains)*sizeof(NODE);
+    size = ((uint32_t)*p->max_grains)*sizeof(NODE);
     if (p->aux2.auxp == NULL || p->aux2.size < size)
         csound->AuxAlloc(csound, size, &p->aux2);
     p->gpool.mempool = p->aux2.auxp;
-    init_pool(&p->gpool, (unsigned)*p->max_grains);
+    init_pool(&p->gpool, (uint32_t)*p->max_grains);
 
     /* find out which of the xrate parameters are arate */
     p->grainfreq_arate = IS_ASIG_ARG(p->grainfreq) ? 1 : 0;
@@ -329,15 +329,15 @@ static int partikkel_init(CSOUND *csound, PARTIKKEL *p)
 
 /* n is sample number for which the grain is to be scheduled
  * offset is time offset for grain in seconds, passed separately for hints */
-static int schedule_grain(CSOUND *csound, PARTIKKEL *p, NODE *node, int32 n,
+static int32_t schedule_grain(CSOUND *csound, PARTIKKEL *p, NODE *node, int32 n,
                           double offset)
 {
     /* make a new grain */
     MYFLT startfreqscale, endfreqscale;
     MYFLT maskgain, maskchannel;
     GRAIN *grain = &node->grain;
-    unsigned int i;
-    unsigned int chan;
+    uint32_t i;
+    uint32_t chan;
     MYFLT graingain;
     MYFLT *gainmasks = p->gainmasktab->ftable;
     MYFLT *chanmasks = p->channelmasktab->ftable;
@@ -345,7 +345,7 @@ static int schedule_grain(CSOUND *csound, PARTIKKEL *p, NODE *node, int32 n,
     MYFLT *freqends = p->wavfreqendtab->ftable;
     MYFLT *fmamps = p->fmamptab->ftable;
     MYFLT *wavgains = p->wavgaintab->ftable;
-    unsigned wavgainsindex;
+    uint32_t wavgainsindex;
 
     /* the table boundary limits might well change at any time, so we do the
      * boundary clipping before using it to fetch a value */
@@ -394,18 +394,18 @@ static int schedule_grain(CSOUND *csound, PARTIKKEL *p, NODE *node, int32 n,
     grain->fmenvtab = p->fmenvtab;
 
     /* place a grain in between two channels according to channel mask value */
-    chan = (unsigned)maskchannel;
+    chan = (uint32_t)maskchannel;
     if (UNLIKELY(chan >= p->num_outputs)) {
         return_grain(&p->gpool, node);
         return PERFERROR("channel mask specifies non-existing output channel");
     }
     /* use panning law table if specified */
     if (p->pantab != NULL) {
-        const unsigned tabsize = p->pantab->flen/8;
+        const uint32_t tabsize = p->pantab->flen/8;
         /* offset of pan table for current output pair */
-        const unsigned tab_offset = chan*tabsize;
-        const unsigned offset = (unsigned)((maskchannel - chan)*(tabsize - 1));
-        const unsigned flip_offset = tabsize - 1 - offset;
+        const uint32_t tab_offset = chan*tabsize;
+        const uint32_t offset = (uint32_t)((maskchannel - chan)*(tabsize - 1));
+        const uint32_t flip_offset = tabsize - 1 - offset;
 
         grain->gain1 = p->pantab->ftable[tab_offset + flip_offset];
         grain->gain2 = p->pantab->ftable[tab_offset + offset];
@@ -434,8 +434,8 @@ static int schedule_grain(CSOUND *csound, PARTIKKEL *p, NODE *node, int32 n,
                             ? p->grainphase/p->graininc
                             : 0.0;
     const double rcp_samples = 1.0/dur_samples;
-    grain->start = (unsigned)((double)n + offset*CS_ESR + phase_corr);
-    grain->stop = (unsigned)(grain->start + dur_samples - phase_corr) + 1;
+    grain->start = (uint32_t)((double)n + offset*CS_ESR + phase_corr);
+    grain->stop = (uint32_t)(grain->start + dur_samples - phase_corr) + 1;
     /* set up the four wavetables and dsf to use in the grain */
     for (i = 0; i < 5; ++i) {
         WAVEDATA *curwav = &grain->wav[i];
@@ -467,7 +467,7 @@ static int schedule_grain(CSOUND *csound, PARTIKKEL *p, NODE *node, int32 n,
             nh = 0.5*CS_ESR/fabs(maxfreq);
             if (nh > fabs(*p->harmonics))
                 nh = fabs(*p->harmonics);
-            grain->harmonics = (unsigned)nh + 1;
+            grain->harmonics = (uint32_t)nh + 1;
             if (grain->harmonics < 2)
                 grain->harmonics = 2;
             grain->falloff = *p->falloff;
@@ -545,7 +545,7 @@ static int schedule_grain(CSOUND *csound, PARTIKKEL *p, NODE *node, int32 n,
 }
 
 /* this function schedules the grains that are bound to happen this k-period */
-static int schedule_grains(CSOUND *csound, PARTIKKEL *p)
+static int32_t schedule_grains(CSOUND *csound, PARTIKKEL *p)
 {
     uint32_t koffset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
@@ -603,7 +603,7 @@ static int schedule_grains(CSOUND *csound, PARTIKKEL *p)
             /* first determine time offset for grain */
             if (*p->distribution >= FL(0.0)) {
                 /* positive distrib, choose random point in table */
-                unsigned rnd = csound->RandMT(&p->randstate);
+                uint32_t rnd = csound->RandMT(&p->randstate);
                 offset = p->disttab->ftable[rnd >> p->disttabshift];
                 offset *= *p->distribution;
             } else {
@@ -636,7 +636,7 @@ static int schedule_grains(CSOUND *csound, PARTIKKEL *p)
             /* check first, in case we'll change the above behaviour of
              * killing a grain */
             if (node) {
-                int ret = schedule_grain(csound, p, node, n, offset);
+                int32_t ret = schedule_grain(csound, p, node, n, offset);
 
                 if (ret != OK)
                     return ret;
@@ -662,15 +662,15 @@ static int schedule_grains(CSOUND *csound, PARTIKKEL *p)
 /* NOTE: the main synthesis loop is duplicated for both wavetable and
  * trainlet synthesis for speed */
 static inline void render_wave(PARTIKKEL *p, GRAIN *grain, WAVEDATA *wav,
-                               MYFLT *buf, unsigned stop)
+                               MYFLT *buf, uint32_t stop)
 {
-    unsigned n;
+    uint32_t n;
     double fmenvphase = grain->envphase;
 
     /* wavetable synthesis */
     for (n = grain->start; n < stop; ++n) {
         double tablen = (double)wav->table->flen;
-        unsigned x0;
+        uint32_t x0;
         MYFLT frac, fmenv;
 
         /* make sure phase accumulator stays within bounds */
@@ -680,7 +680,7 @@ static inline void render_wave(PARTIKKEL *p, GRAIN *grain, WAVEDATA *wav,
             wav->phase += tablen;
 
         /* sample table lookup with linear interpolation */
-        x0 = (unsigned)wav->phase;
+        x0 = (uint32_t)wav->phase;
         frac = (MYFLT)(wav->phase - x0);
         buf[n] += lrp(wav->table->ftable[x0], wav->table->ftable[x0 + 1],
                       frac)*wav->gain;
@@ -695,9 +695,9 @@ static inline void render_wave(PARTIKKEL *p, GRAIN *grain, WAVEDATA *wav,
 }
 
 static inline void render_trainlet(PARTIKKEL *p, GRAIN *grain, WAVEDATA *wav,
-                                   MYFLT *buf, unsigned stop)
+                                   MYFLT *buf, uint32_t stop)
 {
-    unsigned n;
+    uint32_t n;
     double fmenvphase = grain->envphase;
 
     /* trainlet synthesis */
@@ -724,11 +724,12 @@ static inline void render_trainlet(PARTIKKEL *p, GRAIN *grain, WAVEDATA *wav,
 /* do the actual waveform synthesis */
 static inline void render_grain(CSOUND *csound, PARTIKKEL *p, GRAIN *grain)
 {
-    int i;
-    unsigned n;
+    IGN(csound);
+    int32_t i;
+    uint32_t n;
     MYFLT *out1 = *(&(p->output1) + grain->chan1);
     MYFLT *out2 = *(&(p->output1) + grain->chan2);
-    unsigned stop = grain->stop > CS_KSMPS
+    uint32_t stop = grain->stop > CS_KSMPS
                     ? CS_KSMPS : grain->stop;
     MYFLT *buf = (MYFLT *)p->aux.auxp;
 
@@ -790,10 +791,10 @@ static inline void render_grain(CSOUND *csound, PARTIKKEL *p, GRAIN *grain)
     memset(buf + grain->start, 0, (stop - grain->start)*sizeof(MYFLT));
 }
 
-static int partikkel(CSOUND *csound, PARTIKKEL *p)
+static int32_t partikkel(CSOUND *csound, PARTIKKEL *p)
 {
-    int ret;
-    unsigned int n;
+    int32_t ret;
+    uint32_t n;
     NODE **nodeptr;
     MYFLT **outputs = &p->output1;
 
@@ -832,12 +833,12 @@ static int partikkel(CSOUND *csound, PARTIKKEL *p)
 }
 
 /* partikkelsync stuff */
-static int partikkelsync_init(CSOUND *csound, PARTIKKEL_SYNC *p)
+static int32_t partikkelsync_init(CSOUND *csound, PARTIKKEL_SYNC *p)
 {
     PARTIKKEL_GLOBALS *pg;
     PARTIKKEL_GLOBALS_ENTRY *pe;
 
-    if (UNLIKELY((int)*p->opcodeid == 0))
+    if (UNLIKELY((int32_t)*p->opcodeid == 0))
         return csound->InitError(csound,
             Str("partikkelsync: opcode id needs to be a non-zero integer"));
     pg = csound->QueryGlobalVariable(csound, "partikkel");
@@ -856,8 +857,9 @@ static int partikkelsync_init(CSOUND *csound, PARTIKKEL_SYNC *p)
     return OK;
 }
 
-static int partikkelsync(CSOUND *csound, PARTIKKEL_SYNC *p)
+static int32_t partikkelsync(CSOUND *csound, PARTIKKEL_SYNC *p)
 {
+   IGN(csound);
     /* write sync pulse data */
     memcpy(p->syncout, p->ge->synctab, CS_KSMPS*sizeof(MYFLT));
     /* write scheduler phase data, if user wanted it */
@@ -870,7 +872,7 @@ static int partikkelsync(CSOUND *csound, PARTIKKEL_SYNC *p)
     return OK;
 }
 
-static int get_global_entry(CSOUND *csound, PARTIKKEL_GLOBALS_ENTRY **entry,
+static int32_t get_global_entry(CSOUND *csound, PARTIKKEL_GLOBALS_ENTRY **entry,
                             MYFLT opcodeid, const char *prefix)
 {
     PARTIKKEL_GLOBALS *pg;
@@ -892,16 +894,17 @@ static int get_global_entry(CSOUND *csound, PARTIKKEL_GLOBALS_ENTRY **entry,
     return OK;
 }
 
-static int partikkelget_init(CSOUND *csound, PARTIKKEL_GET *p)
+static int32_t partikkelget_init(CSOUND *csound, PARTIKKEL_GET *p)
 {
     return get_global_entry(csound, &p->ge, *p->opcodeid, "partikkelget");
 }
 
-static int partikkelget(CSOUND *csound, PARTIKKEL_GET *p)
+static int32_t partikkelget(CSOUND *csound, PARTIKKEL_GET *p)
 {
+    IGN(csound);
     PARTIKKEL *partikkel = p->ge->partikkel;
 
-    switch ((int)*p->index) {
+    switch ((int32_t)*p->index) {
     case 0:
         *p->valout = (MYFLT)partikkel->gainmaskindex;
         break;
@@ -924,33 +927,34 @@ static int partikkelget(CSOUND *csound, PARTIKKEL_GET *p)
     return OK;
 }
 
-static int partikkelset_init(CSOUND *csound, PARTIKKEL_SET *p)
+static int32_t partikkelset_init(CSOUND *csound, PARTIKKEL_SET *p)
 {
     return get_global_entry(csound, &p->ge, *p->opcodeid, "partikkelset");
 }
 
-static int partikkelset(CSOUND *csound, PARTIKKEL_SET *p)
+static int32_t partikkelset(CSOUND *csound, PARTIKKEL_SET *p)
 {
+    IGN(csound);
     PARTIKKEL *partikkel = p->ge->partikkel;
 
-    switch ((int)*p->index) {
+    switch ((int32_t)*p->index) {
     case 0:
-        partikkel->gainmaskindex = (unsigned)*p->value;
+        partikkel->gainmaskindex = (uint32_t)*p->value;
         break;
     case 1:
-        partikkel->wavfreqstartindex = (unsigned)*p->value;
+        partikkel->wavfreqstartindex = (uint32_t)*p->value;
         break;
     case 2:
-        partikkel->wavfreqendindex = (unsigned)*p->value;
+        partikkel->wavfreqendindex = (uint32_t)*p->value;
         break;
     case 3:
-        partikkel->fmampindex = (unsigned)*p->value;
+        partikkel->fmampindex = (uint32_t)*p->value;
         break;
     case 4:
-        partikkel->channelmaskindex = (unsigned)*p->value;
+        partikkel->channelmaskindex = (uint32_t)*p->value;
         break;
     case 5:
-        partikkel->wavgainindex = (unsigned)*p->value;
+        partikkel->wavgainindex = (uint32_t)*p->value;
         break;
     }
     return OK;
@@ -958,18 +962,16 @@ static int partikkelset(CSOUND *csound, PARTIKKEL_SET *p)
 
 static OENTRY partikkel_localops[] = {
     {
-        "partikkel", sizeof(PARTIKKEL), TR, 5,
+     "partikkel", sizeof(PARTIKKEL), TR, 3,
         "ammmmmmm",
         "xkiakiiikkkkikkiiaikikkkikkkkkiaaaakkkkioj",
         (SUBR)partikkel_init,
-        (SUBR)NULL,
         (SUBR)partikkel
     },
     {
-        "partikkelsync", sizeof(PARTIKKEL_SYNC), TR, 5,
+     "partikkelsync", sizeof(PARTIKKEL_SYNC), TR, 3,
         "am", "i",
         (SUBR)partikkelsync_init,
-        (SUBR)NULL,
         (SUBR)partikkelsync
     },
     {
