@@ -17,8 +17,8 @@
 
     You should have received a copy of the GNU Lesser General Public
     License along with Csound; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-    02111-1307 USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+    02110-1301 USA
 */
 
 /**************************************************************/
@@ -31,7 +31,7 @@
 
 /*RWD 10:9:2000 read pvocex file format */
 #include "pvfileio.h"
-static int pvocex_loadfile(CSOUND *, const char *fname, PVREAD *p);
+static int32_t pvocex_loadfile(CSOUND *, const char *fname, PVREAD *p);
 
 #define WLN   1         /* time window is WLN*2*ksmps long */
 #define OPWLEN (2*WLN*ksmps)    /* manifest used for final time wdw */
@@ -68,16 +68,16 @@ static void FetchInOne(
     }
 }
 
-int pvreadset_(CSOUND *csound, PVREAD *p, int stringname)
+int32_t pvreadset_(CSOUND *csound, PVREAD *p, int32_t stringname)
 {
     char      pvfilnam[256];
 
     if (stringname==0){
       if (csound->ISSTRCOD(*p->ifilno))
-        strncpy(pvfilnam,get_arg_string(csound, *p->ifilno), MAXNAME-1);
+        strNcpy(pvfilnam,get_arg_string(csound, *p->ifilno), MAXNAME);
       else csound->strarg2name(csound, pvfilnam, p->ifilno, "pvoc.",0);
     }
-    else strncpy(pvfilnam, ((STRINGDAT *)p->ifilno)->data, MAXNAME-1);
+    else strNcpy(pvfilnam, ((STRINGDAT *)p->ifilno)->data, MAXNAME);
 
     if (pvocex_loadfile(csound, pvfilnam, p) == OK) {
       p->prFlg = 1;
@@ -87,19 +87,19 @@ int pvreadset_(CSOUND *csound, PVREAD *p, int stringname)
     return NOTOK;
 }
 
-int pvreadset(CSOUND *csound, PVREAD *p){
+int32_t pvreadset(CSOUND *csound, PVREAD *p){
     return pvreadset_(csound,p,0);
 }
 
-int pvreadset_S(CSOUND *csound, PVREAD *p){
+int32_t pvreadset_S(CSOUND *csound, PVREAD *p){
     return pvreadset_(csound,p,1);
 }
 
-int pvread(CSOUND *csound, PVREAD *p)
+int32_t pvread(CSOUND *csound, PVREAD *p)
 {
     MYFLT  frIndx;
     MYFLT  buf[2];
-    int    size = pvfrsiz(p);
+    int32_t    size = pvfrsiz(p);
 
     if (UNLIKELY((frIndx = *p->ktimpnt * p->frPrtim) < 0)) goto err1;
     if (frIndx > p->maxFr) {  /* not past last one */
@@ -117,7 +117,7 @@ int pvread(CSOUND *csound, PVREAD *p)
     return csound->PerfError(csound, p->h.insdshead, Str("PVOC timpnt < 0"));
 }
 
-static int pvocex_loadfile(CSOUND *csound, const char *fname, PVREAD *p)
+static int32_t pvocex_loadfile(CSOUND *csound, const char *fname, PVREAD *p)
 {
     PVOCEX_MEMFILE  pp;
 
