@@ -1,6 +1,6 @@
 /*  sndloop.c sndloop flooper pvsarp pvsvoc
 
-(c) Victor Lazzarini, 2004
+Copyright (c) Victor Lazzarini, 2004
 
 This file is part of Csound.
 
@@ -16,8 +16,8 @@ GNU Lesser General Public License for more details.
 
 You should have received a copy of the GNU Lesser General Public
 License along with Csound; if not, write to the Free Software
-Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-02111-1307 USA
+Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+02110-1301 USA
 
 SNDLOOP
 
@@ -131,7 +131,7 @@ typedef struct _sndloop {
   double rp;                /* read pointer  */
   int32  cfds;              /* crossfade in samples */
   int32 durs;               /* duration in samples */
-  int  rst;                 /* reset indicator */
+  int32_t  rst;                 /* reset indicator */
   MYFLT inc;                /* fade in/out increment/decrement */
   MYFLT  a;                 /* fade amp */
 } sndloop;
@@ -145,8 +145,8 @@ typedef struct _flooper {
   int32 strts;   /* start in samples */
   int32  durs;   /* duration in samples */
   double  ndx;   /* table lookup ndx */
-  int nchnls;
-  int   loop_off;
+  int32_t nchnls;
+  int32_t   loop_off;
 } flooper;
 
 
@@ -158,11 +158,11 @@ typedef struct _flooper2 {
   FUNC  *sfunc;  /* function table */
   FUNC *efunc;
   MYFLT count;
-  int lstart, lend,cfade, mode;
+  int32_t lstart, lend,cfade, mode;
   double  ndx[2];    /* table lookup ndx */
-  int firsttime, init;
+  int32_t firsttime, init;
   MYFLT ostart, oend;
-  int nchnls;
+  int32_t nchnls;
 } flooper2;
 
 
@@ -174,10 +174,10 @@ typedef struct _flooper3 {
   FUNC  *sfunc;  /* function table */
   FUNC *efunc;
   int32 count;
-  int lstart, lend,cfade, mode;
+  int32_t lstart, lend,cfade, mode;
   int32  ndx[2];    /* table lookup ndx */
-  int firsttime, init;
-  int lobits,lomask;
+  int32_t firsttime, init;
+  int32_t lobits,lomask;
   MYFLT lodiv;
 } flooper3;
 
@@ -213,7 +213,7 @@ typedef struct _pvsmorph {
   uint32   lastframe;
 } pvsmorph;
 
-static int sndloop_init(CSOUND *csound, sndloop *p)
+static int32_t sndloop_init(CSOUND *csound, sndloop *p)
 {
     p->durs = (int32) (*(p->dur)*CS_ESR); /* dur in samps */
     p->cfds = (int32) (*(p->cfd)*CS_ESR); /* fade in samps */
@@ -231,9 +231,10 @@ static int sndloop_init(CSOUND *csound, sndloop *p)
     return OK;
 }
 
-static int sndloop_process(CSOUND *csound, sndloop *p)
+static int32_t sndloop_process(CSOUND *csound, sndloop *p)
 {
-    int on = (int) *(p->on), recon;
+     IGN(csound);
+    int32_t on = (int32_t) *(p->on), recon;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t i, nsmps = CS_KSMPS;
@@ -276,7 +277,7 @@ static int sndloop_process(CSOUND *csound, sndloop *p)
       }
       else {
         if (on) { /* if opcode is ON */
-          out[i] = buffer[(int)rp]; /* output the looped sound */
+          out[i] = buffer[(int32_t)rp]; /* output the looped sound */
           rp += pitch;        /* read pointer increment */
           while (rp >= durs) rp -= durs; /* wrap-around */
           while (rp < 0) rp += durs;
@@ -296,7 +297,7 @@ static int sndloop_process(CSOUND *csound, sndloop *p)
     return OK;
 }
 
-static int flooper_init(CSOUND *csound, flooper *p)
+static int32_t flooper_init(CSOUND *csound, flooper *p)
 {
     MYFLT *tab, *buffer, a = FL(0.0), inc;
     int32 cfds = (int32) (*(p->cfd)*CS_ESR);     /* fade in samps  */
@@ -367,8 +368,9 @@ static int flooper_init(CSOUND *csound, flooper *p)
     return OK;
 }
 
-static int flooper_process(CSOUND *csound, flooper *p)
+static int32_t flooper_process(CSOUND *csound, flooper *p)
 {
+     IGN(csound);
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t i, nsmps = CS_KSMPS;
@@ -378,7 +380,7 @@ static int flooper_process(CSOUND *csound, flooper *p)
     MYFLT *tab = p->sfunc->ftable;
     double ndx = p->ndx;
     MYFLT  frac;
-    int tndx, loop_off = p->loop_off, nchnls = p->nchnls;
+    int32_t tndx, loop_off = p->loop_off, nchnls = p->nchnls;
 
     if (UNLIKELY(offset)) memset(aout[0], '\0', offset*sizeof(MYFLT));
     if (UNLIKELY(early)) {
@@ -391,7 +393,7 @@ static int flooper_process(CSOUND *csound, flooper *p)
     }
 
     for (i=offset; i < nsmps; i++) {
-      tndx = (int) ndx;
+      tndx = (int32_t) ndx;
       frac = ndx - tndx;
       /* this is the start portion of the sound */
       if (ndx >= 0  && ndx < end && loop_off) {
@@ -409,7 +411,7 @@ static int flooper_process(CSOUND *csound, flooper *p)
           while(ndx >= end) ndx -= end;
           /* wrap-around, if reading backwards */
           while (tndx < 0) tndx += durs;
-          tndx = (int) ndx;
+          tndx = (int32_t) ndx;
         }
         loop_off = 0;
         tndx *= nchnls;
@@ -432,7 +434,7 @@ static int flooper_process(CSOUND *csound, flooper *p)
     return OK;
 }
 
-static int flooper2_init(CSOUND *csound, flooper2 *p)
+static int32_t flooper2_init(CSOUND *csound, flooper2 *p)
 {
 
     p->sfunc = csound->FTnp2Find(csound, p->ifn);  /* function table */
@@ -443,7 +445,7 @@ static int flooper2_init(CSOUND *csound, flooper2 *p)
     else p->efunc = NULL;
 
     if (*p->iskip == 0){
-      p->mode = (int) *p->imode;
+      p->mode = (int32_t) *p->imode;
       if (p->mode == 0 || p->mode == 2){
         if ((p->ndx[0] = *p->start*CS_ESR) < 0)
           p->ndx[0] = 0;
@@ -456,7 +458,7 @@ static int flooper2_init(CSOUND *csound, flooper2 *p)
       p->cfade = 1;
     }
 
-    p->nchnls = (int)(p->OUTOCOUNT);
+    p->nchnls = (int32_t)(p->OUTOCOUNT);
     if(p->nchnls != p->sfunc->nchanls){
       csound->Warning(csound,
        Str("function table channels do not match opcode outputs"));
@@ -464,7 +466,7 @@ static int flooper2_init(CSOUND *csound, flooper2 *p)
     return OK;
 }
 
-static int flooper2_process(CSOUND *csound, flooper2 *p)
+static int32_t flooper2_process(CSOUND *csound, flooper2 *p)
 {
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
@@ -474,10 +476,10 @@ static int flooper2_process(CSOUND *csound, flooper2 *p)
     MYFLT *tab;
     double *ndx = p->ndx;
     MYFLT frac0, frac1, *etab;
-    int loop_end = p->lend, loop_start = p->lstart,
+    int32_t loop_end = p->lend, loop_start = p->lstart,
       crossfade = p->cfade, len;
     MYFLT count = p->count, fadein, fadeout;
-    int *firsttime = &p->firsttime, elen, mode=p->mode,
+    int32_t *firsttime = &p->firsttime, elen, mode=p->mode,
         init = p->init, ijump = *p->ijump;
     uint32 tndx0, tndx1, nchnls, onchnls = p->nchnls;
     FUNC *func;
@@ -487,7 +489,7 @@ static int flooper2_process(CSOUND *csound, flooper2 *p)
     p->sfunc = func;
     if (UNLIKELY(func == NULL))
       return csound->PerfError(csound, p->h.insdshead,
-                               Str("table %d invalid\n"), (int) *p->ifn);
+                               Str("table %d invalid\n"), (int32_t) *p->ifn);
     if (p->ndx[0] >= p->sfunc->flen)
        p->ndx[0] = (double) p->sfunc->flen - 1.0;
 
@@ -521,17 +523,17 @@ static int flooper2_process(CSOUND *csound, flooper2 *p)
     }
 
     if (*firsttime) {
-      int loopsize;
+      int32_t loopsize;
       /* offset non zero only if firsttime */
       if (UNLIKELY(offset)) memset(out, '\0', offset*sizeof(MYFLT));
-      loop_start = (int) (*p->loop_start*sr);
-      loop_end =   (int) (*p->loop_end*sr);
+      loop_start = (int32_t) (*p->loop_start*sr);
+      loop_end =   (int32_t) (*p->loop_end*sr);
       p->lstart = loop_start = loop_start < 0 ? 0 : loop_start;
       p->lend = loop_end =   loop_end > len ? len :
         (loop_end < loop_start ? loop_start : loop_end);
       loopsize = loop_end - loop_start;
       if (*p->crossfade > 0.0)
-       crossfade = (int) (*p->crossfade*sr);
+       crossfade = (int32_t) (*p->crossfade*sr);
       p->ostart = *p->loop_start; p->oend = *p->loop_end;
       if (mode == 1) {
         ndx[0] = (double) loop_end;
@@ -555,7 +557,7 @@ static int flooper2_process(CSOUND *csound, flooper2 *p)
          (p->ostart != *p->loop_start ||
           p->oend != *p->loop_end)) {
         if (*p->ijump > 1)
-          loop_end = (int)(ndx[0] + crossfade);
+          loop_end = (int32_t)(ndx[0] + crossfade);
         loop_start = *p->loop_start*sr;
         p->ostart = *p->loop_start;
         p->oend = *p->loop_end;
@@ -565,7 +567,7 @@ static int flooper2_process(CSOUND *csound, flooper2 *p)
     nchnls = p->sfunc->nchanls;
     for (i=offset; i < nsmps; i++) {
       if (mode == 1){ /* backwards */
-        tndx0 = (int) ndx[0];
+        tndx0 = (int32_t) ndx[0];
         frac0 = ndx[0] - tndx0;
         if (ndx[0] > crossfade + loop_start) {
           tndx0 *= nchnls;
@@ -576,7 +578,7 @@ static int flooper2_process(CSOUND *csound, flooper2 *p)
           }
         }
         else {
-          tndx1 = (int) ndx[1];
+          tndx1 = (int32_t) ndx[1];
           frac1 = ndx[1] - tndx1;
           if (etab==NULL){
             if(crossfade > 0) //27292
@@ -588,8 +590,8 @@ static int flooper2_process(CSOUND *csound, flooper2 *p)
              if(crossfade > 0) //27292
                fadeout = elen*count/crossfade;
             else fadeout = 0.0;
-            fadein = etab[elen - (int)fadeout];
-            fadeout = etab[(int)fadeout];
+            fadein = etab[elen - (int32_t)fadeout];
+            fadeout = etab[(int32_t)fadeout];
           }
           tndx1 *= nchnls;
           tndx0 *= nchnls;
@@ -611,15 +613,15 @@ static int flooper2_process(CSOUND *csound, flooper2 *p)
         ndx[0]-=pitch;
 
         if (ndx[0] <= loop_start) {
-          int loopsize;
-          loop_start = (int) (*p->loop_start*sr);
-          loop_end =   (int) (*p->loop_end*sr);
+          int32_t loopsize;
+          loop_start = (int32_t) (*p->loop_start*sr);
+          loop_end =   (int32_t) (*p->loop_end*sr);
           p->lstart = loop_start = loop_start < 0 ? 0 : loop_start;
           p->lend = loop_end =   loop_end > len ? len :
             (loop_end < loop_start ? loop_start : loop_end);
           loopsize = loop_end - loop_start;
           if(*p->crossfade > 0.0)
-            crossfade = (int) (*p->crossfade*sr);
+            crossfade = (int32_t) (*p->crossfade*sr);
           p->cfade = crossfade = crossfade > loopsize ? loopsize : crossfade;
           ndx[0] = ndx[1];
           ndx[1] =  (double)loop_end;
@@ -633,7 +635,7 @@ static int flooper2_process(CSOUND *csound, flooper2 *p)
         if(onchnls == 2) out[1] = 0.0;
         /* this is the forward reader */
         if (init && ndx[0] < loop_start + crossfade) {
-          tndx0 = (int) ndx[0];
+          tndx0 = (int32_t) ndx[0];
           frac0 = ndx[0] - tndx0;
           tndx0 *= nchnls;
           out[0] = amp*(tab[tndx0] + frac0*(tab[tndx0+nchnls] - tab[tndx0]));
@@ -645,8 +647,8 @@ static int flooper2_process(CSOUND *csound, flooper2 *p)
         }
         else if (ndx[0] < loop_start + crossfade) {
           if (etab==NULL) fadein = count/crossfade;
-          else fadein = etab[(int)(elen*count/crossfade)];
-          tndx0 = (int) ndx[0];
+          else fadein = etab[(int32_t)(elen*count/crossfade)];
+          tndx0 = (int32_t) ndx[0];
           frac0 = ndx[0] - tndx0;
           tndx0 *= nchnls;
           out[0] += amp*fadein*(tab[tndx0] + frac0*(tab[tndx0+nchnls] -
@@ -660,7 +662,7 @@ static int flooper2_process(CSOUND *csound, flooper2 *p)
           count  += pitch;
         }
         else if (ndx[0] < loop_end - crossfade) {
-          tndx0 = (int) ndx[0];
+          tndx0 = (int32_t) ndx[0];
           frac0 = ndx[0] - tndx0;
           tndx0 *= nchnls;
           out[0] = amp*(tab[tndx0] + frac0*(tab[tndx0+nchnls] - tab[tndx0]));
@@ -677,8 +679,8 @@ static int flooper2_process(CSOUND *csound, flooper2 *p)
         }
         else if (ndx[0] < loop_end) {
           if (etab==NULL) fadeout = FL(1.0) - count/crossfade;
-          else  fadeout = etab[(int)(elen*(1.0 - count/crossfade))];
-          tndx0 = (int) ndx[0];
+          else  fadeout = etab[(int32_t)(elen*(1.0 - count/crossfade))];
+          tndx0 = (int32_t) ndx[0];
           frac0 = ndx[0] - tndx0;
           tndx0 *= nchnls;
           out[0] += amp*fadeout*(tab[tndx0] + frac0*(tab[tndx0+nchnls] -
@@ -694,8 +696,8 @@ static int flooper2_process(CSOUND *csound, flooper2 *p)
         /* this is the backward reader */
         if (ndx[1] > loop_end - crossfade) {
           if (etab==NULL) fadein = count/crossfade;
-          else fadein = etab[(int)(elen*count/crossfade)];
-          tndx1 = (int) ndx[1];
+          else fadein = etab[(int32_t)(elen*count/crossfade)];
+          tndx1 = (int32_t) ndx[1];
           frac1 = ndx[1] - tndx1;
           tndx1 *= nchnls;
           out[0] += amp*fadein*(tab[tndx1] + frac1*(tab[tndx1+nchnls] -
@@ -708,7 +710,7 @@ static int flooper2_process(CSOUND *csound, flooper2 *p)
           ndx[1] -= pitch;
         }
         else if (ndx[1] > loop_start + crossfade) {
-          tndx1 = (int) ndx[1];
+          tndx1 = (int32_t) ndx[1];
           frac1 = ndx[1] - tndx1;
           tndx1 *= nchnls;
           out[0] = amp*(tab[tndx1] + frac1*(tab[tndx1+nchnls] - tab[tndx1]));
@@ -724,8 +726,8 @@ static int flooper2_process(CSOUND *csound, flooper2 *p)
         }
         else if (ndx[1] > loop_start) {
           if (etab==NULL) fadeout = FL(1.0) - count/crossfade;
-          else fadeout = etab[(int)(elen*(1.0 - count/crossfade))];
-          tndx1 = (int) ndx[1];
+          else fadeout = etab[(int32_t)(elen*(1.0 - count/crossfade))];
+          tndx1 = (int32_t) ndx[1];
           frac1 = ndx[1] - tndx1;
           tndx1 *= nchnls;
           out[0] += amp*fadeout*(tab[tndx1] + frac1*(tab[tndx1+nchnls]
@@ -737,15 +739,15 @@ static int flooper2_process(CSOUND *csound, flooper2 *p)
           }
           ndx[1] -= pitch;
           if (ndx[1] <= loop_start) {
-            int loopsize;
-            loop_start = (int) (*p->loop_start*sr);
-            loop_end =   (int) (*p->loop_end*sr);
+            int32_t loopsize;
+            loop_start = (int32_t) (*p->loop_start*sr);
+            loop_end =   (int32_t) (*p->loop_end*sr);
             p->lstart = loop_start = loop_start < 0 ? 0 : loop_start;
             p->lend = loop_end =   loop_end > len ? len :
               (loop_end < loop_start ? loop_start : loop_end);
             loopsize = loop_end - loop_start;
             if(*p->crossfade > 0.0)
-              crossfade = (int) (*p->crossfade*sr);
+              crossfade = (int32_t) (*p->crossfade*sr);
             p->cfade = crossfade = crossfade > loopsize/2 ?
               loopsize/2-1 : crossfade;
             p->oend = *p->loop_end;
@@ -769,7 +771,7 @@ static int flooper2_process(CSOUND *csound, flooper2 *p)
           if (ijump) ndx[1] = loop_start;
         }
         else {
-          tndx1 = (int) ndx[1];
+          tndx1 = (int32_t) ndx[1];
           frac1 = ndx[1] - tndx1;
           if (etab==NULL) {
             fadein = count/crossfade;
@@ -777,8 +779,8 @@ static int flooper2_process(CSOUND *csound, flooper2 *p)
           }
           else {
             fadein = elen*count/crossfade;
-            fadeout = etab[elen - (int)fadein];
-            fadein = etab[(int)fadein];
+            fadeout = etab[elen - (int32_t)fadein];
+            fadein = etab[(int32_t)fadein];
           }
           tndx1 *= nchnls;
           tndx0 *= nchnls;
@@ -799,15 +801,15 @@ static int flooper2_process(CSOUND *csound, flooper2 *p)
         }
         ndx[0]+=pitch;
         if (ndx[0] >= loop_end) {
-          int loopsize;
-          loop_start = (int) (*p->loop_start*sr);
-          loop_end =   (int) (*p->loop_end*sr);
+          int32_t loopsize;
+          loop_start = (int32_t) (*p->loop_start*sr);
+          loop_end =   (int32_t) (*p->loop_end*sr);
           p->lstart = loop_start = loop_start < 0 ? 0 : loop_start;
           p->lend = loop_end =   loop_end > len ? len :
             (loop_end < loop_start ? loop_start : loop_end);
           loopsize = loop_end - loop_start;
           if(*p->crossfade > 0.0)
-            crossfade = (int) (*p->crossfade*sr);
+            crossfade = (int32_t) (*p->crossfade*sr);
           p->cfade = crossfade = crossfade > loopsize ? loopsize-1 : crossfade;
           ndx[0] = ndx[1];
           ndx[1] = (double)loop_start;
@@ -830,9 +832,9 @@ static int flooper2_process(CSOUND *csound, flooper2 *p)
 
 
 /*
-static int flooper3_init(CSOUND *csound, flooper3 *p)
+static int32_t flooper3_init(CSOUND *csound, flooper3 *p)
 {
-    int len,i,p2s,lomod;
+    int32_t len,i,p2s,lomod;
     p->sfunc = csound->FTnp2Find(csound, p->ifn);
     if (UNLIKELY(p->sfunc==NULL)) {
       return csound->InitError(csound,Str("function table not found\n"));
@@ -850,7 +852,7 @@ static int flooper3_init(CSOUND *csound, flooper3 *p)
     p->lodiv = 1.0/lomod;
 
     if (*p->iskip == 0){
-      p->mode = (int) *p->imode;
+      p->mode = (int32_t) *p->imode;
       if (p->mode == 0 || p->mode == 2){
         if ((p->ndx[0] = *p->start*CS_ESR) < 0)
           p->ndx[0] = 0;
@@ -866,21 +868,21 @@ static int flooper3_init(CSOUND *csound, flooper3 *p)
     return OK;
 }
 
-static int flooper3_process(CSOUND *csound, flooper3 *p)
+static int32_t flooper3_process(CSOUND *csound, flooper3 *p)
 {
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t i, nsmps = CS_KSMPS;
-    int lobits = p->lobits,si,ei;
+    int32_t lobits = p->lobits,si,ei;
     MYFLT *out = p->out, sr = CS_ESR;
     MYFLT amp = *(p->amp), pitch = *(p->pitch);
     MYFLT *tab = p->sfunc->ftable, cvt;
     int32 *ndx = p->ndx, lomask = p->lomask, pos;
     MYFLT frac0, frac1, *etab, lodiv = p->lodiv;
-    int loop_end = p->lend, loop_start = p->lstart, mode = p->mode,
+    int32_t loop_end = p->lend, loop_start = p->lstart, mode = p->mode,
       crossfade = p->cfade, len = p->sfunc->flen, count = p->count;
     MYFLT fadein, fadeout;
-    int *firsttime = &p->firsttime, elen, init = p->init;
+    int32_t *firsttime = &p->firsttime, elen, init = p->init;
     uint32 tndx0, tndx1;
 
     if (UNLIKELY(early)) {
@@ -889,7 +891,7 @@ static int flooper3_process(CSOUND *csound, flooper3 *p)
     }
     if (pitch < FL(0.0)) pitch = FL(0.0);
     if (*firsttime) {
-      int loopsize;
+      int32_t loopsize;
       if (UNLIKELY(offset)) memset(out, '\0', offset*sizeof(MYFLT));
       loop_start = MYFLT2LRND(*p->loop_start*sr);
       loop_end =   MYFLT2LRND (*p->loop_end*sr);
@@ -956,7 +958,7 @@ static int flooper3_process(CSOUND *csound, flooper3 *p)
         }
         ndx[0]+=si;
         if (tndx0 >= loop_end) {
-          int loopsize;
+          int32_t loopsize;
           loop_start = MYFLT2LRND(*p->loop_start*sr);
           loop_end =   MYFLT2LRND(*p->loop_end*sr);
           p->lstart = loop_start = (loop_start < 0 ? 0 : loop_start);
@@ -999,7 +1001,7 @@ static int flooper3_process(CSOUND *csound, flooper3 *p)
         ndx[0]-=si;
 
         if (tndx0 <= loop_start) {
-          int loopsize;
+          int32_t loopsize;
           loop_start = MYFLT2LRND(*p->loop_start*sr);
           loop_end =   MYFLT2LRND(*p->loop_end*sr);
           p->lstart = loop_start = (loop_start < 0 ? 0 : loop_start);
@@ -1085,7 +1087,7 @@ static int flooper3_process(CSOUND *csound, flooper3 *p)
           ndx[1] -= si;
           tndx1 = ndx[1]>>lobits;
           if (tndx1 <= loop_start) {
-            int loopsize;
+            int32_t loopsize;
             loop_start = MYFLT2LRND(*p->loop_start*sr);
             loop_end =   MYFLT2LRND(*p->loop_end*sr);
             p->lstart = loop_start = (loop_start < 0 ? 0 : loop_start);
@@ -1111,7 +1113,7 @@ static int flooper3_process(CSOUND *csound, flooper3 *p)
 }
 */
 
-static int pvsarp_init(CSOUND *csound, pvsarp *p)
+static int32_t pvsarp_init(CSOUND *csound, pvsarp *p)
 {
     int32 N = p->fin->N;
 
@@ -1135,7 +1137,7 @@ static int pvsarp_init(CSOUND *csound, pvsarp *p)
     return OK;
 }
 
-static int pvsarp_process(CSOUND *csound, pvsarp *p)
+static int32_t pvsarp_process(CSOUND *csound, pvsarp *p)
 {
     int32 i,j,N = p->fout->N, bins = N/2 + 1;
     float g = (float) *p->gain;
@@ -1149,7 +1151,7 @@ static int pvsarp_process(CSOUND *csound, pvsarp *p)
       cf = cf >= 0 ? (cf < bins ? cf*bins : bins-1) : 0;
       kdepth = kdepth >= 0 ? (kdepth <= 1 ? kdepth : FL(1.0)): FL(0.0);
       for (i=j=0;i < N+2;i+=2, j++) {
-        if (j == (int) cf) fout[i] = fin[i]*g;
+        if (j == (int32_t) cf) fout[i] = fin[i]*g;
         else fout[i] = (float)(fin[i]*(1-kdepth));
         fout[i+1] = fin[i+1];
       }
@@ -1162,7 +1164,7 @@ static int pvsarp_process(CSOUND *csound, pvsarp *p)
                              Str("pvsarp: not initialised\n"));
 }
 
-static int pvsvoc_init(CSOUND *csound, pvsvoc *p)
+static int32_t pvsvoc_init(CSOUND *csound, pvsvoc *p)
 {
     int32 N = p->fin->N;
 
@@ -1197,10 +1199,10 @@ static int pvsvoc_init(CSOUND *csound, pvsvoc *p)
    return OK;
 }
 
-void csoundComplexFFTnp2(CSOUND *csound, MYFLT *buf, int FFTsize);
-void csoundInverseComplexFFTnp2(CSOUND *csound, MYFLT *buf, int FFTsize);
+void csoundComplexFFTnp2(CSOUND *csound, MYFLT *buf, int32_t FFTsize);
+void csoundInverseComplexFFTnp2(CSOUND *csound, MYFLT *buf, int32_t FFTsize);
 
-static int pvsvoc_process(CSOUND *csound, pvsvoc *p)
+static int32_t pvsvoc_process(CSOUND *csound, pvsvoc *p)
 {
     int32 i,N = p->fout->N;
     float gain = (float) *p->gain;
@@ -1209,7 +1211,7 @@ static int pvsvoc_process(CSOUND *csound, pvsvoc *p)
     float *ffr = (float *) p->ffr->frame.auxp;
     float *fexc = (float *) p->fexc.auxp;
     float *fout = (float *) p->fout->frame.auxp;
-    int coefs = (int) *(p->kcoefs), j;
+    int32_t coefs = (int32_t) *(p->kcoefs), j;
     MYFLT   *fenv = (MYFLT *) p->fenv.auxp;
     MYFLT   *ceps = (MYFLT *) p->ceps.auxp;
     float maxe=0.f, maxa=0.f;
@@ -1217,7 +1219,7 @@ static int pvsvoc_process(CSOUND *csound, pvsvoc *p)
     if (UNLIKELY(fout==NULL)) goto err1;
 
     if (p->lastframe < p->fin->framecount) {
-      int tmp = N/2;
+      int32_t tmp = N/2;
       tmp = tmp + tmp%2;
       for (j=0; j < 2; j++) {
         MYFLT a;
@@ -1271,7 +1273,7 @@ static int pvsvoc_process(CSOUND *csound, pvsvoc *p)
                              Str("pvsvoc: not initialised\n"));
 }
 
-static int pvsmorph_init(CSOUND *csound, pvsmorph *p)
+static int32_t pvsmorph_init(CSOUND *csound, pvsmorph *p)
 {
     int32 N = p->fin->N;
 
@@ -1295,7 +1297,7 @@ static int pvsmorph_init(CSOUND *csound, pvsmorph *p)
     return OK;
 }
 
-static int pvsmorph_process(CSOUND *csound, pvsmorph *p)
+static int32_t pvsmorph_process(CSOUND *csound, pvsmorph *p)
 {
     int32 i,N = p->fout->N;
     float frint = (float) *p->gain;
@@ -1323,25 +1325,27 @@ static int pvsmorph_process(CSOUND *csound, pvsmorph *p)
                              Str("pvsmorph: not initialised\n"));
 }
 
-static OENTRY localops[] = {
-  {"sndloop", sizeof(sndloop),0, 5,
-   "ak", "akkii", (SUBR)sndloop_init, NULL, (SUBR)sndloop_process},
-  {"flooper", sizeof(flooper), TR, 5,
-   "mm", "kkiiii", (SUBR)flooper_init, NULL, (SUBR)flooper_process},
-  {"pvsarp", sizeof(pvsarp), 0,3,
-   "f", "fkkk", (SUBR)pvsarp_init, (SUBR)pvsarp_process},
-  {"pvsvoc", sizeof(pvsvoc), 0,3,
-   "f", "ffkkO", (SUBR)pvsvoc_init, (SUBR)pvsvoc_process},
-  {"flooper2", sizeof(flooper2), TR, 5,
-   "mm", "kkkkkiooooO", (SUBR)flooper2_init, NULL, (SUBR)flooper2_process},
-  /* {"flooper3", sizeof(flooper3), TR, 5,
-     "a", "kkkkkioooo", (SUBR)flooper3_init, NULL, (SUBR)flooper3_process},*/
- {"pvsmorph", sizeof(pvsvoc), 0,3,
-   "f", "ffkk", (SUBR)pvsmorph_init, (SUBR)pvsmorph_process}
+static OENTRY localops[] =
+  {
+   {"sndloop", sizeof(sndloop),0, 3,
+    "ak", "akkii", (SUBR)sndloop_init, (SUBR)sndloop_process},
+   {"flooper", sizeof(flooper), TR, 3,
+    "mm", "kkiiii", (SUBR)flooper_init, (SUBR)flooper_process},
+   {"pvsarp", sizeof(pvsarp), 0,3,
+    "f", "fkkk", (SUBR)pvsarp_init, (SUBR)pvsarp_process},
+   {"pvsvoc", sizeof(pvsvoc), 0,3,
+    "f", "ffkkO", (SUBR)pvsvoc_init, (SUBR)pvsvoc_process},
+   {"flooper2", sizeof(flooper2), TR, 3,
+    "mm", "kkkkkiooooO", (SUBR)flooper2_init, (SUBR)flooper2_process},
+  /* {"flooper3", sizeof(flooper3), TR, 3,
+     "a", "kkkkkioooo", (SUBR)flooper3_init, (SUBR)flooper3_process},*/
+   {"pvsmorph", sizeof(pvsvoc), 0,3,
+    "f", "ffkk", (SUBR)pvsmorph_init, (SUBR)pvsmorph_process}
 };
 
-int sndloop_init_(CSOUND *csound)
+int32_t sndloop_init_(CSOUND *csound)
 {
   return csound->AppendOpcodes(csound, &(localops[0]),
-                               (int) (sizeof(localops) / sizeof(OENTRY)));
+                               (int32_t
+                                ) (sizeof(localops) / sizeof(OENTRY)));
 }
