@@ -17,8 +17,8 @@
 
     You should have received a copy of the GNU Lesser General Public
     License along with Csound; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-    02111-1307 USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+    02110-1301 USA
 */
 
 /* ----- spat3d, spat3di, and spat3dt -- written by Istvan Varga, 2001 ----- */
@@ -37,17 +37,17 @@
 
 /* initialise FIR filter for downsampling */
 
-static int    spat3d_init_window(CSOUND *csound, SPAT3D *p)
+static int32_t    spat3d_init_window(CSOUND *csound, SPAT3D *p)
 {
-    int     i, j, o;
+    int32_t i, j, o;
     double  d, w;
 
     o = p->oversamp << 5;           /* window size = 32 * oversample */
 
-    i = ((o + 1) * (sizeof(int) + sizeof(MYFLT)));      /* allocate */
-    if ((p->fltr.auxp == NULL) || (p->fltr.size < (unsigned int)i)) /* space */
+    i = ((o + 1) * (sizeof(int32_t) + sizeof(MYFLT)));      /* allocate */
+    if ((p->fltr.auxp == NULL) || (p->fltr.size < (uint32_t)i)) /* space */
       csound->AuxAlloc(csound, i, &(p->fltr));
-    p->sample = (int *) p->fltr.auxp;                 /* sample number */
+    p->sample = (int32_t *) p->fltr.auxp;             /* sample number */
     p->window = (MYFLT *) (p->sample + o + 1);        /* window value  */
 
     for (i = -(o >> 1), j = 0; i < (o >> 1); i++) {
@@ -70,14 +70,14 @@ static int    spat3d_init_window(CSOUND *csound, SPAT3D *p)
 
 /* initialise parameric equalizer (code taken from pareq opcode) */
 
-static int spat3d_init_eq(CSOUND *csound, SPAT3D_WALL *wstruct, MYFLT *ftable)
+static int32_t spat3d_init_eq(CSOUND *csound, SPAT3D_WALL *wstruct, MYFLT *ftable)
 {
-    int     eqmode;
+    int32_t eqmode;
     double  omega, k, kk, vk, vkk, vkdq, sq, a0, a1, a2, b0, b1, b2;
 
     /* EQ code taken from biquad.c */
 
-    eqmode = (int) ((double) ftable[3] + 0.5);                  /* mode      */
+    eqmode = (int32_t) ((double) ftable[3] + 0.5);              /* mode      */
     omega = (double) ftable[0] * (double) csound->tpidsr;       /* frequency */
     sq = sqrt(2.0 * (double) ftable[1]);                        /* level     */
 
@@ -113,12 +113,12 @@ static int spat3d_init_eq(CSOUND *csound, SPAT3D_WALL *wstruct, MYFLT *ftable)
 
 static SPAT3D_WALL*
 spat3d_init_wall(SPAT3D *p,             /* opcode struct                    */
-                 int    wallno,         /* wall number                      */
-                 int    dep,            /* recursion depth                  */
-                 int32   *wmax,          /* wall structure number            */
+                 int32_t    wallno,     /* wall number                      */
+                 int32_t    dep,        /* recursion depth                  */
+                 int32_t   *wmax,       /* wall structure number            */
                  MYFLT  X, MYFLT Y, MYFLT Z) /* coordinates (spat3di/spat3dt) */
 {
-    int             i;
+    int32_t             i;
     SPAT3D_WALL     *ws;
     MYFLT           *ft, a, d, w, x, y, z;
     double          d0, d1;
@@ -170,19 +170,21 @@ spat3d_init_wall(SPAT3D *p,             /* opcode struct                    */
 
     if (p->o_num != 1) {
       switch (ws->cnum) {                     /* new coordinates   */
-      case 0: X = ws->Xc - X; break;
-      case 1: Y = ws->Xc - Y; break;
-      case 2: Z = ws->Xc - Z; break;
+      /* FALLTHRU */ case 0: X = ws->Xc - X; break;
+      /* FALLTHRU */ case 1: Y = ws->Xc - Y; break;
+      /* FALLTHRU */ case 2: Z = ws->Xc - Z; break;
       }
       if (p->zout < 4) {                      /* convert coord.    */
-        d = SPAT3D_XYZ2DIST(X, Y, Z);           /* distance  */
+        d = SPAT3D_XYZ2DIST(X, Y, Z);         /* distance  */
         d0 = d1 = (double) SPAT3D_DIST2DEL(d);  /* delay     */
-        a = SPAT3D_DIST2AMP(d);                 /* amp.      */
+        a = SPAT3D_DIST2AMP(d);                /* amp.      */
         d = FL(1.0) / (d > p->mdist ? d : p->mdist);
         w = x = y = z = FL(0.0);
         switch (p->zout) {
         case 3: z =  Z * d; w += z*z; z *= a;   /* Z */
+          /* FALLTHRU */
         case 2: x =  Y * d; w += x*x; x *= a;   /* X */
+        /* FALLTHRU */
         case 1: y = -X * d; w += y*y; y *= a;   /* Y */
         }
         w = a - FL(0.293) * w * a;                      /* W */
@@ -228,16 +230,16 @@ spat3d_init_wall(SPAT3D *p,             /* opcode struct                    */
 
 /* allocate space for delay buffers */
 
-static int spat3d_init_delay(CSOUND *csound, SPAT3D *p)
+static int32_t spat3d_init_delay(CSOUND *csound, SPAT3D *p)
 {
-    int32    i, j;
+    int32_t    i, j;
 
-    i = ((int32) (p->mdel * CS_ESR) + (int32) CS_KSMPS + 34L)
-        * (int32) p->oversamp;
+    i = ((int32_t) (p->mdel * CS_ESR) + (int32_t) CS_KSMPS + 34L)
+        * (int32_t) p->oversamp;
     p->mdel_s = i;
     if (p->o_num == 1) i += 4;      /* extra samples for spat3d */
-    j = i * (int32) sizeof(MYFLT) * (int32) (p->zout > 3 ? 4 : p->zout + 1);
-    if ((p->del.auxp == NULL) || (p->del.size < (unsigned int)j)) /* allocate */
+    j = i * (int32_t) sizeof(MYFLT) * (int32_t) (p->zout > 3 ? 4 : p->zout + 1);
+    if ((p->del.auxp == NULL) || (p->del.size < (uint32_t)j)) /* allocate */
       csound->AuxAlloc(csound, j, &(p->del));               /* space    */
     p->Wb = (MYFLT *) p->del.auxp;                  /* W */
     if (p->zout > 0) p->Yb = p->Wb + i;             /* Y */
@@ -245,20 +247,20 @@ static int spat3d_init_delay(CSOUND *csound, SPAT3D *p)
     if (p->zout > 2) p->Zb = p->Xb + i;             /* Z */
     for (j = 0; j < i; j++) {
       switch (p->zout) {              /* clear buffers */
-      case 4:
-      case 3: p->Zb[j] = FL(0.0);
-      case 2: p->Xb[j] = FL(0.0);
-      case 1: p->Yb[j] = FL(0.0);
-      case 0: p->Wb[j] = FL(0.0);
+      /* FALLTHRU */ case 4:
+      /* FALLTHRU */ case 3: p->Zb[j] = FL(0.0);
+      /* FALLTHRU */ case 2: p->Xb[j] = FL(0.0);
+      /* FALLTHRU */ case 1: p->Yb[j] = FL(0.0);
+      /* FALLTHRU */ case 0: p->Wb[j] = FL(0.0);
       }
     }
     if (p->o_num == 1) {
       switch (p->zout) {
-      case 4:
-      case 3: (p->Zb)++;      /* spat3d requires 1    */
-      case 2: (p->Xb)++;      /* extra sample before  */
-      case 1: (p->Yb)++;      /* and 3 samples after  */
-      case 0: (p->Wb)++;      /* the delay buffer     */
+      /* FALLTHRU */ case 4:
+      /* FALLTHRU */ case 3: (p->Zb)++;      /* spat3d requires 1    */
+      /* FALLTHRU */ case 2: (p->Xb)++;      /* extra sample before  */
+      /* FALLTHRU */ case 1: (p->Yb)++;      /* and 3 samples after  */
+      /* FALLTHRU */ case 0: (p->Wb)++;      /* the delay buffer     */
       }
     }
     return OK;
@@ -266,10 +268,10 @@ static int spat3d_init_delay(CSOUND *csound, SPAT3D *p)
 
 /* count reflections */
 
-static void spat3d_count_refl(int32 *cnt, int *md,
-                              int d, int mdep, int w, int wm)
+static void spat3d_count_refl(int32_t *cnt, int32_t *md,
+                              int32_t d, int32_t mdep, int32_t w, int32_t wm)
 {
-    int     j;
+    int32_t     j;
 
     (*cnt)++;                       /* update count    */
     if (++d > *md) *md = d;         /* md is the max. depth reached + 1 */
@@ -281,18 +283,18 @@ static void spat3d_count_refl(int32 *cnt, int *md,
 
 /* initialise opcode structure */
 
-static int spat3d_set_opcode_params(CSOUND *csound, SPAT3D *p)
+static int32_t spat3d_set_opcode_params(CSOUND *csound, SPAT3D *p)
 {
-    int     xidist, xift, ximode, ximdel, xiovr, xirlen, xioutft;
-    int     d, wmask;
-    int32    i;
+    int32_t     xidist, xift, ximode, ximdel, xiovr, xirlen, xioutft;
+    int32_t     d, wmask;
+    int32_t    i;
 
     /* default settings */
 
     p->ftable = p->outft = NULL;    /* no ftables */
     p->zout = p->rseed = p->mindep = p->maxdep = p->outftlnth = wmask = 0;
     p->oversamp = 1;                /* oversample */
-    p->bs = (int) CS_KSMPS;    /* block size */
+    p->bs = (int32_t) CS_KSMPS;    /* block size */
     p->irlen = 2;                   /* IR length  */
     p->mdist = p->mdel = FL(0.001); /* unit circle dist., max. delay */
     p->mdel_s = p->del_p = 0L;
@@ -302,10 +304,10 @@ static int spat3d_set_opcode_params(CSOUND *csound, SPAT3D *p)
 
     xidist = xift = ximode = ximdel = xiovr = xirlen = xioutft = -1;
     switch (p->o_num) {
-    case 1: ximdel = 11; xiovr = 12;                /* spat3d  */
-    case 0: xidist = 8; xift = 9; ximode = 10;      /* spat3di */
+    /* FALLTHRU */ case 1: ximdel = 11; xiovr = 12;                /* spat3d  */
+    /* FALLTHRU */ case 0: xidist = 8; xift = 9; ximode = 10;      /* spat3di */
       break;
-    case 2: xidist = 4; xift = 5; ximode = 6;       /* spat3dt */
+    /* FALLTHRU */ case 2: xidist = 4; xift = 5; ximode = 6;       /* spat3dt */
       xirlen = 7; xioutft = 0;
       break;
     }
@@ -313,24 +315,24 @@ static int spat3d_set_opcode_params(CSOUND *csound, SPAT3D *p)
     /* read opcode args */
 
     if (ximode >= 0)                                /* output mode */
-      p->zout = (int) MYFLT2LRND(*(p->args[ximode]));
+      p->zout = (int32_t) MYFLT2LRND(*(p->args[ximode]));
     if (xidist >= 0)                                /* unit circle dist. */
       p->mdist = *(p->args[xidist]);
     if (xift >= 0) {                                /* ftable */
-      int fLen;
-      fLen = csoundGetTable(csound, &(p->ftable), (int) *(p->args[xift]));
+      int32_t fLen;
+      fLen = csoundGetTable(csound, &(p->ftable), (int32_t) *(p->args[xift]));
       if (fLen < 53)
         p->ftable = NULL;
     }
     if (ximdel >= 0)                                /* max. delay */
       p->mdel = *(p->args[ximdel]);
     if (xiovr >= 0)                                 /* oversample */
-      p->oversamp = (int) MYFLT2LRND(*(p->args[xiovr]));
+      p->oversamp = (int32_t) MYFLT2LRND(*(p->args[xiovr]));
     if (xirlen >= 0)                                /* IR length */
-      p->irlen = (int) MYFLT2LRND(*(p->args[xirlen]) * CS_ESR);
+      p->irlen = (int32_t) MYFLT2LRND(*(p->args[xirlen]) * CS_ESR);
     if (xioutft >= 0) {                             /* output table */
-      int fLen;
-      fLen = csoundGetTable(csound, &(p->outft), (int) *(p->args[xioutft]));
+      int32_t fLen;
+      fLen = csoundGetTable(csound, &(p->outft), (int32_t) *(p->args[xioutft]));
       if (fLen < 1) {
         p->outft = NULL; p->outftlnth = 0;
       }
@@ -342,22 +344,22 @@ static int spat3d_set_opcode_params(CSOUND *csound, SPAT3D *p)
 
     if (p->ftable != NULL) {
       if (p->o_num == 2) {                    /* min, max depth    */
-        p->mindep = (int) MYFLT2LRND(p->ftable[0]) + 1;
-        p->maxdep = (int) MYFLT2LRND(p->ftable[1]);
+        p->mindep = (int32_t) MYFLT2LRND(p->ftable[0]) + 1;
+        p->maxdep = (int32_t) MYFLT2LRND(p->ftable[1]);
       }
       else {
         p->mindep = 0;
-        p->maxdep = (int) MYFLT2LRND(p->ftable[0]);
+        p->maxdep = (int32_t) MYFLT2LRND(p->ftable[0]);
       }
       if (p->ftable[2] >= FL(0.0))            /* max. delay        */
         p->mdel = p->ftable[2];
       if (p->ftable[3] >= FL(0.0))            /* IR length         */
-        p->irlen = (int) MYFLT2LRND(p->ftable[3] * CS_ESR);
+        p->irlen = (int32_t) MYFLT2LRND(p->ftable[3] * CS_ESR);
       if (p->ftable[4] >= FL(0.0))            /* unit circle dist. */
         p->mdist = p->ftable[4];
-      p->rseed = (int32) MYFLT2LRND(p->ftable[5]);     /* seed      */
+      p->rseed = (int32_t) MYFLT2LRND(p->ftable[5]);     /* seed      */
       if (p->rseed < 0L)
-        p->rseed = (int32) csound->GetRandomSeedFromTime() & 0xFFFFL;
+        p->rseed = (int32_t) csound->GetRandomSeedFromTime() & 0xFFFFL;
       for (i = 6; i; i--) {                   /* wall mask         */
         wmask <<= 1; if (p->ftable[i*8 - 2] > FL(0.5)) wmask++;
       }
@@ -380,12 +382,12 @@ static int spat3d_set_opcode_params(CSOUND *csound, SPAT3D *p)
 
     if (p->maxdep >= 0) {
       i = d = 0; spat3d_count_refl(&i, &d, 0, p->maxdep, 0, wmask);
-      i *= (int32) sizeof(SPAT3D_WALL);
-      if ((p->ws.auxp == NULL) || (p->ws.size < (unsigned int)i))
+      i *= (int32_t) sizeof(SPAT3D_WALL);
+      if ((p->ws.auxp == NULL) || (p->ws.size < (uint32_t)i))
         csound->AuxAlloc(csound, i, &(p->ws));
-      i = (int32) p->bs * (int32) d;
-      i *= (int32) sizeof(MYFLT);
-      if ((p->y.auxp == NULL) || (p->y.size < (unsigned int)i))
+      i = (int32_t) p->bs * (int32_t) d;
+      i *= (int32_t) sizeof(MYFLT);
+      if ((p->y.auxp == NULL) || (p->y.size < (uint32_t)i))
         csound->AuxAlloc(csound, i, &(p->y));
     }
     return OK;
@@ -395,9 +397,9 @@ static int spat3d_set_opcode_params(CSOUND *csound, SPAT3D *p)
 
 /* spat3d set-up */
 
-static int    spat3dset(CSOUND *csound, SPAT3D *p)
+static int32_t    spat3dset(CSOUND *csound, SPAT3D *p)
 {
-    int32    wmax;
+    int32_t    wmax;
 
     if (*(p->args[13]) != FL(0.0)) return OK; /* skip init    */
     p->o_num = 1;                             /* opcode number         */
@@ -414,9 +416,9 @@ static int    spat3dset(CSOUND *csound, SPAT3D *p)
 
 /* spat3di set-up */
 
-static int    spat3diset(CSOUND *csound, SPAT3D *p)
+static int32_t    spat3diset(CSOUND *csound, SPAT3D *p)
 {
-    int32    wmax;
+    int32_t    wmax;
 
     if (*(p->args[11]) != FL(0.0)) return OK; /* skip init             */
     p->o_num = 0;                             /* opcode number         */
@@ -444,7 +446,7 @@ static void spat3d_wall_perf(CSOUND     *csound, /* General environment       */
     MYFLT       *yn, W0, X0, Y0, Z0, *Wb, *Xb, *Yb, *Zb;
     MYFLT       a, d, w, x, y, z, wd, xd, yd, zd, x1;
     double      d0, d1, d0d, d1d, D0, D1;
-    int32        xpos, nn, pos;
+    int32_t        xpos, nn, pos;
 
     yn = ws->yn; D0 = ws->D0; D1 = ws->D1; pos = p->del_p;
     W0 = ws->W0; X0 = ws->X0; Y0 = ws->Y0; Z0 = ws->Z0;
@@ -453,9 +455,9 @@ static void spat3d_wall_perf(CSOUND     *csound, /* General environment       */
     /* calculate coordinates of reflection      */
 
     switch (ws->cnum) {
-    case 0:     X = ws->Xc - X; break;
-    case 1:     Y = ws->Xc - Y; break;
-    case 2:     Z = ws->Xc - Z; break;
+    /* FALLTHRU */ case 0:     X = ws->Xc - X; break;
+    /* FALLTHRU */ case 1:     Y = ws->Xc - Y; break;
+    /* FALLTHRU */ case 2:     Z = ws->Xc - Z; break;
     }
 
     /* convert coordinates */
@@ -467,9 +469,9 @@ static void spat3d_wall_perf(CSOUND     *csound, /* General environment       */
       d = FL(1.0) / (d > p->mdist ? d : p->mdist);
       w = x = y = z = FL(0.0);
       switch (p->zout) {
-      case 3:   z =  Z * d; w += z*z; z *= a;   /* Z */
-      case 2:   x =  Y * d; w += x*x; x *= a;   /* X */
-      case 1:   y = -X * d; w += y*y; y *= a;   /* Y */
+      /* FALLTHRU */ case 3:   z =  Z * d; w += z*z; z *= a;   /* Z */
+      /* FALLTHRU */ case 2:   x =  Y * d; w += x*x; x *= a;   /* X */
+      /* FALLTHRU */ case 1:   y = -X * d; w += y*y; y *= a;   /* Y */
       }
       w = a - FL(0.293) * w * a;                /* W */
     }
@@ -499,12 +501,12 @@ static void spat3d_wall_perf(CSOUND     *csound, /* General environment       */
     wd = xd = yd = zd = (MYFLT) d0d;
     a = (MYFLT) p->oversamp;
     switch (p->zout) {
-    case 4:     d1d *= (d1 - D1); D1 -= d1d * 0.5;
+    /* FALLTHRU */ case 4:     d1d *= (d1 - D1); D1 -= d1d * 0.5;
       d = (a + (MYFLT) d1d) / a;        /* correct amplitude */
-    case 3:     zd *= (z - Z0);
-    case 2:     xd *= (x - X0);
-    case 1:     yd *= (y - Y0);
-    case 0:     wd *= (w - W0);
+    /* FALLTHRU */ case 3:     zd *= (z - Z0);
+    /* FALLTHRU */ case 2:     xd *= (x - X0);
+    /* FALLTHRU */ case 1:     yd *= (y - Y0);
+    /* FALLTHRU */ case 0:     wd *= (w - W0);
       d0d *= (d0 - D0); D0 -= d0d * 0.5;
       a = (a + (MYFLT) d0d) / a;
     }
@@ -518,7 +520,7 @@ static void spat3d_wall_perf(CSOUND     *csound, /* General environment       */
 
       /* write to delay buffer with cubic interpolation */
 
-      xpos = (int32) (D0 += d0d);
+      xpos = (int32_t) (D0 += d0d);
       x1 = (MYFLT) (D0 - (double) (xpos--));
       z = x1 * x1; z--; z *= FL(0.1666666667);
       y = x1; y++; w = (y *= FL(0.5)); w--;
@@ -533,20 +535,20 @@ static void spat3d_wall_perf(CSOUND     *csound, /* General environment       */
       *(Wb++) += w * W0; *(Wb++) += x * W0;
       *(Wb++) += y * W0; *Wb += z * W0;
       switch (p->zout) {
-      case 3:   Zb = p->Zb + xpos; Z0 += zd;            /* Z */
+      /* FALLTHRU */ case 3:   Zb = p->Zb + xpos; Z0 += zd;            /* Z */
         *(Zb++) += w * Z0; *(Zb++) += x * Z0;
         *(Zb++) += y * Z0; *Zb += z * Z0;
-      case 2:   Xb = p->Xb + xpos; X0 += xd;            /* X */
+      /* FALLTHRU */ case 2:   Xb = p->Xb + xpos; X0 += xd;            /* X */
         *(Xb++) += w * X0; *(Xb++) += x * X0;
         *(Xb++) += y * X0; *Xb += z * X0;
-      case 1:   Yb = p->Yb + xpos; Y0 += yd;            /* Y */
+      /* FALLTHRU */ case 1:   Yb = p->Yb + xpos; Y0 += yd;            /* Y */
         *(Yb++) += w * Y0; *(Yb++) += x * Y0;
         *(Yb++) += y * Y0; *Yb += z * Y0;
-      case 0:   break;
-      case 4:   Xb = p->Xb + xpos; X0 += xd;    /* Lh */
+      /* FALLTHRU */ case 0:   break;
+      /* FALLTHRU */ case 4:   Xb = p->Xb + xpos; X0 += xd;    /* Lh */
         *(Xb++) += w * X0; *(Xb++) += x * X0;
         *(Xb++) += y * X0; *Xb += z * X0;
-        xpos = (int32) (D1 += d1d);
+        xpos = (int32_t) (D1 += d1d);
         x1 = (MYFLT) (D1 - (double) (xpos--));
         z = x1 * x1; z--; z *= FL(0.1666666667);
         y = x1; y++; w = (y *= FL(0.5)); w--;
@@ -582,9 +584,9 @@ static void spat3d_wall_perf(CSOUND     *csound, /* General environment       */
 
 /* spat3d routine */
 
-static int    spat3d(CSOUND *csound, SPAT3D *p)
+static int32_t    spat3d(CSOUND *csound, SPAT3D *p)
 {
-    int32        nn, i, j;
+    int32_t        nn, i, j;
     MYFLT       *aoutW, *aoutX, *aoutY, *aoutZ, w;
 
     /* assign object data to local variables */
@@ -605,27 +607,32 @@ static int    spat3d(CSOUND *csound, SPAT3D *p)
 
     j = p->mdel_s;
     switch (p->zout) {  /* clear extra samples at beginning and */
+    /* FALLTHRU */
     case 4:             /* end of delay line                    */
+    /* FALLTHRU */
     case 3:     *(p->Zb - 1) = p->Zb[j] = p->Zb[j + 1] = p->Zb[j + 2] =
                   FL(0.0);
+    /* FALLTHRU */
     case 2:     *(p->Xb - 1) = p->Xb[j] = p->Xb[j + 1] = p->Xb[j + 2] =
                   FL(0.0);
+    /* FALLTHRU */
     case 1:     *(p->Yb - 1) = p->Yb[j] = p->Yb[j + 1] = p->Yb[j + 2] =
                   FL(0.0);
+    /* FALLTHRU */
     case 0:     *(p->Wb - 1) = p->Wb[j] = p->Wb[j + 1] = p->Wb[j + 2] =
                   FL(0.0);
     }
     spat3d_wall_perf(csound, p, p->args[4], (SPAT3D_WALL *) p->ws.auxp,
                      *(p->args[5]), *(p->args[6]), *(p->args[7]));
     switch (p->zout) {  /* copy extra samples from beginning and */
-    case 4:             /* end of delay line                     */
-    case 3:     p->Zb[j - 1] += *(p->Zb - 1); p->Zb[0] += p->Zb[j];
+    /* FALLTHRU */ case 4:             /* end of delay line                     */
+    /* FALLTHRU */ case 3:     p->Zb[j - 1] += *(p->Zb - 1); p->Zb[0] += p->Zb[j];
       p->Zb[1] += p->Zb[j + 1]; p->Zb[2] += p->Zb[j + 2];
-    case 2:     p->Xb[j - 1] += *(p->Xb - 1); p->Xb[0] += p->Xb[j];
+    /* FALLTHRU */ case 2:     p->Xb[j - 1] += *(p->Xb - 1); p->Xb[0] += p->Xb[j];
       p->Xb[1] += p->Xb[j + 1]; p->Xb[2] += p->Xb[j + 2];
-    case 1:     p->Yb[j - 1] += *(p->Yb - 1); p->Yb[0] += p->Yb[j];
+    /* FALLTHRU */ case 1:     p->Yb[j - 1] += *(p->Yb - 1); p->Yb[0] += p->Yb[j];
       p->Yb[1] += p->Yb[j + 1]; p->Yb[2] += p->Yb[j + 2];
-    case 0:     p->Wb[j - 1] += *(p->Wb - 1); p->Wb[0] += p->Wb[j];
+    /* FALLTHRU */ case 0:     p->Wb[j - 1] += *(p->Wb - 1); p->Wb[0] += p->Wb[j];
       p->Wb[1] += p->Wb[j + 1]; p->Wb[2] += p->Wb[j + 2];
     }
 
@@ -638,21 +645,21 @@ static int    spat3d(CSOUND *csound, SPAT3D *p)
         if (j < 0) j += p->mdel_s;
         if (j >= p->mdel_s) j -= p->mdel_s;
         switch (p->zout) {
-        case 4:
-        case 3: *aoutZ += p->Zb[j] * w;
-        case 2: *aoutX += p->Xb[j] * w;
-        case 1: *aoutY += p->Yb[j] * w;
-        case 0: *aoutW += p->Wb[j] * w;
+        /* FALLTHRU */ case 4:
+        /* FALLTHRU */ case 3: *aoutZ += p->Zb[j] * w;
+        /* FALLTHRU */ case 2: *aoutX += p->Xb[j] * w;
+        /* FALLTHRU */ case 1: *aoutY += p->Yb[j] * w;
+        /* FALLTHRU */ case 0: *aoutW += p->Wb[j] * w;
         }
       }
       j = p->del_p - (p->oversamp << 4); if (j < 0) j += p->mdel_s;
       for (i = 0; i < p->oversamp; i++, j++) {
         switch (p->zout) {
-        case 4:
-        case 3: p->Zb[j] = FL(0.0);
-        case 2: p->Xb[j] = FL(0.0);
-        case 1: p->Yb[j] = FL(0.0);
-        case 0: p->Wb[j] = FL(0.0);
+        /* FALLTHRU */ case 4:
+        /* FALLTHRU */ case 3: p->Zb[j] = FL(0.0);
+        /* FALLTHRU */ case 2: p->Xb[j] = FL(0.0);
+        /* FALLTHRU */ case 1: p->Yb[j] = FL(0.0);
+        /* FALLTHRU */ case 0: p->Wb[j] = FL(0.0);
         }
       }
       aoutW++; aoutX++; aoutY++; aoutZ++;               /* next   */
@@ -661,7 +668,7 @@ static int    spat3d(CSOUND *csound, SPAT3D *p)
     }
     return OK;
  err1:
-    return csound->PerfError(csound, p->h.insdshead,
+    return csound->PerfError(csound, p->h.insdshead, "%s",
                              Str("spat3d: not initialised"));
 }
 
@@ -674,20 +681,20 @@ static void spat3di_wall_perf(SPAT3D        *p,     /* opcode struct    */
                               SPAT3D_WALL   *ws)    /* wall params      */
 {
     MYFLT       *yn, *Wb, *Xb, *Yb, *Zb, w, x, y, z;
-    int32        xpos0, xpos1, nn, bs;
+    int32_t     xpos0, xpos1, nn, bs;
 
     yn = ws->yn;
     bs = p->mdel_s;
-    xpos0 = (int32) ws->D0 + p->del_p; while (xpos0 >= bs) xpos0 -= bs;
+    xpos0 = (int32_t) ws->D0 + p->del_p; while (xpos0 >= bs) xpos0 -= bs;
     xpos1 = xpos0; Wb = Xb = Yb = Zb = NULL;
     w = ws->W0; x = ws->X0; y = ws->Y0; z = ws->Z0;
     switch (p->zout) {
-    case 4:     xpos1 = (int32) ws->D1 + p->del_p;
+    /* FALLTHRU */ case 4:     xpos1 = (int32_t) ws->D1 + p->del_p;
       while (xpos1 >= bs) xpos1 -= bs;
-    case 3:     Zb = p->Zb + xpos1;             /* Z / Rh */
-    case 2:     Xb = p->Xb + xpos0;             /* X / Lh */
-    case 1:     Yb = p->Yb + xpos1;             /* Y / Rl */
-    case 0:     Wb = p->Wb + xpos0;             /* W / Ll */
+    /* FALLTHRU */ case 3:     Zb = p->Zb + xpos1;             /* Z / Rh */
+    /* FALLTHRU */ case 2:     Xb = p->Xb + xpos0;             /* X / Lh */
+    /* FALLTHRU */ case 1:     Yb = p->Yb + xpos1;             /* Y / Rl */
+    /* FALLTHRU */ case 0:     Wb = p->Wb + xpos0;             /* W / Ll */
     }
 
     nn = p->bs; while (nn--) {  /* EQ */
@@ -700,21 +707,21 @@ static void spat3di_wall_perf(SPAT3D        *p,     /* opcode struct    */
       /* write to delay buffer */
 
       switch (p->zout) {
-      case 3:   *(Zb++) += *yn * z;             /* Z */
-      case 2:   *(Xb++) += *yn * x;             /* X */
-      case 1:   *(Yb++) += *yn * y;             /* Y */
-      case 0:   *(Wb++) += *yn * w;             /* W */
+      /* FALLTHRU */ case 3:   *(Zb++) += *yn * z;             /* Z */
+      /* FALLTHRU */ case 2:   *(Xb++) += *yn * x;             /* X */
+      /* FALLTHRU */ case 1:   *(Yb++) += *yn * y;             /* Y */
+      /* FALLTHRU */ case 0:   *(Wb++) += *yn * w;             /* W */
         if (++xpos0 >= bs) {
           xpos0 -= bs;
           switch (p->zout) {
-          case 3:       Zb -= bs;
-          case 2:       Xb -= bs;
-          case 1:       Yb -= bs;
-          case 0:       Wb -= bs;
+          /* FALLTHRU */ case 3:       Zb -= bs;
+          /* FALLTHRU */ case 2:       Xb -= bs;
+          /* FALLTHRU */ case 1:       Yb -= bs;
+          /* FALLTHRU */ case 0:       Wb -= bs;
           }
         }
         break;
-      case 4:   *(Wb++) += *yn * w;             /* Ll */
+      /* FALLTHRU */ case 4:   *(Wb++) += *yn * w;             /* Ll */
         *(Xb++) += *yn * x;                     /* Lh */
         *(Yb++) += *yn * y;                     /* Rl */
         *(Zb++) += *yn * z;                     /* Rh */
@@ -737,9 +744,9 @@ static void spat3di_wall_perf(SPAT3D        *p,     /* opcode struct    */
 
 /* spat3di routine */
 
-static int    spat3di(CSOUND *csound, SPAT3D *p)
+static int32_t    spat3di(CSOUND *csound, SPAT3D *p)
 {
-    int32        nn;
+    int32_t     nn;
     MYFLT       *a_outW, *a_outX, *a_outY, *a_outZ;
 
     /* assign object data to local variables */
@@ -764,14 +771,17 @@ static int    spat3di(CSOUND *csound, SPAT3D *p)
     nn = p->bs;
     do {        /* read from delay line */
       switch (p->zout) {
-      case 4:
-      case 3:   *(a_outZ++) = p->Zb[p->del_p];          /* Z */
+      /* FALLTHRU */ case 4:
+      /* FALLTHRU */ case 3:   *(a_outZ++) = p->Zb[p->del_p];          /* Z */
         p->Zb[p->del_p] = FL(0.0);
-      case 2:   *(a_outX++) = p->Xb[p->del_p];          /* X */
+        /* FALLTHRU */
+      /* FALLTHRU */ case 2:   *(a_outX++) = p->Xb[p->del_p];          /* X */
         p->Xb[p->del_p] = FL(0.0);
-      case 1:   *(a_outY++) = p->Yb[p->del_p];          /* Y */
+        /* FALLTHRU */
+      /* FALLTHRU */ case 1:   *(a_outY++) = p->Yb[p->del_p];          /* Y */
         p->Yb[p->del_p] = FL(0.0);
-      case 0:   *(a_outW++) = p->Wb[p->del_p];          /* W */
+        /* FALLTHRU */
+      /* FALLTHRU */ case 0:   *(a_outW++) = p->Wb[p->del_p];          /* W */
         p->Wb[p->del_p] = FL(0.0);
       }
       /* next sample */
@@ -779,7 +789,7 @@ static int    spat3di(CSOUND *csound, SPAT3D *p)
     } while (--nn);
     return OK;
  err1:
-    return csound->PerfError(csound, p->h.insdshead,
+    return csound->PerfError(csound, p->h.insdshead, "%s",
                              Str("spat3di: not initialised"));
 }
 
@@ -792,12 +802,11 @@ static void spat3dt_wall_perf(SPAT3D        *p,     /* opcode struct    */
                               SPAT3D_WALL   *ws)    /* wall params      */
 {
     MYFLT       *yn, *Wb, *Yb, *endp, w, x, y, z, a, d, ad, yw;
-    int32        nn;
-
+    int32_t     nn;
     yn = ws->yn;
     endp = p->outft;            /* write to ftable      */
-    Wb = endp + ((int32) ws->D0 << 2);
-    Yb = (p->zout < 4 ? Wb : endp + ((int32) ws->D1 << 2)) + 2;
+    Wb = endp + ((int32_t) ws->D0 << 2);
+    Yb = (p->zout < 4 ? Wb : endp + ((int32_t) ws->D1 << 2)) + 2;
     endp += p->outftlnth;       /* end of table         */
 
     w = ws->W0; x = ws->X0; y = ws->Y0; z = ws->Z0;
@@ -838,9 +847,9 @@ static void spat3dt_wall_perf(SPAT3D        *p,     /* opcode struct    */
 
 /* spat3dt opcode (i-time only) */
 
-static int    spat3dt(CSOUND *csound, SPAT3D *p)
+static int32_t    spat3dt(CSOUND *csound, SPAT3D *p)
 {
-    int32    wmax;
+    int32_t wmax;
     MYFLT   *ir;
 
     p->o_num = 2;                           /* opcode number         */
@@ -855,9 +864,9 @@ static int    spat3dt(CSOUND *csound, SPAT3D *p)
 
     /* initialise IR */
 
-    ir = (MYFLT *) csound->Malloc(csound, sizeof(MYFLT) * (int32) p->bs);
+    ir = (MYFLT *) csound->Malloc(csound, sizeof(MYFLT) * (int32_t) p->bs);
     ir[0] = FL(1.0);
-    wmax = 0; while (++wmax < (int32) p->bs)
+    wmax = 0; while (++wmax <  p->bs)
       ir[wmax] = (sizeof(MYFLT) < 8 ? FL(1.0e-24) : FL(1.0e-48));
 
     if (*(p->args[8]) == FL(0.0)) {          /* clear ftable (if enabled) */
@@ -874,18 +883,19 @@ static int    spat3dt(CSOUND *csound, SPAT3D *p)
 
 #define S(x)    sizeof(x)
 
-static OENTRY localops[] = {
-    { "spat3d", S(SPAT3D), 0, 5, "aaaa", "akkkiiiiio",
-                    (SUBR) spat3dset,   NULL,   (SUBR) spat3d   },
-    { "spat3di",S(SPAT3D), 0, 5, "aaaa", "aiiiiiio",
-                    (SUBR) spat3diset,  NULL,   (SUBR) spat3di  },
-    { "spat3dt",S(SPAT3D), 0, 1, "", "iiiiiiiio",
-                    (SUBR) spat3dt,     NULL,   NULL            }
+static OENTRY localops[] =
+  {
+   { "spat3d", S(SPAT3D), 0, 3, "aaaa", "akkkiiiiio",
+     (SUBR) spat3dset,   (SUBR) spat3d   },
+   { "spat3di",S(SPAT3D), 0, 3, "aaaa", "aiiiiiio",
+     (SUBR) spat3diset,   (SUBR) spat3di  },
+   { "spat3dt",S(SPAT3D), 0, 1, "", "iiiiiiiio",
+     (SUBR) spat3dt,     NULL,   NULL            }
 };
 
-int spat3d_init_(CSOUND *csound)
+int32_t spat3d_init_(CSOUND *csound)
 {
     return csound->AppendOpcodes(csound, &(localops[0]),
-                                 (int) (sizeof(localops) / sizeof(OENTRY)));
+                                 (int32_t) (sizeof(localops) / sizeof(OENTRY)));
 }
 
