@@ -17,15 +17,15 @@
 
     You should have received a copy of the GNU Lesser General Public
     License along with Csound; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-    02111-1307 USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+    02110-1301 USA
 */
 
 #include "csdl.h"
 #include "interlocks.h"
 #include "pstream.h"
 
-static int STR_ARG_P(CSOUND *csound, void* arg) {
+static int32_t STR_ARG_P(CSOUND *csound, void* arg) {
     CS_TYPE *cs_type = csound->GetTypeForArg(arg);
     if (strcmp("S", cs_type->varTypeName) == 0) {
       return 1;
@@ -34,7 +34,7 @@ static int STR_ARG_P(CSOUND *csound, void* arg) {
     }
 }
 
-static int ASIG_ARG_P(CSOUND *csound, void* arg) {
+static int32_t ASIG_ARG_P(CSOUND *csound, void* arg) {
     CS_TYPE *cs_type = csound->GetTypeForArg(arg);
     if (strcmp("a", cs_type->varTypeName) == 0) {
       return 1;
@@ -57,8 +57,8 @@ typedef struct CsoundArgStack_s CsoundArgStack_t;
 struct CsoundArgStack_s {
     void    *curBundle;
     void    *dataSpace;
-    int     freeSpaceOffset;
-    int     freeSpaceEndOffset;
+    int32_t     freeSpaceOffset;
+    int32_t     freeSpaceEndOffset;
 };
 
 typedef struct STACK_OPCODE_ {
@@ -73,9 +73,9 @@ typedef struct PUSH_OPCODE_ {
     /* argMap[1]: number of stack bytes required at i-time */
     /* argMap[2]: number of stack bytes required at performace time */
     /* argMap[3] to argMap[35]: 0 terminated type/offset list */
-    int     argMap[36];
+    int32_t     argMap[36];
     CsoundArgStack_t  *pp;
-    int     initDone;
+    int32_t     initDone;
 } PUSH_OPCODE;
 
 typedef struct POP_OPCODE_ {
@@ -85,9 +85,9 @@ typedef struct POP_OPCODE_ {
     /* argMap[1]: number of stack bytes required at i-time */
     /* argMap[2]: number of stack bytes required at performace time */
     /* argMap[3] to argMap[35]: 0 terminated type/offset list */
-    int     argMap[36];
+    int32_t     argMap[36];
     CsoundArgStack_t  *pp;
-    int     initDone;
+    int32_t     initDone;
 } POP_OPCODE;
 
 /* fsg_assign() was taken from pstream.c, written by Richard Dobson */
@@ -96,7 +96,8 @@ static CS_NOINLINE void fsg_assign(CSOUND *csound,
                                 PVSDAT *fdst, const PVSDAT *fsrc)
 {
   if (UNLIKELY(fsrc->frame.auxp == NULL)) {
-      csound->ErrorMsg(csound, Str("fsig = : source signal is not initialised"));
+      csound->ErrorMsg(csound, "%s",
+                       Str("fsig = : source signal is not initialised"));
       return;
   }
     fdst->N = fsrc->N;
@@ -107,7 +108,7 @@ static CS_NOINLINE void fsg_assign(CSOUND *csound,
     if (fdst->frame.auxp == NULL ||
         fdst->frame.size != (uint32_t)((fdst->N + 2L) * sizeof(float)))
       csound->AuxAlloc(csound,
-                       (fdst->N + 2L) * (long) sizeof(float), &(fdst->frame));
+                       (fdst->N + 2L) * (int64_t) sizeof(float), &(fdst->frame));
     if (fdst->framecount != fsrc->framecount) {
       memcpy((float*) fdst->frame.auxp, (float*) fsrc->frame.auxp,
              ((size_t) fdst->N + (size_t) 2) * sizeof(float));
@@ -115,12 +116,12 @@ static CS_NOINLINE void fsg_assign(CSOUND *csound,
     }
 }
 
-static inline int csoundStack_Align(int n)
+static inline int32_t csoundStack_Align(int32_t n)
 {
     return ((n + (CS_STACK_ALIGN - 1)) & (~(CS_STACK_ALIGN - 1)));
 }
 
-static CS_NOINLINE int csoundStack_Error(void *p, const char *msg)
+static CS_NOINLINE int32_t csoundStack_Error(void *p, const char *msg)
 {
     CSOUND  *csound;
 
@@ -130,53 +131,53 @@ static CS_NOINLINE int csoundStack_Error(void *p, const char *msg)
     return NOTOK;
 }
 
-static CS_NOINLINE int csoundStack_OverflowError(void *p)
+static CS_NOINLINE int32_t csoundStack_OverflowError(void *p)
 {
     /* CSOUND  *csound= ((OPDS*) p)->insdshead->csound; */
-    return csoundStack_Error(p, Str("stack overflow"));
+    return csoundStack_Error(p, "stack overflow");
 }
 
-static CS_NOINLINE int csoundStack_EmptyError(void *p)
+static CS_NOINLINE int32_t csoundStack_EmptyError(void *p)
 {
     /* CSOUND  *csound((OPDS*) p)->insdshead->csound; */
-    return csoundStack_Error(p, Str("cannot pop from empty stack"));
+    return csoundStack_Error(p, "cannot pop from empty stack");
 }
 
-static CS_NOINLINE int csoundStack_TypeError(void *p)
+static CS_NOINLINE int32_t csoundStack_TypeError(void *p)
 {
     /* CSOUND  *csound = ((OPDS*) p)->insdshead->csound; */
-    return csoundStack_Error(p, Str("argument number or type mismatch"));
+    return csoundStack_Error(p, "argument number or type mismatch");
 }
 
-/* static CS_NOINLINE int csoundStack_LengthError(void *p) */
+/* static CS_NOINLINE int32_t csoundStack_LengthError(void *p) */
 /* { */
 /*     /\* CSOUND  *csound = ((OPDS*) p)->insdshead->csound; *\/ */
 /*     return csoundStack_Error(p, Str("string argument is too long")); */
 /* } */
 
 static CS_NOINLINE CsoundArgStack_t *csoundStack_AllocGlobals(CSOUND *csound,
-                                                              int stackSize)
+                                                              int32_t stackSize)
 {
     CsoundArgStack_t  *pp;
-    int               nBytes;
+    int32_t               nBytes;
 
     if (UNLIKELY(stackSize < 1024))
       stackSize = 1024;
     else if (UNLIKELY(stackSize > 16777200))
       stackSize = 16777200;
-    nBytes = csoundStack_Align((int) sizeof(CsoundArgStack_t));
+    nBytes = csoundStack_Align((int32_t) sizeof(CsoundArgStack_t));
     nBytes += stackSize;
     if (UNLIKELY(csound->CreateGlobalVariable(csound,
                                               "csArgStack", (size_t) nBytes)
                  != 0)) {
-      csound->ErrorMsg(csound, Str("Error allocating argument stack"));
+      csound->ErrorMsg(csound, "%s", Str("Error allocating argument stack"));
       return NULL;
     }
     pp = (CsoundArgStack_t*) csound->QueryGlobalVariable(csound, "csArgStack");
     pp->curBundle = (CsoundArgStack_t*) NULL;
     pp->dataSpace =
         (void*) ((char*) pp
-                 + (int) csoundStack_Align((int) sizeof(CsoundArgStack_t)));
+                 + (int32_t) csoundStack_Align((int32_t) sizeof(CsoundArgStack_t)));
     pp->freeSpaceOffset = 0;
     pp->freeSpaceEndOffset = stackSize;
 
@@ -193,11 +194,11 @@ static CS_NOINLINE CsoundArgStack_t *csoundStack_GetGlobals(CSOUND *csound)
     return pp;
 }
 
-static CS_NOINLINE int csoundStack_CreateArgMap(PUSH_OPCODE *p, int *argMap,
-                                                int isOutput)
+static CS_NOINLINE int32_t csoundStack_CreateArgMap(PUSH_OPCODE *p, int32_t *argMap,
+                                                int32_t isOutput)
 {
     CSOUND  *csound;
-    int     i, argCnt, argCnt_i, argCnt_p, curOffs_i, curOffs_p;
+    int32_t     i, argCnt, argCnt_i, argCnt_p, curOffs_i, curOffs_p;
     MYFLT** args = p->args;
 
     csound = ((OPDS*) p)->insdshead->csound;
@@ -208,12 +209,12 @@ static CS_NOINLINE int csoundStack_CreateArgMap(PUSH_OPCODE *p, int *argMap,
       argCnt = csound->GetOutputArgCnt(p);
     }
     if (UNLIKELY(argCnt > 31))
-      return csoundStack_Error(p, Str("too many arguments"));
+      return csoundStack_Error(p, "too many arguments");
     argMap[0] = 0;
     argCnt_i = 0;
     argCnt_p = 0;
     for (i = 0; i < argCnt; i++) {
-      int   maskVal = (1 << i);
+      int32_t   maskVal = (1 << i);
       if (ASIG_ARG_P(csound, args[i])) {
         argMap[0] |= maskVal;
         argCnt_p++;
@@ -238,36 +239,36 @@ static CS_NOINLINE int csoundStack_CreateArgMap(PUSH_OPCODE *p, int *argMap,
           argCnt_i++;
       }
     }
-    curOffs_i = (int) sizeof(void*);
+    curOffs_i = (int32_t) sizeof(void*);
     curOffs_i = csoundStack_Align(curOffs_i);
     curOffs_p = curOffs_i;
-    curOffs_i += ((int) sizeof(int) * (argCnt_i + 1));
+    curOffs_i += ((int32_t) sizeof(int32_t) * (argCnt_i + 1));
     curOffs_i = csoundStack_Align(curOffs_i);
-    curOffs_p += ((int) sizeof(int) * (argCnt_p + 1));
+    curOffs_p += ((int32_t) sizeof(int32_t) * (argCnt_p + 1));
     curOffs_p = csoundStack_Align(curOffs_p);
     for (i = 0; i < argCnt; i++) {
-      int   maskVal = (1 << i);
+      int32_t   maskVal = (1 << i);
       if (argMap[0] & maskVal) {
         /* performance time types */
         if (ASIG_ARG_P(csound, args[i])) {
           argMap[i + 3] = (curOffs_p | CS_STACK_A);
-          curOffs_p += ((int) sizeof(MYFLT) * CS_KSMPS);
+          curOffs_p += ((int32_t) sizeof(MYFLT) * CS_KSMPS);
         }
         else {
           argMap[i + 3] = (curOffs_p | CS_STACK_K);
-          curOffs_p += (int) sizeof(MYFLT);
+          curOffs_p += (int32_t) sizeof(MYFLT);
         }
       }
       else {
         /* init time types */
         if (STR_ARG_P(csound, args[i])) {
           argMap[i + 3] = (curOffs_i | CS_STACK_S);
-          curOffs_i += (int) sizeof(STRINGDAT);
+          curOffs_i += (int32_t) sizeof(STRINGDAT);
             /* curOffs_i = csoundStack_Align(curOffs_i);*/
         }
         else {
           argMap[i + 3] = (curOffs_i | CS_STACK_I);
-          curOffs_i += (int) sizeof(MYFLT);
+          curOffs_i += (int32_t) sizeof(MYFLT);
         }
       }
     }
@@ -284,40 +285,42 @@ static CS_NOINLINE int csoundStack_CreateArgMap(PUSH_OPCODE *p, int *argMap,
     return OK;
 }
 
-static int stack_opcode_init(CSOUND *csound, STACK_OPCODE *p)
+static int32_t stack_opcode_init(CSOUND *csound, STACK_OPCODE *p)
 {
     if (UNLIKELY(csound->QueryGlobalVariable(csound, "csArgStack") != NULL))
-      return csound->InitError(csound, Str("the stack is already allocated"));
-    csoundStack_AllocGlobals(csound, (int) (*(p->iStackSize) + 0.5));
+      return csound->InitError(csound, "%s", Str("the stack is already allocated"));
+    csoundStack_AllocGlobals(csound, (int32_t) (*(p->iStackSize) + 0.5));
     return OK;
 }
 
-static int notinit_opcode_stub_perf(CSOUND *csound, void *p)
+static int32_t notinit_opcode_stub_perf(CSOUND *csound, void *p)
 {
     return csound->PerfError(csound, ((OPDS*)p)->insdshead,
                              Str("%s: not initialised"),
                              csound->GetOpcodeName(p));
 }
 
-static int push_opcode_perf(CSOUND *csound, PUSH_OPCODE *p)
+static int32_t push_opcode_perf(CSOUND *csound, PUSH_OPCODE *p)
 {
+     IGN(csound);
     if (p->argMap[2] != 0) {
       void  *bp;
-      int   i, *ofsp;
+      int32_t   i, *ofsp;
       if (p->pp->freeSpaceOffset + p->argMap[2] > p->pp->freeSpaceEndOffset)
         return csoundStack_OverflowError(p);
-      bp = (void*) ((char*) p->pp->dataSpace + (int) p->pp->freeSpaceOffset);
+      bp = (void*) ((char*) p->pp->dataSpace + (int32_t) p->pp->freeSpaceOffset);
       p->pp->freeSpaceOffset += p->argMap[2];
       *((void**) bp) = p->pp->curBundle;
       p->pp->curBundle = bp;
-      ofsp = (int*) ((char*) bp + (int) csoundStack_Align((int) sizeof(void*)));
+      ofsp = (int32_t*) ((char*) bp +
+                         (int32_t) csoundStack_Align((int32_t) sizeof(void*)));
       for (i = 0; p->argMap[i + 3] != CS_STACK_END; i++) {
         if (p->argMap[0] & (1 << i)) {
-          int   curOffs = p->argMap[i + 3];
+          int32_t   curOffs = p->argMap[i + 3];
           *(ofsp++) = curOffs;
-          switch (curOffs & (int) 0x7F000000) {
+          switch (curOffs & (int32_t) 0x7F000000) {
           case CS_STACK_K:
-            *((MYFLT*) ((char*) bp + (int) (curOffs & (int) 0x00FFFFFF))) =
+            *((MYFLT*) ((char*) bp + (int32_t) (curOffs & (int32_t) 0x00FFFFFF))) =
                 *(p->args[i]);
             break;
           case CS_STACK_A:
@@ -327,7 +330,8 @@ static int push_opcode_perf(CSOUND *csound, PUSH_OPCODE *p)
               uint32_t early  = p->h.insdshead->ksmps_no_end;
               uint32_t nsmps = CS_KSMPS;
               src = p->args[i];
-              dst = (MYFLT*) ((char*) bp + (int) (curOffs & (int) 0x00FFFFFF));
+              dst = (MYFLT*) ((char*) bp +
+                              (int32_t) (curOffs & (int32_t) 0x00FFFFFF));
               if (UNLIKELY(offset)) memset(dst, '\0', offset*sizeof(MYFLT));
               if (UNLIKELY(early)) {
                 nsmps -= early;
@@ -345,42 +349,44 @@ static int push_opcode_perf(CSOUND *csound, PUSH_OPCODE *p)
     return OK;
 }
 
-static int push_opcode_init(CSOUND *csound, PUSH_OPCODE *p)
+static int32_t push_opcode_init(CSOUND *csound, PUSH_OPCODE *p)
 {
     if (!p->initDone) {
       p->pp = csoundStack_GetGlobals(csound);
-      if (UNLIKELY(csoundStack_CreateArgMap(p, (int*)&(p->argMap[0]), 0) != OK))
+      if (UNLIKELY(csoundStack_CreateArgMap(p, (int32_t*)&(p->argMap[0]), 0) != OK))
         return NOTOK;
-      p->h.opadr = (int (*)(CSOUND *, void *)) push_opcode_perf;
+      p->h.opadr = (int32_t (*)(CSOUND *, void *)) push_opcode_perf;
       p->initDone = 1;
     }
     if (p->argMap[1] != 0) {
       void  *bp;
-      int   i, *ofsp;
+      int32_t   i, *ofsp;
       if (UNLIKELY(p->pp->freeSpaceOffset + p->argMap[1] >
                    p->pp->freeSpaceEndOffset))
         return csoundStack_OverflowError(p);
-      bp = (void*) ((char*) p->pp->dataSpace + (int) p->pp->freeSpaceOffset);
+      bp = (void*) ((char*) p->pp->dataSpace + (int32_t) p->pp->freeSpaceOffset);
       p->pp->freeSpaceOffset += p->argMap[1];
       *((void**) bp) = p->pp->curBundle;
       p->pp->curBundle = bp;
-      ofsp = (int*) ((char*) bp + (int) csoundStack_Align((int) sizeof(void*)));
+      ofsp = (int32_t*) ((char*) bp +
+                         (int32_t) csoundStack_Align((int32_t) sizeof(void*)));
       for (i = 0; p->argMap[i + 3] != CS_STACK_END; i++) {
         if (!(p->argMap[0] & (1 << i))) {
-          int   curOffs = p->argMap[i + 3];
+          int32_t   curOffs = p->argMap[i + 3];
           *(ofsp++) = curOffs;
-          switch (curOffs & (int) 0x7F000000) {
+          switch (curOffs & (int32_t) 0x7F000000) {
           case CS_STACK_I:
-            *((MYFLT*) ((char*) bp + (int) (curOffs & (int) 0x00FFFFFF))) =
+            *((MYFLT*) ((char*) bp + (int32_t) (curOffs & (int32_t) 0x00FFFFFF))) =
                 *(p->args[i]);
             break;
           case CS_STACK_S:
             {
               char  *src;
               STRINGDAT **ans, *dst;
-              /* int   j, maxLen; */
+              /* int32_t   j, maxLen; */
               src = ((STRINGDAT*) p->args[i])->data;
-              ans = ((STRINGDAT**)(char*) bp + (int) (curOffs & (int) 0x00FFFFFF));
+              ans = ((STRINGDAT**)(char*) bp +
+                     (int32_t) (curOffs & (int32_t) 0x00FFFFFF));
               dst = (STRINGDAT*) csound->Malloc(csound, sizeof(STRINGDAT));
               dst->data = csound->Strdup(csound, src);
               dst->size = strlen(src) + 1;
@@ -396,25 +402,28 @@ static int push_opcode_init(CSOUND *csound, PUSH_OPCODE *p)
     return OK;
 }
 
-static int pop_opcode_perf(CSOUND *csound, POP_OPCODE *p)
+static int32_t pop_opcode_perf(CSOUND *csound, POP_OPCODE *p)
 {
+     IGN(csound);
     if (p->argMap[2] != 0) {
       void  *bp;
-      int   i, *ofsp;
+      int32_t   i, *ofsp;
       if (UNLIKELY(p->pp->curBundle == NULL))
         return csoundStack_EmptyError(p);
       bp = p->pp->curBundle;
-      ofsp = (int*) ((char*) bp + (int) csoundStack_Align((int) sizeof(void*)));
+      ofsp = (int32_t*) ((char*) bp +
+                         (int32_t) csoundStack_Align((int32_t) sizeof(void*)));
       for (i = 0; *ofsp != CS_STACK_END; i++) {
         if (p->argMap[0] & (1 << i)) {
-          int   curOffs = p->argMap[i + 3];
+          int32_t   curOffs = p->argMap[i + 3];
           if (curOffs != *ofsp)
             csoundStack_TypeError(p);
           ofsp++;
-          switch (curOffs & (int) 0x7F000000) {
+          switch (curOffs & (int32_t) 0x7F000000) {
           case CS_STACK_K:
             *(p->args[i]) =
-                *((MYFLT*) ((char*) bp + (int) (curOffs & (int) 0x00FFFFFF)));
+                *((MYFLT*) ((char*) bp +
+                            (int32_t) (curOffs & (int32_t) 0x00FFFFFF)));
             break;
           case CS_STACK_A:
             {
@@ -422,7 +431,8 @@ static int pop_opcode_perf(CSOUND *csound, POP_OPCODE *p)
               uint32_t offset = p->h.insdshead->ksmps_offset;
               uint32_t early  = p->h.insdshead->ksmps_no_end;
               uint32_t nsmps = CS_KSMPS;
-              src = (MYFLT*) ((char*) bp + (int) (curOffs & (int) 0x00FFFFFF));
+              src = (MYFLT*) ((char*) bp +
+                              (int32_t) (curOffs & (int32_t) 0x00FFFFFF));
               dst = p->args[i];
               if (UNLIKELY(offset)) memset(dst, '\0', offset*sizeof(MYFLT));
               if (UNLIKELY(early)) {
@@ -438,43 +448,46 @@ static int pop_opcode_perf(CSOUND *csound, POP_OPCODE *p)
         }
       }
       p->pp->curBundle = *((void**) bp);
-      p->pp->freeSpaceOffset = (int) ((char*) bp - (char*) p->pp->dataSpace);
+      p->pp->freeSpaceOffset = (int32_t) ((char*) bp - (char*) p->pp->dataSpace);
     }
     return OK;
 }
 
-static int pop_opcode_init(CSOUND *csound, POP_OPCODE *p)
+static int32_t pop_opcode_init(CSOUND *csound, POP_OPCODE *p)
 {
     if (!p->initDone) {
       p->pp = csoundStack_GetGlobals(csound);
       if (UNLIKELY(csoundStack_CreateArgMap((PUSH_OPCODE*)p,
                                             &(p->argMap[0]), 1) != OK))
         return NOTOK;
-      p->h.opadr = (int (*)(CSOUND *, void *)) pop_opcode_perf;
+      p->h.opadr = (int32_t (*)(CSOUND *, void *)) pop_opcode_perf;
       p->initDone = 1;
     }
     if (p->argMap[1] != 0) {
       void  *bp;
-      int   i, *ofsp;
+      int32_t   i, *ofsp;
       if (p->pp->curBundle == NULL)
         return csoundStack_EmptyError(p);
       bp = p->pp->curBundle;
-      ofsp = (int*) ((char*) bp + (int) csoundStack_Align((int) sizeof(void*)));
+      ofsp = (int32_t*) ((char*) bp +
+                         (int32_t) csoundStack_Align((int32_t) sizeof(void*)));
       for (i = 0; *ofsp != CS_STACK_END; i++) {
         if (!(p->argMap[0] & (1 << i))) {
-          int   curOffs = p->argMap[i + 3];
+          int32_t   curOffs = p->argMap[i + 3];
           if (curOffs != *ofsp)
             csoundStack_TypeError(p);
           ofsp++;
-          switch (curOffs & (int) 0x7F000000) {
+          switch (curOffs & (int32_t) 0x7F000000) {
           case CS_STACK_I:
             *(p->args[i]) =
-                *((MYFLT*) ((char*) bp + (int) (curOffs & (int) 0x00FFFFFF)));
+                *((MYFLT*) ((char*) bp +
+                            (int32_t) (curOffs & (int32_t) 0x00FFFFFF)));
             break;
           case CS_STACK_S:
             {
               STRINGDAT **ans =
-                ((STRINGDAT**)(char*) bp + (int) (curOffs & (int) 0x00FFFFFF));
+                ((STRINGDAT**)(char*) bp +
+                 (int32_t) (curOffs & (int32_t) 0x00FFFFFF));
               STRINGDAT *str = *ans;
               STRINGDAT *dst = (STRINGDAT*)p->args[i];
               /* printf("***string: %p\nbp=%p Off = %x\n", ans, bp, curOffs); */
@@ -498,45 +511,47 @@ static int pop_opcode_init(CSOUND *csound, POP_OPCODE *p)
         }
       }
       p->pp->curBundle = *((void**) bp);
-      p->pp->freeSpaceOffset = (int) ((char*) bp - (char*) p->pp->dataSpace);
+      p->pp->freeSpaceOffset = (int32_t) ((char*) bp - (char*) p->pp->dataSpace);
     }
     return OK;
 }
 
-static int push_f_opcode_perf(CSOUND *csound, PUSH_OPCODE *p)
+static int32_t push_f_opcode_perf(CSOUND *csound, PUSH_OPCODE *p)
 {
+    IGN(csound);
     void    *bp;
-    int     *ofsp;
-    int     offs;
+    int32_t     *ofsp;
+    int32_t     offs;
 
     if (UNLIKELY(p->pp->freeSpaceOffset + p->argMap[2] >
                  p->pp->freeSpaceEndOffset))
       return csoundStack_OverflowError(p);
-    bp = (void*) ((char*) p->pp->dataSpace + (int) p->pp->freeSpaceOffset);
+    bp = (void*) ((char*) p->pp->dataSpace + (int32_t) p->pp->freeSpaceOffset);
     p->pp->freeSpaceOffset += p->argMap[2];
     *((void**) bp) = p->pp->curBundle;
     p->pp->curBundle = bp;
-    ofsp = (int*) ((char*) bp + (int) csoundStack_Align((int) sizeof(void*)));
+    ofsp = (int32_t*) ((char*) bp +
+                       (int32_t) csoundStack_Align((int32_t) sizeof(void*)));
     offs = p->argMap[3];
     *(ofsp++) = offs;
-    *((PVSDAT**) ((char*) bp + (int) (offs & (int) 0x00FFFFFF))) =
+    *((PVSDAT**) ((char*) bp + (int32_t) (offs & (int32_t) 0x00FFFFFF))) =
         (PVSDAT*) ((char*) p->args[0]);
     *ofsp = CS_STACK_END;
 
     return OK;
 }
 
-static int push_f_opcode_init(CSOUND *csound, PUSH_OPCODE *p)
+static int32_t push_f_opcode_init(CSOUND *csound, PUSH_OPCODE *p)
 {
     void    *bp;
-    int     *ofsp;
-    int     offs;
+    int32_t     *ofsp;
+    int32_t     offs;
 
     if (!p->initDone) {
       p->pp = csoundStack_GetGlobals(csound);
-      offs = (int) sizeof(void*);
+      offs = (int32_t) sizeof(void*);
       offs = csoundStack_Align(offs);
-      offs += ((int) sizeof(int) * 2);
+      offs += ((int32_t) sizeof(int32_t) * 2);
       offs = csoundStack_Align(offs);
       /* the 'f' type is special: */
       /*   it is copied at both init and performance time */
@@ -545,39 +560,41 @@ static int push_f_opcode_init(CSOUND *csound, PUSH_OPCODE *p)
       p->argMap[4] = CS_STACK_END;
       /* FIXME: store only the address of the f-signal on the stack */
       /* this may be dangerous... */
-      offs += (int) sizeof(PVSDAT*);
+      offs += (int32_t) sizeof(PVSDAT*);
       offs = csoundStack_Align(offs);
       p->argMap[1] = offs;
       p->argMap[2] = offs;
-      p->h.opadr = (int (*)(CSOUND *, void *)) push_f_opcode_perf;
+      p->h.opadr = (int32_t (*)(CSOUND *, void *)) push_f_opcode_perf;
       p->initDone = 1;
     }
     if (UNLIKELY(p->pp->freeSpaceOffset + p->argMap[1] > p->pp->freeSpaceEndOffset))
       return csoundStack_OverflowError(p);
-    bp = (void*) ((char*) p->pp->dataSpace + (int) p->pp->freeSpaceOffset);
+    bp = (void*) ((char*) p->pp->dataSpace + (int32_t) p->pp->freeSpaceOffset);
     p->pp->freeSpaceOffset += p->argMap[1];
     *((void**) bp) = p->pp->curBundle;
     p->pp->curBundle = bp;
-    ofsp = (int*) ((char*) bp + (int) csoundStack_Align((int) sizeof(void*)));
+    ofsp = (int32_t*) ((char*) bp +
+                       (int32_t) csoundStack_Align((int32_t) sizeof(void*)));
     offs = p->argMap[3];
     *(ofsp++) = offs;
-    *((PVSDAT**) ((char*) bp + (int) (offs & (int) 0x00FFFFFF))) =
+    *((PVSDAT**) ((char*) bp + (int32_t) (offs & (int32_t) 0x00FFFFFF))) =
         (PVSDAT*) ((char*) p->args[0]);
     *ofsp = CS_STACK_END;
 
     return OK;
 }
 
-static int pop_f_opcode_perf(CSOUND *csound, POP_OPCODE *p)
+static int32_t pop_f_opcode_perf(CSOUND *csound, POP_OPCODE *p)
 {
     void    *bp;
-    int     *ofsp;
-    int     offs;
+    int32_t     *ofsp;
+    int32_t     offs;
 
     if (UNLIKELY(p->pp->curBundle == NULL))
       return csoundStack_EmptyError(p);
     bp = p->pp->curBundle;
-    ofsp = (int*) ((char*) bp + (int) csoundStack_Align((int) sizeof(void*)));
+    ofsp = (int32_t*) ((char*) bp +
+                       (int32_t) csoundStack_Align((int32_t) sizeof(void*)));
     offs = p->argMap[3];
     if (UNLIKELY(offs != *ofsp))
       csoundStack_TypeError(p);
@@ -586,24 +603,24 @@ static int pop_f_opcode_perf(CSOUND *csound, POP_OPCODE *p)
       csoundStack_TypeError(p);
     fsg_assign(csound,
             (PVSDAT*) p->args[0],
-            *((PVSDAT**) ((char*) bp + (int) (offs & (int) 0x00FFFFFF))));
+            *((PVSDAT**) ((char*) bp + (int32_t) (offs & (int32_t) 0x00FFFFFF))));
     p->pp->curBundle = *((void**) bp);
-    p->pp->freeSpaceOffset = (int) ((char*) bp - (char*) p->pp->dataSpace);
+    p->pp->freeSpaceOffset = (int32_t) ((char*) bp - (char*) p->pp->dataSpace);
 
     return OK;
 }
 
-static int pop_f_opcode_init(CSOUND *csound, POP_OPCODE *p)
+static int32_t pop_f_opcode_init(CSOUND *csound, POP_OPCODE *p)
 {
     void    *bp;
-    int     *ofsp;
-    int     offs;
+    int32_t     *ofsp;
+    int32_t     offs;
 
     if (!p->initDone) {
       p->pp = csoundStack_GetGlobals(csound);
-      offs = (int) sizeof(void*);
+      offs = (int32_t) sizeof(void*);
       offs = csoundStack_Align(offs);
-      offs += ((int) sizeof(int) * 2);
+      offs += ((int32_t) sizeof(int32_t) * 2);
       offs = csoundStack_Align(offs);
       /* the 'f' type is special: */
       /*   it is copied at both init and performance time */
@@ -612,17 +629,18 @@ static int pop_f_opcode_init(CSOUND *csound, POP_OPCODE *p)
       p->argMap[4] = CS_STACK_END;
       /* FIXME: only the address of the f-signal is stored on the stack */
       /* this may be dangerous... */
-      offs += (int) sizeof(PVSDAT*);
+      offs += (int32_t) sizeof(PVSDAT*);
       offs = csoundStack_Align(offs);
       p->argMap[1] = offs;
       p->argMap[2] = offs;
-      p->h.opadr = (int (*)(CSOUND *, void *)) pop_f_opcode_perf;
+      p->h.opadr = (int32_t (*)(CSOUND *, void *)) pop_f_opcode_perf;
       p->initDone = 1;
     }
     if (UNLIKELY(p->pp->curBundle == NULL))
       return csoundStack_EmptyError(p);
     bp = p->pp->curBundle;
-    ofsp = (int*) ((char*) bp + (int) csoundStack_Align((int) sizeof(void*)));
+    ofsp = (int32_t*) ((char*) bp +
+                       (int32_t) csoundStack_Align((int32_t) sizeof(void*)));
     offs = p->argMap[3];
     if (UNLIKELY(offs != *ofsp))
       csoundStack_TypeError(p);
@@ -631,9 +649,9 @@ static int pop_f_opcode_init(CSOUND *csound, POP_OPCODE *p)
       csoundStack_TypeError(p);
     fsg_assign(csound,
             (PVSDAT*) p->args[0],
-            *((PVSDAT**) ((char*) bp + (int) (offs & (int) 0x00FFFFFF))));
+            *((PVSDAT**) ((char*) bp + (int32_t) (offs & (int32_t) 0x00FFFFFF))));
     p->pp->curBundle = *((void**) bp);
-    p->pp->freeSpaceOffset = (int) ((char*) bp - (char*) p->pp->dataSpace);
+    p->pp->freeSpaceOffset = (int32_t) ((char*) bp - (char*) p->pp->dataSpace);
 
     return OK;
 }
