@@ -17,8 +17,8 @@
 
     You should have received a copy of the GNU Lesser General Public
     License along with Csound; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-    02111-1307 USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+    02110-1301 USA
 */
 
 #include "stdopcod.h"   /*                                      UGENS9.C        */
@@ -26,14 +26,15 @@
 #include "convolve.h"
 #include "ugens9.h"
 #include "soundio.h"
+#include <inttypes.h>
 
-static int cvset_(CSOUND *csound, CONVOLVE *p, int stringname)
+static int32_t cvset_(CSOUND *csound, CONVOLVE *p, int32_t stringname)
 {
     char     cvfilnam[MAXNAME];
     MEMFIL   *mfp;
     MYFLT    *fltp;
     CVSTRUCT *cvh;
-    int       siz;
+    int32_t       siz;
     int32     Hlenpadded = 1, obufsiz, Hlen;
     uint32_t  nchanls;
     uint32_t  nsmps = CS_KSMPS;
@@ -43,10 +44,10 @@ static int cvset_(CSOUND *csound, CONVOLVE *p, int stringname)
 
     if (stringname==0){
       if (csound->ISSTRCOD(*p->ifilno))
-        strncpy(cvfilnam,get_arg_string(csound, *p->ifilno), MAXNAME-1);
+        strNcpy(cvfilnam,get_arg_string(csound, *p->ifilno), MAXNAME-1);
       else csound->strarg2name(csound, cvfilnam,p->ifilno, "convolve.",0);
     }
-    else strncpy(cvfilnam, ((STRINGDAT *)p->ifilno)->data, MAXNAME-1);
+    else strNcpy(cvfilnam, ((STRINGDAT *)p->ifilno)->data, MAXNAME-1);
 
     if ((mfp = p->mfp) == NULL || strcmp(mfp->filename, cvfilnam) != 0) {
       /* if file not already readin */
@@ -60,7 +61,7 @@ static int cvset_(CSOUND *csound, CONVOLVE *p, int stringname)
     cvh = (CVSTRUCT *)mfp->beginp;
     if (UNLIKELY(cvh->magic != CVMAGIC)) {
       return csound->InitError(csound,
-                               Str("%s not a CONVOLVE file (magic %d)"),
+                               Str("%s not a CONVOLVE file (magic %"PRIi32")"),
                                cvfilnam, cvh->magic);
     }
 
@@ -97,7 +98,7 @@ static int cvset_(CSOUND *csound, CONVOLVE *p, int stringname)
     p->Hlenpadded = Hlenpadded;
     p->H = (MYFLT *) ((char *)cvh+cvh->headBsize);
     if ((p->nchanls == 1) && (*p->channel > 0))
-      p->H += (Hlenpadded + 2) * (int)(*p->channel - 1);
+      p->H += (Hlenpadded + 2) * (int32_t)(*p->channel - 1);
 
     if (UNLIKELY(cvh->samplingRate != CS_ESR)) {
       /* & chk the data */
@@ -107,7 +108,7 @@ static int cvset_(CSOUND *csound, CONVOLVE *p, int stringname)
     if (UNLIKELY(cvh->dataFormat != CVMYFLT)) {
       return csound->InitError(csound,
                                Str("unsupported CONVOLVE data "
-                                   "format %d in %s"),
+                                   "format %"PRIi32" in %s"),
                                cvh->dataFormat, cvfilnam);
     }
 
@@ -143,12 +144,12 @@ static int cvset_(CSOUND *csound, CONVOLVE *p, int stringname)
     return OK;
 }
 
-static int cvset(CSOUND *csound, CONVOLVE *p){
+static int32_t cvset(CSOUND *csound, CONVOLVE *p){
   return cvset_(csound,p,0);
 
 }
 
-static int cvset_S(CSOUND *csound, CONVOLVE *p){
+static int32_t cvset_S(CSOUND *csound, CONVOLVE *p){
   return cvset_(csound,p,1);
 
 }
@@ -182,10 +183,10 @@ static void writeFromCircBuf(
     return;
 }
 
-static int convolve(CSOUND *csound, CONVOLVE *p)
+static int32_t convolve(CSOUND *csound, CONVOLVE *p)
 {
-    int    nsmpso=CS_KSMPS,nsmpsi=CS_KSMPS,outcnt_sav;
-    int    nchm1 = p->nchanls - 1,chn;
+    int32_t    nsmpso=CS_KSMPS,nsmpsi=CS_KSMPS,outcnt_sav;
+    int32_t    nchm1 = p->nchanls - 1,chn;
     int32  i,j;
     MYFLT  *ar[4];
     MYFLT  *ai = p->ain;
@@ -205,7 +206,7 @@ static int convolve(CSOUND *csound, CONVOLVE *p)
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t nn,nsmpso_sav;
 
-    scaleFac = csound->GetInverseRealFFTScale(csound, (int) Hlenpadded);
+    scaleFac = csound->GetInverseRealFFTScale(csound, (int32_t) Hlenpadded);
     ar[0] = p->ar1;
     ar[1] = p->ar2;
     ar[2] = p->ar3;
@@ -214,7 +215,7 @@ static int convolve(CSOUND *csound, CONVOLVE *p)
     if (UNLIKELY(p->auxch.auxp==NULL)) goto err1;
     /* First dump as much pre-existing audio in output buffer as possible */
     if (outcnt > 0) {
-      if (outcnt <= (int)CS_KSMPS)
+      if (outcnt <= (int32_t)CS_KSMPS)
         i = outcnt;
       else
         i = CS_KSMPS;
@@ -275,10 +276,10 @@ static int convolve(CSOUND *csound, CONVOLVE *p)
 
           {
             MYFLT *a, *b, re, im;
-            int   i;
-            a = (MYFLT*) p->H + (int) (chn * (Hlenpadded + 2));
+            int32_t   i;
+            a = (MYFLT*) p->H + (int32_t) (chn * (Hlenpadded + 2));
             b = (MYFLT*) p->fftbuf;
-            for (i = 0; i <= (int) Hlenpadded; i += 2) {
+            for (i = 0; i <= (int32_t) Hlenpadded; i += 2) {
               re = a[i + 0] * b[i + 0] - a[i + 1] * b[i + 1];
               im = a[i + 0] * b[i + 1] + a[i + 1] * b[i + 0];
               b[i + 0] = re;
@@ -376,9 +377,9 @@ static int convolve(CSOUND *csound, CONVOLVE *p)
    allow this opcode to accept .con files.
    -ma++ april 2004 */
 
-static int pconvset_(CSOUND *csound, PCONVOLVE *p, int stringname)
+static int32_t pconvset_(CSOUND *csound, PCONVOLVE *p, int32_t stringname)
 {
-    int     channel = (*(p->channel) <= 0 ? ALLCHNLS : (int) *(p->channel));
+    int32_t     channel = (*(p->channel) <= 0 ? ALLCHNLS : (int32_t) *(p->channel));
     SNDFILE *infd;
     SOUNDIN IRfile;
     MYFLT   *inbuf, *fp1,*fp2;
@@ -394,10 +395,10 @@ static int pconvset_(CSOUND *csound, PCONVOLVE *p, int stringname)
 
      if (stringname==0){
       if (csound->ISSTRCOD(*p->ifilno))
-        strncpy(IRfile.sfname,get_arg_string(csound, *p->ifilno), 511);
+        strNcpy(IRfile.sfname,get_arg_string(csound, *p->ifilno), 511);
       else csound->strarg2name(csound, IRfile.sfname, p->ifilno, "soundin.",0);
     }
-    else strncpy(IRfile.sfname, ((STRINGDAT *)p->ifilno)->data, 511);
+    else strNcpy(IRfile.sfname, ((STRINGDAT *)p->ifilno)->data, 511);
 
     IRfile.sr = 0;
     if (UNLIKELY(channel < 1 || ((channel > 4) && (channel != ALLCHNLS)))) {
@@ -424,7 +425,7 @@ static int pconvset_(CSOUND *csound, PCONVOLVE *p, int stringname)
                             (long) IRfile.getframes, ainput_dur);
 
     p->nchanls = (channel != ALLCHNLS ? 1 : IRfile.nchanls);
-    if (UNLIKELY(p->nchanls != (int)p->OUTOCOUNT)) {
+    if (UNLIKELY(p->nchanls != (int32_t)p->OUTOCOUNT)) {
       return csound->InitError(csound, Str("PCONVOLVE: number of output channels "
                                            "not equal to input channels"));
     }
@@ -468,7 +469,7 @@ static int pconvset_(CSOUND *csound, PCONVOLVE *p, int stringname)
 
       /* take FFT of each channel */
       scaleFac = csound->dbfs_to_float
-                 * csound->GetInverseRealFFTScale(csound, (int) p->Hlenpadded);
+                 * csound->GetInverseRealFFTScale(csound, (int32_t) p->Hlenpadded);
       for (i = 0; i < p->nchanls; i++) {
         fp1 = inbuf + i;
         fp2 = IRblock;
@@ -502,7 +503,7 @@ static int pconvset_(CSOUND *csound, PCONVOLVE *p, int stringname)
 
     /* allocate circular output sample buffer */
     p->outBufSiz = sizeof(MYFLT) * p->nchanls *
-      (p->Hlen >= (int)CS_KSMPS ? p->Hlenpadded : 2*(int)CS_KSMPS);
+      (p->Hlen >= (int32_t)CS_KSMPS ? p->Hlenpadded : 2*(int32_t)CS_KSMPS);
     csound->AuxAlloc(csound, p->outBufSiz, &p->output);
     p->outRead = (MYFLT *)p->output.auxp;
 
@@ -510,7 +511,7 @@ static int pconvset_(CSOUND *csound, PCONVOLVE *p, int stringname)
        empty ksmps pass after a few initial generated buffers.  There is
        probably an equation to figure this out to reduce the delay, but
        I can't seem to figure it out */
-    if (p->Hlen > (int)CS_KSMPS) {
+    if (p->Hlen > (int32_t)CS_KSMPS) {
       p->outCount = p->Hlen + CS_KSMPS;
       p->outWrite = p->outRead + (p->nchanls * p->outCount);
     }
@@ -521,15 +522,15 @@ static int pconvset_(CSOUND *csound, PCONVOLVE *p, int stringname)
     return OK;
 }
 
-static int pconvset(CSOUND *csound, PCONVOLVE *p){
+static int32_t pconvset(CSOUND *csound, PCONVOLVE *p){
   return pconvset_(csound,p,0);
 }
 
-static int pconvset_S(CSOUND *csound, PCONVOLVE *p){
+static int32_t pconvset_S(CSOUND *csound, PCONVOLVE *p){
   return pconvset_(csound,p,1);
 }
 
-static int pconvolve(CSOUND *csound, PCONVOLVE *p)
+static int32_t pconvolve(CSOUND *csound, PCONVOLVE *p)
 {
     uint32_t nn, nsmps = CS_KSMPS;
     uint32_t offset = p->h.insdshead->ksmps_offset;
@@ -562,8 +563,8 @@ static int pconvolve(CSOUND *csound, PCONVOLVE *p)
         /* for every IR partition convolve and add to previous convolves */
         for (i = 0; i < p->numPartitions*p->nchanls; i++) {
           MYFLT *src = workBuf;
-          int n;
-          for (n = 0; n <= (int) p->Hlenpadded; n += 2) {
+          int32_t n;
+          for (n = 0; n <= (int32_t) p->Hlenpadded; n += 2) {
             dest[n + 0] += (h[n + 0] * src[n + 0]) - (h[n + 1] * src[n + 1]);
             dest[n + 1] += (h[n + 1] * src[n + 0]) + (h[n + 0] * src[n + 1]);
           }
@@ -614,8 +615,8 @@ static int pconvolve(CSOUND *csound, PCONVOLVE *p)
 
     /* copy to output if we have enough samples [we always should
        except the first Hlen samples] */
-    if (p->outCount >= (int)CS_KSMPS) {
-      unsigned int n;
+    if (p->outCount >= (int32_t)CS_KSMPS) {
+      uint32_t n;
       p->outCount -= CS_KSMPS;
       for (n=0; n < CS_KSMPS; n++) {
         switch (p->nchanls) {
@@ -649,23 +650,24 @@ static int pconvolve(CSOUND *csound, PCONVOLVE *p)
     return OK;
 }
 
-static OENTRY localops[] = {
-    { "convolve", sizeof(CONVOLVE),   0, 5, "mmmm", "aSo",
-            (SUBR) cvset_S,     (SUBR) NULL,    (SUBR) convolve   },
-    { "convle",   sizeof(CONVOLVE),   0, 5, "mmmm", "aSo",
-            (SUBR) cvset_S,     (SUBR) NULL,    (SUBR) convolve   },
-    { "pconvolve",sizeof(PCONVOLVE),  0, 5, "mmmm", "aSoo",
-      (SUBR) pconvset_S,  (SUBR) NULL,    (SUBR) pconvolve  },
-     { "convolve.i", sizeof(CONVOLVE),   0, 5, "mmmm", "aio",
-            (SUBR) cvset,     (SUBR) NULL,    (SUBR) convolve   },
-    { "convle.i",   sizeof(CONVOLVE),   0, 5, "mmmm", "aio",
-            (SUBR) cvset,     (SUBR) NULL,    (SUBR) convolve   },
-    { "pconvolve.i",sizeof(PCONVOLVE),  0, 5, "mmmm", "aioo",
-            (SUBR) pconvset,  (SUBR) NULL,    (SUBR) pconvolve  }
+static OENTRY localops[] =
+  {
+   { "convolve", sizeof(CONVOLVE),   0, 3, "mmmm", "aSo",
+            (SUBR) cvset_S,    (SUBR) convolve   },
+   { "convle",   sizeof(CONVOLVE),   0, 3, "mmmm", "aSo",
+            (SUBR) cvset_S,    (SUBR) convolve   },
+   { "pconvolve",sizeof(PCONVOLVE),  0, 3, "mmmm", "aSoo",
+      (SUBR) pconvset_S,    (SUBR) pconvolve  },
+   { "convolve.i", sizeof(CONVOLVE),   0, 3, "mmmm", "aio",
+            (SUBR) cvset,    (SUBR) convolve   },
+   { "convle.i",   sizeof(CONVOLVE),   0, 3, "mmmm", "aio",
+            (SUBR) cvset,    (SUBR) convolve   },
+   { "pconvolve.i",sizeof(PCONVOLVE),  0, 3, "mmmm", "aioo",
+            (SUBR) pconvset,    (SUBR) pconvolve  }
 };
 
-int ugens9_init_(CSOUND *csound)
+int32_t ugens9_init_(CSOUND *csound)
 {
     return csound->AppendOpcodes(csound, &(localops[0]),
-                                 (int) (sizeof(localops) / sizeof(OENTRY)));
+                                 (int32_t) (sizeof(localops) / sizeof(OENTRY)));
 }
