@@ -17,8 +17,8 @@
 
     You should have received a copy of the GNU Lesser General Public
     License along with Csound; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-    02111-1307 USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+    02110-1301 USA
 */
 
                                                         /* ugmoss.c */
@@ -35,22 +35,22 @@
 
 /* rewritten code for dconv, includes speedup tip from
    Moore: Elements of Computer Music */
-static int dconvset(CSOUND *csound, DCONV *p)
+static int32_t dconvset(CSOUND *csound, DCONV *p)
 {
     FUNC *ftp;
 
-    p->len = (int)*p->isize;
+    p->len = (int32_t)*p->isize;
     if (LIKELY((ftp = csound->FTnp2Find(csound,
                                         p->ifn)) != NULL)) {   /* find table */
       p->ftp = ftp;
-      if ((unsigned)ftp->flen < p->len)
+      if ((uint32_t)ftp->flen < p->len)
         p->len = ftp->flen; /* correct len if flen shorter */
     }
     else {
       return csound->InitError(csound, Str("No table for dconv"));
     }
     if (p->sigbuf.auxp == NULL ||
-        p->sigbuf.size < (unsigned int)(p->len*sizeof(MYFLT)))
+        p->sigbuf.size < (uint32_t)(p->len*sizeof(MYFLT)))
       csound->AuxAlloc(csound, p->len*sizeof(MYFLT), &p->sigbuf);
     else
       memset(p->sigbuf.auxp, '\0', p->len*sizeof(MYFLT));
@@ -58,13 +58,14 @@ static int dconvset(CSOUND *csound, DCONV *p)
     return OK;
 }
 
-static int dconv(CSOUND *csound, DCONV *p)
+static int32_t dconv(CSOUND *csound, DCONV *p)
 {
-    int32 i = 0;
+    IGN(csound);
+    int32_t i = 0;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
-    int32 len = p->len;
+    int32_t len = p->len;
     MYFLT *ar, *ain, *ftp, *startp, *endp, *curp;
     MYFLT sum;
 
@@ -97,23 +98,25 @@ static int dconv(CSOUND *csound, DCONV *p)
     return OK;
 }
 
-static int and_kk(CSOUND *csound, AOP *p)
+static int32_t and_kk(CSOUND *csound, AOP *p)
 {
-    int32 input1 = MYFLT2LRND(*p->a);
-    int32 input2 = MYFLT2LRND(*p->b);
+    IGN(csound);
+    int32_t input1 = MYFLT2LRND(*p->a);
+    int32_t input2 = MYFLT2LRND(*p->b);
     *p->r = (MYFLT)(input1 & input2);
     return OK;
 }
 
-static int and_aa(CSOUND *csound, AOP *p)
+static int32_t and_aa(CSOUND *csound, AOP *p)
 {
+    IGN(csound);
     MYFLT *r    = p->r;
     MYFLT *in1  = p->a;
     MYFLT *in2  = p->b;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
-    int   n, nsmps = CS_KSMPS;
-    int32  input1, input2;
+    int32_t   n, nsmps = CS_KSMPS;
+    int32_t  input1, input2;
 
     if (UNLIKELY(offset)) memset(r, '\0', offset*sizeof(MYFLT));
     if (UNLIKELY(early)) {
@@ -128,14 +131,15 @@ static int and_aa(CSOUND *csound, AOP *p)
     return OK;
 }
 
-static int and_ak(CSOUND *csound, AOP *p)
+static int32_t and_ak(CSOUND *csound, AOP *p)
 {
+    IGN(csound);
     MYFLT *r = p->r;
     MYFLT *in1 = p->a;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
-    int32  input2 = MYFLT2LRND(*p->b), input1;
+    int32_t  input2 = MYFLT2LRND(*p->b), input1;
 
     if (UNLIKELY(offset)) memset(r, '\0', offset*sizeof(MYFLT));
     if (UNLIKELY(early)) {
@@ -149,14 +153,15 @@ static int and_ak(CSOUND *csound, AOP *p)
     return OK;
 }
 
-static int and_ka(CSOUND *csound, AOP *p)
+static int32_t and_ka(CSOUND *csound, AOP *p)
 {
+    IGN(csound);
     MYFLT *r = p->r;
     MYFLT *in2 = p->b;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
-    int32  input2, input1 = MYFLT2LRND(*p->a);
+    int32_t  input2, input1 = MYFLT2LRND(*p->a);
 
     if (UNLIKELY(offset)) memset(r, '\0', offset*sizeof(MYFLT));
     if (UNLIKELY(early)) {
@@ -170,23 +175,25 @@ static int and_ka(CSOUND *csound, AOP *p)
     return OK;
 }
 
-static int or_kk(CSOUND *csound, AOP *p)
+static int32_t or_kk(CSOUND *csound, AOP *p)
 {
-    int32 input1 = MYFLT2LRND(*p->a);
-    int32 input2 = MYFLT2LRND(*p->b);
+    IGN(csound);
+    int32_t input1 = MYFLT2LRND(*p->a);
+    int32_t input2 = MYFLT2LRND(*p->b);
     *p->r = (MYFLT)(input1 | input2);
     return OK;
 }
 
-static int or_aa(CSOUND *csound, AOP *p)
+static int32_t or_aa(CSOUND *csound, AOP *p)
 {
+    IGN(csound);
     MYFLT *r = p->r;
     MYFLT *in1 = p->a;
     MYFLT *in2 = p->b;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
-    int32  input2, input1;
+    int32_t  input2, input1;
 
     if (UNLIKELY(offset)) memset(r, '\0', offset*sizeof(MYFLT));
     if (UNLIKELY(early)) {
@@ -201,14 +208,15 @@ static int or_aa(CSOUND *csound, AOP *p)
     return OK;
 }
 
-static int or_ak(CSOUND *csound, AOP *p)
+static int32_t or_ak(CSOUND *csound, AOP *p)
 {
+    IGN(csound);
     MYFLT *r = p->r;
     MYFLT *in1 = p->a;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
-    int32  input2 = MYFLT2LRND(*p->b), input1;
+    int32_t  input2 = MYFLT2LRND(*p->b), input1;
 
     if (UNLIKELY(offset)) memset(r, '\0', offset*sizeof(MYFLT));
     if (UNLIKELY(early)) {
@@ -222,14 +230,15 @@ static int or_ak(CSOUND *csound, AOP *p)
     return OK;
 }
 
-static int or_ka(CSOUND *csound, AOP *p)
+static int32_t or_ka(CSOUND *csound, AOP *p)
 {
+    IGN(csound);
     MYFLT *r = p->r;
     MYFLT *in2 = p->b;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
-    int32  input2, input1 = MYFLT2LRND(*p->a);
+    int32_t  input2, input1 = MYFLT2LRND(*p->a);
 
     if (UNLIKELY(offset)) memset(r, '\0', offset*sizeof(MYFLT));
     if (UNLIKELY(early)) {
@@ -243,23 +252,25 @@ static int or_ka(CSOUND *csound, AOP *p)
     return OK;
 }
 
-static int xor_kk(CSOUND *csound, AOP *p)
+static int32_t xor_kk(CSOUND *csound, AOP *p)
 {
-    int32 input1 = MYFLT2LRND(*p->a);
-    int32 input2 = MYFLT2LRND(*p->b);
+    IGN(csound);
+    int32_t input1 = MYFLT2LRND(*p->a);
+    int32_t input2 = MYFLT2LRND(*p->b);
     *p->r = (MYFLT)(input1 ^ input2);
     return OK;
 }
 
-static int xor_aa(CSOUND *csound, AOP *p)
+static int32_t xor_aa(CSOUND *csound, AOP *p)
 {
+    IGN(csound);
     MYFLT *r = p->r;
     MYFLT *in1 = p->a;
     MYFLT *in2 = p->b;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
-    int32  input2, input1;
+    int32_t  input2, input1;
 
     if (UNLIKELY(offset)) memset(r, '\0', offset*sizeof(MYFLT));
     if (UNLIKELY(early)) {
@@ -274,14 +285,15 @@ static int xor_aa(CSOUND *csound, AOP *p)
     return OK;
 }
 
-static int xor_ak(CSOUND *csound, AOP *p)
+static int32_t xor_ak(CSOUND *csound, AOP *p)
 {
+    IGN(csound);
     MYFLT *r = p->r;
     MYFLT *in1 = p->a;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
-    int32  input2 = MYFLT2LRND(*p->b), input1;
+    int32_t  input2 = MYFLT2LRND(*p->b), input1;
 
     if (UNLIKELY(offset)) memset(r, '\0', offset*sizeof(MYFLT));
     if (UNLIKELY(early)) {
@@ -295,14 +307,15 @@ static int xor_ak(CSOUND *csound, AOP *p)
     return OK;
 }
 
-static int xor_ka(CSOUND *csound, AOP *p)
+static int32_t xor_ka(CSOUND *csound, AOP *p)
 {
+    IGN(csound);
     MYFLT *r = p->r;
     MYFLT *in2 = p->b;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
-    int32  input2, input1 = MYFLT2LRND(*p->a);
+    int32_t  input2, input1 = MYFLT2LRND(*p->a);
 
     if (UNLIKELY(offset)) memset(r, '\0', offset*sizeof(MYFLT));
     if (UNLIKELY(early)) {
@@ -316,17 +329,19 @@ static int xor_ka(CSOUND *csound, AOP *p)
     return OK;
 }
 
-static int shift_left_kk(CSOUND *csound, AOP *p)
+static int32_t shift_left_kk(CSOUND *csound, AOP *p)
 {
-    int32 input1 = MYFLT2LRND(*p->a);
-    int  input2 = (int) MYFLT2LRND(*p->b);
+    IGN(csound);
+    int32_t input1 = MYFLT2LRND(*p->a);
+    int32_t input2 = (int32_t) MYFLT2LRND(*p->b);
     *p->r = (MYFLT) (input1 << input2);
     return OK;
 }
 
-static int shift_left_aa(CSOUND *csound, AOP *p)
+static int32_t shift_left_aa(CSOUND *csound, AOP *p)
 {
-    int32  input1, input2;
+    IGN(csound);
+    int32_t  input1, input2;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
@@ -344,10 +359,11 @@ static int shift_left_aa(CSOUND *csound, AOP *p)
     return OK;
 }
 
-static int shift_left_ak(CSOUND *csound, AOP *p)
+static int32_t shift_left_ak(CSOUND *csound, AOP *p)
 {
-    int32  input1;
-    int   input2 = MYFLT2LRND(*p->b);
+    IGN(csound);
+    int32_t  input1;
+    int32_t   input2 = MYFLT2LRND(*p->b);
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
@@ -364,9 +380,10 @@ static int shift_left_ak(CSOUND *csound, AOP *p)
     return OK;
 }
 
-static int shift_left_ka(CSOUND *csound, AOP *p)
+static int32_t shift_left_ka(CSOUND *csound, AOP *p)
 {
-    int32  input1 = MYFLT2LRND(*p->a), input2;
+    IGN(csound);
+    int32_t  input1 = MYFLT2LRND(*p->a), input2;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
@@ -383,17 +400,19 @@ static int shift_left_ka(CSOUND *csound, AOP *p)
     return OK;
 }
 
-static int shift_right_kk(CSOUND *csound, AOP *p)
+static int32_t shift_right_kk(CSOUND *csound, AOP *p)
 {
-    int32 input1 = MYFLT2LRND(*p->a);
-    int  input2 = (int) MYFLT2LRND(*p->b);
+    IGN(csound);
+    int32_t input1 = MYFLT2LRND(*p->a);
+    int32_t  input2 = (int32_t) MYFLT2LRND(*p->b);
     *p->r = (MYFLT) (input1 >> input2);
     return OK;
 }
 
-static int shift_right_aa(CSOUND *csound, AOP *p)
+static int32_t shift_right_aa(CSOUND *csound, AOP *p)
 {
-    int32  input1, input2;
+     IGN(csound);
+    int32_t  input1, input2;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
@@ -405,16 +424,17 @@ static int shift_right_aa(CSOUND *csound, AOP *p)
     }
     for (n = offset; n < nsmps; n++) {
       input1 = MYFLT2LRND(p->a[n]);
-      input2 = (int) MYFLT2LRND(p->b[n]);
+      input2 = (int32_t) MYFLT2LRND(p->b[n]);
       p->r[n] = (MYFLT) (input1 >> input2);
     }
     return OK;
 }
 
-static int shift_right_ak(CSOUND *csound, AOP *p)
+static int32_t shift_right_ak(CSOUND *csound, AOP *p)
 {
-    int32  input1;
-    int32   input2 = MYFLT2LRND(*p->b);
+    IGN(csound);
+    int32_t  input1;
+    int32_t   input2 = MYFLT2LRND(*p->b);
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
@@ -431,9 +451,10 @@ static int shift_right_ak(CSOUND *csound, AOP *p)
     return OK;
 }
 
-static int shift_right_ka(CSOUND *csound, AOP *p)
+static int32_t shift_right_ka(CSOUND *csound, AOP *p)
 {
-    int32  input1 = MYFLT2LRND(*p->a), input2;
+    IGN(csound);
+    int32_t  input1 = MYFLT2LRND(*p->a), input2;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
@@ -450,21 +471,23 @@ static int shift_right_ka(CSOUND *csound, AOP *p)
     return OK;
 }
 
-static int not_k(CSOUND *csound, AOP *p)    /* Added for completeness by JPff */
+static int32_t not_k(CSOUND *csound, AOP *p)    /* Added for completeness by JPff */
 {
-    int32 input1 = MYFLT2LRND(*p->a);
+     IGN(csound);
+    int32_t input1 = MYFLT2LRND(*p->a);
     *p->r = (MYFLT)(~input1);
     return OK;
 }
 
-static int not_a(CSOUND *csound, AOP *p)
+static int32_t not_a(CSOUND *csound, AOP *p)
 {
+    IGN(csound);
     MYFLT *r = p->r;
     MYFLT *in1 = p->a;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
-    int32  input1;
+    int32_t  input1;
 
     if (UNLIKELY(offset)) memset(r, '\0', offset*sizeof(MYFLT));
     if (UNLIKELY(early)) {
@@ -481,9 +504,9 @@ static int not_a(CSOUND *csound, AOP *p)
 /* all the vcomb and valpass stuff adapted from comb() and alpass()
    with additional insight from me (petemoss@petemoss.org)  */
 
-static int vcombset(CSOUND *csound, VCOMB *p)
+static int32_t vcombset(CSOUND *csound, VCOMB *p)
 {
-    int32        lpsiz, nbytes;
+    int32_t        lpsiz, nbytes;
 
     if (*p->insmps != FL(0.0)) {
       if (UNLIKELY((lpsiz = MYFLT2LONG(*p->imaxlpt)) <= 0)) {
@@ -494,7 +517,7 @@ static int vcombset(CSOUND *csound, VCOMB *p)
       return csound->InitError(csound, Str("illegal loop time"));
     }
     nbytes = lpsiz * sizeof(MYFLT);
-    if (p->auxch.auxp == NULL || nbytes != (int)p->auxch.size) {
+    if (p->auxch.auxp == NULL || nbytes != (int32_t)p->auxch.size) {
       csound->AuxAlloc(csound, (size_t)nbytes, &p->auxch);
       p->pntr = (MYFLT *) p->auxch.auxp;
       if (UNLIKELY(p->pntr==NULL)) {
@@ -502,7 +525,7 @@ static int vcombset(CSOUND *csound, VCOMB *p)
       }
     }
     else if (!(*p->istor)) {
-      int32 *fp = (int32 *) p->auxch.auxp;
+      int32_t *fp = (int32_t *) p->auxch.auxp;
       p->pntr = (MYFLT *) fp;
       memset(p->pntr, 0, nbytes);
       /* do   /\* Seems to assume sizeof(int32)=sizeof(MYFLT) *\/ */
@@ -518,12 +541,12 @@ static int vcombset(CSOUND *csound, VCOMB *p)
     return OK;
 }
 
-static int vcomb(CSOUND *csound, VCOMB *p)
+static int32_t vcomb(CSOUND *csound, VCOMB *p)
 {
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t    n, nsmps = CS_KSMPS;
-    uint32      xlpt, maxlpt = (uint32)p->maxlpt;
+    uint32_t      xlpt, maxlpt = (uint32)p->maxlpt;
     MYFLT       *ar, *asig, *rp, *endp, *startp, *wp, *lpt;
     MYFLT       g = p->g;
 
@@ -578,12 +601,12 @@ static int vcomb(CSOUND *csound, VCOMB *p)
                              Str("vcomb: not initialised"));
 }
 
-static int valpass(CSOUND *csound, VCOMB *p)
+static int32_t valpass(CSOUND *csound, VCOMB *p)
 {
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t n, nsmps = CS_KSMPS;
-    uint32 xlpt, maxlpt = (uint32)p->maxlpt;
+    uint32_t xlpt, maxlpt = (uint32)p->maxlpt;
     MYFLT       *ar, *asig, *rp, *startp, *endp, *wp, *lpt;
     MYFLT       y, z, g = p->g;
 
@@ -639,11 +662,11 @@ static int valpass(CSOUND *csound, VCOMB *p)
                              Str("valpass: not initialised"));
 }
 
-static int ftmorfset(CSOUND *csound, FTMORF *p)
+static int32_t ftmorfset(CSOUND *csound, FTMORF *p)
 {
     FUNC *ftp;
-    int j = 0;
-    unsigned int len;
+    int32_t j = 0;
+    uint32_t len;
     /* make sure resfn exists and set it up */
     if (LIKELY((ftp = csound->FTnp2Find(csound, p->iresfn)) != NULL)) {
       p->resfn = ftp, len = p->resfn->flen;
@@ -661,7 +684,7 @@ static int ftmorfset(CSOUND *csound, FTMORF *p)
 
     do {                /* make sure tables in ftfn exist and are right size*/
       if (LIKELY((ftp = csound->FTnp2Find(csound, p->ftfn->ftable + j)) != NULL)) {
-        if (UNLIKELY((unsigned int)ftp->flen != len)) {
+        if (UNLIKELY((uint32_t)ftp->flen != len)) {
           return csound->InitError(csound,
                                    Str("table in iftfn for ftmorf wrong size"));
         }
@@ -670,22 +693,22 @@ static int ftmorfset(CSOUND *csound, FTMORF *p)
         return csound->InitError(csound, Str("table in iftfn for ftmorf "
                                              "does not exist"));
       }
-    } while (++j < (int)p->ftfn->flen);
+    } while (++j < (int32_t)p->ftfn->flen);
 
     p->len = len;
     p->ftndx = -FL(1.0);
     return OK;
 }
 
-static int ftmorf(CSOUND *csound, FTMORF *p)
+static int32_t ftmorf(CSOUND *csound, FTMORF *p)
 {
-    unsigned int j = 0;
-    int i;
+    uint32_t j = 0;
+    int32_t i;
     MYFLT f;
     FUNC *ftp1, *ftp2;
 
     if (*p->kftndx >= p->ftfn->flen) *p->kftndx = (MYFLT)(p->ftfn->flen - 1);
-    i = (int)*p->kftndx;
+    i = (int32_t)*p->kftndx;
     f = *p->kftndx - i;
     if (p->ftndx != *p->kftndx) {
       p->ftndx = *p->kftndx;
@@ -702,43 +725,45 @@ static int ftmorf(CSOUND *csound, FTMORF *p)
 /* end of ugmoss.c */
 #define S(x)    sizeof(x)
 
-static OENTRY localops[] = {
-{ "dconv",  S(DCONV), TR, 5, "a", "aii",   (SUBR)dconvset, NULL, (SUBR)dconv },
-{ "vcomb", S(VCOMB),  0,5, "a", "akxioo", (SUBR)vcombset, NULL, (SUBR)vcomb   },
-{ "valpass", S(VCOMB),0,5, "a", "akxioo", (SUBR)vcombset, NULL, (SUBR)valpass },
-{ "ftmorf", S(FTMORF),TR, 3, "",  "kii",  (SUBR)ftmorfset,  (SUBR)ftmorf,    },
-{ "##and.ii",  S(AOP),  0,1, "i", "ii",   (SUBR)and_kk                  },
-{ "##and.kk",  S(AOP),  0,2, "k", "kk",   NULL,   (SUBR)and_kk          },
-{ "##and.ka",  S(AOP),  0,4, "a", "ka",   NULL,   NULL,   (SUBR)and_ka  },
-{ "##and.ak",  S(AOP),  0,4, "a", "ak",   NULL,   NULL,   (SUBR)and_ak  },
-{ "##and.aa",  S(AOP),  0,4, "a", "aa",   NULL,   NULL,   (SUBR)and_aa  },
-{ "##or.ii",   S(AOP),  0,1, "i", "ii",   (SUBR)or_kk                   },
-{ "##or.kk",   S(AOP),  0,2, "k", "kk",   NULL,   (SUBR)or_kk           },
-{ "##or.ka",   S(AOP),  0,4, "a", "ka",   NULL,   NULL,   (SUBR)or_ka   },
-{ "##or.ak",   S(AOP),  0,4, "a", "ak",   NULL,   NULL,   (SUBR)or_ak   },
-{ "##or.aa",   S(AOP),  0,4, "a", "aa",   NULL,   NULL,   (SUBR)or_aa   },
-{ "##xor.ii",  S(AOP),  0,1, "i", "ii",   (SUBR)xor_kk                  },
-{ "##xor.kk",  S(AOP),  0,2, "k", "kk",   NULL,   (SUBR)xor_kk          },
-{ "##xor.ka",  S(AOP),  0,4, "a", "ka",   NULL,   NULL,   (SUBR)xor_ka  },
-{ "##xor.ak",  S(AOP),  0,4, "a", "ak",   NULL,   NULL,   (SUBR)xor_ak  },
-{ "##xor.aa",  S(AOP),  0,4, "a", "aa",   NULL,   NULL,   (SUBR)xor_aa  },
-{ "##not.i",   S(AOP),  0,1, "i", "i",    (SUBR)not_k                   },
-{ "##not.k",   S(AOP),  0,2, "k", "k",    NULL,   (SUBR)not_k           },
-{ "##not.a",   S(AOP),  0,4, "a", "a",    NULL,   NULL,   (SUBR)not_a   },
-{ "##shl.ii",  S(AOP),  0,1, "i", "ii",   (SUBR) shift_left_kk          },
-{ "##shl.kk",  S(AOP),  0,2, "k", "kk",   NULL, (SUBR) shift_left_kk    },
-{ "##shl.ka", S(AOP), 0,4, "a", "ka", NULL, NULL, (SUBR) shift_left_ka  },
-{ "##shl.ak", S(AOP), 0,4, "a", "ak", NULL, NULL, (SUBR) shift_left_ak  },
-{ "##shl.aa", S(AOP), 0,4, "a", "aa", NULL, NULL, (SUBR) shift_left_aa  },
-{ "##shr.ii",  S(AOP),  0,1, "i", "ii",   (SUBR) shift_right_kk         },
-{ "##shr.kk",  S(AOP),  0,2, "k", "kk",   NULL, (SUBR) shift_right_kk   },
-{ "##shr.ka", S(AOP), 0,4, "a", "ka", NULL, NULL, (SUBR) shift_right_ka },
-{ "##shr.ak", S(AOP), 0,4, "a", "ak", NULL, NULL, (SUBR) shift_right_ak },
-{ "##shr.aa", S(AOP), 0,4, "a", "aa", NULL, NULL, (SUBR) shift_right_aa }
+static OENTRY localops[] =
+  {
+   { "dconv",  S(DCONV), TR, 3, "a", "aii",   (SUBR)dconvset, (SUBR)dconv },
+   { "vcomb", S(VCOMB),  0,3, "a", "akxioo", (SUBR)vcombset, (SUBR)vcomb   },
+   { "valpass", S(VCOMB),0,3, "a", "akxioo", (SUBR)vcombset, (SUBR)valpass },
+   { "ftmorf", S(FTMORF),TR, 3, "",  "kii",  (SUBR)ftmorfset,  (SUBR)ftmorf,    },
+   { "##and.ii",  S(AOP),  0,1, "i", "ii",   (SUBR)and_kk                  },
+   { "##and.kk",  S(AOP),  0,2, "k", "kk",   NULL,   (SUBR)and_kk          },
+   { "##and.ka",  S(AOP),  0,2, "a", "ka",   NULL,   (SUBR)and_ka  },
+   { "##and.ak",  S(AOP),  0,2, "a", "ak",   NULL,   (SUBR)and_ak  },
+   { "##and.aa",  S(AOP),  0,2, "a", "aa",   NULL,   (SUBR)and_aa  },
+   { "##or.ii",   S(AOP),  0,1, "i", "ii",   (SUBR)or_kk                   },
+   { "##or.kk",   S(AOP),  0,2, "k", "kk",   NULL,   (SUBR)or_kk           },
+   { "##or.ka",   S(AOP),  0,2, "a", "ka",   NULL,   (SUBR)or_ka   },
+   { "##or.ak",   S(AOP),  0,2, "a", "ak",   NULL,   (SUBR)or_ak   },
+   { "##or.aa",   S(AOP),  0,2, "a", "aa",   NULL,   (SUBR)or_aa   },
+   { "##xor.ii",  S(AOP),  0,1, "i", "ii",   (SUBR)xor_kk                  },
+   { "##xor.kk",  S(AOP),  0,2, "k", "kk",   NULL,   (SUBR)xor_kk          },
+   { "##xor.ka",  S(AOP),  0,2, "a", "ka",   NULL,   (SUBR)xor_ka  },
+   { "##xor.ak",  S(AOP),  0,2, "a", "ak",   NULL,   (SUBR)xor_ak  },
+   { "##xor.aa",  S(AOP),  0,2, "a", "aa",   NULL,   (SUBR)xor_aa  },
+   { "##not.i",   S(AOP),  0,1, "i", "i",    (SUBR)not_k                   },
+   { "##not.k",   S(AOP),  0,2, "k", "k",    NULL,   (SUBR)not_k           },
+   { "##not.a",   S(AOP),  0,2, "a", "a",    NULL,   (SUBR)not_a   },
+   { "##shl.ii",  S(AOP),  0,1, "i", "ii",   (SUBR) shift_left_kk          },
+   { "##shl.kk",  S(AOP),  0,2, "k", "kk",   NULL, (SUBR) shift_left_kk    },
+   { "##shl.ka", S(AOP), 0,2, "a", "ka", NULL, (SUBR) shift_left_ka  },
+   { "##shl.ak", S(AOP), 0,2, "a", "ak", NULL, (SUBR) shift_left_ak  },
+   { "##shl.aa", S(AOP), 0,2, "a", "aa", NULL, (SUBR) shift_left_aa  },
+   { "##shr.ii",  S(AOP),  0,1, "i", "ii",   (SUBR) shift_right_kk         },
+   { "##shr.kk",  S(AOP),  0,2, "k", "kk",   NULL, (SUBR) shift_right_kk   },
+   { "##shr.ka", S(AOP), 0,2, "a", "ka", NULL, (SUBR) shift_right_ka },
+   { "##shr.ak", S(AOP), 0,2, "a", "ak", NULL, (SUBR) shift_right_ak },
+   { "##shr.aa", S(AOP), 0,2, "a", "aa", NULL, (SUBR) shift_right_aa }
 };
 
-int ugmoss_init_(CSOUND *csound)
+int32_t ugmoss_init_(CSOUND *csound)
 {
     return csound->AppendOpcodes(csound, &(localops[0]),
-                                 (int) (sizeof(localops) / sizeof(OENTRY)));
+                                 (int32_t
+                                  ) (sizeof(localops) / sizeof(OENTRY)));
 }
