@@ -17,8 +17,8 @@
 
     You should have received a copy of the GNU Lesser General Public
     License along with Csound; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-    02111-1307 USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+    02110-1301 USA
 */
 
 #define LOWEST_ACCEPTABLE_WT FL(0.0)
@@ -45,25 +45,25 @@ typedef struct {
 
 /* A struct for a loudspeaker triplet or pair (set) */
 typedef struct {
-  int ls_nos[3];
+  int32_t ls_nos[3];
   MYFLT ls_mx[9];
   MYFLT set_gains[3];
   MYFLT smallest_wt;
-  int neg_g_am;
+  int32_t neg_g_am;
 } LS_SET;
 
 /* VBAP structure of n loudspeaker panning */
 typedef struct {
-  int number;
+  int32_t number;
   MYFLT beg_gains[CHANNELS];
   MYFLT curr_gains[CHANNELS];
   MYFLT end_gains[CHANNELS];
   MYFLT updated_gains[CHANNELS];
-  int dim;
+  int32_t dim;
   AUXCH aux;
   LS_SET *ls_sets;
-  int ls_am;
-  int ls_set_am;
+  int32_t ls_am;
+  int32_t ls_set_am;
   CART_VEC cart_dir;
   CART_VEC spread_base;
   ANG_VEC ang_dir;
@@ -86,13 +86,13 @@ typedef struct {
 } VBAPA;
 
 typedef struct {
-  int number;
+  int32_t number;
   MYFLT gains[CHANNELS];
-  int dim;
+  int32_t dim;
   AUXCH aux;
   LS_SET *ls_sets;
-  int ls_am;
-  int ls_set_am;
+  int32_t ls_am;
+  int32_t ls_set_am;
   CART_VEC cart_dir;
   CART_VEC spread_base;
   ANG_VEC ang_dir;
@@ -117,17 +117,17 @@ typedef struct {
 /* VBAP structure of loudspeaker moving panning */
 typedef struct {
   MYFLT gains[CHANNELS];
-  int number;
-  int upd_interval;
-  int dim;
+  int32_t number;
+  int32_t upd_interval;
+  int32_t dim;
   AUXCH aux;
   LS_SET *ls_sets;
-  int ls_am;
-  int ls_set_am;
+  int32_t ls_am;
+  int32_t ls_set_am;
   CART_VEC cart_dir;
   CART_VEC spread_base;
   ANG_VEC ang_dir, prev_ang_dir, next_ang_dir;
-  int point_change_interval, point_change_counter, curr_fld, next_fld;
+  int32_t point_change_interval, point_change_counter, curr_fld, next_fld;
   MYFLT ele_vel;
   MYFLT end_gains[CHANNELS];
 } VBAP1_MOVE_DATA;
@@ -155,17 +155,17 @@ typedef struct {
   MYFLT beg_gains[CHANNELS];
   MYFLT curr_gains[CHANNELS];
   MYFLT updated_gains[CHANNELS];
-  int number;
-  int upd_interval;
-  int dim;
+  int32_t number;
+  int32_t upd_interval;
+  int32_t dim;
   AUXCH aux;
   LS_SET *ls_sets;
-  int ls_am;
-  int ls_set_am;
+  int32_t ls_am;
+  int32_t ls_set_am;
   CART_VEC cart_dir;
   CART_VEC spread_base;
   ANG_VEC ang_dir, prev_ang_dir, next_ang_dir;
-  int point_change_interval, point_change_counter, curr_fld, next_fld;
+  int32_t point_change_interval, point_change_counter, curr_fld, next_fld;
   MYFLT ele_vel;
   MYFLT end_gains[CHANNELS];
 } VBAP_MOVE_DATA;
@@ -205,12 +205,12 @@ typedef struct {
 typedef struct {
   CART_VEC coords;
   ANG_VEC angles;
-  int channel_nbr;
+  int32_t channel_nbr;
 } ls;
 
 /* A struct for all loudspeakers */
 typedef struct ls_triplet_chain {
-  int ls_nos[3];
+  int32_t ls_nos[3];
   MYFLT inv_mx[9];
   struct ls_triplet_chain *next;
 } ls_triplet_chain;
@@ -218,30 +218,30 @@ typedef struct ls_triplet_chain {
 /* functions */
 
 void angle_to_cart_II( ANG_VEC *from,  CART_VEC *to);
-int lines_intersect(int i,int j,int k,int l, ls lss[]);
+int32_t lines_intersect(int32_t i,int32_t j,int32_t k,int32_t l, ls lss[]);
 MYFLT vec_angle(CART_VEC v1, CART_VEC v2);
 void vec_mean(CART_VEC v1, CART_VEC v2, CART_VEC *v3);
 MYFLT angle_in_base(CART_VEC vb1,CART_VEC vb2,CART_VEC vec);
 void cross_prod(CART_VEC v1,CART_VEC v2,
                 CART_VEC *res) ;
-/* void sort_angles(MYFLT angles[], int sorted_angles[], */
-/*                  int ls_amount); */
-/* void remove_connections_in_planey(int i,int j,int k,int l, */
+/* void sort_angles(MYFLT angles[], int32_t sorted_angles[], */
+/*                  int32_t ls_amount); */
+/* void remove_connections_in_planey(int32_t i,int32_t j,int32_t k,int32_t l, */
 /*                                    ls  lss[CHANNELS], */
-/*                                     int connections[CHANNELS][CHANNELS]); */
-int calc_2D_inv_tmatrix(MYFLT azi1,MYFLT azi2, MYFLT inv_mat[4]);
+/*                                     int32_t connections[CHANNELS][CHANNELS]); */
+int32_t calc_2D_inv_tmatrix(MYFLT azi1,MYFLT azi2, MYFLT inv_mat[4]);
 
 extern void cart_to_angle(CART_VEC cvec, ANG_VEC *avec);
 extern void angle_to_cart(ANG_VEC avec, CART_VEC *cvec);
 extern void normalize_wts(OUT_WTS *wts);
 
-extern int vbap_control(CSOUND*, VBAP_DATA *p, MYFLT*, MYFLT*, MYFLT*);
+extern int32_t vbap_control(CSOUND*, VBAP_DATA *p, MYFLT*, MYFLT*, MYFLT*);
 
-void calc_vbap_gns(int ls_set_am, int dim, LS_SET *sets,
-                   MYFLT *gains, int ls_amount,
+void calc_vbap_gns(int32_t ls_set_am, int32_t dim, LS_SET *sets,
+                   MYFLT *gains, int32_t ls_amount,
                    CART_VEC cart_dir);
 void scale_angles(ANG_VEC *avec);
-MYFLT vol_p_side_lgth(int i, int j, int k, ls  lss[]);
+MYFLT vol_p_side_lgth(int32_t i, int32_t j, int32_t k, ls  lss[]);
 
 void new_spread_dir(CART_VEC *spreaddir, CART_VEC vscartdir,
                     CART_VEC spread_base, MYFLT azi, MYFLT spread);
@@ -252,7 +252,7 @@ void new_spread_base(CART_VEC spreaddir, CART_VEC vscartdir,
 typedef struct {
   OPDS      h;                  /* required header */
   MYFLT     *numb, *ndx, *audio, *azi, *ele, *spread, *layout;
-  int       n;
+  int32_t       n;
   MYFLT     *out_array;
   AUXCH     auxch;
   AUXCH     aux;
@@ -260,10 +260,10 @@ typedef struct {
   MYFLT     *beg_gains;
   MYFLT     *end_gains;
   MYFLT     *updated_gains;
-  int       dim;
+  int32_t       dim;
   LS_SET    *ls_sets;
-  int       ls_am;
-  int       ls_set_am;
+  int32_t       ls_am;
+  int32_t       ls_set_am;
   CART_VEC  cart_dir;
   CART_VEC  spread_base;
   ANG_VEC   ang_dir;
@@ -275,7 +275,7 @@ typedef struct {
   MYFLT     *numb, *ndx, *audio, *dur, *spread, *field_am,
             *fld[VARGMAX]; /* field_am positive: point to point
                                        negative: angle velocities */
-  int       n;
+  int32_t       n;
   MYFLT     *out_array;
   AUXCH     auxch;
   AUXCH     aux;
@@ -283,36 +283,37 @@ typedef struct {
   MYFLT     *beg_gains;
   MYFLT     *end_gains;
   MYFLT     *updated_gains;
-  int       dim;
+  int32_t       dim;
   LS_SET    *ls_sets;
-  int       ls_am;
-  int       ls_set_am;
+  int32_t       ls_am;
+  int32_t       ls_set_am;
   CART_VEC  cart_dir;
   CART_VEC  spread_base;
   ANG_VEC   ang_dir, prev_ang_dir, next_ang_dir;
-  int       point_change_interval, point_change_counter, curr_fld, next_fld;
+  int32_t       point_change_interval, point_change_counter, curr_fld, next_fld;
   MYFLT     ele_vel;
 } VBAP_ZAK_MOVING;
 
-int     vbap_init(CSOUND *, VBAP *);
-int     vbap_init_a(CSOUND *, VBAPA *);
-int     vbap(CSOUND *, VBAP *);
-int     vbap_a(CSOUND *, VBAPA *);
-int     vbap_zak_init(CSOUND *, VBAP_ZAK *);
-int     vbap_zak(CSOUND *, VBAP_ZAK *);
-int     vbap_ls_init(CSOUND *, VBAP_LS_INIT *);
-int     vbap_moving_init(CSOUND *, VBAP_MOVING *);
-int     vbap_moving(CSOUND *, VBAP_MOVING *);
-int     vbap_moving_init_a(CSOUND *, VBAPA_MOVING *);
-int     vbap_moving_a(CSOUND *, VBAPA_MOVING *);
-int     vbap_zak_moving_init(CSOUND *, VBAP_ZAK_MOVING *);
-int     vbap_zak_moving(CSOUND *, VBAP_ZAK_MOVING *);
-int     vbap1_init(CSOUND *, VBAP1 *);
-int     vbap1(CSOUND *, VBAP1 *);
-int     vbap1_init_a(CSOUND *, VBAPA1 *);
-int     vbap1a(CSOUND *, VBAPA1 *);
-int     vbap1_moving_init(CSOUND *, VBAP1_MOVING *);
-int     vbap1_moving(CSOUND *, VBAP1_MOVING *);
-int     vbap1_moving_init_a(CSOUND *, VBAPA1_MOVING *);
-int     vbap1_moving_a(CSOUND *, VBAPA1_MOVING *);
+int32_t     vbap_init(CSOUND *, VBAP *);
+int32_t     vbap_init_a(CSOUND *, VBAPA *);
+int32_t     vbap(CSOUND *, VBAP *);
+int32_t     vbap_a(CSOUND *, VBAPA *);
+int32_t     vbap_zak_init(CSOUND *, VBAP_ZAK *);
+int32_t     vbap_zak(CSOUND *, VBAP_ZAK *);
+int32_t     vbap_ls_init(CSOUND *, VBAP_LS_INIT *);
+int32_t     vbap_moving_init(CSOUND *, VBAP_MOVING *);
+int32_t     vbap_moving(CSOUND *, VBAP_MOVING *);
+int32_t     vbap_moving_init_a(CSOUND *, VBAPA_MOVING *);
+int32_t     vbap_moving_a(CSOUND *, VBAPA_MOVING *);
+int32_t     vbap_zak_moving_init(CSOUND *, VBAP_ZAK_MOVING *);
+int32_t     vbap_zak_moving(CSOUND *, VBAP_ZAK_MOVING *);
+int32_t     vbap1_init(CSOUND *, VBAP1 *);
+int32_t     vbap1(CSOUND *, VBAP1 *);
+int32_t     vbap1_init_a(CSOUND *, VBAPA1 *);
+int32_t     vbap1a(CSOUND *, VBAPA1 *);
+int32_t     vbap1_moving_init(CSOUND *, VBAP1_MOVING *);
+int32_t     vbap1_moving(CSOUND *, VBAP1_MOVING *);
+int32_t     vbap1_moving_init_a(CSOUND *, VBAPA1_MOVING *);
+int32_t
+vbap1_moving_a(CSOUND *, VBAPA1_MOVING *);
 
