@@ -17,8 +17,8 @@
 
     You should have received a copy of the GNU Lesser General Public
     License along with Csound; if not, write to the Free Software
-    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
-    02111-1307 USA
+    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
+    02110-1301 USA
 */
 
 /* vbap_n.c
@@ -35,19 +35,19 @@ Ville Pulkki heavily modified by John ffitch 2012
 #include <stdio.h>
 #include <stdlib.h>
 
-int vbap_moving_control(CSOUND *, VBAP_MOVE_DATA *, INSDS*, MYFLT,
+int32_t vbap_moving_control(CSOUND *, VBAP_MOVE_DATA *, INSDS*, MYFLT,
                         MYFLT *, MYFLT*,MYFLT**);
 
-int vbap(CSOUND *csound, VBAP *p) /* during note performance: */
+int32_t vbap(CSOUND *csound, VBAP *p) /* during note performance: */
 {
     MYFLT *outptr, *inptr;
     MYFLT ogain, ngain, gainsubstr;
     MYFLT invfloatn;
-    int j;
+    int32_t j;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t i, nsmps = CS_KSMPS;
-    int cnt = p->q.number;
+    int32_t cnt = p->q.number;
     vbap_control(csound,&p->q, p->azi, p->ele, p->spread);
     for (j=0; j<cnt; j++) {
       p->q.beg_gains[j] = p->q.end_gains[j];
@@ -89,17 +89,17 @@ int vbap(CSOUND *csound, VBAP *p) /* during note performance: */
     return OK;
 }
 
-int vbap_a(CSOUND *csound, VBAPA *p) /* during note performance: */
+int32_t vbap_a(CSOUND *csound, VBAPA *p) /* during note performance: */
 {
     MYFLT *outptr, *inptr;
     MYFLT ogain, ngain, gainsubstr;
     MYFLT invfloatn;
-    int j;
+    int32_t j;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t i, nsmps = CS_KSMPS;
     uint32_t ksmps = nsmps;
-    int cnt = p->q.number;
+    int32_t cnt = p->q.number;
 
     vbap_control(csound,&p->q, p->azi, p->ele, p->spread);
     for (j=0; j<cnt; j++) {
@@ -140,14 +140,14 @@ int vbap_a(CSOUND *csound, VBAPA *p) /* during note performance: */
     return OK;
 }
 
-int vbap_control(CSOUND *csound, VBAP_DATA *p,
+int32_t vbap_control(CSOUND *csound, VBAP_DATA *p,
                  MYFLT *azi, MYFLT *ele, MYFLT *spread)
 {
     CART_VEC spreaddir[16];
     CART_VEC spreadbase[16];
     ANG_VEC atmp;
     int32 i,j, spreaddirnum;
-    int cnt = p->number;
+    int32_t cnt = p->number;
     MYFLT *tmp_gains = malloc(sizeof(MYFLT)*cnt),sum=FL(0.0);
     if (UNLIKELY(p->dim == 2 && fabs(*ele) > 0.0)) {
       csound->Warning(csound,
@@ -251,12 +251,12 @@ int vbap_control(CSOUND *csound, VBAP_DATA *p,
     return OK;
 }
 
-int vbap_init(CSOUND *csound, VBAP *p)
+int32_t vbap_init(CSOUND *csound, VBAP *p)
 {                               /* Initializations before run time*/
-    int     i, j;
+    int32_t     i, j;
     MYFLT   *ls_table, *ptr;
     LS_SET  *ls_set_ptr;
-    int cnt = p->q.number = (int)(p->OUTOCOUNT);
+    int32_t cnt = p->q.number = (int32_t)(p->OUTOCOUNT);
     char name[24];
 
     if ((!strcmp(p->h.optext->t.opcod, "vbap.a")) == 0) {
@@ -266,21 +266,21 @@ int vbap_init(CSOUND *csound, VBAP *p)
       p->spread = p->out_array[cnt+3];
       p->layout = p->out_array[cnt+4];
     }
-    snprintf(name, 24, "vbap_ls_table_%d", (p->layout==NULL?0:(int)*p->layout));
+    snprintf(name, 24, "vbap_ls_table_%d", (p->layout==NULL?0:(int32_t)*p->layout));
     ls_table = (MYFLT*) (csound->QueryGlobalVariable(csound, name));
 
     if (UNLIKELY(ls_table==NULL))
       return csound->InitError(csound,
                                Str("could not find layout table no.%d"),
-                               (int)*p->layout );
+                               (int32_t)*p->layout );
 
-    p->q.dim       = (int)ls_table[0];   /* reading in loudspeaker info */
-    p->q.ls_am     = (int)ls_table[1];
-    p->q.ls_set_am = (int)ls_table[2];
+    p->q.dim       = (int32_t)ls_table[0];   /* reading in loudspeaker info */
+    p->q.ls_am     = (int32_t)ls_table[1];
+    p->q.ls_set_am = (int32_t)ls_table[2];
     ptr = &(ls_table[3]);
     if (UNLIKELY(!p->q.ls_set_am))
       return csound->InitError(csound,
-                               Str("vbap system NOT configured. \nMissing"
+                               Str("vbap system NOT configured.\nMissing"
                                    " vbaplsinit opcode in orchestra?"));
     csound->AuxAlloc(csound, p->q.ls_set_am * sizeof (LS_SET), &p->q.aux);
     if (UNLIKELY(p->q.aux.auxp == NULL)) {
@@ -291,7 +291,7 @@ int vbap_init(CSOUND *csound, VBAP *p)
     for (i=0; i < p->q.ls_set_am; i++) {
       ls_set_ptr[i].ls_nos[2] = 0;     /* initial setting */
       for (j=0 ; j < p->q.dim ; j++) {
-        ls_set_ptr[i].ls_nos[j] = (int)*(ptr++);
+        ls_set_ptr[i].ls_nos[j] = (int32_t)*(ptr++);
       }
       memset(ls_set_ptr[i].ls_mx, '\0', 9*sizeof(MYFLT)); // initial setting
       /* for (j=0 ; j < 9; j++) */
@@ -322,26 +322,26 @@ int vbap_init(CSOUND *csound, VBAP *p)
     return OK;
 }
 
-int vbap_init_a(CSOUND *csound, VBAPA *p)
+int32_t vbap_init_a(CSOUND *csound, VBAPA *p)
 {                               /* Initializations before run time*/
-    int     i, j;
+    int32_t     i, j;
     MYFLT   *ls_table, *ptr;
     LS_SET  *ls_set_ptr;
-    int cnt;
+    int32_t cnt;
     char name[24];
 
     cnt = p->q.number = p->tabout->sizes[0];
-    snprintf(name, 24, "vbap_ls_table_%d", (int)*p->layout);
+    snprintf(name, 24, "vbap_ls_table_%d", (int32_t)*p->layout);
     ls_table = (MYFLT*) (csound->QueryGlobalVariable(csound, name));
 
     if (UNLIKELY(ls_table==NULL))
       return csound->InitError(csound,
                                Str("could not find layout table no.%d"),
-                               (int)*p->layout );
+                               (int32_t)*p->layout );
 
-    p->q.dim       = (int)ls_table[0];   /* reading in loudspeaker info */
-    p->q.ls_am     = (int)ls_table[1];
-    p->q.ls_set_am = (int)ls_table[2];
+    p->q.dim       = (int32_t)ls_table[0];   /* reading in loudspeaker info */
+    p->q.ls_am     = (int32_t)ls_table[1];
+    p->q.ls_set_am = (int32_t)ls_table[2];
     ptr = &(ls_table[3]);
     if (UNLIKELY(!p->q.ls_set_am))
       return csound->InitError(csound,
@@ -356,7 +356,7 @@ int vbap_init_a(CSOUND *csound, VBAPA *p)
     for (i=0; i < p->q.ls_set_am; i++) {
       ls_set_ptr[i].ls_nos[2] = 0;     /* initial setting */
       for (j=0 ; j < p->q.dim ; j++) {
-        ls_set_ptr[i].ls_nos[j] = (int)*(ptr++);
+        ls_set_ptr[i].ls_nos[j] = (int32_t)*(ptr++);
       }
       memset(ls_set_ptr[i].ls_mx, '\0', 9*sizeof(MYFLT));
       /* for (j=0 ; j < 9; j++) */
@@ -387,16 +387,16 @@ int vbap_init_a(CSOUND *csound, VBAPA *p)
     return OK;
 }
 
-int vbap_moving(CSOUND *csound, VBAP_MOVING *p)
+int32_t vbap_moving(CSOUND *csound, VBAP_MOVING *p)
 {                               /* during note performance:   */
     MYFLT *outptr, *inptr;
     MYFLT ogain, ngain, gainsubstr;
     MYFLT invfloatn;
-    int j;
+    int32_t j;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t i, nsmps = CS_KSMPS;
-    int cnt = p->q.number;
+    int32_t cnt = p->q.number;
 
     vbap_moving_control(csound,&p->q, p->h.insdshead, CS_ONEDKR,
                         p->spread, p->field_am, p->fld);
@@ -436,7 +436,7 @@ int vbap_moving(CSOUND *csound, VBAP_MOVING *p)
     return OK;
 }
 
-int vbap_moving_control(CSOUND *csound, VBAP_MOVE_DATA *p, INSDS *insdshead,
+int32_t vbap_moving_control(CSOUND *csound, VBAP_MOVE_DATA *p, INSDS *insdshead,
                         MYFLT ONEDKR, MYFLT* spread, MYFLT* field_am, MYFLT *fld[])
 {
     CART_VEC spreaddir[16];
@@ -445,7 +445,7 @@ int vbap_moving_control(CSOUND *csound, VBAP_MOVE_DATA *p, INSDS *insdshead,
     int32 i,j, spreaddirnum;
     CART_VEC tmp1, tmp2, tmp3;
     MYFLT coeff, angle;
-    int cnt = p->number;
+    int32_t cnt = p->number;
     MYFLT *tmp_gains=malloc(sizeof(MYFLT)*cnt),sum=FL(0.0);
 
     if (UNLIKELY(p->dim == 2 && fabs(p->ang_dir.ele) > 0.0)) {
@@ -460,7 +460,7 @@ int vbap_moving_control(CSOUND *csound, VBAP_MOVE_DATA *p, INSDS *insdshead,
     if (p->point_change_counter++ >= p->point_change_interval) {
       p->point_change_counter = 0;
       p->curr_fld = p->next_fld;
-      if (++p->next_fld >= (int) fabs(*field_am)) {
+      if (++p->next_fld >= (int32_t) fabs(*field_am)) {
         if (*field_am >= FL(0.0)) /* point-to-point */
           p->next_fld = 0;
         else
@@ -468,7 +468,7 @@ int vbap_moving_control(CSOUND *csound, VBAP_MOVE_DATA *p, INSDS *insdshead,
       }
       if (p->dim == 3) { /*jumping over second field */
         p->curr_fld = p->next_fld;
-        if (++p->next_fld >= ((int) fabs(*field_am))) {
+        if (++p->next_fld >= ((int32_t) fabs(*field_am))) {
           if (*field_am >= FL(0.0)) /* point-to-point */
             p->next_fld = 0;
           else
@@ -510,9 +510,9 @@ int vbap_moving_control(CSOUND *csound, VBAP_MOVE_DATA *p, INSDS *insdshead,
         scale_angles(&(p->prev_ang_dir));
         scale_angles(&(p->next_ang_dir));
         angle = (p->prev_ang_dir.azi - p->next_ang_dir.azi);
-        while(angle > FL(180.0))
+        while (angle > FL(180.0))
           angle -= FL(360.0);
-        while(angle < -FL(180.0))
+        while (angle < -FL(180.0))
           angle += FL(360.0);
         coeff = ((MYFLT) p->point_change_counter) /
           ((MYFLT) p->point_change_interval);
@@ -632,12 +632,12 @@ int vbap_moving_control(CSOUND *csound, VBAP_MOVE_DATA *p, INSDS *insdshead,
     return OK;
 }
 
-int vbap_moving_init(CSOUND *csound, VBAP_MOVING *p)
+int32_t vbap_moving_init(CSOUND *csound, VBAP_MOVING *p)
 {
-    int     i, j;
+    int32_t     i, j;
     MYFLT   *ls_table, *ptr;
     LS_SET  *ls_set_ptr;
-    int cnt = (int)p->h.optext->t.outArgCount;
+    int32_t cnt = (int32_t)p->h.optext->t.outArgCount;
     if ((!strncmp(p->h.optext->t.opcod, "vbapmove", 8)) == 0) {
       p->audio = p->out_array[cnt];
       p->dur = p->out_array[cnt+1];
@@ -653,12 +653,12 @@ int vbap_moving_init(CSOUND *csound, VBAP_MOVING *p)
       return csound->InitError(csound, Str("could not find layout table no.0"));
     p->q.number = cnt;
     /* reading in loudspeaker info */
-    p->q.dim       = (int)ls_table[0];
-    p->q.ls_am     = (int)ls_table[1];
-    p->q.ls_set_am = (int)ls_table[2];
+    p->q.dim       = (int32_t)ls_table[0];
+    p->q.ls_am     = (int32_t)ls_table[1];
+    p->q.ls_set_am = (int32_t)ls_table[2];
     ptr = &(ls_table[3]);
     if (UNLIKELY(!p->q.ls_set_am))
-      return csound->InitError(csound, Str("vbap system NOT configured. \nMissing"
+      return csound->InitError(csound, Str("vbap system NOT configured.\nMissing"
                                            " vbaplsinit opcode in orchestra?"));
     csound->AuxAlloc(csound, p->q.ls_set_am * sizeof(LS_SET), &p->q.aux);
     if (UNLIKELY(p->q.aux.auxp == NULL)) {
@@ -669,7 +669,7 @@ int vbap_moving_init(CSOUND *csound, VBAP_MOVING *p)
     for (i=0 ; i < p->q.ls_set_am ; i++) {
       ls_set_ptr[i].ls_nos[2] = 0;     /* initial setting */
       for (j=0 ; j < p->q.dim ; j++) {
-        ls_set_ptr[i].ls_nos[j] = (int)*(ptr++);
+        ls_set_ptr[i].ls_nos[j] = (int32_t)*(ptr++);
       }
       for (j=0 ; j < 9; j++)
         ls_set_ptr[i].ls_mx[j] = FL(0.0);  /*initial setting*/
@@ -687,10 +687,10 @@ int vbap_moving_init(CSOUND *csound, VBAP_MOVING *p)
     }
     if (p->q.dim == 2)
       p->q.point_change_interval =
-        (int)(CS_EKR * *p->dur /(fabs(*p->field_am) - 1.0));
+        (int32_t)(CS_EKR * *p->dur /(fabs(*p->field_am) - 1.0));
     else if (LIKELY(p->q.dim == 3))
       p->q.point_change_interval =
-        (int)(CS_EKR * *p->dur /(fabs(*p->field_am)*0.5 - 1.0));
+        (int32_t)(CS_EKR * *p->dur /(fabs(*p->field_am)*0.5 - 1.0));
     else
       return csound->InitError(csound, Str("Wrong dimension"));
     p->q.point_change_counter = 0;
@@ -719,17 +719,17 @@ int vbap_moving_init(CSOUND *csound, VBAP_MOVING *p)
     return OK;
 }
 
-int vbap_moving_a(CSOUND *csound, VBAPA_MOVING *p)
+int32_t vbap_moving_a(CSOUND *csound, VBAPA_MOVING *p)
 {                               /* during note performance:   */
     MYFLT *outptr, *inptr;
     MYFLT ogain, ngain, gainsubstr;
     MYFLT invfloatn;
-    int j;
+    int32_t j;
     uint32_t offset = p->h.insdshead->ksmps_offset;
     uint32_t early  = p->h.insdshead->ksmps_no_end;
     uint32_t i, nsmps = CS_KSMPS;
     uint32_t ksmps = nsmps;
-    int cnt = p->q.number;
+    int32_t cnt = p->q.number;
 
     vbap_moving_control(csound,&p->q, p->h.insdshead, CS_ONEDKR,
                         p->spread, p->field_am, p->fld);
@@ -770,12 +770,12 @@ int vbap_moving_a(CSOUND *csound, VBAPA_MOVING *p)
     return OK;
 }
 
-int vbap_moving_init_a(CSOUND *csound, VBAPA_MOVING *p)
+int32_t vbap_moving_init_a(CSOUND *csound, VBAPA_MOVING *p)
 {
-    int     i, j;
+    int32_t     i, j;
     MYFLT   *ls_table, *ptr;
     LS_SET  *ls_set_ptr;
-    int cnt;
+    int32_t cnt;
 
     if (UNLIKELY(p->tabout->data==NULL)) {
       return csound->InitError(csound,
@@ -789,9 +789,9 @@ int vbap_moving_init_a(CSOUND *csound, VBAPA_MOVING *p)
       return csound->InitError(csound, Str("could not find layout table no.0"));
     p->q.number = cnt;
     /* reading in loudspeaker info */
-    p->q.dim       = (int)ls_table[0];
-    p->q.ls_am     = (int)ls_table[1];
-    p->q.ls_set_am = (int)ls_table[2];
+    p->q.dim       = (int32_t)ls_table[0];
+    p->q.ls_am     = (int32_t)ls_table[1];
+    p->q.ls_set_am = (int32_t)ls_table[2];
     ptr = &(ls_table[3]);
     if (UNLIKELY(!p->q.ls_set_am))
       return csound->InitError(csound,
@@ -806,7 +806,7 @@ int vbap_moving_init_a(CSOUND *csound, VBAPA_MOVING *p)
     for (i=0 ; i < p->q.ls_set_am ; i++) {
       ls_set_ptr[i].ls_nos[2] = 0;     /* initial setting */
       for (j=0 ; j < p->q.dim ; j++) {
-        ls_set_ptr[i].ls_nos[j] = (int)*(ptr++);
+        ls_set_ptr[i].ls_nos[j] = (int32_t)*(ptr++);
       }
       memset(ls_set_ptr[i].ls_mx, '\0', 9*sizeof(MYFLT));
       /* for (j=0 ; j < 9; j++) */
@@ -825,10 +825,10 @@ int vbap_moving_init_a(CSOUND *csound, VBAPA_MOVING *p)
     }
     if (p->q.dim == 2)
       p->q.point_change_interval =
-        (int)(CS_EKR * *p->dur /(fabs(*p->field_am) - 1.0));
+        (int32_t)(CS_EKR * *p->dur /(fabs(*p->field_am) - 1.0));
     else if (LIKELY(p->q.dim == 3))
       p->q.point_change_interval =
-        (int)(CS_EKR * *p->dur /(fabs(*p->field_am)*0.5 - 1.0));
+        (int32_t)(CS_EKR * *p->dur /(fabs(*p->field_am)*0.5 - 1.0));
     else
       return csound->InitError(csound, Str("Wrong dimension"));
     p->q.point_change_counter = 0;
