@@ -1,6 +1,6 @@
 /*
  * threadsafe.c: threadsafe API functions
- *               (c) V Lazzarini, 2013
+ *               Copyright (c) V Lazzarini, 2013
  *
  * L I C E N S E
  *
@@ -16,7 +16,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this software; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
 
 #include "csoundCore.h"
@@ -72,17 +72,8 @@ static long atomicGet_Incr_Mod(volatile long* val, long mod) {
   do {
     oldVal = *val;
     newVal = (oldVal + 1) % mod;
-
-#if defined(MSVC)
-  } while (InterlockedCompareExchange(val, newVal, oldVal) != oldVal);
-#elif defined(HAVE_ATOMIC_BUILTIN)
-  } while (!__atomic_compare_exchange(val, (long *) &oldVal, &newVal, 0,
-                                      __ATOMIC_SEQ_CST, __ATOMIC_SEQ_CST));
-#else /* FIXME: no atomics, what to do? */
-} while ((*val = newVal) != newVal);
-#endif
-
-return oldVal;
+  } while (ATOMIC_CMP_XCH(val, newVal, oldVal));
+  return oldVal;
 }
 
 /* called by csoundCreate() at the start
@@ -112,13 +103,7 @@ void *message_enqueue(CSOUND *csound, int32_t message, char *args,
 
     /* block if queue is full */
     do {
-#if defined(MSVC)
-      items = InterlockedExchangeAdd(&csound->msg_queue_items, 0);
-#elif defined(HAVE_ATOMIC_BUILTIN)
-      items = __atomic_load_n (&csound->msg_queue_items, __ATOMIC_SEQ_CST);
-#else
-      items = csound->msg_queue_items;
-#endif
+      items = ATOMIC_GET(csound->msg_queue_items);
     } while(items >= API_MAX_QUEUE);
 
     message_queue_t* msg =
@@ -132,13 +117,7 @@ void *message_enqueue(CSOUND *csound, int32_t message, char *args,
     rtn = &msg->rtn;
     csound->msg_queue[atomicGet_Incr_Mod(&csound->msg_queue_wput,
                                          API_MAX_QUEUE)] = msg;
-#ifdef MSVC
-    InterlockedIncrement(&csound->msg_queue_items);
-#elif defined(HAVE_ATOMIC_BUILTIN)
-    __atomic_add_fetch(&csound->msg_queue_items, 1, __ATOMIC_SEQ_CST);
-#else
-    csound->msg_queue_items++;
-#endif
+    ATOMIC_INCR(csound->msg_queue_items);
     return (void *) rtn;
   }
   else return NULL;
@@ -153,8 +132,6 @@ void message_dequeue(CSOUND *csound) {
     long items = csound->msg_queue_items;
     long rend = rp + items;
 
-    int64_t rtn = 0;            /* This value is not used */
-
     while(rp < rend) {
       message_queue_t* msg = csound->msg_queue[rp % API_MAX_QUEUE];
       switch(msg->message) {
@@ -168,7 +145,7 @@ void message_dequeue(CSOUND *csound) {
       case READ_SCORE:
         {
           const char *str = msg->args;
-          rtn = csoundReadScoreInternal(csound, str);
+          csoundReadScoreInternal(csound, str);
         }
         break;
       case SCORE_EVENT:
@@ -181,8 +158,8 @@ void message_dequeue(CSOUND *csound) {
                  sizeof(MYFLT *));
           memcpy(&numFields, msg->args + ARG_ALIGN*2,
                  sizeof(long));
-          rtn =
-            csoundScoreEventInternal(csound, type, pfields, numFields);
+
+          csoundScoreEventInternal(csound, type, pfields, numFields);
         }
         break;
       case SCORE_EVENT_ABS:
@@ -198,8 +175,8 @@ void message_dequeue(CSOUND *csound) {
                  sizeof(long));
           memcpy(&ofs, msg->args + ARG_ALIGN*3,
                  sizeof(double));
-          rtn =
-            csoundScoreEventAbsoluteInternal(csound, type, pfields, numFields,
+
+          csoundScoreEventAbsoluteInternal(csound, type, pfields, numFields,
                                              ofs);
         }
         break;
@@ -269,13 +246,7 @@ void message_dequeue(CSOUND *csound) {
       msg->message = 0;
       rp += 1;
     }
-#ifdef MSVC
-    InterlockedExchangeAdd(&csound->msg_queue_items, -items);
-#elif defined(HAVE_ATOMIC_BUILTIN)
-    __atomic_sub_fetch(&csound->msg_queue_items, items, __ATOMIC_SEQ_CST);
-#else
-    csound->msg_queue_items -= items;
-#endif
+    ATOMIC_SUB(csound->msg_queue_items, items);
     csound->msg_queue_rstart = rp % API_MAX_QUEUE;
   }
 }
@@ -451,11 +422,18 @@ int csoundCompileOrc(CSOUND *csound, const char *str) {
   return csoundCompileOrcInternal(csound, str, async);
 }
 
+int init0(CSOUND *csound);
+
 MYFLT csoundEvalCode(CSOUND *csound, const char *str)
 {
   int async = 0;
-  if (str && csoundCompileOrcInternal(csound,str,async) == CSOUND_SUCCESS)
-    return csound->instr0->instance[0].retval;
+  if (str && csoundCompileOrcInternal(csound,str,async)
+      == CSOUND_SUCCESS){
+    if(!(csound->engineStatus & CS_STATE_COMP)) {
+      init0(csound);
+    }
+      return csound->instr0->instance[0].retval;
+    }
 #ifdef NAN
   else return NAN;
 #else
@@ -568,7 +546,7 @@ void csoundSetControlChannel(CSOUND *csound, const char *name, MYFLT val){
     __sync_lock_test_and_set((MYFLT_INT_TYPE *)pval,x.i);
 #else
   {
-    int    *lock =
+    spin_lock_t *lock = (spin_lock_t *)
       csoundGetChannelLock(csound, (char*) name);
     csoundSpinLock(lock);
     *pval  = val;
@@ -585,7 +563,7 @@ void csoundGetAudioChannel(CSOUND *csound, const char *name, MYFLT *samples)
   if (csoundGetChannelPtr(csound, &psamples, name,
                           CSOUND_AUDIO_CHANNEL | CSOUND_OUTPUT_CHANNEL)
       == CSOUND_SUCCESS) {
-    int *lock = csoundGetChannelLock(csound, (char*) name);
+    spin_lock_t *lock = (spin_lock_t *)csoundGetChannelLock(csound, (char*) name);
     csoundSpinLock(lock);
     memcpy(samples, psamples, csoundGetKsmps(csound)*sizeof(MYFLT));
     csoundSpinUnLock(lock);
@@ -598,7 +576,7 @@ void csoundSetAudioChannel(CSOUND *csound, const char *name, MYFLT *samples)
   if (csoundGetChannelPtr(csound, &psamples, name,
                           CSOUND_AUDIO_CHANNEL | CSOUND_INPUT_CHANNEL)
       == CSOUND_SUCCESS){
-    int *lock = csoundGetChannelLock(csound, (char*) name);
+    spin_lock_t *lock = (spin_lock_t *)csoundGetChannelLock(csound, (char*) name);
     csoundSpinLock(lock);
     memcpy(psamples, samples, csoundGetKsmps(csound)*sizeof(MYFLT));
     csoundSpinUnLock(lock);
@@ -615,7 +593,7 @@ void csoundSetStringChannel(CSOUND *csound, const char *name, char *string)
 
     STRINGDAT* stringdat = (STRINGDAT*) pstring;
     int    size = stringdat->size; //csoundGetChannelDatasize(csound, name);
-    int    *lock = csoundGetChannelLock(csound, (char*) name);
+    spin_lock_t *lock = (spin_lock_t *) csoundGetChannelLock(csound, (char*) name);
 
     if (lock != NULL) {
       csoundSpinLock(lock);
@@ -645,14 +623,14 @@ void csoundGetStringChannel(CSOUND *csound, const char *name, char *string)
   if (csoundGetChannelPtr(csound, &pstring, name,
                           CSOUND_STRING_CHANNEL | CSOUND_OUTPUT_CHANNEL)
       == CSOUND_SUCCESS){
-    int *lock = csoundGetChannelLock(csound, (char*) name);
+    spin_lock_t *lock = (spin_lock_t *) csoundGetChannelLock(csound, (char*) name);
     chstring = ((STRINGDAT *) pstring)->data;
     if (lock != NULL)
       csoundSpinLock(lock);
     if (string != NULL && chstring != NULL) {
       n2 = strlen(chstring);
-      strncpy(string,chstring, n2);
-      string[n2] = 0;
+      strNcpy(string,chstring, n2+1);
+      //string[n2] = '\0';
     }
     if (lock != NULL)
       csoundSpinUnLock(lock);
@@ -667,7 +645,7 @@ PUBLIC int csoundSetPvsChannel(CSOUND *csound, const PVSDATEXT *fin,
   if (LIKELY(csoundGetChannelPtr(csound, &pp, name,
                                  CSOUND_PVS_CHANNEL | CSOUND_INPUT_CHANNEL)
              == CSOUND_SUCCESS)){
-    int    *lock =
+    spin_lock_t *lock = (spin_lock_t *)
       csoundGetChannelLock(csound, name);
     f = (PVSDATEXT *) pp;
     csoundSpinLock(lock);
@@ -697,7 +675,7 @@ PUBLIC int csoundGetPvsChannel(CSOUND *csound, PVSDATEXT *fout,
   if (UNLIKELY(csoundGetChannelPtr(csound, &pp, name,
                                    CSOUND_PVS_CHANNEL | CSOUND_OUTPUT_CHANNEL)
                == CSOUND_SUCCESS)){
-    int    *lock =
+    spin_lock_t *lock = (spin_lock_t *)
       csoundGetChannelLock(csound, name);
     f = (PVSDATEXT *) pp;
     if (UNLIKELY(pp == NULL)) return CSOUND_ERROR;
